
DROP SEQUENCE seq_va_admin_privileges;
DROP TABLE va_admin_privileges;

CREATE SEQUENCE seq_va_admin_privileges START 3;
CREATE TABLE va_admin_privileges (
  privilege_id INT4 NOT NULL DEFAULT nextval('seq_va_admin_privileges'),
  support_privilege INT4 default '0',
  privilege_name VARCHAR(64) NOT NULL
  ,PRIMARY KEY (privilege_id));



DROP SEQUENCE seq_va_admin_privileges_settings;
DROP TABLE va_admin_privileges_settings;

CREATE SEQUENCE seq_va_admin_privileges_settings START 1;
CREATE TABLE va_admin_privileges_settings (
  privilege_id INT4 NOT NULL default '0',
  block_name VARCHAR(64) NOT NULL,
  permission INT4
  ,PRIMARY KEY (privilege_id,block_name));



DROP SEQUENCE seq_va_admins;
DROP TABLE va_admins;

CREATE SEQUENCE seq_va_admins START 2;
CREATE TABLE va_admins (
  admin_id INT4 NOT NULL DEFAULT nextval('seq_va_admins'),
  admin_name VARCHAR(255) NOT NULL,
  admin_alias VARCHAR(16),
  privilege_id INT4 NOT NULL default '0',
  email VARCHAR(255) NOT NULL,
  login VARCHAR(64) NOT NULL,
  password VARCHAR(32) NOT NULL,
  personal_image VARCHAR(255),
  signature TEXT,
  last_order_id INT4 default '0',
  exported_order_id INT4 default '0',
  exported_order_fields TEXT,
  last_user_id INT4 default '0',
  exported_user_id INT4 default '0',
  exported_user_fields TEXT,
  imported_user_fields TEXT,
  exported_item_fields TEXT,
  imported_item_fields TEXT,
  edited_item_fields TEXT,
  last_visit_date TIMESTAMP,
  is_generate_big_image INT4 default '0',
  is_generate_small_image INT4 default '0'
  ,PRIMARY KEY (admin_id));

CREATE INDEX va_admins_login ON va_admins (login);
CREATE INDEX va_admins_password ON va_admins (password);


DROP SEQUENCE seq_va_ads_assigned;
DROP TABLE va_ads_assigned;

CREATE SEQUENCE seq_va_ads_assigned START 1;
CREATE TABLE va_ads_assigned (
  item_id INT4 NOT NULL default '0',
  category_id INT4 NOT NULL default '0'
  ,PRIMARY KEY (item_id,category_id));



DROP SEQUENCE seq_va_ads_categories;
DROP TABLE va_ads_categories;

CREATE SEQUENCE seq_va_ads_categories START 4;
CREATE TABLE va_ads_categories (
  category_id INT4 NOT NULL DEFAULT nextval('seq_va_ads_categories'),
  language_code VARCHAR(2),
  parent_category_id INT4 default '0',
  alias_category_id INT4 default '0',
  category_path VARCHAR(255) NOT NULL,
  category_name VARCHAR(255),
  category_order INT4 default '0',
  allowed_view INT4 default '0',
  allowed_post INT4 default '0',
  short_description TEXT,
  full_description TEXT,
  image_small VARCHAR(255),
  image_large VARCHAR(255),
  total_ads INT4 default '0',
  total_subcategories INT4 default '0'
  ,PRIMARY KEY (category_id));

CREATE INDEX va_ads_categories_category_path ON va_ads_categories (category_path);
CREATE INDEX va_ads_categories_parent_ca_1 ON va_ads_categories (parent_category_id);


DROP SEQUENCE seq_va_ads_features;
DROP TABLE va_ads_features;

CREATE SEQUENCE seq_va_ads_features START 1;
CREATE TABLE va_ads_features (
  feature_id INT4 NOT NULL DEFAULT nextval('seq_va_ads_features'),
  item_id INT4 default '0',
  group_id INT4 default '0',
  feature_name VARCHAR(255),
  feature_value VARCHAR(255)
  ,PRIMARY KEY (feature_id));

CREATE INDEX va_ads_features_group_id ON va_ads_features (group_id);
CREATE INDEX va_ads_features_item_id ON va_ads_features (item_id);


DROP SEQUENCE seq_va_ads_features_default;
DROP TABLE va_ads_features_default;

CREATE SEQUENCE seq_va_ads_features_default START 1;
CREATE TABLE va_ads_features_default (
  feature_id INT4 NOT NULL DEFAULT nextval('seq_va_ads_features_default'),
  type_id INT4 default '0',
  group_id INT4 default '0',
  feature_name VARCHAR(50),
  feature_value TEXT
  ,PRIMARY KEY (feature_id));

CREATE INDEX va_ads_features_default_group_id ON va_ads_features_default (group_id);
CREATE INDEX va_ads_features_default_ite_2 ON va_ads_features_default (type_id);


DROP SEQUENCE seq_va_ads_features_groups;
DROP TABLE va_ads_features_groups;

CREATE SEQUENCE seq_va_ads_features_groups START 4;
CREATE TABLE va_ads_features_groups (
  group_id INT4 NOT NULL DEFAULT nextval('seq_va_ads_features_groups'),
  group_order INT4 NOT NULL default '1',
  group_name VARCHAR(255)
  ,PRIMARY KEY (group_id));



DROP SEQUENCE seq_va_ads_images;
DROP TABLE va_ads_images;

CREATE SEQUENCE seq_va_ads_images START 1;
CREATE TABLE va_ads_images (
  image_id INT4 NOT NULL DEFAULT nextval('seq_va_ads_images'),
  item_id INT4 NOT NULL default '0',
  image_small VARCHAR(255),
  small_width INT4,
  small_height INT4,
  image_large VARCHAR(255),
  image_title VARCHAR(255),
  image_description TEXT
  ,PRIMARY KEY (image_id));

CREATE INDEX va_ads_images_item_id ON va_ads_images (item_id);


DROP SEQUENCE seq_va_ads_items;
DROP TABLE va_ads_items;

CREATE SEQUENCE seq_va_ads_items START 1;
CREATE TABLE va_ads_items (
  item_id INT4 NOT NULL DEFAULT nextval('seq_va_ads_items'),
  type_id INT4 NOT NULL default '0',
  language_code VARCHAR(2),
  item_title VARCHAR(50) NOT NULL,
  item_order INT4 default '0',
  user_id INT4 default '0',
  admin_id INT4 default '0',
  date_start TIMESTAMP,
  date_end TIMESTAMP,
  date_added TIMESTAMP,
  date_updated TIMESTAMP,
  image_small VARCHAR(255),
  image_large VARCHAR(255),
  is_hot INT4 default '0',
  hot_description TEXT,
  short_description TEXT,
  full_description TEXT,
  price FLOAT4 default '0',
  quantity INT4 default '0',
  availability VARCHAR(255),
  location_info TEXT,
  location_city VARCHAR(128),
  location_state VARCHAR(8),
  location_country VARCHAR(4),
  is_approved INT4 default '0',
  is_compared INT4 default '0'
  ,PRIMARY KEY (item_id));

CREATE INDEX va_ads_items_item_title ON va_ads_items (item_title);
CREATE INDEX va_ads_items_type_id ON va_ads_items (type_id);


DROP SEQUENCE seq_va_ads_properties;
DROP TABLE va_ads_properties;

CREATE SEQUENCE seq_va_ads_properties START 1;
CREATE TABLE va_ads_properties (
  property_id INT4 NOT NULL DEFAULT nextval('seq_va_ads_properties'),
  item_id INT4 NOT NULL default '0',
  property_name VARCHAR(255) NOT NULL,
  property_value TEXT
  ,PRIMARY KEY (property_id));

CREATE INDEX va_ads_properties_item_id ON va_ads_properties (item_id);


DROP SEQUENCE seq_va_ads_properties_default;
DROP TABLE va_ads_properties_default;

CREATE SEQUENCE seq_va_ads_properties_default START 1;
CREATE TABLE va_ads_properties_default (
  property_id INT4 NOT NULL DEFAULT nextval('seq_va_ads_properties_default'),
  type_id INT4 NOT NULL default '0',
  property_name VARCHAR(255) NOT NULL,
  property_value TEXT
  ,PRIMARY KEY (property_id));

CREATE INDEX va_ads_properties_default_i_3 ON va_ads_properties_default (type_id);


DROP SEQUENCE seq_va_ads_types;
DROP TABLE va_ads_types;

CREATE SEQUENCE seq_va_ads_types START 3;
CREATE TABLE va_ads_types (
  type_id INT4 NOT NULL DEFAULT nextval('seq_va_ads_types'),
  type_name VARCHAR(50)
  ,PRIMARY KEY (type_id));



DROP SEQUENCE seq_va_articles;
DROP TABLE va_articles;

CREATE SEQUENCE seq_va_articles START 26;
CREATE TABLE va_articles (
  article_id INT4 NOT NULL DEFAULT nextval('seq_va_articles'),
  language_code VARCHAR(2),
  article_date TIMESTAMP,
  date_end TIMESTAMP,
  article_title VARCHAR(255),
  article_template VARCHAR(255),
  article_order INT4 default '0',
  author_name VARCHAR(255),
  author_email VARCHAR(255),
  author_url VARCHAR(255),
  author_remote_address VARCHAR(255),
  created_user_id INT4 default '0',
  created_admin_id INT4 default '0',
  updated_user_id INT4 default '0',
  updated_admin_id INT4 default '0',
  status_id INT4 NOT NULL default '0',
  is_html INT4 default '0',
  allowed_rate VARCHAR(50),
  is_hot INT4 default '0',
  link_url VARCHAR(255),
  download_url VARCHAR(255),
  is_link_direct VARCHAR(255),
  date_added VARCHAR(255),
  date_updated VARCHAR(255),
  keywords TEXT,
  hot_description TEXT,
  short_description TEXT,
  full_description TEXT,
  notes TEXT,
  total_views INT4 default '0',
  total_votes INT4 default '0',
  total_points INT4 default '0',
  rating FLOAT4 default '0',
  total_clicks INT4 default '0',
  image_small VARCHAR(255),
  image_small_alt VARCHAR(255),
  image_large VARCHAR(255),
  image_large_alt VARCHAR(255),
  meta_title VARCHAR(255),
  meta_keywords VARCHAR(255),
  meta_description VARCHAR(255)
  ,PRIMARY KEY (article_id));

CREATE INDEX va_articles_status_id ON va_articles (status_id);


DROP SEQUENCE seq_va_articles_assigned;
DROP TABLE va_articles_assigned;

CREATE SEQUENCE seq_va_articles_assigned START 1;
CREATE TABLE va_articles_assigned (
  article_id INT4 NOT NULL default '0',
  category_id INT4 NOT NULL default '0'
  ,PRIMARY KEY (article_id,category_id));



DROP SEQUENCE seq_va_articles_categories;
DROP TABLE va_articles_categories;

CREATE SEQUENCE seq_va_articles_categories START 31;
CREATE TABLE va_articles_categories (
  category_id INT4 NOT NULL DEFAULT nextval('seq_va_articles_categories'),
  language_code VARCHAR(2),
  parent_category_id INT4 default '0',
  alias_category_id INT4 default '0',
  category_path VARCHAR(255) NOT NULL,
  category_name VARCHAR(255),
  category_order INT4 default '0',
  articles_list_template VARCHAR(255),
  articles_details_template VARCHAR(255),
  articles_order_column VARCHAR(50),
  articles_order_direction VARCHAR(50),
  article_list_fields TEXT,
  article_details_fields TEXT,
  article_required_fields TEXT,
  moderators_ids VARCHAR(255),
  is_hot INT4 default '0',
  allowed_view INT4 default '0',
  allowed_post INT4 default '0',
  allowed_rate INT4 default '0',
  short_description TEXT,
  full_description TEXT,
  image_small VARCHAR(255),
  image_small_alt VARCHAR(255),
  image_large VARCHAR(255),
  image_large_alt VARCHAR(255),
  is_rss INT4 default '0',
  rss_limit INT4 default '0',
  rss_on_breadcrumb INT4 default '0',
  rss_on_list INT4 default '0',
  meta_title VARCHAR(255),
  meta_keywords VARCHAR(255),
  meta_description VARCHAR(255),
  total_articles INT4 default '0',
  total_subcategories INT4 default '0'
  ,PRIMARY KEY (category_id));

CREATE INDEX va_articles_categories_cate_4 ON va_articles_categories (category_path);
CREATE INDEX va_articles_categories_pare_5 ON va_articles_categories (parent_category_id);


DROP SEQUENCE seq_va_articles_images;
DROP TABLE va_articles_images;

CREATE SEQUENCE seq_va_articles_images START 1;
CREATE TABLE va_articles_images (
  image_id INT4 NOT NULL DEFAULT nextval('seq_va_articles_images'),
  article_id INT4 default '0',
  image_name VARCHAR(255),
  image_title VARCHAR(255),
  image_width VARCHAR(255),
  image_height VARCHAR(255),
  image_alt VARCHAR(255),
  image_align VARCHAR(255),
  date_added TIMESTAMP
  ,PRIMARY KEY (image_id));

CREATE INDEX va_articles_images_article_id ON va_articles_images (article_id);


DROP SEQUENCE seq_va_articles_related;
DROP TABLE va_articles_related;

CREATE SEQUENCE seq_va_articles_related START 1;
CREATE TABLE va_articles_related (
  article_id INT4 NOT NULL default '0',
  related_id INT4 NOT NULL default '0',
  related_order INT4 NOT NULL default '1'
  ,PRIMARY KEY (article_id,related_id));



DROP SEQUENCE seq_va_articles_reviews;
DROP TABLE va_articles_reviews;

CREATE SEQUENCE seq_va_articles_reviews START 5;
CREATE TABLE va_articles_reviews (
  review_id INT4 NOT NULL DEFAULT nextval('seq_va_articles_reviews'),
  article_id INT4 NOT NULL default '0',
  recommended INT4 default '0',
  approved INT4 default '0',
  rating INT4 default '0',
  summary TEXT,
  user_name VARCHAR(255),
  remote_address VARCHAR(255),
  date_added TIMESTAMP,
  comments TEXT
  ,PRIMARY KEY (review_id));

CREATE INDEX va_articles_reviews_article_id ON va_articles_reviews (article_id);


DROP SEQUENCE seq_va_articles_statuses;
DROP TABLE va_articles_statuses;

CREATE SEQUENCE seq_va_articles_statuses START 5;
CREATE TABLE va_articles_statuses (
  status_id INT4 NOT NULL DEFAULT nextval('seq_va_articles_statuses'),
  status_name VARCHAR(255),
  status_description VARCHAR(255),
  is_shown INT4 default '0',
  status_icon VARCHAR(255),
  status_style VARCHAR(255),
  allowed_view INT4 NOT NULL default '0'
  ,PRIMARY KEY (status_id));



DROP SEQUENCE seq_va_banned_contents;
DROP TABLE va_banned_contents;

CREATE SEQUENCE seq_va_banned_contents START 1;
CREATE TABLE va_banned_contents (
  content_id INT4 NOT NULL DEFAULT nextval('seq_va_banned_contents'),
  content_text VARCHAR(255) NOT NULL
  ,PRIMARY KEY (content_id));



DROP SEQUENCE seq_va_banners;
DROP TABLE va_banners;

CREATE SEQUENCE seq_va_banners START 1;
CREATE TABLE va_banners (
  banner_id INT4 NOT NULL DEFAULT nextval('seq_va_banners'),
  banner_rank INT4 NOT NULL default '1',
  banner_title VARCHAR(255) NOT NULL,
  show_title INT4 default '0',
  image_src VARCHAR(255),
  image_alt VARCHAR(255),
  html_text TEXT,
  target_url VARCHAR(255),
  is_new_window INT4 default '0',
  is_active INT4 default '0',
  show_on_ssl INT4 default '0',
  max_impressions INT4 default '0',
  max_clicks INT4 default '0',
  expiry_date TIMESTAMP,
  total_impressions INT4 default '0',
  total_clicks INT4 default '0'
  ,PRIMARY KEY (banner_id));

CREATE INDEX va_banners_is_active ON va_banners (is_active);
CREATE INDEX va_banners_max_clicks ON va_banners (max_clicks);
CREATE INDEX va_banners_max_impressions ON va_banners (max_impressions);


DROP SEQUENCE seq_va_banners_assigned;
DROP TABLE va_banners_assigned;

CREATE SEQUENCE seq_va_banners_assigned START 1;
CREATE TABLE va_banners_assigned (
  banner_id INT4 NOT NULL default '0',
  group_id INT4 NOT NULL default '0'
  ,PRIMARY KEY (banner_id,group_id));



DROP SEQUENCE seq_va_banners_clicks;
DROP TABLE va_banners_clicks;

CREATE SEQUENCE seq_va_banners_clicks START 1;
CREATE TABLE va_banners_clicks (
  click_id INT4 NOT NULL DEFAULT nextval('seq_va_banners_clicks'),
  banner_id INT4 default '0',
  user_id INT4 default '0',
  remote_address VARCHAR(50),
  click_date TIMESTAMP NOT NULL
  ,PRIMARY KEY (click_id));

CREATE INDEX va_banners_clicks_banner_id ON va_banners_clicks (banner_id);
CREATE INDEX va_banners_clicks_click_date ON va_banners_clicks (click_date);
CREATE INDEX va_banners_clicks_user_id ON va_banners_clicks (user_id);


DROP SEQUENCE seq_va_banners_groups;
DROP TABLE va_banners_groups;

CREATE SEQUENCE seq_va_banners_groups START 1;
CREATE TABLE va_banners_groups (
  group_id INT4 NOT NULL DEFAULT nextval('seq_va_banners_groups'),
  group_name VARCHAR(128),
  group_desc TEXT,
  is_active INT4 default '0'
  ,PRIMARY KEY (group_id));

CREATE INDEX va_banners_groups_is_active ON va_banners_groups (is_active);


DROP SEQUENCE seq_va_black_ips;
DROP TABLE va_black_ips;

CREATE SEQUENCE seq_va_black_ips START 1;
CREATE TABLE va_black_ips (
  ip_address VARCHAR(32) NOT NULL,
  address_action INT4 default '0',
  address_notes VARCHAR(255)
  ,PRIMARY KEY (ip_address));



DROP SEQUENCE seq_va_categories;
DROP TABLE va_categories;

CREATE SEQUENCE seq_va_categories START 57;
CREATE TABLE va_categories (
  category_id INT4 NOT NULL DEFAULT nextval('seq_va_categories'),
  parent_category_id INT4 NOT NULL default '0',
  category_path VARCHAR(255) NOT NULL,
  category_name VARCHAR(255) NOT NULL,
  category_order INT4 NOT NULL default '1',
  is_showing INT4 default '0',
  show_sub_products INT4 default '0',
  short_description TEXT,
  full_description TEXT,
  image VARCHAR(255),
  image_alt VARCHAR(255),
  image_large VARCHAR(255),
  image_large_alt VARCHAR(255),
  list_template VARCHAR(128),
  details_template VARCHAR(128),
  meta_title VARCHAR(255),
  meta_keywords VARCHAR(255),
  meta_description VARCHAR(255),
  admin_id_added_by INT4 default '0',
  admin_id_modified_by INT4 default '0',
  date_added TIMESTAMP,
  date_modified TIMESTAMP
  ,PRIMARY KEY (category_id));

CREATE INDEX va_categories_category_path ON va_categories (category_path);
CREATE INDEX va_categories_parent_category_id ON va_categories (parent_category_id);


DROP SEQUENCE seq_va_cc_expiry_years;
DROP TABLE va_cc_expiry_years;

CREATE SEQUENCE seq_va_cc_expiry_years START 1;
CREATE TABLE va_cc_expiry_years (
  expiry_year INT4 NOT NULL default '0'
  ,PRIMARY KEY (expiry_year));



DROP SEQUENCE seq_va_cc_start_years;
DROP TABLE va_cc_start_years;

CREATE SEQUENCE seq_va_cc_start_years START 1;
CREATE TABLE va_cc_start_years (
  start_year INT4 NOT NULL default '0'
  ,PRIMARY KEY (start_year));



DROP SEQUENCE seq_va_change_types;
DROP TABLE va_change_types;

CREATE SEQUENCE seq_va_change_types START 3;
CREATE TABLE va_change_types (
  type_id INT4 NOT NULL DEFAULT nextval('seq_va_change_types'),
  type_name VARCHAR(255) NOT NULL
  ,PRIMARY KEY (type_id));



DROP SEQUENCE seq_va_companies;
DROP TABLE va_companies;

CREATE SEQUENCE seq_va_companies START 1;
CREATE TABLE va_companies (
  company_id INT4 NOT NULL DEFAULT nextval('seq_va_companies'),
  company_name VARCHAR(255) NOT NULL,
  image_small VARCHAR(50),
  image_large VARCHAR(50),
  address_info TEXT,
  phone_number VARCHAR(32),
  fax_number VARCHAR(32),
  site_url VARCHAR(128),
  contact_email VARCHAR(128),
  short_description TEXT,
  full_description TEXT
  ,PRIMARY KEY (company_id));



DROP SEQUENCE seq_va_countries;
DROP TABLE va_countries;

CREATE SEQUENCE seq_va_countries START 1;
CREATE TABLE va_countries (
  country_code VARCHAR(4) NOT NULL,
  country_iso_number VARCHAR(4),
  country_order INT4 default '1',
  country_name VARCHAR(64) NOT NULL,
  currency_code VARCHAR(4)
  ,PRIMARY KEY (country_code));



DROP SEQUENCE seq_va_coupons;
DROP TABLE va_coupons;

CREATE SEQUENCE seq_va_coupons START 1;
CREATE TABLE va_coupons (
  coupon_id INT4 NOT NULL DEFAULT nextval('seq_va_coupons'),
  order_id INT4 default '0',
  order_item_id INT4 default '0',
  coupon_code VARCHAR(64),
  coupon_title VARCHAR(255),
  is_active INT4 default '1',
  discount_type INT4 default '0',
  discount_amount FLOAT4 default '0',
  discount_tax_free INT4 default '0',
  free_postage INT4 default '0',
  tax_free INT4 default '0',
  items_all INT4 default '1',
  items_ids TEXT,
  users_ids TEXT,
  minimum_amount FLOAT4 default '0',
  expiry_date TIMESTAMP,
  is_exclusive INT4 default '0',
  quantity_limit INT4 default '1',
  coupon_uses INT4 default '0'
  ,PRIMARY KEY (coupon_id));

CREATE INDEX va_coupons_coupon_code ON va_coupons (coupon_code);
CREATE INDEX va_coupons_order_id ON va_coupons (order_id);
CREATE INDEX va_coupons_order_item_id ON va_coupons (order_item_id);


DROP SEQUENCE seq_va_credit_cards;
DROP TABLE va_credit_cards;

CREATE SEQUENCE seq_va_credit_cards START 11;
CREATE TABLE va_credit_cards (
  credit_card_id INT4 NOT NULL DEFAULT nextval('seq_va_credit_cards'),
  credit_card_code VARCHAR(32) NOT NULL,
  credit_card_name VARCHAR(64) NOT NULL
  ,PRIMARY KEY (credit_card_id));



DROP SEQUENCE seq_va_currencies;
DROP TABLE va_currencies;

CREATE SEQUENCE seq_va_currencies START 19;
CREATE TABLE va_currencies (
  currency_id INT4 NOT NULL DEFAULT nextval('seq_va_currencies'),
  is_default INT4 default '0',
  currency_code VARCHAR(4),
  currency_value VARCHAR(16),
  currency_title VARCHAR(64),
  currency_image VARCHAR(255),
  exchange_rate FLOAT4 NOT NULL default '1',
  symbol_left VARCHAR(32),
  symbol_right VARCHAR(32)
  ,PRIMARY KEY (currency_id));

CREATE INDEX va_currencies_currency_code ON va_currencies (currency_code);


DROP SEQUENCE seq_va_custom_blocks;
DROP TABLE va_custom_blocks;

CREATE SEQUENCE seq_va_custom_blocks START 4;
CREATE TABLE va_custom_blocks (
  block_id INT4 NOT NULL DEFAULT nextval('seq_va_custom_blocks'),
  block_name VARCHAR(128),
  block_notes TEXT,
  block_title VARCHAR(255),
  block_path VARCHAR(255),
  block_desc TEXT
  ,PRIMARY KEY (block_id));



DROP SEQUENCE seq_va_events;
DROP TABLE va_events;

CREATE SEQUENCE seq_va_events START 1;
CREATE TABLE va_events (
  event_id INT4 NOT NULL DEFAULT nextval('seq_va_events'),
  event_date TIMESTAMP NOT NULL,
  event_title VARCHAR(255) NOT NULL,
  is_html INT4 NOT NULL default '1',
  is_showing INT4 NOT NULL default '1',
  show_on_index INT4 NOT NULL default '0',
  preview_text TEXT,
  event_body TEXT
  ,PRIMARY KEY (event_id));



DROP SEQUENCE seq_va_faq;
DROP TABLE va_faq;

CREATE SEQUENCE seq_va_faq START 1;
CREATE TABLE va_faq (
  faq_id INT4 NOT NULL DEFAULT nextval('seq_va_faq'),
  faq_group_id INT4 NOT NULL default '0',
  faq_order INT4 NOT NULL default '1',
  question TEXT NOT NULL,
  answer TEXT NOT NULL
  ,PRIMARY KEY (faq_id));



DROP SEQUENCE seq_va_features;
DROP TABLE va_features;

CREATE SEQUENCE seq_va_features START 1;
CREATE TABLE va_features (
  feature_id INT4 NOT NULL DEFAULT nextval('seq_va_features'),
  item_id INT4 default '0',
  group_id INT4 default '0',
  feature_name VARCHAR(255),
  feature_value VARCHAR(255)
  ,PRIMARY KEY (feature_id));

CREATE INDEX va_features_group_id ON va_features (group_id);
CREATE INDEX va_features_item_id ON va_features (item_id);


DROP SEQUENCE seq_va_features_default;
DROP TABLE va_features_default;

CREATE SEQUENCE seq_va_features_default START 1;
CREATE TABLE va_features_default (
  feature_id INT4 NOT NULL DEFAULT nextval('seq_va_features_default'),
  item_type_id INT4 default '0',
  group_id INT4 default '0',
  feature_name VARCHAR(50),
  feature_value TEXT
  ,PRIMARY KEY (feature_id));

CREATE INDEX va_features_default_group_id ON va_features_default (group_id);
CREATE INDEX va_features_default_item_type_id ON va_features_default (item_type_id);


DROP SEQUENCE seq_va_features_groups;
DROP TABLE va_features_groups;

CREATE SEQUENCE seq_va_features_groups START 4;
CREATE TABLE va_features_groups (
  group_id INT4 NOT NULL DEFAULT nextval('seq_va_features_groups'),
  group_order INT4 NOT NULL default '1',
  group_name VARCHAR(255)
  ,PRIMARY KEY (group_id));



DROP SEQUENCE seq_va_forum;
DROP TABLE va_forum;

CREATE SEQUENCE seq_va_forum START 1;
CREATE TABLE va_forum (
  thread_id INT4 NOT NULL DEFAULT nextval('seq_va_forum'),
  forum_id INT4 NOT NULL default '0',
  user_id INT4 NOT NULL default '0',
  user_name VARCHAR(64) NOT NULL,
  user_email VARCHAR(128) NOT NULL,
  remote_address VARCHAR(32),
  topic VARCHAR(255) NOT NULL,
  description TEXT NOT NULL,
  email_notification INT4,
  views INT4,
  replies INT4,
  date_added TIMESTAMP NOT NULL,
  date_modified TIMESTAMP NOT NULL,
  admin_id_added_by INT4 default '0',
  admin_id_modified_by INT4 default '0'
  ,PRIMARY KEY (thread_id));

CREATE INDEX va_forum_forum_id ON va_forum (forum_id);


DROP SEQUENCE seq_va_forum_categories;
DROP TABLE va_forum_categories;

CREATE SEQUENCE seq_va_forum_categories START 2;
CREATE TABLE va_forum_categories (
  category_id INT4 NOT NULL DEFAULT nextval('seq_va_forum_categories'),
  category_name VARCHAR(255) NOT NULL,
  category_order INT4 default '0',
  short_description TEXT,
  full_description TEXT,
  allowed_view INT4 NOT NULL default '0'
  ,PRIMARY KEY (category_id));



DROP SEQUENCE seq_va_forum_list;
DROP TABLE va_forum_list;

CREATE SEQUENCE seq_va_forum_list START 2;
CREATE TABLE va_forum_list (
  forum_id INT4 NOT NULL DEFAULT nextval('seq_va_forum_list'),
  category_id INT4 NOT NULL default '0',
  forum_name VARCHAR(255) NOT NULL,
  forum_order INT4 NOT NULL default '0',
  short_description TEXT,
  full_description TEXT,
  small_image VARCHAR(255),
  large_image VARCHAR(255),
  date_added TIMESTAMP NOT NULL,
  threads_number INT4 NOT NULL default '0',
  messages_number INT4 NOT NULL default '0',
  last_post_added TIMESTAMP,
  last_post_user_id INT4 NOT NULL default '0',
  last_post_thread_id INT4 NOT NULL default '0',
  allowed_view INT4 NOT NULL default '0',
  allowed_view_topics INT4 default '0',
  allowed_view_topic INT4 default '0',
  allowed_post_topics INT4 default '0',
  allowed_post_replies INT4 default '0'
  ,PRIMARY KEY (forum_id));



DROP SEQUENCE seq_va_forum_messages;
DROP TABLE va_forum_messages;

CREATE SEQUENCE seq_va_forum_messages START 1;
CREATE TABLE va_forum_messages (
  message_id INT4 NOT NULL DEFAULT nextval('seq_va_forum_messages'),
  thread_id INT4 NOT NULL default '0',
  admin_id INT4,
  user_name VARCHAR(64) NOT NULL,
  user_email VARCHAR(128) NOT NULL,
  remote_address VARCHAR(32),
  message_text TEXT NOT NULL,
  date_added TIMESTAMP NOT NULL,
  user_id INT4 default '0'
  ,PRIMARY KEY (message_id));



DROP SEQUENCE seq_va_forum_moderators;
DROP TABLE va_forum_moderators;

CREATE SEQUENCE seq_va_forum_moderators START 1;
CREATE TABLE va_forum_moderators (
  admin_id INT4 NOT NULL default '0',
  forum_id INT4 NOT NULL default '0',
  is_default_forum INT4 default '0'
  ,PRIMARY KEY (admin_id,forum_id));



DROP SEQUENCE seq_va_global_settings;
DROP TABLE va_global_settings;

CREATE SEQUENCE seq_va_global_settings START 1;
CREATE TABLE va_global_settings (
  setting_type VARCHAR(32) NOT NULL,
  setting_name VARCHAR(64) NOT NULL,
  setting_value TEXT
  ,PRIMARY KEY (setting_type,setting_name));



DROP SEQUENCE seq_va_header_links;
DROP TABLE va_header_links;

CREATE SEQUENCE seq_va_header_links START 136;
CREATE TABLE va_header_links (
  menu_id INT4 NOT NULL DEFAULT nextval('seq_va_header_links'),
  layout_id INT4 NOT NULL default '0',
  parent_menu_id INT4 default '0',
  menu_path VARCHAR(255),
  menu_title VARCHAR(255),
  menu_url VARCHAR(255),
  menu_image VARCHAR(255),
  menu_image_active VARCHAR(255),
  menu_order INT4,
  show_non_logged INT4,
  show_logged INT4
  ,PRIMARY KEY (menu_id));

CREATE INDEX va_header_links_parent_menu_id ON va_header_links (parent_menu_id);


DROP SEQUENCE seq_va_issue_numbers;
DROP TABLE va_issue_numbers;

CREATE SEQUENCE seq_va_issue_numbers START 1;
CREATE TABLE va_issue_numbers (
  issue_number INT4 NOT NULL default '0'
  ,PRIMARY KEY (issue_number));



DROP SEQUENCE seq_va_item_types;
DROP TABLE va_item_types;

CREATE SEQUENCE seq_va_item_types START 5;
CREATE TABLE va_item_types (
  item_type_id INT4 NOT NULL DEFAULT nextval('seq_va_item_types'),
  item_type_name VARCHAR(50),
  is_gift_voucher INT4 default '0',
  is_bundle INT4 default '0'
  ,PRIMARY KEY (item_type_id));



DROP SEQUENCE seq_va_items;
DROP TABLE va_items;

CREATE SEQUENCE seq_va_items START 145;
CREATE TABLE va_items (
  item_id INT4 NOT NULL DEFAULT nextval('seq_va_items'),
  item_name VARCHAR(255) NOT NULL,
  item_order INT4 NOT NULL default '1',
  item_type_id INT4 NOT NULL default '0',
  issue_date TIMESTAMP,
  language_code VARCHAR(4),
  manufacturer_id INT4,
  manufacturer_code VARCHAR(255),
  template_name VARCHAR(255),
  hide_add_list INT4 default '0',
  hide_add_details INT4 default '0',
  features TEXT,
  short_description TEXT,
  full_desc_type INT4,
  full_description TEXT,
  is_special_offer INT4 NOT NULL default '0',
  special_offer TEXT,
  notes TEXT,
  small_image VARCHAR(255),
  small_image_alt VARCHAR(255),
  big_image VARCHAR(255),
  big_image_alt VARCHAR(255),
  super_image VARCHAR(255),
  preview_url VARCHAR(255),
  preview_width INT4,
  preview_height INT4,
  specification VARCHAR(255),
  buying_price FLOAT4 default '0',
  price FLOAT4 NOT NULL default '0',
  is_price_edit INT4 default '0',
  properties_price FLOAT4 default '0',
  tax_free INT4 default '0',
  weight FLOAT4,
  stock_level INT4,
  use_stock_level INT4 NOT NULL default '1',
  hide_out_of_stock INT4 NOT NULL default '0',
  disable_out_of_stock INT4 default '0',
  shipping_in_stock INT4,
  shipping_out_stock INT4 default '0',
  shipping_rule_id INT4,
  shipping_cost FLOAT4,
  is_sales INT4,
  sales_price FLOAT4,
  discount_percent FLOAT4,
  downloadable INT4,
  download_period INT4,
  download_path TEXT,
  generate_serial INT4 default '0',
  activations_number INT4 default '0',
  is_showing INT4 NOT NULL default '1',
  is_compared INT4 default '0',
  buy_link VARCHAR(255),
  votes INT4,
  points INT4,
  rating FLOAT4,
  meta_title VARCHAR(255),
  meta_keywords VARCHAR(255),
  meta_description VARCHAR(255),
  mail_notify INT4 default '0',
  mail_to VARCHAR(255),
  mail_from VARCHAR(64),
  mail_cc VARCHAR(255),
  mail_bcc VARCHAR(255),
  mail_reply_to VARCHAR(64),
  mail_return_path VARCHAR(64),
  mail_type INT4 default '0',
  mail_subject VARCHAR(255),
  mail_body TEXT,
  sms_notify INT4 default '0',
  sms_recipient VARCHAR(255),
  sms_originator VARCHAR(64),
  sms_message TEXT,
  admin_id_added_by INT4 default '0',
  admin_id_modified_by INT4 default '0',
  date_added TIMESTAMP,
  date_modified TIMESTAMP
  ,PRIMARY KEY (item_id));

CREATE INDEX va_items_is_showing ON va_items (is_showing);
CREATE INDEX va_items_item_name ON va_items (item_name);
CREATE INDEX va_items_language_code ON va_items (language_code);
CREATE INDEX va_items_price ON va_items (price);


DROP SEQUENCE seq_va_items_accessories;
DROP TABLE va_items_accessories;

CREATE SEQUENCE seq_va_items_accessories START 1;
CREATE TABLE va_items_accessories (
  item_id INT4 NOT NULL default '0',
  accessory_id INT4 NOT NULL default '0',
  accessory_order INT4 NOT NULL default '1'
  ,PRIMARY KEY (item_id,accessory_id));



DROP SEQUENCE seq_va_items_categories;
DROP TABLE va_items_categories;

CREATE SEQUENCE seq_va_items_categories START 1;
CREATE TABLE va_items_categories (
  item_id INT4 NOT NULL default '0',
  category_id INT4 NOT NULL default '0'
  ,PRIMARY KEY (item_id,category_id));



DROP SEQUENCE seq_va_items_downloads;
DROP TABLE va_items_downloads;

CREATE SEQUENCE seq_va_items_downloads START 1;
CREATE TABLE va_items_downloads (
  download_id INT4 NOT NULL DEFAULT nextval('seq_va_items_downloads'),
  order_id INT4 NOT NULL default '0',
  user_id INT4 NOT NULL default '0',
  order_item_id INT4 NOT NULL default '0',
  item_id INT4 NOT NULL default '0',
  download_notes VARCHAR(255),
  download_path VARCHAR(255),
  activated INT4,
  max_downloads INT4,
  download_added TIMESTAMP NOT NULL,
  download_expiry TIMESTAMP NOT NULL
  ,PRIMARY KEY (download_id));

CREATE INDEX va_items_downloads_item_id ON va_items_downloads (item_id);
CREATE INDEX va_items_downloads_order_id ON va_items_downloads (order_id);
CREATE INDEX va_items_downloads_order_item_id ON va_items_downloads (order_item_id);
CREATE INDEX va_items_downloads_user_id ON va_items_downloads (user_id);


DROP SEQUENCE seq_va_items_downloads_statistic;
DROP TABLE va_items_downloads_statistic;

CREATE SEQUENCE seq_va_items_downloads_statistic START 1;
CREATE TABLE va_items_downloads_statistic (
  download_id INT4 NOT NULL default '0',
  order_item_id INT4 NOT NULL default '0',
  remote_address VARCHAR(32) NOT NULL,
  downloaded_date TIMESTAMP NOT NULL
);

CREATE INDEX va_items_downloads_statisti_6 ON va_items_downloads_statistic (download_id);
CREATE INDEX va_items_downloads_statisti_7 ON va_items_downloads_statistic (downloaded_date);
CREATE INDEX va_items_downloads_statisti_8 ON va_items_downloads_statistic (order_item_id);
CREATE INDEX va_items_downloads_statisti_9 ON va_items_downloads_statistic (remote_address);


DROP SEQUENCE seq_va_items_images;
DROP TABLE va_items_images;

CREATE SEQUENCE seq_va_items_images START 1;
CREATE TABLE va_items_images (
  image_id INT4 NOT NULL DEFAULT nextval('seq_va_items_images'),
  item_id INT4 NOT NULL default '0',
  image_small VARCHAR(255) NOT NULL,
  small_width INT4,
  small_height INT4,
  image_large VARCHAR(255),
  image_title VARCHAR(255),
  image_description TEXT
  ,PRIMARY KEY (image_id));

CREATE INDEX va_items_images_item_id ON va_items_images (item_id);


DROP SEQUENCE seq_va_items_prices;
DROP TABLE va_items_prices;

CREATE SEQUENCE seq_va_items_prices START 1;
CREATE TABLE va_items_prices (
  price_id INT4 NOT NULL DEFAULT nextval('seq_va_items_prices'),
  item_id INT4 default '0',
  is_active INT4 default '0',
  min_quantity INT4 default '1',
  max_quantity INT4 default '1',
  price FLOAT4 default '0',
  user_type_id INT4 default '0',
  discount_action INT4 default '0',
  properties_discount FLOAT4 default '0'
  ,PRIMARY KEY (price_id));

CREATE INDEX va_items_prices_item_id ON va_items_prices (item_id);
CREATE INDEX va_items_prices_user_type_id ON va_items_prices (user_type_id);


DROP SEQUENCE seq_va_items_properties;
DROP TABLE va_items_properties;

CREATE SEQUENCE seq_va_items_properties START 1;
CREATE TABLE va_items_properties (
  property_id INT4 NOT NULL DEFAULT nextval('seq_va_items_properties'),
  property_type_id INT4 default '1',
  item_type_id INT4 default '0',
  item_id INT4 NOT NULL default '0',
  sub_item_id INT4 default '0',
  additional_price FLOAT4,
  property_order INT4 NOT NULL default '1',
  property_name VARCHAR(255) NOT NULL,
  property_description TEXT,
  property_style TEXT,
  use_on_list INT4 default '1',
  use_on_details INT4 default '1',
  use_on_checkout INT4 default '0',
  use_on_second INT4 default '0',
  control_type VARCHAR(16) NOT NULL,
  control_style VARCHAR(255),
  control_code TEXT,
  onchange_code TEXT,
  onclick_code TEXT,
  required INT4,
  start_html TEXT,
  middle_html TEXT,
  before_control_html TEXT,
  after_control_html TEXT,
  end_html TEXT
  ,PRIMARY KEY (property_id));

CREATE INDEX va_items_properties_item_id ON va_items_properties (item_id);
CREATE INDEX va_items_properties_item_type_id ON va_items_properties (item_type_id);
CREATE INDEX va_items_properties_propert_10 ON va_items_properties (property_type_id);
CREATE INDEX va_items_properties_sub_item_id ON va_items_properties (sub_item_id);


DROP SEQUENCE seq_va_items_properties_values;
DROP TABLE va_items_properties_values;

CREATE SEQUENCE seq_va_items_properties_values START 1;
CREATE TABLE va_items_properties_values (
  item_property_id INT4 NOT NULL DEFAULT nextval('seq_va_items_properties_values'),
  property_id INT4 NOT NULL default '0',
  sub_item_id INT4 default '0',
  property_value VARCHAR(255) NOT NULL,
  manufacturer_code VARCHAR(64),
  download_period INT4,
  download_path VARCHAR(255),
  buying_price FLOAT4,
  additional_price FLOAT4,
  additional_weight FLOAT4,
  use_stock_level VARCHAR(50),
  stock_level INT4,
  hide_out_of_stock INT4 default '0',
  hide_value INT4 NOT NULL default '0',
  is_default_value INT4 default '0'
  ,PRIMARY KEY (item_property_id));

CREATE INDEX va_items_properties_values__11 ON va_items_properties_values (hide_value);
CREATE INDEX va_items_properties_values__12 ON va_items_properties_values (property_id);
CREATE INDEX va_items_properties_values__13 ON va_items_properties_values (sub_item_id);


DROP SEQUENCE seq_va_items_related;
DROP TABLE va_items_related;

CREATE SEQUENCE seq_va_items_related START 1;
CREATE TABLE va_items_related (
  item_id INT4 NOT NULL default '0',
  related_id INT4 NOT NULL default '0',
  related_order INT4 NOT NULL default '1'
);

CREATE INDEX va_items_related_item_id ON va_items_related (item_id);
CREATE INDEX va_items_related_related_id ON va_items_related (related_id);


DROP SEQUENCE seq_va_items_serials;
DROP TABLE va_items_serials;

CREATE SEQUENCE seq_va_items_serials START 1;
CREATE TABLE va_items_serials (
  serial_id INT4 NOT NULL DEFAULT nextval('seq_va_items_serials'),
  item_id INT4 default '0',
  serial_number VARCHAR(128),
  used INT4 default '0'
  ,PRIMARY KEY (serial_id));

CREATE INDEX va_items_serials_item_id ON va_items_serials (item_id);


DROP SEQUENCE seq_va_languages;
DROP TABLE va_languages;

CREATE SEQUENCE seq_va_languages START 1;
CREATE TABLE va_languages (
  language_code VARCHAR(2) NOT NULL,
  language_order INT4 default '1',
  language_name VARCHAR(255) NOT NULL,
  show_for_user INT4 default '0',
  language_image VARCHAR(128),
  currency_code VARCHAR(4)
  ,PRIMARY KEY (language_code));



DROP SEQUENCE seq_va_layouts;
DROP TABLE va_layouts;

CREATE SEQUENCE seq_va_layouts START 13;
CREATE TABLE va_layouts (
  layout_id INT4 NOT NULL DEFAULT nextval('seq_va_layouts'),
  layout_name VARCHAR(64) NOT NULL,
  style_name VARCHAR(64),
  templates_dir VARCHAR(255) NOT NULL,
  admin_templates_dir VARCHAR(255) NOT NULL
  ,PRIMARY KEY (layout_id));



DROP SEQUENCE seq_va_manufacturers;
DROP TABLE va_manufacturers;

CREATE SEQUENCE seq_va_manufacturers START 3;
CREATE TABLE va_manufacturers (
  manufacturer_id INT4 NOT NULL DEFAULT nextval('seq_va_manufacturers'),
  manufacturer_name VARCHAR(255) NOT NULL,
  affiliate_code VARCHAR(255)
  ,PRIMARY KEY (manufacturer_id));



DROP SEQUENCE seq_va_news;
DROP TABLE va_news;

CREATE SEQUENCE seq_va_news START 4;
CREATE TABLE va_news (
  news_id INT4 NOT NULL DEFAULT nextval('seq_va_news'),
  news_date TIMESTAMP NOT NULL,
  news_title VARCHAR(255) NOT NULL,
  author VARCHAR(255),
  is_html INT4 NOT NULL default '1',
  is_showing INT4 NOT NULL default '1',
  show_on_index INT4 NOT NULL default '0',
  preview_text TEXT,
  news_body TEXT
  ,PRIMARY KEY (news_id));



DROP SEQUENCE seq_va_newsletters;
DROP TABLE va_newsletters;

CREATE SEQUENCE seq_va_newsletters START 1;
CREATE TABLE va_newsletters (
  newsletter_id INT4 NOT NULL DEFAULT nextval('seq_va_newsletters'),
  newsletter_date TIMESTAMP NOT NULL,
  newsletter_subject VARCHAR(255) NOT NULL,
  newsletter_body TEXT,
  mail_type INT4 default '0',
  mail_from VARCHAR(128),
  mail_reply_to VARCHAR(128),
  mail_return_path VARCHAR(128),
  mailing_start TIMESTAMP,
  mailing_end TIMESTAMP,
  emails_left INT4 default '0',
  emails_sent INT4 default '0',
  is_active INT4 default '0',
  is_sent INT4 default '0',
  is_prepared INT4 default '0',
  users_recipients TEXT,
  admins_recipients TEXT,
  subscribed_recipients TEXT,
  orders_recipients TEXT,
  added_by INT4 default '0',
  added_date TIMESTAMP,
  edited_by INT4 default '0',
  edited_date TIMESTAMP
  ,PRIMARY KEY (newsletter_id));



DROP SEQUENCE seq_va_newsletters_emails;
DROP TABLE va_newsletters_emails;

CREATE SEQUENCE seq_va_newsletters_emails START 1;
CREATE TABLE va_newsletters_emails (
  email_id INT4 NOT NULL DEFAULT nextval('seq_va_newsletters_emails'),
  newsletter_id INT4 default '0',
  user_email VARCHAR(128) NOT NULL,
  user_name VARCHAR(128)
  ,PRIMARY KEY (email_id));

CREATE INDEX va_newsletters_emails_newsl_14 ON va_newsletters_emails (newsletter_id);


DROP SEQUENCE seq_va_newsletters_users;
DROP TABLE va_newsletters_users;

CREATE SEQUENCE seq_va_newsletters_users START 1;
CREATE TABLE va_newsletters_users (
  email_id INT4 NOT NULL DEFAULT nextval('seq_va_newsletters_users'),
  email VARCHAR(50),
  date_added TIMESTAMP
  ,PRIMARY KEY (email_id));

CREATE INDEX va_newsletters_users_email ON va_newsletters_users (email);


DROP SEQUENCE seq_va_order_custom_properties;
DROP TABLE va_order_custom_properties;

CREATE SEQUENCE seq_va_order_custom_properties START 1;
CREATE TABLE va_order_custom_properties (
  property_id INT4 NOT NULL DEFAULT nextval('seq_va_order_custom_properties'),
  payment_id INT4 default '0',
  property_order INT4 default '0',
  property_name VARCHAR(255),
  property_description TEXT,
  default_value TEXT,
  property_style VARCHAR(255),
  property_type INT4 default '0',
  tax_free INT4 default '0',
  control_type VARCHAR(16),
  control_style VARCHAR(255),
  control_code TEXT,
  onchange_code TEXT,
  onclick_code TEXT,
  required INT4 default '0',
  before_name_html TEXT,
  after_name_html TEXT,
  before_control_html TEXT,
  after_control_html TEXT
  ,PRIMARY KEY (property_id));

CREATE INDEX va_order_custom_properties__15 ON va_order_custom_properties (payment_id);


DROP SEQUENCE seq_va_order_custom_values;
DROP TABLE va_order_custom_values;

CREATE SEQUENCE seq_va_order_custom_values START 1;
CREATE TABLE va_order_custom_values (
  property_value_id INT4 NOT NULL DEFAULT nextval('seq_va_order_custom_values'),
  property_id INT4 default '0',
  property_value VARCHAR(255),
  property_price FLOAT4 default '0',
  property_weight FLOAT4 default '0',
  hide_value INT4 default '0',
  is_default_value INT4 default '0'
  ,PRIMARY KEY (property_value_id));

CREATE INDEX va_order_custom_values_prop_16 ON va_order_custom_values (property_id);


DROP SEQUENCE seq_va_order_statuses;
DROP TABLE va_order_statuses;

CREATE SEQUENCE seq_va_order_statuses START 13;
CREATE TABLE va_order_statuses (
  status_id INT4 NOT NULL DEFAULT nextval('seq_va_order_statuses'),
  status_name VARCHAR(64) NOT NULL,
  is_user_cancel INT4 default '0',
  allow_user_cancel INT4 default '0',
  is_dispatch INT4 default '0',
  is_list INT4 default '1',
  download_activation INT4,
  download_notify INT4 default '0',
  item_notify INT4 default '0',
  mail_notify INT4 default '0',
  mail_to VARCHAR(255),
  mail_from VARCHAR(64),
  mail_cc VARCHAR(255),
  mail_bcc VARCHAR(255),
  mail_reply_to VARCHAR(64),
  mail_return_path VARCHAR(64),
  mail_type INT4 default '0',
  mail_subject VARCHAR(255),
  mail_body TEXT,
  sms_notify INT4 default '0',
  sms_recipient VARCHAR(255),
  sms_originator VARCHAR(64),
  sms_message TEXT
  ,PRIMARY KEY (status_id));



DROP SEQUENCE seq_va_orders;
DROP TABLE va_orders;

CREATE SEQUENCE seq_va_orders START 1;
CREATE TABLE va_orders (
  order_id INT4 NOT NULL DEFAULT nextval('seq_va_orders'),
  transaction_id VARCHAR(128),
  user_id INT4 NOT NULL default '0',
  payment_id INT4 default '0',
  success_message VARCHAR(255),
  pending_message VARCHAR(50),
  error_message VARCHAR(255),
  remote_address VARCHAR(32),
  initial_ip VARCHAR(32),
  cookie_ip VARCHAR(32),
  affiliate_code VARCHAR(64) NOT NULL,
  coupons_ids TEXT,
  currency_code VARCHAR(4),
  currency_rate FLOAT4 default '1',
  order_status INT4 NOT NULL default '1',
  total_buying FLOAT4 NOT NULL default '0',
  goods_total FLOAT4 NOT NULL default '0',
  goods_taxable FLOAT4 NOT NULL default '0',
  total_quantity INT4 NOT NULL default '0',
  weight_total FLOAT4 default '0',
  total_discount FLOAT4 default '0',
  total_discount_tax FLOAT4 default '0',
  shipping_type_id INT4 default '0',
  shipping_type_desc VARCHAR(255),
  shipping_cost FLOAT4,
  shipping_taxable INT4 default '0',
  shipping_tracking_id VARCHAR(64),
  shipping_expecting_date TIMESTAMP,
  properties_total FLOAT4 default '0',
  properties_taxable FLOAT4 default '0',
  tax_name VARCHAR(255),
  tax_percent FLOAT4,
  tax_total FLOAT4 default '0',
  processing_fee FLOAT4 default '0',
  order_total FLOAT4 NOT NULL default '0',
  name VARCHAR(128) NOT NULL,
  first_name VARCHAR(64) NOT NULL,
  last_name VARCHAR(64) NOT NULL,
  company_id INT4 default '0',
  company_name VARCHAR(128),
  email VARCHAR(128) NOT NULL,
  address1 VARCHAR(255),
  address2 VARCHAR(255),
  city VARCHAR(128),
  province VARCHAR(128),
  state_code VARCHAR(8),
  zip VARCHAR(16),
  country_code VARCHAR(2),
  phone VARCHAR(32),
  daytime_phone VARCHAR(32),
  evening_phone VARCHAR(32),
  cell_phone VARCHAR(32),
  fax VARCHAR(32),
  delivery_name VARCHAR(128),
  delivery_first_name VARCHAR(64),
  delivery_last_name VARCHAR(64),
  delivery_company_id INT4 default '0',
  delivery_company_name VARCHAR(128),
  delivery_email VARCHAR(128),
  delivery_address1 VARCHAR(255),
  delivery_address2 VARCHAR(255),
  delivery_city VARCHAR(128),
  delivery_province VARCHAR(128),
  delivery_state_code VARCHAR(8),
  delivery_zip VARCHAR(16),
  delivery_country_code VARCHAR(2),
  delivery_phone VARCHAR(32),
  delivery_daytime_phone VARCHAR(32),
  delivery_evening_phone VARCHAR(32),
  delivery_cell_phone VARCHAR(32),
  delivery_fax VARCHAR(32),
  cc_name VARCHAR(90),
  cc_first_name VARCHAR(64),
  cc_last_name VARCHAR(64),
  cc_number VARCHAR(32),
  cc_start_date TIMESTAMP,
  cc_expiry_date TIMESTAMP,
  cc_type INT4,
  cc_issue_number INT4,
  cc_security_code VARCHAR(32),
  pay_without_cc TEXT,
  order_placed_date TIMESTAMP NOT NULL,
  modified_date TIMESTAMP,
  is_placed INT4 default '0',
  is_exported INT4 default '0'
  ,PRIMARY KEY (order_id));

CREATE INDEX va_orders_affiliate_code ON va_orders (affiliate_code);
CREATE INDEX va_orders_currency_code ON va_orders (currency_code);
CREATE INDEX va_orders_email ON va_orders (email);
CREATE INDEX va_orders_first_name ON va_orders (first_name);
CREATE INDEX va_orders_goods_total ON va_orders (goods_total);
CREATE INDEX va_orders_last_name ON va_orders (last_name);
CREATE INDEX va_orders_name ON va_orders (name);
CREATE INDEX va_orders_order_placed_date ON va_orders (order_placed_date);
CREATE INDEX va_orders_order_status ON va_orders (order_status);
CREATE INDEX va_orders_payment_id ON va_orders (payment_id);
CREATE INDEX va_orders_shipping_tracking_id ON va_orders (shipping_tracking_id);
CREATE INDEX va_orders_shipping_type_id ON va_orders (shipping_type_id);
CREATE INDEX va_orders_total_buying ON va_orders (total_buying);
CREATE INDEX va_orders_user_id ON va_orders (user_id);


DROP SEQUENCE seq_va_orders_events;
DROP TABLE va_orders_events;

CREATE SEQUENCE seq_va_orders_events START 1;
CREATE TABLE va_orders_events (
  event_id INT4 NOT NULL DEFAULT nextval('seq_va_orders_events'),
  order_id INT4 default '0',
  admin_id INT4 default '0',
  status_id INT4 default '0',
  order_items TEXT,
  event_date TIMESTAMP,
  event_name VARCHAR(64),
  event_description TEXT
  ,PRIMARY KEY (event_id));

CREATE INDEX va_orders_events_admin_id ON va_orders_events (admin_id);
CREATE INDEX va_orders_events_order_id ON va_orders_events (order_id);
CREATE INDEX va_orders_events_status_id ON va_orders_events (status_id);


DROP SEQUENCE seq_va_orders_items;
DROP TABLE va_orders_items;

CREATE SEQUENCE seq_va_orders_items START 1;
CREATE TABLE va_orders_items (
  order_item_id INT4 NOT NULL DEFAULT nextval('seq_va_orders_items'),
  order_id INT4 NOT NULL default '0',
  item_id INT4 NOT NULL default '0',
  parent_item_id INT4 default '0',
  item_type_id INT4 NOT NULL default '0',
  manufacturer_code VARCHAR(255),
  coupons_ids TEXT,
  item_status INT4 NOT NULL default '1',
  item_name VARCHAR(255) NOT NULL,
  item_properties TEXT,
  buying_price FLOAT4 default '0',
  real_price FLOAT4 default '0',
  discount_amount FLOAT4 default '0',
  price FLOAT4 NOT NULL default '0',
  tax_free INT4 default '0',
  tax_percent FLOAT4,
  weight FLOAT4 default '0',
  quantity INT4,
  downloadable INT4 default '0',
  shipping_tracking_id VARCHAR(128),
  shipping_expecting_date TIMESTAMP
  ,PRIMARY KEY (order_item_id));

CREATE INDEX va_orders_items_item_id ON va_orders_items (item_id);
CREATE INDEX va_orders_items_item_status ON va_orders_items (item_status);
CREATE INDEX va_orders_items_item_type ON va_orders_items (item_type_id);
CREATE INDEX va_orders_items_order_id ON va_orders_items (order_id);
CREATE INDEX va_orders_items_parent_item_id ON va_orders_items (parent_item_id);
CREATE INDEX va_orders_items_price ON va_orders_items (price);


DROP SEQUENCE seq_va_orders_items_properties;
DROP TABLE va_orders_items_properties;

CREATE SEQUENCE seq_va_orders_items_properties START 1;
CREATE TABLE va_orders_items_properties (
  item_property_id INT4 NOT NULL DEFAULT nextval('seq_va_orders_items_properties'),
  order_id INT4 NOT NULL default '0',
  order_item_id INT4 NOT NULL default '0',
  property_id INT4 NOT NULL default '0',
  property_values_ids TEXT,
  property_name VARCHAR(255) NOT NULL,
  property_value VARCHAR(255),
  additional_price FLOAT4 default '0',
  additional_weight FLOAT4 default '0'
  ,PRIMARY KEY (item_property_id));

CREATE INDEX va_orders_items_properties__17 ON va_orders_items_properties (order_id);
CREATE INDEX va_orders_items_properties__18 ON va_orders_items_properties (order_item_id);
CREATE INDEX va_orders_items_properties__19 ON va_orders_items_properties (property_id);


DROP SEQUENCE seq_va_orders_items_serials;
DROP TABLE va_orders_items_serials;

CREATE SEQUENCE seq_va_orders_items_serials START 1;
CREATE TABLE va_orders_items_serials (
  serial_id INT4 NOT NULL DEFAULT nextval('seq_va_orders_items_serials'),
  order_id INT4 default '0',
  user_id INT4 default '0',
  order_item_id INT4 default '0',
  item_id INT4 default '0',
  serial_number VARCHAR(128),
  activated INT4 default '0',
  activations_number INT4 default '0',
  serial_added TIMESTAMP
  ,PRIMARY KEY (serial_id));

CREATE INDEX va_orders_items_serials_item_id ON va_orders_items_serials (item_id);
CREATE INDEX va_orders_items_serials_order_id ON va_orders_items_serials (order_id);
CREATE INDEX va_orders_items_serials_ord_20 ON va_orders_items_serials (order_item_id);
CREATE INDEX va_orders_items_serials_ser_21 ON va_orders_items_serials (serial_number);
CREATE INDEX va_orders_items_serials_user_id ON va_orders_items_serials (user_id);


DROP SEQUENCE seq_va_orders_notes;
DROP TABLE va_orders_notes;

CREATE SEQUENCE seq_va_orders_notes START 1;
CREATE TABLE va_orders_notes (
  note_id INT4 NOT NULL DEFAULT nextval('seq_va_orders_notes'),
  order_id INT4 default '0',
  note_title VARCHAR(255),
  note_details TEXT,
  show_for_user INT4 default '0',
  date_added TIMESTAMP,
  date_updated TIMESTAMP
  ,PRIMARY KEY (note_id));

CREATE INDEX va_orders_notes_order_id ON va_orders_notes (order_id);


DROP SEQUENCE seq_va_orders_properties;
DROP TABLE va_orders_properties;

CREATE SEQUENCE seq_va_orders_properties START 1;
CREATE TABLE va_orders_properties (
  order_property_id INT4 NOT NULL DEFAULT nextval('seq_va_orders_properties'),
  order_id INT4 default '0',
  property_id INT4 default '0',
  property_order INT4 default '1',
  property_type INT4 default '0',
  property_name VARCHAR(255) NOT NULL,
  property_value TEXT,
  property_price FLOAT4 default '0',
  property_weight FLOAT4 default '0',
  tax_free INT4 default '0'
  ,PRIMARY KEY (order_property_id));

CREATE INDEX va_orders_properties_order_id ON va_orders_properties (order_id);
CREATE INDEX va_orders_properties_order__22 ON va_orders_properties (order_property_id);
CREATE INDEX va_orders_properties_property_id ON va_orders_properties (property_id);
CREATE INDEX va_orders_properties_proper_23 ON va_orders_properties (property_name);


DROP SEQUENCE seq_va_orders_serials_activations;
DROP TABLE va_orders_serials_activations;

CREATE SEQUENCE seq_va_orders_serials_activations START 1;
CREATE TABLE va_orders_serials_activations (
  activation_id INT4 NOT NULL DEFAULT nextval('seq_va_orders_serials_activations'),
  serial_id INT4 default '0',
  order_id INT4 default '0',
  remote_address VARCHAR(32),
  generation_key VARCHAR(255),
  activation_key TEXT,
  date_added TIMESTAMP
  ,PRIMARY KEY (activation_id));

CREATE INDEX va_orders_serials_activatio_24 ON va_orders_serials_activations (order_id);
CREATE INDEX va_orders_serials_activatio_25 ON va_orders_serials_activations (serial_id);


DROP SEQUENCE seq_va_page_settings;
DROP TABLE va_page_settings;

CREATE SEQUENCE seq_va_page_settings START 1;
CREATE TABLE va_page_settings (
  layout_id INT4 NOT NULL default '0',
  page_name VARCHAR(32) NOT NULL,
  setting_name VARCHAR(64) NOT NULL,
  setting_order INT4,
  setting_value TEXT
  ,PRIMARY KEY (layout_id,page_name,setting_name));



DROP SEQUENCE seq_va_pages;
DROP TABLE va_pages;

CREATE SEQUENCE seq_va_pages START 18;
CREATE TABLE va_pages (
  page_id INT4 NOT NULL DEFAULT nextval('seq_va_pages'),
  page_code VARCHAR(16) NOT NULL,
  page_title VARCHAR(255) NOT NULL,
  page_url VARCHAR(255),
  page_order INT4 NOT NULL default '1',
  is_showing INT4 NOT NULL default '1',
  link_in_footer INT4 NOT NULL default '0',
  is_html INT4,
  page_type INT4,
  page_path VARCHAR(255),
  page_body TEXT,
  meta_title VARCHAR(255),
  meta_keywords VARCHAR(255),
  meta_description VARCHAR(255)
  ,PRIMARY KEY (page_id));

CREATE INDEX va_pages_is_showing ON va_pages (is_showing);
CREATE INDEX va_pages_link_in_footer ON va_pages (link_in_footer);
CREATE INDEX va_pages_page_code ON va_pages (page_code);


DROP SEQUENCE seq_va_payment_parameters;
DROP TABLE va_payment_parameters;

CREATE SEQUENCE seq_va_payment_parameters START 539;
CREATE TABLE va_payment_parameters (
  parameter_id INT4 NOT NULL DEFAULT nextval('seq_va_payment_parameters'),
  payment_id INT4 NOT NULL default '0',
  parameter_name VARCHAR(255) NOT NULL,
  parameter_type VARCHAR(16) NOT NULL,
  parameter_source VARCHAR(255),
  not_passed INT4 default '0'
  ,PRIMARY KEY (parameter_id));



DROP SEQUENCE seq_va_payment_systems;
DROP TABLE va_payment_systems;

CREATE SEQUENCE seq_va_payment_systems START 30;
CREATE TABLE va_payment_systems (
  payment_id INT4 NOT NULL DEFAULT nextval('seq_va_payment_systems'),
  payment_name VARCHAR(255) NOT NULL,
  payment_info TEXT,
  payment_notes TEXT,
  payment_url VARCHAR(255) NOT NULL,
  processing_time INT4 default '0',
  processing_fee FLOAT4,
  fee_type INT4 default '0',
  submit_method VARCHAR(4),
  is_advanced INT4 default '0',
  advanced_url VARCHAR(255),
  advanced_php_lib VARCHAR(255),
  success_status_id INT4,
  pending_status_id INT4,
  failure_status_id INT4,
  failure_action INT4 default '0',
  is_active INT4 default '0',
  is_default INT4 default '0'
  ,PRIMARY KEY (payment_id));



DROP SEQUENCE seq_va_polls;
DROP TABLE va_polls;

CREATE SEQUENCE seq_va_polls START 2;
CREATE TABLE va_polls (
  poll_id INT4 NOT NULL DEFAULT nextval('seq_va_polls'),
  poll_type INT4 NOT NULL default '1',
  question TEXT NOT NULL,
  is_active INT4 NOT NULL default '0',
  date_added TIMESTAMP NOT NULL,
  total_votes INT4 default '0'
  ,PRIMARY KEY (poll_id));



DROP SEQUENCE seq_va_polls_options;
DROP TABLE va_polls_options;

CREATE SEQUENCE seq_va_polls_options START 7;
CREATE TABLE va_polls_options (
  poll_option_id INT4 NOT NULL DEFAULT nextval('seq_va_polls_options'),
  poll_id INT4 NOT NULL default '0',
  option_description TEXT NOT NULL,
  is_default_value INT4 default '0'
  ,PRIMARY KEY (poll_option_id));

CREATE INDEX va_polls_options_poll_id ON va_polls_options (poll_id);


DROP SEQUENCE seq_va_polls_votes;
DROP TABLE va_polls_votes;

CREATE SEQUENCE seq_va_polls_votes START 1;
CREATE TABLE va_polls_votes (
  poll_id INT4 NOT NULL default '0',
  poll_option_id INT4 NOT NULL default '0',
  remote_address VARCHAR(32) NOT NULL,
  date_added TIMESTAMP NOT NULL
);

CREATE INDEX va_polls_votes_poll_id ON va_polls_votes (poll_id);
CREATE INDEX va_polls_votes_poll_option_id ON va_polls_votes (poll_option_id);
CREATE INDEX va_polls_votes_remote_address ON va_polls_votes (remote_address);


DROP SEQUENCE seq_va_release_changes;
DROP TABLE va_release_changes;

CREATE SEQUENCE seq_va_release_changes START 28;
CREATE TABLE va_release_changes (
  change_id INT4 NOT NULL DEFAULT nextval('seq_va_release_changes'),
  release_id INT4 NOT NULL default '0',
  change_type_id INT4 NOT NULL default '0',
  change_date TIMESTAMP NOT NULL,
  change_desc TEXT,
  is_showing INT4 NOT NULL default '1'
  ,PRIMARY KEY (change_id));

CREATE INDEX va_release_changes_release_id ON va_release_changes (release_id);


DROP SEQUENCE seq_va_release_types;
DROP TABLE va_release_types;

CREATE SEQUENCE seq_va_release_types START 4;
CREATE TABLE va_release_types (
  type_id INT4 NOT NULL DEFAULT nextval('seq_va_release_types'),
  type_name VARCHAR(255) NOT NULL
  ,PRIMARY KEY (type_id));



DROP SEQUENCE seq_va_releases;
DROP TABLE va_releases;

CREATE SEQUENCE seq_va_releases START 2;
CREATE TABLE va_releases (
  release_id INT4 NOT NULL DEFAULT nextval('seq_va_releases'),
  item_id INT4 NOT NULL default '0',
  release_type_id INT4 NOT NULL default '0',
  release_date TIMESTAMP NOT NULL,
  release_title VARCHAR(255) NOT NULL,
  version VARCHAR(32),
  release_desc TEXT,
  download_type INT4 NOT NULL default '0',
  path_to_file VARCHAR(255),
  is_showing INT4 NOT NULL default '1',
  show_on_index INT4 NOT NULL default '0'
  ,PRIMARY KEY (release_id));

CREATE INDEX va_releases_item_id ON va_releases (item_id);


DROP SEQUENCE seq_va_reviews;
DROP TABLE va_reviews;

CREATE SEQUENCE seq_va_reviews START 1;
CREATE TABLE va_reviews (
  review_id INT4 NOT NULL DEFAULT nextval('seq_va_reviews'),
  item_id INT4 NOT NULL default '0',
  recommended INT4 NOT NULL default '0',
  approved INT4 NOT NULL default '0',
  rating INT4,
  summary VARCHAR(255),
  user_name VARCHAR(255),
  remote_address VARCHAR(32) NOT NULL,
  date_added TIMESTAMP NOT NULL,
  comments TEXT
  ,PRIMARY KEY (review_id));

CREATE INDEX va_reviews_approved ON va_reviews (approved);
CREATE INDEX va_reviews_item_id ON va_reviews (item_id);
CREATE INDEX va_reviews_recommended ON va_reviews (recommended);


DROP SEQUENCE seq_va_shipping_modules;
DROP TABLE va_shipping_modules;

CREATE SEQUENCE seq_va_shipping_modules START 5;
CREATE TABLE va_shipping_modules (
  shipping_module_id INT4 NOT NULL DEFAULT nextval('seq_va_shipping_modules'),
  shipping_module_name VARCHAR(255),
  module_notes TEXT,
  is_external INT4 default '1',
  php_external_lib VARCHAR(255),
  external_url VARCHAR(255),
  tracking_url VARCHAR(255),
  is_active INT4 default '0'
  ,PRIMARY KEY (shipping_module_id));



DROP SEQUENCE seq_va_shipping_modules_parameters;
DROP TABLE va_shipping_modules_parameters;

CREATE SEQUENCE seq_va_shipping_modules_parameters START 54;
CREATE TABLE va_shipping_modules_parameters (
  parameter_id INT4 NOT NULL DEFAULT nextval('seq_va_shipping_modules_parameters'),
  shipping_module_id INT4 default '0',
  parameter_name VARCHAR(255),
  parameter_source TEXT,
  not_passed INT4 default '0'
  ,PRIMARY KEY (parameter_id));

CREATE INDEX va_shipping_modules_paramet_26 ON va_shipping_modules_parameters (shipping_module_id);


DROP SEQUENCE seq_va_shipping_rules;
DROP TABLE va_shipping_rules;

CREATE SEQUENCE seq_va_shipping_rules START 4;
CREATE TABLE va_shipping_rules (
  shipping_rule_id INT4 NOT NULL DEFAULT nextval('seq_va_shipping_rules'),
  shipping_rule_desc VARCHAR(255) NOT NULL
  ,PRIMARY KEY (shipping_rule_id));



DROP SEQUENCE seq_va_shipping_times;
DROP TABLE va_shipping_times;

CREATE SEQUENCE seq_va_shipping_times START 3;
CREATE TABLE va_shipping_times (
  shipping_time_id INT4 NOT NULL DEFAULT nextval('seq_va_shipping_times'),
  shipping_time_desc VARCHAR(255) NOT NULL,
  availability_time INT4 default '0'
  ,PRIMARY KEY (shipping_time_id));



DROP SEQUENCE seq_va_shipping_types;
DROP TABLE va_shipping_types;

CREATE SEQUENCE seq_va_shipping_types START 54;
CREATE TABLE va_shipping_types (
  shipping_type_id INT4 NOT NULL DEFAULT nextval('seq_va_shipping_types'),
  shipping_module_id INT4 default '0',
  shipping_order INT4 default '1',
  shipping_type_code VARCHAR(64),
  shipping_type_desc VARCHAR(255) NOT NULL,
  shipping_time INT4 default '0',
  tare_weight FLOAT4 default '0',
  min_goods_cost FLOAT4 default '0',
  max_goods_cost FLOAT4 default '0',
  min_weight FLOAT4 default '0',
  max_weight FLOAT4 default '0',
  cost_per_order FLOAT4 default '0',
  cost_per_product FLOAT4 default '0',
  cost_per_weight FLOAT4 default '0',
  is_taxable INT4 default '1',
  is_active INT4 default '1'
  ,PRIMARY KEY (shipping_type_id));

CREATE INDEX va_shipping_types_shipping__27 ON va_shipping_types (shipping_module_id);
CREATE INDEX va_shipping_types_shipping__28 ON va_shipping_types (shipping_type_id);


DROP SEQUENCE seq_va_shipping_types_countries;
DROP TABLE va_shipping_types_countries;

CREATE SEQUENCE seq_va_shipping_types_countries START 1;
CREATE TABLE va_shipping_types_countries (
  shipping_type_id INT4 NOT NULL default '0',
  country_code VARCHAR(4) NOT NULL
);

CREATE INDEX va_shipping_types_countries_29 ON va_shipping_types_countries (country_code);
CREATE INDEX va_shipping_types_countries_30 ON va_shipping_types_countries (shipping_type_id);


DROP SEQUENCE seq_va_states;
DROP TABLE va_states;

CREATE SEQUENCE seq_va_states START 1;
CREATE TABLE va_states (
  state_code VARCHAR(8) NOT NULL,
  state_name VARCHAR(64) NOT NULL
  ,PRIMARY KEY (state_code));



DROP SEQUENCE seq_va_support;
DROP TABLE va_support;

CREATE SEQUENCE seq_va_support START 1;
CREATE TABLE va_support (
  support_id INT4 NOT NULL DEFAULT nextval('seq_va_support'),
  user_id INT4 NOT NULL default '0',
  user_name VARCHAR(64) NOT NULL,
  user_email VARCHAR(128) NOT NULL,
  remote_address VARCHAR(32),
  identifier VARCHAR(128),
  environment VARCHAR(255),
  support_product_id INT4 NOT NULL default '0',
  support_type_id INT4 NOT NULL default '0',
  dep_id INT4 NOT NULL default '0',
  summary VARCHAR(255) NOT NULL,
  description TEXT,
  support_status_id INT4,
  support_priority_id INT4,
  admin_id_assign_to INT4 NOT NULL default '0',
  admin_id_assign_by INT4,
  admin_id_added_by INT4,
  admin_id_modified_by INT4,
  date_added TIMESTAMP NOT NULL,
  date_modified TIMESTAMP NOT NULL,
  date_viewed TIMESTAMP
  ,PRIMARY KEY (support_id));

CREATE INDEX va_support_admin_id_assign_to ON va_support (admin_id_assign_to);
CREATE INDEX va_support_date_added ON va_support (date_added);
CREATE INDEX va_support_dep_id ON va_support (dep_id);
CREATE INDEX va_support_summary ON va_support (summary);
CREATE INDEX va_support_support_product_id ON va_support (support_product_id);
CREATE INDEX va_support_support_type_id ON va_support (support_type_id);
CREATE INDEX va_support_user_email ON va_support (user_email);
CREATE INDEX va_support_user_id ON va_support (user_id);
CREATE INDEX va_support_user_name ON va_support (user_name);


DROP SEQUENCE seq_va_support_attachments;
DROP TABLE va_support_attachments;

CREATE SEQUENCE seq_va_support_attachments START 1;
CREATE TABLE va_support_attachments (
  attachment_id INT4 NOT NULL DEFAULT nextval('seq_va_support_attachments'),
  support_id INT4 NOT NULL default '0',
  message_id INT4 default '0',
  admin_id INT4 default '0',
  attachment_status INT4 default '0',
  file_name VARCHAR(255),
  file_path VARCHAR(255),
  date_added TIMESTAMP
  ,PRIMARY KEY (attachment_id));

CREATE INDEX va_support_attachments_admin_id ON va_support_attachments (admin_id);
CREATE INDEX va_support_attachments_mess_31 ON va_support_attachments (message_id);
CREATE INDEX va_support_attachments_supp_32 ON va_support_attachments (support_id);


DROP SEQUENCE seq_va_support_departments;
DROP TABLE va_support_departments;

CREATE SEQUENCE seq_va_support_departments START 2;
CREATE TABLE va_support_departments (
  dep_id INT4 NOT NULL DEFAULT nextval('seq_va_support_departments'),
  short_title VARCHAR(255),
  full_title VARCHAR(255),
  signature TEXT,
  attachments_dir VARCHAR(255),
  attachments_mask TEXT,
  incoming_account TEXT,
  incoming_type_id INT4 default '0',
  incoming_product_id INT4 default '0',
  outgoing_account VARCHAR(50),
  show_for_user INT4 default '1'
  ,PRIMARY KEY (dep_id));

CREATE INDEX va_support_departments_inco_33 ON va_support_departments (incoming_product_id);
CREATE INDEX va_support_departments_inco_34 ON va_support_departments (incoming_type_id);


DROP SEQUENCE seq_va_support_messages;
DROP TABLE va_support_messages;

CREATE SEQUENCE seq_va_support_messages START 1;
CREATE TABLE va_support_messages (
  message_id INT4 NOT NULL DEFAULT nextval('seq_va_support_messages'),
  support_id INT4 NOT NULL default '0',
  internal INT4 NOT NULL default '0',
  dep_id INT4 NOT NULL default '0',
  support_status_id INT4 NOT NULL default '0',
  admin_id_assign_by INT4,
  admin_id_assign_to INT4,
  admin_id_modified_by INT4,
  subject VARCHAR(255),
  message_text TEXT,
  reply_to VARCHAR(255),
  reply_from VARCHAR(255),
  date_added TIMESTAMP NOT NULL,
  date_viewed TIMESTAMP,
  date_modified TIMESTAMP,
  is_user_reply INT4 default '0',
  is_html INT4 default '0'
  ,PRIMARY KEY (message_id));

CREATE INDEX va_support_messages_date_added ON va_support_messages (date_added);
CREATE INDEX va_support_messages_dep_id ON va_support_messages (dep_id);
CREATE INDEX va_support_messages_support_id ON va_support_messages (support_id);


DROP SEQUENCE seq_va_support_predefined;
DROP TABLE va_support_predefined;

CREATE SEQUENCE seq_va_support_predefined START 1;
CREATE TABLE va_support_predefined (
  reply_id INT4 NOT NULL DEFAULT nextval('seq_va_support_predefined'),
  subject VARCHAR(255),
  body TEXT,
  reply_type VARCHAR(255)
  ,PRIMARY KEY (reply_id));



DROP SEQUENCE seq_va_support_priorities;
DROP TABLE va_support_priorities;

CREATE SEQUENCE seq_va_support_priorities START 4;
CREATE TABLE va_support_priorities (
  priority_id INT4 NOT NULL DEFAULT nextval('seq_va_support_priorities'),
  priority_name VARCHAR(255) NOT NULL,
  priority_rank INT4 default '0',
  admin_html TEXT,
  is_default INT4 default '0'
  ,PRIMARY KEY (priority_id));



DROP SEQUENCE seq_va_support_products;
DROP TABLE va_support_products;

CREATE SEQUENCE seq_va_support_products START 2;
CREATE TABLE va_support_products (
  product_id INT4 NOT NULL DEFAULT nextval('seq_va_support_products'),
  product_name VARCHAR(255) NOT NULL,
  show_for_user INT4
  ,PRIMARY KEY (product_id));



DROP SEQUENCE seq_va_support_statuses;
DROP TABLE va_support_statuses;

CREATE SEQUENCE seq_va_support_statuses START 10;
CREATE TABLE va_support_statuses (
  status_id INT4 NOT NULL DEFAULT nextval('seq_va_support_statuses'),
  status_name VARCHAR(255) NOT NULL,
  show_for_user INT4,
  status_caption VARCHAR(255),
  status_icon VARCHAR(128),
  html_start VARCHAR(255),
  html_end VARCHAR(255),
  is_user_new INT4 default '0',
  is_user_reply INT4 default '0',
  is_operation INT4 default '0',
  is_reassign INT4 default '0',
  is_internal INT4 default '0',
  is_list INT4 default '0',
  is_closed INT4 default '0',
  is_add_knowledge INT4 default '0'
  ,PRIMARY KEY (status_id));

CREATE INDEX va_support_statuses_status_id ON va_support_statuses (status_id);


DROP SEQUENCE seq_va_support_time_report;
DROP TABLE va_support_time_report;

CREATE SEQUENCE seq_va_support_time_report START 1;
CREATE TABLE va_support_time_report (
  report_id INT4 NOT NULL DEFAULT nextval('seq_va_support_time_report'),
  admin_id INT4 NOT NULL default '0',
  support_id INT4 NOT NULL default '0',
  started_date TIMESTAMP,
  report_date TIMESTAMP,
  spent_hours INT4 default '0'
  ,PRIMARY KEY (report_id));

CREATE INDEX va_support_time_report_admin_id ON va_support_time_report (admin_id);
CREATE INDEX va_support_time_report_supp_35 ON va_support_time_report (support_id);


DROP SEQUENCE seq_va_support_types;
DROP TABLE va_support_types;

CREATE SEQUENCE seq_va_support_types START 5;
CREATE TABLE va_support_types (
  type_id INT4 NOT NULL DEFAULT nextval('seq_va_support_types'),
  type_name VARCHAR(255) NOT NULL,
  show_for_user INT4
  ,PRIMARY KEY (type_id));



DROP SEQUENCE seq_va_support_users_departments;
DROP TABLE va_support_users_departments;

CREATE SEQUENCE seq_va_support_users_departments START 1;
CREATE TABLE va_support_users_departments (
  admin_id INT4 NOT NULL default '0',
  dep_id INT4 NOT NULL default '0',
  is_default_dep INT4 default '0'
  ,PRIMARY KEY (admin_id,dep_id));



DROP SEQUENCE seq_va_support_users_priorities;
DROP TABLE va_support_users_priorities;

CREATE SEQUENCE seq_va_support_users_priorities START 1;
CREATE TABLE va_support_users_priorities (
  user_priority_id INT4 NOT NULL DEFAULT nextval('seq_va_support_users_priorities'),
  priority_id INT4 default '0',
  user_id INT4 default '0',
  user_email VARCHAR(255)
  ,PRIMARY KEY (user_priority_id));

CREATE INDEX va_support_users_priorities_36 ON va_support_users_priorities (priority_id);
CREATE INDEX va_support_users_priorities_37 ON va_support_users_priorities (user_id);


DROP SEQUENCE seq_va_tax_rates;
DROP TABLE va_tax_rates;

CREATE SEQUENCE seq_va_tax_rates START 29;
CREATE TABLE va_tax_rates (
  tax_id INT4 NOT NULL DEFAULT nextval('seq_va_tax_rates'),
  tax_name VARCHAR(255) NOT NULL,
  state_code VARCHAR(8),
  country_code VARCHAR(4) NOT NULL,
  tax_percent FLOAT4 NOT NULL default '0'
  ,PRIMARY KEY (tax_id));



DROP SEQUENCE seq_va_tax_rates_items;
DROP TABLE va_tax_rates_items;

CREATE SEQUENCE seq_va_tax_rates_items START 1;
CREATE TABLE va_tax_rates_items (
  tax_item_id INT4 NOT NULL DEFAULT nextval('seq_va_tax_rates_items'),
  tax_id INT4 default '0',
  item_type_id INT4 default '0',
  tax_percent FLOAT4
  ,PRIMARY KEY (tax_item_id));

CREATE INDEX va_tax_rates_items_item_type_id ON va_tax_rates_items (item_type_id);
CREATE INDEX va_tax_rates_items_tax_id ON va_tax_rates_items (tax_id);


DROP SEQUENCE seq_va_user_types;
DROP TABLE va_user_types;

CREATE SEQUENCE seq_va_user_types START 2;
CREATE TABLE va_user_types (
  type_id INT4 NOT NULL DEFAULT nextval('seq_va_user_types'),
  type_name VARCHAR(128),
  is_default INT4 default '0',
  discount_type INT4,
  discount_amount FLOAT4 default '0',
  coupons_ids TEXT
  ,PRIMARY KEY (type_id));



DROP SEQUENCE seq_va_user_types_settings;
DROP TABLE va_user_types_settings;

CREATE SEQUENCE seq_va_user_types_settings START 1;
CREATE TABLE va_user_types_settings (
  type_id INT4 NOT NULL default '0',
  setting_name VARCHAR(64) NOT NULL,
  setting_value VARCHAR(50)
  ,PRIMARY KEY (type_id,setting_name));



DROP SEQUENCE seq_va_users;
DROP TABLE va_users;

CREATE SEQUENCE seq_va_users START 2;
CREATE TABLE va_users (
  user_id INT4 NOT NULL DEFAULT nextval('seq_va_users'),
  user_type_id INT4 default '0',
  is_approved INT4 default '0',
  discount_type INT4,
  discount_amount FLOAT4 default '0',
  coupons_ids TEXT,
  login VARCHAR(32) NOT NULL,
  password VARCHAR(32) NOT NULL,
  security_question VARCHAR(255),
  security_answer VARCHAR(255),
  personal_image VARCHAR(255),
  name VARCHAR(128) NOT NULL,
  first_name VARCHAR(64) NOT NULL,
  last_name VARCHAR(64) NOT NULL,
  company_id INT4 default '0',
  company_name VARCHAR(128),
  email VARCHAR(128) NOT NULL,
  address1 VARCHAR(255),
  address2 VARCHAR(255),
  city VARCHAR(128),
  province VARCHAR(128),
  state_code VARCHAR(8),
  zip VARCHAR(16),
  country_code VARCHAR(2),
  phone VARCHAR(32),
  daytime_phone VARCHAR(32),
  evening_phone VARCHAR(32),
  cell_phone VARCHAR(32),
  fax VARCHAR(32),
  delivery_name VARCHAR(128),
  delivery_first_name VARCHAR(64),
  delivery_last_name VARCHAR(64),
  delivery_company_id INT4 default '0',
  delivery_company_name VARCHAR(128),
  delivery_email VARCHAR(128),
  delivery_address1 VARCHAR(255),
  delivery_address2 VARCHAR(255),
  delivery_city VARCHAR(128),
  delivery_province VARCHAR(128),
  delivery_state_code VARCHAR(8),
  delivery_zip VARCHAR(16),
  delivery_country_code VARCHAR(2),
  delivery_phone VARCHAR(32),
  delivery_daytime_phone VARCHAR(32),
  delivery_evening_phone VARCHAR(32),
  delivery_cell_phone VARCHAR(32),
  delivery_fax VARCHAR(32),
  registration_ip VARCHAR(32),
  registration_date TIMESTAMP,
  modified_ip VARCHAR(32),
  modified_date TIMESTAMP,
  last_visit_ip VARCHAR(32),
  last_visit_date TIMESTAMP,
  reset_password_code VARCHAR(64),
  reset_password_date TIMESTAMP
  ,PRIMARY KEY (user_id));

CREATE INDEX va_users_company_id ON va_users (company_id);
CREATE INDEX va_users_delivery_company_id ON va_users (delivery_company_id);
CREATE INDEX va_users_email ON va_users (email);
CREATE INDEX va_users_first_name ON va_users (first_name);
CREATE INDEX va_users_last_name ON va_users (last_name);
CREATE INDEX va_users_login ON va_users (login);
CREATE INDEX va_users_name ON va_users (name);
CREATE INDEX va_users_password ON va_users (password);
CREATE INDEX va_users_reset_password_code ON va_users (reset_password_code);

 UPDATE va_global_settings SET setting_value=1 WHERE setting_type='global' AND setting_name='layout_id';

INSERT INTO va_admin_privileges (privilege_id,support_privilege,privilege_name) VALUES (1 , 0 , 'Administrator' ) ;
INSERT INTO va_admin_privileges (privilege_id,support_privilege,privilege_name) VALUES (2 , 1 , 'HelpDesk Manager' ) ;


INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'admin_users' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'ads' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'articles' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'banned_contents' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'banners' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'black_ips' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'coupons' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'custom_blocks' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'filemanager' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'forum' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'import_export' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'layouts' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'newsletter' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'order_confirmation' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'order_links' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'order_notes' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'order_payment' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'order_profile' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'order_serials' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'order_statuses' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'order_vouchers' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'orders_stats' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'payment_systems' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'polls' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'products_categories' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'products_reviews' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'remove_orders' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'sales_orders' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'site_settings' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'site_users' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'static_messages' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'static_tables' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support_departments' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support_predefined_reply' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support_settings' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support_static_data' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support_ticket_close' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support_ticket_edit' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support_ticket_new' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support_ticket_reply' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support_users' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support_users_priorities' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'support_users_stats' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'tax_rates' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'update_orders' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (1 , 'web_pages' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'admin_users' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'ads' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'articles' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'banners' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'coupons' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'custom_blocks' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'filemanager' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'forum' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'import_export' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'layouts' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'newsletter' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'order_confirmation' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'order_links' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'order_notes' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'order_profile' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'order_serials' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'order_statuses' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'order_vouchers' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'orders_stats' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'payment_systems' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'polls' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'products_categories' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'products_reviews' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'remove_orders' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'sales_orders' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'site_settings' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'site_users' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'static_messages' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'static_tables' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support_departments' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support_predefined_reply' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support_settings' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support_static_data' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support_ticket_close' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support_ticket_edit' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support_ticket_new' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support_ticket_reply' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support_users' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support_users_priorities' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'support_users_stats' , 1 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'tax_rates' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'update_orders' , 0 ) ;
INSERT INTO va_admin_privileges_settings (privilege_id,block_name,permission) VALUES (2 , 'web_pages' , 0 ) ;


INSERT INTO va_admins (admin_id,admin_name,admin_alias,privilege_id,email,login,password,personal_image,signature,last_order_id,exported_order_id,exported_order_fields,last_user_id,exported_user_id,exported_user_fields,imported_user_fields,exported_item_fields,imported_item_fields,edited_item_fields,last_visit_date,is_generate_big_image,is_generate_small_image) VALUES (1 , 'Site Administrator' , NULL , 1 , 'admin@yoursite.com' , 'admin' , 'admin' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 'i.item_id,i.item_name,i.item_order,i.buying_price,i.features,csv_delimiter,csv_delimiter,related_delimiterrelated_delimiter' , NULL , NULL , NULL , 0 , 0 ) ;




INSERT INTO va_ads_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,allowed_view,allowed_post,short_description,full_description,image_small,image_large,total_ads,total_subcategories) VALUES (1 , NULL , 0 , 0 , '0,' , 'Books' , 1 , 1 , 1 , NULL , NULL , 'images/categories/books.gif' , NULL , 0 , 0 ) ;
INSERT INTO va_ads_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,allowed_view,allowed_post,short_description,full_description,image_small,image_large,total_ads,total_subcategories) VALUES (2 , NULL , 0 , 0 , '0,' , 'Electronics ' , 2 , 1 , 1 , NULL , NULL , 'images/categories/electronics.gif' , NULL , 0 , 0 ) ;
INSERT INTO va_ads_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,allowed_view,allowed_post,short_description,full_description,image_small,image_large,total_ads,total_subcategories) VALUES (3 , NULL , 0 , 0 , '0,' , 'Computers' , 3 , 1 , 1 , NULL , NULL , 'images/categories/computers.gif' , NULL , 0 , 0 ) ;






INSERT INTO va_ads_features_groups (group_id,group_order,group_name) VALUES (1 , 1 , 'General' ) ;
INSERT INTO va_ads_features_groups (group_id,group_order,group_name) VALUES (2 , 2 , 'Sizes' ) ;
INSERT INTO va_ads_features_groups (group_id,group_order,group_name) VALUES (3 , 3 , 'Accessories' ) ;










INSERT INTO va_ads_types (type_id,type_name) VALUES (1 , 'Product' ) ;
INSERT INTO va_ads_types (type_id,type_name) VALUES (2 , 'Accessory' ) ;


INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (1 , NULL , '2005-06-10 15:06:00' , NULL , 'Tropical storm watch posted as Arlene moves north' , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , NULL , '06.09.2005 18:28:32' , NULL , 'MIAMI, Florida (AP) -- A tropical storm watch was issued Friday for central Louisiana to the Florida Panhandle, where residents are still recovering from last year\'s hurricanes' , 'MIAMI, Florida (AP) -- A tropical storm watch was issued Friday for central Louisiana to the Florida Panhandle, where residents are still recovering from last year\'s hurricanes' , 'Arlene, the Atlantic hurricane season\'s first named tropical storm, was centered about 10 miles south-southeast of the western tip of Cuba at 5 a.m. EDT. It was moving north about 8 mph, and could cross near or over western Cuba as it moved into the Gulf of Mexico, forecasters said.\r\n\r\nWind and rain extended 140 miles to the north and east from the storm\'s center.\r\n\r\nArlene had maximum sustained winds of 45 mph. The storm could drop as much as 5 to 10 inches of rain, and possibly cause flooding in western Cuba and tornados in southwest Florida and the Florida Keys, meteorologists said.\r\n\r\n"This is going to be a major rainfall event before and ahead of the storm," said Trisha Wallace, a meteorologist at the National Hurricane Center in Miami.\r\n\r\nThe Cuban government issued a tropical storm warning for the western province of Pinar Del Rio to the capital of Havana. A tropical storm warning was also in effect for the Dry Tortugas, a cluster of islands about 70 miles west of Key West that comprise a U.S. national park. Other than park personnel, there are no permanent residents.\r\n\r\nThe storm was not expected to develop into a hurricane before making landfall, Wallace said.\r\n\r\nHurricane season began June 1 and ends November 30. Last season, Florida was struck by hurricanes Charley, Frances, Ivan and Jeanne; between them, the four storms damaged one out of every five homes in the state. The storms caused about 130 deaths in the United States and are blamed for $22 billion in insured damage.\r\n\r\n' , NULL , 0 , 1 , 4 , 4 , 0 , 'images/big/story3.jpg' , NULL , 'images/big/story3.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (2 , NULL , '2005-06-10 15:10:00' , NULL , 'Bolivia names new president' , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , NULL , '21.09.2005 14:09:13' , NULL , '(CNN) -- The head of Bolivia\'s Supreme Court -- Eduardo Rodriguez -- has been sworn in as interim president to succeed the outgoing Carlos Mesa.' , '(CNN) -- The head of Bolivia\'s Supreme Court -- Eduardo Rodriguez -- has been sworn in as interim president to succeed the outgoing Carlos Mesa.' , 'Mesa offered to resign after weeks of crippling street protests that threatened to paralyze the South American country. Troops shot and killed a protester on Thursday.\r\n\r\nThe job of interim president automatically went to Rodriguez after two congressional leaders, who were first and second in line for the post, turned it down.\r\n\r\nElections are expected in the next three to six months. Mesa\'s term was to have ended in August 2007. \r\n\r\nCongressional lawmakers met in an emergency session in the historic colonial capital of Sucre Thursday to accept Mesa\'s resignation and swear in Rodriguez.\r\n\r\nProtests earlier forced Congress to suspend proceedings as the armed forces chief threatened military intervention. \r\n\r\nHundreds of miners and farmers clashed with riot police outside the whitewashed hall where the session was to have been held.\r\n\r\nThe naming of an interim president meets the protesters\' demand that Mesa step down.\r\n\r\nBut other issues, such as the nationalization of the oil and gas industry and the formation of a new constituent assembly to rewrite the constitution, were still unmet, journalist Noah Rudovsky told CNN.\r\n\r\nHe said it was unclear whether demonstrations would continue. \r\n\r\nWeeks of blockade have nearly paralyzed the capital of La Paz where nearly two million residents live, with gas stations closed, supermarkets empty and drinking water scarce.\r\n\r\n"I think his [the new president\'s] job at this point mainly is to bring the nation together if he can to bring an end to the roadblock and to pave the way for a peaceful election within the next three to six months," Rudovsky said.\r\n\r\nThe protesters -- largely members of the country\'s Indian population -- also seek a more even distribution of wealth.\r\n\r\nBolivia, with a population of 9 million, has long been one of South America\'s poorest countries and a major recipient of international aid.\r\n\r\nThe protests grew after Bolivia\'s Congress moved last month to raise taxes on foreign oil companies that have flocked to the country to develop its natural gas reserves -- the second largest in South America after Venezuela.\r\n\r\nThe measure was intended to calm street tensions, but it only unleashed new street protests in a nation where anti-globalization anger is high.\r\n\r\nMesa took office in October 2003 when a bloody popular revolt over free-market economic policies forced his predecessor, former president Gonzalo Sanchez de Lozada, to flee the country.\r\n\r\nBolivia has a history of unrest. \r\n\r\nSince breaking away from Spanish rule in 1825, it has been beset by nearly 200 coups and counter-coups.\r\n\r\n' , NULL , 0 , 1 , 5 , 5 , 0 , 'images/big/story1.jpg' , NULL , 'images/big/story1.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (3 , NULL , '2005-06-10 15:12:00' , NULL , 'Hopes raised of Africa debt deal' , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , NULL , '21.09.2005 14:09:22' , NULL , 'LONDON, England -- Hopes of an accord on debt relief for poor African nations were raised Friday with reports of an agreement between the United States and Britain on writing off $16.7 billion owed by 18 countries.' , 'LONDON, England -- Hopes of an accord on debt relief for poor African nations were raised Friday with reports of an agreement between the United States and Britain on writing off $16.7 billion owed by 18 countries.' , 'British officials said they were confident the world\'s most powerful financial ministers would reach a historic deal at their meeting in London this weekend -- although some differences remain between the Group of Eight (G8) major industrialized nations.\r\n\r\nWith the deadline of the G8 summit in Gleneagles, Scotland, just a month away, finance ministers meeting in London on Friday and Saturday were trying to find common ground.\r\n\r\nIn addition to the United States and Britain, the G8 nations include France, Germany, Italy, Canada, Japan and Russia. \r\n\r\nUK Prime Minister Tony Blair -- current G8 president -- has demanded that poor countries\' debts be cancelled and their aid doubled. He and U.S. President George W. Bush agreed this week in Washington that help on debt should be given only to countries ready to tackle corruption. \r\n\r\nThe New York Times reported that the United States and Britain had reached an agreement on freeing 18 countries, mostly in Africa, from any obligation to pay $16.7 billion in debt.\r\n\r\nThe countries are Benin, Bolivia, Burkina Faso, Ethiopia, Ghana, Guyana, Honduras, Madagascar, Mali, Mauritania, Mozambique, Nicaragua, Niger, Rwanda, Senegal, Tanzania, Uganda and Zambia.\r\n\r\nA significant omission from the list is Nigeria, whose external debt is put at $36 billion. Nigerian President Olusegun Obasanjo was in London this week for talks with Blair.\r\n\r\nThe number of countries to be helped is a sticking point. Blair\'s spokesman said earlier this week that about 25 countries would benefit, while charities say 62 countries need urgent debt relief.\r\n\r\nFrance, Germany and Japan have their own proposal that would mean debt relief for only five countries.\r\n\r\nThe New York Times Friday quoted a senior official as saying that U.S. Treasury Secretary John Snow and his British counterpart, Chancellor of the Exchequer Gordon Brown, would present their proposal to a meeting of the finance ministers of seven of the G8 nations on Friday in London.\r\n\r\nThe debts would be written off by the lenders in an effort to allow the debtor countries to start fresh, get their books in order and eventually be able to borrow again for economic development, health, education and social programs, rather than simply to repay existing loans. \r\n\r\nBush had signaled his willingness to go along with writing off the debts in principle, but the United States and Britain had very different approaches to how such a plan would work, the newspaper said.\r\n\r\nBritain wanted the rich nations to take over responsibility for repaying the debts. but Washington wants the loans to be written off entirely by the lenders, the Times said.\r\n\r\nIn the end, said the paper, Britain agreed to the U.S. approach with a promise from Washington to provide additional money to the lenders to make up for the assets they were writing off. \r\n\r\nSub-Saharan Africa has $230 billion in external debt and pays $12 billion a year on servicing the loans, according to the most recent figures from the World Bank, Reuters reported. \r\n\r\nA third of the debt is owed to multilateral lenders like the International Monetary Fund. Britain has said that without 100 percent multilateral debt relief, the poorest countries would pay up to $27.5 billion in principal and interest payments to international organizations between now and 2015. \r\n\r\n"President Bush and Prime Minister Blair made great progress and Gordon Brown and John Snow agreed on an excellent proposal for debt cancellation for many of the poorest countries," Jamie Drummond of DATA, a lobbying group founded by rock star Bono, told The New York Times.\r\n\r\nBono joined European Commission President Jose Manuel Barroso Thursday in an appeal to government leaders to double development aid to Africa and other poor regions over the next 10 years. (Full story)\r\n\r\n"It is no substitute for an overall plan on aid and trade at the G8 summit, but this degree of cooperation should make a historic breakthrough more likely," Drummond said.\r\n\r\nAll of the countries eligible for debt relief have had to show that they have acted to improve governing, ' , NULL , 0 , 0 , 0 , 0 , 0 , 'images/big/story2.jpg' , NULL , 'images/big/story2.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (4 , NULL , '2005-06-10 15:20:00' , NULL , 'Brian Johnston' , NULL , 4 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , NULL , NULL , NULL , NULL , '21.09.2005 13:43:52' , NULL , 'On 16 May 1994, more than 2,000 people crammed into Westminster Abbey to give thanks for the life of a cricket commentator. \r\n\r\nThe then Prime Minister John Major gave an address, two Guardsmen played on fife and drum and the Abbey organ ended proceedings with the theme from Neighbours. \r\n' , 'On 16 May 1994, more than 2,000 people crammed into Westminster Abbey to give thanks for the life of a cricket commentator. \r\n\r\nThe then Prime Minister John Major gave an address, two Guardsmen played on fife and drum and the Abbey organ ended proceedings with the theme from Neighbours. \r\n\r\n' , 'On 16 May 1994, more than 2,000 people crammed into Westminster Abbey to give thanks for the life of a cricket commentator. \r\n\r\nThe then Prime Minister John Major gave an address, two Guardsmen played on fife and drum and the Abbey organ ended proceedings with the theme from Neighbours. \r\n\r\nBrian Johnston was, of course, much more than just a cricket commentator - he was a national institution. \r\n\r\nHe joined the BBC in 1946 after wartime service in the Guards and before that in the family coffee business. \r\n\r\nHe was naturally suited to the ad lib life of radio outside broadcasting and in his early days undertook a variety of assignments in the days when anything outside a studio was something of a novelty. \r\n\r\nJohnston\'s first job was to cover the disposal of a bomb discovered in Hyde Park, which he covered from the apparent safety of a ladies\' lavatory. \r\n\r\nHis propensity for awful puns produced the line that he emerged "looking a bit flushed". \r\n\r\nSuch occasions led to his own live spot - Let\'s Go Somewhere - on In Town Tonight. \r\n\r\nThe highlights included him riding bareback in the circus, reporting from beneath an express train and from inside a post box at Christmas. \r\n\r\nHis career as a cricket commentator actually began on television. \r\n\r\nHe did not cross to Test Match Special until 1970, when television unceremoniously dropped him in a change of policy, recruiting only former players. \r\n\r\nThe lack of any word from television rankled Brian for the rest of his life, but his arrival at Test Match Special was a true homecoming. \r\n\r\n  Brian would say TMS was "just a bunch of friends going to a Test Match and talking about it" \r\n\r\nPeter Baxter on Johnners  \r\nHis informal style was a complete contrast to John Arlott, but his natural popular appeal brought a new audience to the programme and gave it a new lease of life. \r\n\r\nHe was by this time the BBC\'s first cricket correspondent, having made a huge impact while on extended leave in Australia to watch England play in 1958/9. \r\n\r\nThereafter, he was to accompany England tours round the world until his retirement in 1972. \r\n\r\nHowever, retirement from the BBC staff did not end his involvement with Test Match Special. \r\n\r\nIn fact, he was still an integral part of the commentary team at his death in January 1994 at the age of 81. \r\n\r\nEveryone was given a nickname. Scorer Bill Findall became \'the Bearded Wonder\'. And to this day, Henry Blofeld and Jonathan Agnew are fondly known as Blowers and Aggers. \r\n\r\nLaughter was never far away with Brian and he will inevitably be remembered for the so-called "leg-over" incident. \r\n\r\n  The famous "leg over" clip from 1991  \r\nDuring the summary of a day\'s play at the Oval, Aggers suggested that Ian Botham, in being out hit wicket had failed to "get his leg over." \r\n\r\nBrian fought the giggles manfully for almost half a minute and then dissolved, wheezing helplessly into a large spotted handkerchief. \r\n\r\nWhen asked about Test Match Special, Brian would say that it was "just a bunch of friends going to a Test Match and talking about it." \r\n\r\nAnd with him, it was. \r\n\r\n' , NULL , 0 , 1 , 5 , 5 , 0 , 'images/big/story4.jpg' , NULL , 'images/big/story4.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (5 , NULL , '2005-06-10 15:25:00' , NULL , 'Image 1' , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , NULL , NULL , NULL , NULL , '07.09.2005 11:46:56' , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 0 , 0 , 'images/big/story1.jpg' , NULL , 'images/big/story1.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (6 , NULL , '2005-06-10 15:26:00' , NULL , 'Image 2' , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , NULL , NULL , NULL , NULL , '07.09.2005 11:47:13' , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 0 , 0 , 'images/big/story2.jpg' , NULL , 'images/big/story2.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (7 , NULL , '2005-06-10 15:27:00' , NULL , 'Image 3' , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 15:27:42' , '10.06.2005 15:27:42' , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 0 , 0 , 'images/big/story3.jpg' , NULL , 'images/big/story3.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (8 , NULL , '2005-06-10 15:27:00' , NULL , 'Image 4' , NULL , 4 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 15:28:04' , '10.06.2005 15:28:04' , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 0 , 0 , 'images/big/story4.jpg' , NULL , 'images/big/story4.jpg' , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (9 , NULL , '2005-06-10 15:55:45' , NULL , 'ACHUKA' , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.achuka.co.uk/' , NULL , NULL , NULL , '10.06.2005 15:55:45' , NULL , NULL , NULL , 'Children\'s books UK. Independent site with reviews, interviews, news and articles' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (10 , NULL , '2005-06-10 15:56:05' , NULL , 'Ancient Paths' , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.literatureclassics.com/ancientpaths/litweb.html' , NULL , NULL , '10.06.2005 15:56:05' , '10.06.2005 15:56:05' , NULL , NULL , NULL , 'Various resources, criticism and research including an annotated timeline of English literature and the historical events shaping it.' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (11 , NULL , '2005-06-10 16:04:11' , NULL , 'BookEnds ' , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , 'http://www.bookends.co.uk/' , NULL , NULL , NULL , '10.06.2005 16:04:11' , NULL , NULL , NULL , 'News, reviews, short stories, features, trade news and top tens for the book industry' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (12 , NULL , '2005-06-10 15:56:48' , NULL , 'British Poetry 1780-1910 ' , NULL , 4 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://etext.lib.virginia.edu/britpo.html' , NULL , NULL , '10.06.2005 15:56:48' , '10.06.2005 15:56:48' , NULL , NULL , NULL , 'A hypertext archive of scholarly editions: Electronic Text Center, University of Virginia. \r\n' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (13 , NULL , '2005-06-10 15:57:49' , NULL , 'Alan De Smet - Role-Playing Games ' , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.highprogrammer.com/alan/gaming/' , NULL , NULL , '10.06.2005 15:57:49' , '10.06.2005 15:57:49' , NULL , NULL , NULL , 'A selection of practical tips for game masters and players of any system, information about some Gaming Conventions, and resources for Amber, Dungeons & Dragons, and Shadowrun. \r\n' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (14 , NULL , '2005-06-10 16:04:20' , NULL , 'GameWyrd ' , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , 'http://www.gamewyrd.com/' , NULL , NULL , NULL , '10.06.2005 16:04:20' , NULL , NULL , NULL , 'News and reviews with forums and chatrooms' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (15 , NULL , '2005-06-10 15:58:40' , NULL , 'Land of Shadows ' , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.shadowlord.co.uk/' , NULL , NULL , '10.06.2005 15:58:40' , '10.06.2005 15:58:40' , NULL , NULL , NULL , 'Short Introduction to Roleplaying. ' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (16 , NULL , '2005-06-10 15:59:41' , NULL , 'Braintrack University Index -' , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.braintrack.com/' , NULL , NULL , '10.06.2005 15:59:41' , '10.06.2005 15:59:41' , NULL , NULL , NULL , 'Index to institutions of higher education throughout the world.' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (17 , NULL , '2005-06-10 16:04:28' , NULL , 'College and University Home Pages' , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 1 , 'http://www.fjg.com/research.html' , NULL , NULL , NULL , '10.06.2005 16:04:28' , NULL , NULL , NULL , ' College and University Home Pages - Alphabetical Listing ' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (18 , NULL , '2005-06-10 16:00:27' , NULL , 'International Association for Management Education (AACSB) -' , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , 'http://www.aacsb.edu/' , NULL , NULL , '10.06.2005 16:00:27' , '10.06.2005 16:00:27' , NULL , NULL , NULL , 'Accrediting agency for bachelor\'s, master\'s and doctoral degree programs in business administration and accounting' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (19 , NULL , '2005-06-10 17:18:00' , NULL , 'PHP Applications gathering ' , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:18:26' , '10.06.2005 17:18:26' , NULL , NULL , 'The PHP Quebec Conference team is looking for the best software developed with PHP, MySQL and Apache. Each proposal received by April 29th 29 will be will be reviewed by an experts and members of the PHP Quebec community. ' , 'The PHP Quebec Conference team is looking for the best software developed with PHP, MySQL and Apache. Each proposal received by April 29th 29 will be will be reviewed by an experts and members of the PHP Quebec community. \r\n\r\nThe most useful software will be included on the 2005 PHP Quebec Conference CDROM along with over 25 hours of conference which where given by the leaders behind PHP, MySQL and Apache, as well as regional and international experts at the 2005 PHP Quebec conference. ' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (20 , NULL , '2005-06-10 17:18:00' , NULL , 'MySQL, RedHat and other partners started a new campaign against software patents' , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:19:00' , '10.06.2005 17:19:00' , NULL , NULL , 'In order to boost more awareness of the pending software patent issues in the European UnionMySQL, ISP 1&1, RedHat and other partners started a new portal "http://nosoftwarepatents.com". The site is available in 10 different european languages and explains why software patents are bad, and how they might affect you. ' , 'Under the influence of the patent system and big industry lobbyists, the European Union is on the verge of making a huge mistake: to pass a law that would legalize software patents. \r\n\r\nIf that happens, you will pay dearly. Europe\'s software industry will fall victim to unscrupulous extortioners. A cartel of large corporations will crush smaller competitors. Consequently, we will all pay more money for less good and less secure software. You personally, your household, your company, your government, all of us. \r\n\r\nYou\'ll know when you get the bill. When someone breaks into your computer, reads your E-mails, and steals the password of your bank account. When your computer crashes every day. When spam doesn\'t stop. When prices go up and companies shut down. When people lose their jobs. \r\n\r\n"Chances are that patents on software, common practice in the US and on the brink of being legalised in Europe, in fact stifle innovation. Europe could still alter course." \r\nDeutsche Bank Research \r\n\r\nWithout software patents, Europe could save costs, foster innovation, enhance security, and create jobs. Thanks to Linux and other open-source software, Europe has the chance to gain independence from Microsoft and other large American companies. However, if the EU allows software patents, then that\'s the beginning of the end for Linux. Not only for Linux. It\'s just a prominent example' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (21 , NULL , '2005-06-10 17:19:00' , NULL , 'PHP Quebec 2005: PHP - MySQL - Apache ' , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:19:19' , '10.06.2005 17:19:19' , NULL , NULL , 'PHP Quebec is proud to present an extended conference in Montreal, Quebec, covering the latest innovations in PHP, MySQL and Apache.' , 'PHP Quebec is proud to present an extended conference in Montreal, Quebec, covering the latest innovations in PHP, MySQL and Apache. From March 30th until April 1st, major AMP contributors will talk about Security, Web Services, PHP 5 and great achievements with PHP in North America. The 4 tracks are available at the PHP Quebec site. \r\n\r\nPHP Certification exams by Zend are included with every admission ticket to the conference. The certification center will also provide MySQL and Linux certification from MySQL AB, LPI and Savoir Faire Linux. The examination center is open to everyone. ' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (22 , NULL , '2005-06-10 17:27:28' , NULL , 'What is eShopping? ' , NULL , 1 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:27:28' , '10.06.2005 17:27:28' , NULL , NULL , NULL , 'eShopping contains sites of which the primary focus is to allow the consumer to select and obtain goods and services over the Web. Common examples include: \r\nIntegrated online shopping-cart systems that allow the user to order directly over the Web \r\nOnline shopping-cart systems that allow the user to generate an order form to be sent to the merchant via fax or snail-mail \r\nSimple directories of products and prices that the user can order via mail or phone. \r\nThe key is that the site contains three elements: lists of products for sale, prices, and information on how the consumer can obtain the product from their own h\r\n' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (23 , NULL , '2005-06-10 17:28:21' , NULL , 'How to Shop at Our Online Store?' , NULL , 2 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:28:21' , '10.06.2005 17:28:21' , NULL , NULL , NULL , 'Read online help please. See Help Section' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (24 , NULL , '2005-06-10 17:29:09' , NULL , 'I\'ve received an error message stating that my credit card is invalid. What should I do?' , NULL , 3 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:29:09' , '10.06.2005 17:29:09' , NULL , NULL , NULL , 'If you see an error message stating that your credit card is invalid, this has most likely happened for one of the following reasons: \r\n1. You have incorrectly entered your credit card number. \r\n2. You have incorrectly entered your CVV code. \r\n3. You have incorrectly entered your expiration date. \r\n4. You have used a cancelled credit card to place your order. \r\n5. Your card is restricted to point-of-sale transactions only (sales where your card is physically scanned). \r\n\r\nPlease double-check your credit card and/or with your bank to ensure that none of these problems have occurred. If you realize that you\'ve made a mistake, simply return to the payment option page and enter in the correct information. Continue checking out as normal. \r\n\r\nIf you\'re still encountering problems, please contact us. However, at NO point should you ever e-mail us your full credit card number. Your e-mail does not have the same security features in place as the website. If you wish to reference a specific credit card that you already have on file with us, please reference by the order number.\r\n\r\nIf you believe that you have provided us with an incorrect CVV code or expiration date you may send us that corrected information via e-mail referencing by the order number.\r\n\r\nIf you believe that your card was declined due to insufficient funds, but now have those funds available, you may ask that we attempt to charge your credit card again.\r\n\r\nIf you believe that your card is restricted to point-of-sale transactions, you must either contact your bank about removing such restrictions, provide us with a different credit card, or choose a new payment method.\r\n' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_articles (article_id,language_code,article_date,date_end,article_title,article_template,article_order,author_name,author_email,author_url,author_remote_address,created_user_id,created_admin_id,updated_user_id,updated_admin_id,status_id,is_html,allowed_rate,is_hot,link_url,download_url,is_link_direct,date_added,date_updated,keywords,hot_description,short_description,full_description,notes,total_views,total_votes,total_points,rating,total_clicks,image_small,image_small_alt,image_large,image_large_alt,meta_title,meta_keywords,meta_description) VALUES (25 , NULL , '2005-06-10 17:29:38' , NULL , 'Why is my online confirmation number different from my order number?' , NULL , 4 , NULL , NULL , NULL , '10.1.1.6' , NULL , 1 , NULL , 1 , 1 , 0 , '1' , 0 , NULL , NULL , NULL , '10.06.2005 17:29:38' , '10.06.2005 17:29:38' , NULL , NULL , NULL , 'This is due to the internal process we must maintain to properly track your order through the system. Once an order number is assigned you may use it for all future references to that purchase.' , NULL , 0 , 0 , 0 , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;


INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 1 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 15 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 16 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 17 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 18 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 19 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 20 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 21 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 22 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 23 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 24 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 25 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 26 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 27 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 28 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (1 , 29 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (2 , 1 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (2 , 18 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (2 , 19 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (2 , 21 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (2 , 23 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (2 , 29 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (3 , 1 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (3 , 20 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (3 , 28 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (4 , 1 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (4 , 16 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (4 , 23 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (5 , 5 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (6 , 5 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (7 , 5 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (8 , 5 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (9 , 7 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (10 , 7 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (11 , 7 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (12 , 7 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (13 , 8 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (14 , 8 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (15 , 8 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (16 , 10 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (17 , 10 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (18 , 10 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (19 , 6 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (20 , 6 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (21 , 6 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (22 , 4 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (23 , 4 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (24 , 4 ) ;
INSERT INTO va_articles_assigned (article_id,category_id) VALUES (25 , 4 ) ;


INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (1 , NULL , 0 , 0 , '0,' , 'News' , 10 , NULL , NULL , 'article_date' , 'DESC' , 'article_date,article_title,short_description,image_small' , 'article_date,article_title,full_description,image_large' , 'article_date,article_title' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 4 , 15 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (3 , NULL , 0 , 0 , '0,' , 'Links' , 7 , NULL , NULL , NULL , NULL , 'article_title,link_url,full_description' , 'full_description' , 'article_title,link_url' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 7 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (4 , NULL , 0 , 0 , '0,' , 'FAQ' , 9 , NULL , NULL , NULL , NULL , 'article_title,full_description,image_small' , 'article_title,full_description,image_large' , 'article_title' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 4 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (5 , NULL , 0 , 0 , '0,' , 'Image Gallery' , 5 , NULL , NULL , NULL , NULL , 'article_date,article_title,short_description,image_small' , 'article_date,article_title,full_description,image_large' , 'article_date,article_title' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 4 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (6 , NULL , 0 , 0 , '0,' , 'Events' , 6 , NULL , NULL , NULL , NULL , 'article_date,article_title,short_description,image_small' , 'article_date,article_title,full_description,image_large' , 'article_date,article_title' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 3 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (7 , NULL , 3 , 0 , '0,3,' , 'Arts' , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 4 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (8 , NULL , 3 , 0 , '0,3,' , 'Games' , 2 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 3 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (10 , NULL , 3 , 0 , '0,3,' , 'Reference' , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 3 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (11 , NULL , 3 , 0 , '0,3,' , 'Shopping' , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (12 , NULL , 3 , 0 , '0,3,' , 'World' , 6 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (13 , NULL , 3 , 0 , '0,3,' , 'Business' , 7 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (14 , NULL , 3 , 0 , '0,3,' , 'Computers' , 8 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (15 , NULL , 1 , 0 , '0,1,' , 'Asia' , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (16 , NULL , 1 , 0 , '0,1,' , 'Europe' , 2 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (17 , NULL , 1 , 0 , '0,1,' , 'U.S.' , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (18 , NULL , 1 , 0 , '0,1,' , 'WorldWorld' , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (19 , NULL , 1 , 0 , '0,1,' , 'Business' , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (20 , NULL , 1 , 0 , '0,1,' , 'Technology' , 6 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (21 , NULL , 1 , 0 , '0,1,' , 'Science & Space' , 7 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (22 , NULL , 1 , 0 , '0,1,' , 'Entertainment' , 8 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (23 , NULL , 1 , 0 , '0,1,' , 'World Sport' , 9 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (24 , NULL , 1 , 0 , '0,1,' , 'Travel' , 10 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (25 , NULL , 1 , 0 , '0,1,' , 'Executive' , 11 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (26 , NULL , 1 , 0 , '0,1,' , 'Education' , 12 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (27 , NULL , 1 , 0 , '0,1,' , 'Weather' , 13 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (28 , NULL , 1 , 0 , '0,1,' , 'Special Reports' , 14 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (29 , NULL , 1 , 0 , '0,1,' , 'Video' , 15 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_articles_categories (category_id,language_code,parent_category_id,alias_category_id,category_path,category_name,category_order,articles_list_template,articles_details_template,articles_order_column,articles_order_direction,article_list_fields,article_details_fields,article_required_fields,moderators_ids,is_hot,allowed_view,allowed_post,allowed_rate,short_description,full_description,image_small,image_small_alt,image_large,image_large_alt,is_rss,rss_limit,rss_on_breadcrumb,rss_on_list,meta_title,meta_keywords,meta_description,total_articles,total_subcategories) VALUES (30 , NULL , 0 , 0 , '0,' , 'Knowledge Base' , 11 , NULL , NULL , 'article_order' , 'ASC' , 'article_date,article_title,short_description' , 'article_date,article_title,full_description' , 'article_date,article_title,full_description' , NULL , 0 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 0 , NULL , NULL , NULL , 0 , 0 ) ;




INSERT INTO va_articles_related (article_id,related_id,related_order) VALUES (1 , 2 , 1 ) ;
INSERT INTO va_articles_related (article_id,related_id,related_order) VALUES (1 , 3 , 2 ) ;
INSERT INTO va_articles_related (article_id,related_id,related_order) VALUES (2 , 1 , 2 ) ;
INSERT INTO va_articles_related (article_id,related_id,related_order) VALUES (2 , 3 , 1 ) ;
INSERT INTO va_articles_related (article_id,related_id,related_order) VALUES (3 , 1 , 2 ) ;
INSERT INTO va_articles_related (article_id,related_id,related_order) VALUES (3 , 2 , 1 ) ;


INSERT INTO va_articles_reviews (review_id,article_id,recommended,approved,rating,summary,user_name,remote_address,date_added,comments) VALUES (1 , 1 , 1 , 1 , 4 , NULL , 'Author' , '10.1.1.6' , '2005-06-10 15:21:00' , NULL ) ;
INSERT INTO va_articles_reviews (review_id,article_id,recommended,approved,rating,summary,user_name,remote_address,date_added,comments) VALUES (2 , 4 , 1 , 1 , 5 , NULL , 'test' , '127.0.0.1' , '2005-09-07 10:30:25' , NULL ) ;
INSERT INTO va_articles_reviews (review_id,article_id,recommended,approved,rating,summary,user_name,remote_address,date_added,comments) VALUES (3 , 2 , 1 , 1 , 5 , NULL , 'test3' , '127.0.0.1' , '2005-09-07 10:30:52' , NULL ) ;
INSERT INTO va_articles_reviews (review_id,article_id,recommended,approved,rating,summary,user_name,remote_address,date_added,comments) VALUES (4 , 3 , 1 , 1 , 0 , NULL , 'test2' , '127.0.0.1' , '2005-09-07 10:31:13' , NULL ) ;


INSERT INTO va_articles_statuses (status_id,status_name,status_description,is_shown,status_icon,status_style,allowed_view) VALUES (1 , 'New' , NULL , 1 , NULL , NULL , 1 ) ;
INSERT INTO va_articles_statuses (status_id,status_name,status_description,is_shown,status_icon,status_style,allowed_view) VALUES (2 , 'Published' , NULL , 1 , NULL , NULL , 1 ) ;
INSERT INTO va_articles_statuses (status_id,status_name,status_description,is_shown,status_icon,status_style,allowed_view) VALUES (3 , 'Pending' , NULL , 1 , NULL , NULL , 0 ) ;
INSERT INTO va_articles_statuses (status_id,status_name,status_description,is_shown,status_icon,status_style,allowed_view) VALUES (4 , 'Hidden' , NULL , 1 , NULL , NULL , 0 ) ;














INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (1 , 0 , '0,' , 'Books' , 2 , 1 , NULL , '' , '' , 'images/categories/books.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (2 , 1 , '0,1,' , 'Arts & Photography' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (3 , 0 , '0,' , 'Toys & Games' , 3 , 1 , NULL , '' , '' , 'images/categories/games.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (4 , 3 , '0,3,' , 'Games' , 1 , 1 , NULL , '' , '' , 'images/categories/dvd.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (5 , 0 , '0,' , 'DVD' , 4 , 1 , NULL , '' , '' , 'images/categories/dvd.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (8 , 1 , '0,1,' , 'Travel' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (9 , 1 , '0,1,' , 'Mystery & Thrillers' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (10 , 1 , '0,1,' , 'Christian Books' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (11 , 1 , '0,1,' , 'Science Fiction & Fantasy' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (12 , 5 , '0,5,' , 'African American Cinema' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (13 , 0 , '0,' , 'Software' , 1 , 1 , NULL , '' , '' , 'images/categories/software.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (14 , 13 , '0,13,' , 'Web Development' , 3 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (15 , 5 , '0,5,' , 'Comedy' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (16 , 13 , '0,13,' , 'Graphics' , 2 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (19 , 13 , '0,13,' , 'Games' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (24 , 0 , '0,' , 'Music' , 8 , 1 , NULL , '' , '' , 'images/categories/music.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (25 , 24 , '0,24,' , 'Hard Rock & Metal' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (26 , 24 , '0,24,' , 'Folk' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (27 , 24 , '0,24,' , 'Children\'s' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (28 , 24 , '0,24,' , 'New Age' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (29 , 3 , '0,3,' , 'Bikes, Scooters & More...' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (30 , 24 , '0,24,' , 'Classical' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (34 , 3 , '0,3,' , 'Stuffed Animals' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (35 , 0 , '0,' , 'Computers' , 11 , 1 , NULL , '' , '' , 'images/categories/computers.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (36 , 35 , '0,35,' , 'Notebooks' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (37 , 35 , '0,35,' , 'Desktops' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (41 , 35 , '0,35,' , 'Monitors' , 1 , 1 , NULL , '' , '' , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (43 , 0 , '0,' , 'Cell Phones & Service' , 5 , 1 , NULL , '' , '' , 'images/categories/cellphones.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (47 , 0 , '0,' , 'Amazon\'s affiliates' , 12 , 1 , NULL , 'This category shows you how to create an affiliate program with Amazon.com' , 'This category shows you how to create an affiliate program with Amazon.com' , 'images/categories/books.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (48 , 47 , '0,47,' , 'Books' , 1 , 1 , NULL , 'Buy books with Amazon.com' , NULL , 'images/categories/books.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (49 , 48 , '0,47,48,' , 'Science Fiction & Fantasy' , 1 , 1 , NULL , NULL , NULL , 'images/categories/computers.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (50 , 48 , '0,47,48,' , 'Christian Books' , 2 , 1 , NULL , NULL , NULL , 'images/categories/house.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (51 , 48 , '0,47,48,' , 'Mystery & Thrillers' , 3 , 1 , NULL , NULL , NULL , 'images/categories/theatre.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (52 , 48 , '0,47,48,' , 'Travel' , 4 , 1 , NULL , NULL , NULL , 'images/categories/travel.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (53 , 48 , '0,47,48,' , 'Arts & Photography  ' , 5 , 1 , NULL , NULL , NULL , 'images/categories/cameras.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (54 , 47 , '0,47,' , 'DVD' , 2 , 1 , NULL , 'Buy DVD\'s with Amazon.com' , NULL , 'images/categories/dvd.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (55 , 54 , '0,47,54,' , 'Comedy' , 1 , 1 , NULL , NULL , NULL , 'images/categories/dvd.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_categories (category_id,parent_category_id,category_path,category_name,category_order,is_showing,show_sub_products,short_description,full_description,image,image_alt,image_large,image_large_alt,list_template,details_template,meta_title,meta_keywords,meta_description,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (56 , 54 , '0,47,54,' , 'African American Cinema' , 2 , 1 , NULL , NULL , NULL , 'images/categories/dvd.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;


INSERT INTO va_cc_expiry_years (expiry_year) VALUES (2006 ) ;
INSERT INTO va_cc_expiry_years (expiry_year) VALUES (2007 ) ;
INSERT INTO va_cc_expiry_years (expiry_year) VALUES (2008 ) ;
INSERT INTO va_cc_expiry_years (expiry_year) VALUES (2009 ) ;
INSERT INTO va_cc_expiry_years (expiry_year) VALUES (2010 ) ;
INSERT INTO va_cc_expiry_years (expiry_year) VALUES (2011 ) ;
INSERT INTO va_cc_expiry_years (expiry_year) VALUES (2012 ) ;


INSERT INTO va_cc_start_years (start_year) VALUES (2000 ) ;
INSERT INTO va_cc_start_years (start_year) VALUES (2001 ) ;
INSERT INTO va_cc_start_years (start_year) VALUES (2002 ) ;
INSERT INTO va_cc_start_years (start_year) VALUES (2003 ) ;
INSERT INTO va_cc_start_years (start_year) VALUES (2004 ) ;
INSERT INTO va_cc_start_years (start_year) VALUES (2005 ) ;
INSERT INTO va_cc_start_years (start_year) VALUES (2006 ) ;


INSERT INTO va_change_types (type_id,type_name) VALUES (1 , 'Bug' ) ;
INSERT INTO va_change_types (type_id,type_name) VALUES (2 , 'New Feature' ) ;




INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AD' , '020' , 3 , 'Andorra' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AE' , '784' , 3 , 'United Arab Emirates' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AF' , '004' , 3 , 'Afghanistan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AG' , '028' , 3 , 'Antigua and Barbuda' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AI' , '660' , 3 , 'Anguilla' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AL' , '008' , 3 , 'Albania' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AM' , '051' , 3 , 'Armenia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AN' , '530' , 2 , 'Netherlands Antilles' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AO' , '024' , 3 , 'Angola' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AQ' , '010' , 3 , 'Antarctica' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AR' , '032' , 3 , 'Argentina' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AS' , '016' , 3 , 'American Samoa' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AT' , '040' , 2 , 'Austria EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AU' , '036' , 3 , 'Australia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AW' , '533' , 3 , 'Aruba' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AX' , '248' , 3 , 'Aland Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('AZ' , '031' , 3 , 'Azerbaijan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BA' , '070' , 3 , 'Bosnia and Herzegowina' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BB' , '052' , 3 , 'Barbados' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BD' , '050' , 3 , 'Bangladesh' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BE' , '056' , 2 , 'Belgium EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BF' , '854' , 3 , 'Burkina Faso' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BG' , '100' , 3 , 'Bulgaria' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BH' , '048' , 3 , 'Bahrain' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BI' , '108' , 3 , 'Burundi' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BJ' , '204' , 3 , 'Benin' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BM' , '060' , 3 , 'Bermuda' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BN' , '096' , 3 , 'Brunei Darussalam' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BO' , '068' , 3 , 'Bolivia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BR' , '076' , 3 , 'Brazil' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BS' , '044' , 3 , 'Bahamas' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BT' , '064' , 3 , 'Bhutan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BV' , '074' , 3 , 'Bouvet Island' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BW' , '072' , 3 , 'Botswana' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BY' , '112' , 3 , 'Belarus' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('BZ' , '084' , 3 , 'Belize' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CA' , '124' , 3 , 'Canada' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CC' , '166' , 3 , 'Cocos (Keeling) Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CD' , '180' , 3 , 'Congo, the Democratic Republic of the' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CF' , '140' , 3 , 'Central African Republic' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CG' , '178' , 3 , 'Congo' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CH' , '756' , 3 , 'Switzerland' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CI' , '384' , 3 , 'Cote D\'Ivoire' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CK' , '184' , 3 , 'Cook Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CL' , '152' , 3 , 'Chile' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CM' , '120' , 3 , 'Cameroon' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CN' , '156' , 3 , 'China' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CO' , '170' , 3 , 'Colombia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CR' , '188' , 3 , 'Costa Rica' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CS' , '891' , 3 , 'Serbia and Montenegro' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CU' , '192' , 3 , 'Cuba' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CV' , '132' , 3 , 'Cape Verde' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CX' , '162' , 3 , 'Christmas Island' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CY' , '196' , 2 , 'Cyprus EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('CZ' , '203' , 2 , 'Czech Republic EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('DE' , '276' , 2 , 'Germany EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('DJ' , '262' , 3 , 'Djibouti' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('DK' , '208' , 2 , 'Denmark EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('DM' , '212' , 3 , 'Dominica' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('DO' , '214' , 3 , 'Dominican Republic' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('DZ' , '012' , 3 , 'Algeria' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('EC' , '218' , 3 , 'Ecuador' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('EE' , '233' , 2 , 'Estonia EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('EG' , '818' , 3 , 'Egypt' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('EH' , '732' , 3 , 'Western Sahara' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('ER' , '232' , 3 , 'Eritrea' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('ES' , '724' , 2 , 'Spain EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('ET' , '231' , 3 , 'Ethiopia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('FI' , '246' , 2 , 'Finland EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('FJ' , '242' , 3 , 'Fiji' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('FK' , '238' , 3 , 'Falkland Islands (Malvinas)' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('FM' , '583' , 3 , 'Micronesia, Federated States of' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('FO' , '234' , 3 , 'Faroe Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('FR' , '250' , 2 , 'France EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('FX' , '249' , 3 , 'France, Metropolitan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GA' , '266' , 3 , 'Gabon' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GB' , '826' , 1 , 'United Kingdom' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GD' , '308' , 3 , 'Grenada' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GE' , '268' , 3 , 'Georgia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GF' , '254' , 3 , 'French Guiana' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GG' , '831' , 3 , 'Guernsey' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GH' , '288' , 3 , 'Ghana' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GI' , '292' , 3 , 'Gibraltar' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GL' , '304' , 3 , 'Greenland' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GM' , '270' , 3 , 'Gambia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GN' , '324' , 3 , 'Guinea' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GP' , '312' , 3 , 'Guadeloupe' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GQ' , '226' , 3 , 'Equatorial Guinea' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GR' , '300' , 2 , 'Greece EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GS' , '239' , 3 , 'South Georgia and the South Sandwich Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GT' , '320' , 3 , 'Guatemala' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GU' , '316' , 3 , 'Guam' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GW' , '624' , 3 , 'Guinea-Bissau' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('GY' , '328' , 3 , 'Guyana' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('HK' , '344' , 3 , 'Hong Kong' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('HM' , '334' , 3 , 'Heard and Mc Donald Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('HN' , '340' , 3 , 'Honduras' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('HR' , '191' , 3 , 'Croatia (local name: Hrvatska)' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('HT' , '332' , 3 , 'Haiti' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('HU' , '348' , 2 , 'Hungary EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('ID' , '360' , 3 , 'Indonesia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('IE' , '372' , 2 , 'Ireland EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('IL' , '376' , 3 , 'Israel' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('IM' , '833' , 3 , 'Isle of Man' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('IN' , '356' , 3 , 'India' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('IO' , '086' , 3 , 'British Indian Ocean Territory' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('IQ' , '368' , 3 , 'Iraq' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('IR' , '364' , 3 , 'Iran (Islamic Republic of)' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('IS' , '352' , 3 , 'Iceland' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('IT' , '380' , 2 , 'Italy EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('JE' , '832' , 3 , 'Jersey' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('JM' , '388' , 3 , 'Jamaica' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('JO' , '400' , 3 , 'Jordan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('JP' , '392' , 3 , 'Japan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('KE' , '404' , 3 , 'Kenya' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('KG' , '417' , 3 , 'Kyrgyzstan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('KH' , '116' , 3 , 'Cambodia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('KI' , '296' , 3 , 'Kiribati' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('KM' , '174' , 3 , 'Comoros' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('KN' , '659' , 3 , 'Saint Kitts and Nevis' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('KP' , '408' , 3 , 'Korea, Democratic People\'s Republic of' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('KR' , '410' , 3 , 'Korea, Republic of' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('KW' , '414' , 3 , 'Kuwait' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('KY' , '136' , 3 , 'Cayman Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('KZ' , '398' , 3 , 'Kazakhstan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('LA' , '418' , 3 , 'Lao People\'s Democratic Republic' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('LB' , '422' , 3 , 'Lebanon' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('LC' , '662' , 3 , 'Saint Lucia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('LI' , '438' , 3 , 'Liechtenstein' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('LK' , '144' , 3 , 'Sri Lanka' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('LR' , '430' , 3 , 'Liberia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('LS' , '426' , 3 , 'Lesotho' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('LT' , '440' , 2 , 'Lithuania EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('LU' , '442' , 2 , 'Luxembourg EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('LV' , '428' , 2 , 'Latvia EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('LY' , '434' , 3 , 'Libyan Arab Jamahiriya' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MA' , '504' , 3 , 'Morocco' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MC' , '492' , 2 , 'Monaco' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MD' , '498' , 3 , 'Moldova, Republic of' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MG' , '450' , 3 , 'Madagascar' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MH' , '584' , 3 , 'Marshall Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MK' , '807' , 3 , 'Macedonia, the former Yugoslav Republic of' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('ML' , '466' , 3 , 'Mali' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MM' , '104' , 3 , 'Myanmar' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MN' , '496' , 3 , 'Mongolia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MO' , '446' , 3 , 'Macau' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MP' , '580' , 3 , 'Northern Mariana Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MQ' , '474' , 3 , 'Martinique' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MR' , '478' , 3 , 'Mauritania' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MS' , '500' , 3 , 'Montserrat' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MT' , '470' , 2 , 'Malta EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MU' , '480' , 3 , 'Mauritius' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MV' , '462' , 3 , 'Maldives' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MW' , '454' , 3 , 'Malawi' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MX' , '484' , 3 , 'Mexico' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MY' , '458' , 3 , 'Malaysia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('MZ' , '508' , 3 , 'Mozambique' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NA' , '516' , 3 , 'Namibia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NC' , '540' , 3 , 'New Caledonia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NE' , '562' , 3 , 'Niger' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NF' , '574' , 3 , 'Norfolk Island' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NG' , '566' , 3 , 'Nigeria' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NI' , '558' , 3 , 'Nicaragua' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NL' , '528' , 2 , 'Netherlands EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NO' , '578' , 3 , 'Norway' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NP' , '524' , 3 , 'Nepal' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NR' , '520' , 3 , 'Nauru' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NU' , '570' , 3 , 'Niue' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('NZ' , '554' , 3 , 'New Zealand' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('OM' , '512' , 3 , 'Oman' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PA' , '591' , 3 , 'Panama' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PE' , '604' , 3 , 'Peru' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PF' , '258' , 3 , 'French Polynesia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PG' , '598' , 3 , 'Papua New Guinea' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PH' , '608' , 3 , 'Philippines' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PK' , '586' , 3 , 'Pakistan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PL' , '616' , 2 , 'Poland EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PM' , '666' , 3 , 'St. Pierre and Miquelon' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PN' , '612' , 3 , 'Pitcairn' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PR' , '630' , 3 , 'Puerto Rico' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PS' , '275' , 3 , 'Palestinian Territory, Occupied' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PT' , '620' , 2 , 'Portugal EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PW' , '585' , 3 , 'Palau' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('PY' , '600' , 3 , 'Paraguay' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('QA' , '634' , 3 , 'Qatar' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('RE' , '638' , 3 , 'Reunion' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('RO' , '642' , 3 , 'Romania' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('RU' , '643' , 3 , 'Russian Federation' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('RW' , '646' , 3 , 'Rwanda' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SA' , '682' , 3 , 'Saudi Arabia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SB' , '090' , 3 , 'Solomon Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SC' , '690' , 3 , 'Seychelles' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SD' , '736' , 3 , 'Sudan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SE' , '752' , 2 , 'Sweden EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SG' , '702' , 3 , 'Singapore' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SH' , '654' , 3 , 'St. Helena' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SI' , '705' , 2 , 'Slovenia EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SJ' , '744' , 3 , 'Svalbard and Jan Mayen Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SK' , '703' , 2 , 'Slovakia (Slovak Republic) EU' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SL' , '694' , 3 , 'Sierra Leone' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SM' , '674' , 3 , 'San Marino' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SN' , '686' , 3 , 'Senegal' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SO' , '706' , 3 , 'Somalia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SR' , '740' , 3 , 'Suriname' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('ST' , '678' , 3 , 'Sao Tome and Principe' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SV' , '222' , 3 , 'El Salvador' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SY' , '760' , 3 , 'Syrian Arab Republic' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('SZ' , '748' , 3 , 'Swaziland' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TC' , '796' , 3 , 'Turks and Caicos Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TD' , '148' , 3 , 'Chad' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TF' , '260' , 3 , 'French Southern Territories' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TG' , '768' , 3 , 'Togo' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TH' , '764' , 3 , 'Thailand' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TJ' , '762' , 3 , 'Tajikistan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TK' , '772' , 3 , 'Tokelau' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TL' , '626' , 3 , 'Timor-Leste' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TM' , '795' , 3 , 'Turkmenistan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TN' , '788' , 3 , 'Tunisia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TO' , '776' , 3 , 'Tonga' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TR' , '792' , 3 , 'Turkey' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TT' , '780' , 3 , 'Trinidad and Tobago' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TV' , '798' , 3 , 'Tuvalu' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TW' , '158' , 3 , 'Taiwan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('TZ' , '834' , 3 , 'Tanzania, United Republic of' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('UA' , '804' , 3 , 'Ukraine' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('UG' , '800' , 3 , 'Uganda' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('UM' , '581' , 3 , 'United States Minor Outlying Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('US' , '840' , 1 , 'United States' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('UY' , '858' , 3 , 'Uruguay' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('UZ' , '860' , 3 , 'Uzbekistan' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('VA' , '336' , 3 , 'Vatican City State (Holy See)' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('VC' , '670' , 3 , 'Saint Vincent and the Grenadines' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('VE' , '862' , 3 , 'Venezuela' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('VG' , '092' , 3 , 'Virgin Islands (British)' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('VI' , '850' , 3 , 'Virgin Islands (U.S.)' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('VN' , '704' , 3 , 'Vietnam' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('VU' , '548' , 3 , 'Vanuatu' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('WF' , '876' , 3 , 'Wallis And Futuna Islands' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('WS' , '882' , 3 , 'Samoa' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('YE' , '887' , 3 , 'Yemen' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('YT' , '175' , 3 , 'Mayotte' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('ZA' , '710' , 3 , 'South Africa' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('ZM' , '894' , 3 , 'Zambia' , NULL ) ;
INSERT INTO va_countries (country_code,country_iso_number,country_order,country_name,currency_code) VALUES ('ZW' , '716' , 3 , 'Zimbabwe' , NULL ) ;




INSERT INTO va_credit_cards (credit_card_id,credit_card_code,credit_card_name) VALUES (1 , 'Visa' , 'VISA' ) ;
INSERT INTO va_credit_cards (credit_card_id,credit_card_code,credit_card_name) VALUES (2 , 'Visa' , 'VISA Electron' ) ;
INSERT INTO va_credit_cards (credit_card_id,credit_card_code,credit_card_name) VALUES (3 , 'MC' , 'Mastercard' ) ;
INSERT INTO va_credit_cards (credit_card_id,credit_card_code,credit_card_name) VALUES (4 , 'AMEX' , 'American Express' ) ;
INSERT INTO va_credit_cards (credit_card_id,credit_card_code,credit_card_name) VALUES (5 , 'Switch' , 'Switch' ) ;
INSERT INTO va_credit_cards (credit_card_id,credit_card_code,credit_card_name) VALUES (6 , 'Solo' , 'Solo' ) ;
INSERT INTO va_credit_cards (credit_card_id,credit_card_code,credit_card_name) VALUES (7 , 'JCB' , 'JCB' ) ;
INSERT INTO va_credit_cards (credit_card_id,credit_card_code,credit_card_name) VALUES (8 , 'Delta' , 'Delta' ) ;
INSERT INTO va_credit_cards (credit_card_id,credit_card_code,credit_card_name) VALUES (9 , 'Eurocard' , 'Eurocard' ) ;
INSERT INTO va_credit_cards (credit_card_id,credit_card_code,credit_card_name) VALUES (10 , 'discover' , 'Discover' ) ;


INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (1 , 1 , 'USD' , '840' , 'American Dollar' , 'images/flags/us.gif' , 1 , '$' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (2 , 0 , 'AUD' , '036' , 'Australian Dollar' , 'images/flags/au.gif' , 1.3245 , '$' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (3 , 0 , 'GBP' , '826' , 'British Pound' , 'images/flags/uk.gif' , 0.548065 , '' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (4 , 0 , 'CAD' , '124' , 'Canadian Dollar' , 'images/flags/ca.gif' , 1.2627 , '$' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (5 , 0 , 'DKK' , '208' , 'Danish Krone' , 'images/flags/dk.gif' , 5.9324 , 'DKK' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (6 , 0 , 'EUR' , '978' , 'Euro' , 'images/flags/eu.gif' , 0.796622 , '' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (7 , 0 , 'HKD' , '344' , 'Hong Kong Dollar' , 'images/flags/hk.gif' , 7.7905 , 'HK$' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (8 , 0 , 'HUF' , '348' , 'Hungarian Forint' , 'images/flags/hu.gif' , 190.54 , 'HUF' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (9 , 0 , 'ISK' , '352' , 'Iceland Krona' , 'images/flags/is.gif' , 61.15 , 'ISK' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (10 , 0 , 'ILS' , '376' , 'Israeli Shekel' , 'images/flags/il.gif' , 4.366 , 'ILS' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (11 , 0 , 'JPY' , '392' , 'Japanese Yen' , 'images/flags/jp.gif' , 108.17 , 'JPY' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (12 , 0 , 'NZD' , '554' , 'New Zealand Dollar' , 'images/flags/nz.gif' , 1.41203 , '$' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (13 , 0 , 'NOK' , '578' , 'Norwegian Kroner' , 'images/flags/no.gif' , 6.4656 , 'NOK' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (14 , 0 , 'SGD' , '702' , 'Singapore Dollar' , 'images/flags/sg.gif' , 1.6635 , 'SG$' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (15 , 0 , 'ZAR' , '710' , 'South African Rand' , 'images/flags/za.gif' , 6.5415 , 'ZAR' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (16 , 0 , 'SEK' , '752' , 'Swedish Krona SEK' , 'images/flags/se.gif' , 7.3069 , 'SEK' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (17 , 0 , 'CHF' , '756' , 'Swiss Franc' , 'images/flags/ch.gif' , 1.2335 , 'CHF' , NULL ) ;
INSERT INTO va_currencies (currency_id,is_default,currency_code,currency_value,currency_title,currency_image,exchange_rate,symbol_left,symbol_right) VALUES (18 , 0 , 'TWD' , '901' , 'Taiwan Dollar' , 'images/flags/tw.gif' , 31.47 , 'TW$' , NULL ) ;


INSERT INTO va_custom_blocks (block_id,block_name,block_notes,block_title,block_path,block_desc) VALUES (2 , 'Custom' , NULL , 'Custom Block' , NULL , 'Feel free to add any text here' ) ;
INSERT INTO va_custom_blocks (block_id,block_name,block_notes,block_title,block_path,block_desc) VALUES (3 , 'Categories' , NULL , 'All categories' , NULL , '<br>Asia\r\n<br>Europe\r\n<br>U.S.\r\n<br>WorldWorld \r\n<br>Business\r\n<br>Technology\r\n<br>Science & Space\r\n<br>Entertainment\r\n<br>World Sport\r\n<br>Travel\r\n<br>Executive\r\n<br>Education\r\n<br>Weather\r\n<br>Special Reports\r\n<br>Video\r\n\r\n' ) ;










INSERT INTO va_features_groups (group_id,group_order,group_name) VALUES (1 , 1 , 'General' ) ;
INSERT INTO va_features_groups (group_id,group_order,group_name) VALUES (2 , 2 , 'Sizes' ) ;
INSERT INTO va_features_groups (group_id,group_order,group_name) VALUES (3 , 3 , 'Accessories' ) ;




INSERT INTO va_forum_categories (category_id,category_name,category_order,short_description,full_description,allowed_view) VALUES (1 , 'General' , 1 , 'General category' , 'General category' , 1 ) ;


INSERT INTO va_forum_list (forum_id,category_id,forum_name,forum_order,short_description,full_description,small_image,large_image,date_added,threads_number,messages_number,last_post_added,last_post_user_id,last_post_thread_id,allowed_view,allowed_view_topics,allowed_view_topic,allowed_post_topics,allowed_post_replies) VALUES (1 , 1 , 'Forum' , 1 , NULL , NULL , '' , '' , '2006-05-23 00:00:00' , 0 , 0 , '2006-05-23 00:00:00' , 0 , 0 , 1 , 1 , 1 , 1 , 1 ) ;






INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_images' , 'image_large_height' , '300' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_images' , 'image_large_size' , '50000' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_images' , 'image_large_width' , '300' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_images' , 'image_small_height' , '100' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_images' , 'image_small_size' , '16000' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_images' , 'image_small_width' , '100' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_images' , 'images_number' , '4' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'admin_message' , 'ID: {item_id}\r\nTitle: {item_title}\r\nURL: {site_url}ads_details.php?item_id={item_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'admin_subject' , 'Ad modifications #{item_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'user_message' , 'Dear {seller_name},\r\n\r\nOnce our editors have reviewed and approved your Ad we will post it on our web site.\r\n\r\nThank you.\r\nCustomer Services\r\n' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_notify' , 'user_subject' , 'Your ad \'{item_title}\' was received.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'admin_message' , 'Title: {item_title} \r\nPrice: {offer_price}\r\nUser ID: {user_id}\r\nName: {user_name}\r\nEmail: {user_email}\r\n--------------------\r\n{offer_message}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'admin_subject' , 'New offer for Ad #{item_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'user_message' , 'Hi {seller_name},\r\n\r\nYou have received an offer for the item listed in your ad: {item_title}\r\n\r\nThey have offered {offer_price} and they left you this message: \r\n{offer_message}\r\n\r\nTo reply click here:\r\nReply To: {user_email}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_request' , 'user_subject' , 'New offer for you ad: {item_title}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_search' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_search' , 'price' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_search' , 'search_for' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_search' , 'search_in' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_search' , 'search_in_category' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_search' , 'user' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_search' , 'user_type_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {item_title} at this site {item_url}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {item_title} at {item_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('ads_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_1_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_1_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_1_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_1_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_1_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_1_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_1_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_1_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_1_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_3_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_3_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_3_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_3_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_3_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_3_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_3_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_3_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_3_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_30_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_30_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_30_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_30_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_30_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_30_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_30_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_30_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_30_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_4_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_4_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_4_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_4_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_4_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_4_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_4_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_4_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_4_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_5_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_5_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_5_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_5_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_5_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_5_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_5_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_5_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_5_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_6_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {article_title} at this site {article_url}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_6_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_6_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_6_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_6_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_6_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_6_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {article_title} at {article_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_6_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('articles_6_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'show_cc_start_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_1' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_10' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_12' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_16' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'admin_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'admin_message_type' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'admin_subject' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'cc_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'cc_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'cc_number_split' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'cc_type_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'show_cc_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'show_cc_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'show_cc_security_code' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'show_cc_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_17' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_number_split' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'cc_type_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'show_cc_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_18' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last}\r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'cc_type_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'show_cc_start_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'show_cc_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_19' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'admin_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'admin_subject' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'cc_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'cc_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'cc_type_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'show_cc_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'show_cc_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'show_cc_security_code' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'show_cc_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_2' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_message' , 'First Name: {cc_first_name}\r\nLast Name: {cc_last_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_first_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_last_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'show_cc_first_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'show_cc_last_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'show_cc_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_22' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'admin_message' , 'Name: {cc_first_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_code_security' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_number_security' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_security_code_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_23' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n   Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_code_security' , '2' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_number_security' , '2' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_security_code_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_25' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Expiry Date: {cc_expiry_date}\r\n          Card Type: {cc_type}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_number_split' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_security_code_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_26' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_message' , 'First Name: {cc_first_name}\r\nLast Name: {cc_last_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_security_code_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'show_cc_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_27' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'admin_subject' , 'Credit Card Information for Oder No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'show_cc_security_code' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_28' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'admin_subject' , 'Credit Card Information for Oder No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_security_code_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'cc_type_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_29' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'admin_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'admin_subject' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'cc_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'cc_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'cc_number_split' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'cc_type_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'show_cc_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'show_cc_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'show_cc_security_code' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'show_cc_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_3' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'admin_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'admin_subject' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'cc_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'cc_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'cc_type_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'show_cc_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'show_cc_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'show_cc_security_code' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'show_cc_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_4' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'admin_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'admin_subject' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'cc_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'cc_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'cc_type_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'show_cc_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'show_cc_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'show_cc_security_code' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'show_cc_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_5' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'admin_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'admin_subject' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'cc_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'cc_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'cc_type_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'show_cc_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'show_cc_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'show_cc_security_code' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'show_cc_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_6' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_7' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_message' , 'Name of Cardholder: {cc_name}\r\nLast 4 digit of CC: {cc_number_last} \r\n        Start Date: {cc_start_date}\r\n       Expiry Date: {cc_expiry_date}\r\n         Card Type: {cc_type}\r\n      Issue Number: {cc_issue_number}\r\n     Security Code: {cc_security_code}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_message_type' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_sms_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'admin_subject' , 'Credit Card Information for Order No: {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_code_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_expiry_date_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_number_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_number_security' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'cc_type_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'show_cc_expiry_date' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'show_cc_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'show_cc_issue_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'show_cc_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'show_cc_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'show_cc_number' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'show_cc_security_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'show_cc_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_8' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'admin_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'admin_subject' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'cc_expiry_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'cc_issue_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'cc_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'cc_number_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'cc_number_split' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'cc_security_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'cc_start_date_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'cc_type_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'pay_without_cc_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'show_cc_expiry_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'show_cc_issue_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'show_cc_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'show_cc_number' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'show_cc_security_code' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'show_cc_start_date' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'show_cc_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('credit_card_info_9' , 'show_pay_without_cc' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'links_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'links_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'links_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'links_message' , 'To download product click on link below:\r\n{links}\r\n\r\nThanks for purchase,\r\nSales Team.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'links_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'links_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'links_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'links_subject' , 'Links for your Order # {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'max_downloads' , '3' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'serials_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'serials_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'serials_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'serials_message' , 'To activate your product use serial numbers below:\r\n{serials}\r\n\r\nThanks for purchase,\r\nSales Team.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'serials_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'serials_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'serials_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'serials_subject' , 'Serial Numbers for your Order # {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'vouchers_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'vouchers_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'vouchers_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'vouchers_message' , 'Here the list of your gift vouhers:\r\n{vouchers}\r\n\r\nThanks for purchase,\r\nSales Team.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'vouchers_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'vouchers_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'vouchers_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('download_info' , 'vouchers_subject' , 'Gift Vouchers for your Order # {order_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forgotten_password' , 'md5_message' , 'Hi,\r\n\r\nTo reset your password please use the link below:\r\n\r\n{reset_password_url}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forgotten_password' , 'md5_subject' , 'Password reset instructions' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forgotten_password' , 'md5_time_limit' , '360' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forgotten_password' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forgotten_password' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forgotten_password' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forgotten_password' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forgotten_password' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forgotten_password' , 'user_message' , 'Hi,\r\n\r\nHere are the details you requested:\r\n\r\nLogin: {login}\r\nPassword: {password}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forgotten_password' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forgotten_password' , 'user_subject' , 'Your login and password details' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'admin_message' , 'Topic descrition:\r\n{topic_description}\r\n\r\nMessage:\r\n{message}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'admin_subject' , 'New post at forum :: {topic}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'reply_form' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'sort_messages' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'topic_information' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'use_random_image' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'user_info' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'user_message' , 'Topic descrition:\r\n{topic_description}\r\n\r\nMessage:\r\n{message}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'user_no_image' , 'images/no_photo.gif' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'user_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('forum' , 'user_subject' , 'New post at your topic :: {topic}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'admin_email' , 'admin@yoursite.com' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'approve_review' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'country_code' , 'GB' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'html_below_footer' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'html_editor' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'html_on_index' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'index_description' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'index_keywords' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'index_title' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'layout_id' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'min_rating' , '4' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'min_votes' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'password_encrypt' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'reviews_per_page' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'secure_order_profile' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'secure_payments' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'secure_url' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'secure_user_profile' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'site_url' , 'http://localhost/' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'state_code' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('global' , 'weight_measure' , 'lb' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_confirmation' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_1' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_10' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_11' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_12' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'pending_message' , 'Your transaction wasn\'t finished and waiting for approval.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'pending_status_id' , '6' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_13' , 'validation_php_lib' , './payments/paypal_pdt.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'pending_message' , 'Your transaction wasn\'t finished and waiting for approval.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'pending_status_id' , '6' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_14' , 'validation_php_lib' , './payments/paymate_express.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_15' , 'validation_php_lib' , './payments/protx_form_check.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_16' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'pending_message' , 'Your transaction is still processing. Please wait for approval.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'pending_status_id' , '6' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_17' , 'validation_php_lib' , './payments/egold_check.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_18' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_19' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_2' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_20' , 'validation_php_lib' , './payments/ideal_check.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'pending_message' , 'Your transaction wasn\'t finished and waiting for approval.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'pending_status_id' , '6' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_21' , 'validation_php_lib' , './payments/paypal_payment.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_22' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'pending_message' , 'Your transaction wasn\'t finished and waiting for approval.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_23' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'pending_message' , 'Your transaction wasn\'t finished and waiting for approval.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'pending_status_id' , '6' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_24' , 'validation_php_lib' , './payments/epqd_cpi_check.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_sms_failure' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_sms_pending' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_sms_success' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_sms_failure' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_sms_pending' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_sms_success' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_25' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_sms_failure' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_sms_pending' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_sms_success' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_sms_failure' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_sms_pending' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_sms_success' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_26' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_sms_failure' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_sms_pending' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_sms_success' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_sms_failure' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_sms_pending' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_sms_success' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_27' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_sms_failure' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_sms_pending' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_sms_success' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'pending_message' , 'Your transaction wasn\'t finished and waiting for approval.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'pending_status_id' , '6' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_sms_failure' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_sms_pending' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_sms_success' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_28' , 'validation_php_lib' , './payments/proxypay_check.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_sms_failure' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_sms_pending' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_sms_success' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'pending_message' , 'Your transaction wasn\'t finished and waiting for approval.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_sms_failure' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_sms_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_sms_originator' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_sms_pending' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_sms_recipient' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_sms_success' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_29' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'pending_message' , 'Your transaction wasn\'t finished and waiting for approval.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'pending_status_id' , '6' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_3' , 'validation_php_lib' , './payments/authorize_check.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_4' , 'validation_php_lib' , './payments/worldpay_check.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'pending_message' , 'Your transaction wasn\'t finished and waiting for approval.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'pending_status_id' , '6' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_5' , 'validation_php_lib' , './payments/2checkout.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'failure_status_id' , '10' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'is_validation' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'pending_message' , 'Your transaction wasn\'t finished and waiting for approval.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'pending_status_id' , '6' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'success_status_id' , '9' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_6' , 'validation_php_lib' , './payments/paypal_pdt.php' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_7' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_8' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'admin_failure_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'admin_message' , 'Order Info\r\n-----------------------\r\nOrder Number: {order_id}\r\nGoods Value: {goods_total}\r\nTotal Order Amount: {order_total}\r\n\r\nMessages\r\n-----------------------\r\nError message: {error_message}\r\nPending message: {pending_message}\r\n\r\nShopping Cart Info\r\n-----------------------\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'admin_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'admin_subject' , 'Order #{order_id} was submitted.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'failure_message' , 'An error: "{error_message}" occurred while processing your order. We are sorry for any inconvenient caused.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'failure_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'is_validation' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'pending_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'pending_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'success_message' , '<p>Thank You for Purchase!</p>\r\n\r\n<p align="justify">\r\nYou\'ll receive an immediate notification by email to tell you that we\'ve got your order and we\'ll confirm it with a response from our sales department within the next few days or hours. In the meantime if you have any queries or require any more information you can contact us anytime by our contact emails and phone numbers.\r\n</p>\r\n\r\n<p align="right">Sales Department</p>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'success_status_id' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'user_failure_notify' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'user_message' , 'Thank you for your order received today at {site_url}.\r\n\r\nYour reference number is {order_id}.\r\n\r\nThese are the products you have ordered:\r\n{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'user_pending_notify' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'user_subject' , 'Order Confirmation' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_final_9' , 'validation_php_lib' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'address1_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'address2_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'admin_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'admin_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'admin_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'admin_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'admin_message' , '{basket}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'admin_subject' , 'New order #{order_id} submitted' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'cell_phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'city_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'company_id_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'company_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'country_code_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'daytime_phone_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_address1_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_address2_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_cell_phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_city_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_company_id_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_company_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_country_code_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_daytime_phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_email_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_evening_phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_fax_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_province_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_state_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'delivery_zip_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'email_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'evening_phone_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'fax_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'intro_text' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'province_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_address1' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_address2' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_cell_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_city' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_company_id' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_company_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_country_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_daytime_phone' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_address1' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_address2' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_cell_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_city' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_company_id' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_company_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_country_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_daytime_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_email' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_evening_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_fax' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_province' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_state_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_delivery_zip' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_email' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_evening_phone' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_fax' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_province' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_state_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'show_zip' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'state_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'user_message' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'user_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'user_subject' , '{name} your contact information was saved.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('order_info' , 'zip_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('printable' , 'invoice_footer' , 'Viart Limited, Ellerbeck Court, Stokesley Business Park, North Yorkshire, TS9 5PT, England' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('printable' , 'invoice_header' , 'Viart Limited\r\nEllerbeck Court\r\nStokesley Business Park\r\nNorth Yorkshire\r\nTS9 5PT\r\nEngland' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('printable' , 'invoice_logo' , '../images/silver/logo.jpg' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('printable' , 'packing_footer' , 'Viart Limited, Ellerbeck Court, Stokesley Business Park, North Yorkshire, TS9 5PT, England' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('printable' , 'packing_header' , 'Viart Limited\r\nEllerbeck Court\r\nStokesley Business Park\r\nNorth Yorkshire\r\nTS9 5PT\r\nEngland' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('printable' , 'packing_logo' , '../images/silver/logo.jpg' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'big_image_max_height' , '300' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'big_image_max_width' , '300' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'confirm_add' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'coupons_enable' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'display_products' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'froogle_tax' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'hide_add_details' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'hide_add_list' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'hide_checkout_details' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'hide_checkout_list' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'hide_view_details' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'hide_view_list' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'hide_weight_details' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'logout_cart_clear' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'orders_currency' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'product_code_basket' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'product_code_checkout' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'product_code_details' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'product_code_list' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'product_no_image' , 'images/no_image.gif' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'product_quantity' , 'LISTBOX' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'products_description' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'products_keywords' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'products_title' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'quantity_control' , 'LISTBOX' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'redirect_to_cart' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'resize_big_image' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'resize_small_image' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'resize_super_image' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'reviews_availability' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'small_image_max_height' , '100' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'small_image_max_width' , '100' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'super_image_max_height' , '768' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'super_image_max_width' , '1024' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'tax_note' , 'incl. VAT' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'tax_note_excl' , 'excl. VAT' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'tax_prices' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products' , 'user_registration' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products_tell_friend' , 'default_comment' , 'Hi {friend_name} - I thought you might be interested in seeing the {item_name} at this site {item_url}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products_tell_friend' , 'user_mail_bcc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products_tell_friend' , 'user_mail_cc' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products_tell_friend' , 'user_mail_from' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products_tell_friend' , 'user_mail_reply_to' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products_tell_friend' , 'user_mail_return_path' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products_tell_friend' , 'user_message' , 'Thought you might be interested in seeing the {item_name} at {item_url}\r\n\r\n{user_name} left you a note:\r\n{user_comment}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products_tell_friend' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('products_tell_friend' , 'user_subject' , 'You were invited by {user_name} to visit site at {site_url}!' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('search' , 'manufacturer' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('search' , 'price' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('search' , 'search_for' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('search' , 'search_in' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('search' , 'search_in_category' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('search' , 'weight' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'admin_message' , 'Request Description:\r\n{description}\r\n\r\nReply message:\r\n{message_text}\r\n\r\n{site_url}admin/admin_support_reply.php?support_id={support_id}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'admin_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'admin_subject' , 'Support Request :: {summary}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'intro_text' , 'Dont hesitate to contact us if you have any questions or problems. Our Support Team try help you with your request.' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'knowledge_article_status' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'knowledge_category' , '30' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'user_message' , '{message_text}\r\n\r\nUse following URL to reply\r\n{support_url}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'user_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'user_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('support' , 'user_subject' , 'Support Request :: {summary}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'address1_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'address2_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'admin_email' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'admin_message' , 'Name: {name}\r\nDate: {registration_date}' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'admin_message_type' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'admin_notification' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'admin_subject' , 'New user was registered' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'cc_emails' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'cell_phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'city_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'company_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'country_code_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'daytime_phone_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_address1_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_address2_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_cell_phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_city_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_company_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_country_code_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_daytime_phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_email_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_evening_phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_fax_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_province_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_state_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'delivery_zip_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'email_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'evening_phone_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'fax_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'first_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'intro_text_new' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'intro_text_registered' , NULL ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'last_name_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'name_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'phone_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'province_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_address1' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_address2' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_cell_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_city' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_company_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_country_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_daytime_phone' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_address1' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_address2' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_cell_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_city' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_company_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_country_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_daytime_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_email' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_evening_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_fax' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_province' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_state_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_delivery_zip' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_email' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_evening_phone' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_fax' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_first_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_last_name' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_name' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_phone' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_province' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_state_code' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'show_zip' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'state_code_required' , '0' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'user_message' , 'Your login is <b>{login}</b> and password is <b>{password}</b><br>\r\n<br><br>\r\nYou can visit our site at any time at following URL: <a target="_blank" href="{site_url}">{site_url}</a>' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'user_message_type' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'user_notification' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'user_subject' , 'Dear {name}, you were successfully registered' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('user_profile_1' , 'zip_required' , '1' ) ;
INSERT INTO va_global_settings (setting_type,setting_name,setting_value) VALUES ('version' , 'number' , '2.7.1' ) ;


INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (1 , 2 , 0 , NULL , 'MENU_HOME' , 'index.php' , 'images/curved/menu-main.gif' , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (2 , 2 , 0 , NULL , 'MENU_PRODUCTS' , 'products.php' , 'images/curved/menu-products.gif' , NULL , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (3 , 2 , 0 , NULL , 'MENU_BASKET' , 'basket.php' , 'images/curved/menu-basket.gif' , NULL , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (4 , 2 , 0 , NULL , 'MENU_MYPROFILE' , 'user_profile.php' , 'images/curved/menu-registration.gif' , NULL , 4 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (5 , 2 , 0 , NULL , 'MENU_ADMIN' , 'admin/admin.php' , 'images/curved/menu-admin.gif' , NULL , 5 , 1 , 0 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (6 , 2 , 0 , NULL , 'MENU_EVENTS' , 'articles.php?category_id=6' , 'images/curved/menu-events.gif' , NULL , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (7 , 2 , 0 , NULL , NULL , 'index.php' , 'images/curved/logo_os.gif' , NULL , 7 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (8 , 2 , 0 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , 'images/curved/menu-news.gif' , NULL , 8 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (9 , 2 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , 'images/curved/menu-user_home.gif' , NULL , 9 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (10 , 2 , 0 , NULL , 'MENU_SUPPORT' , 'support.php' , 'images/curved/menu-support.gif' , NULL , 10 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (11 , 2 , 0 , NULL , 'MENU_FORUM' , 'forums.php' , 'images/curved/menu-forum.gif' , NULL , 11 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (12 , 2 , 0 , NULL , 'MENU_HELP' , 'page.php?page=help' , 'images/curved/menu-help.gif' , NULL , 12 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (13 , 2 , 0 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , 'images/curved/menu-about.gif' , NULL , 13 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (21 , 1 , 0 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (22 , 1 , 0 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (23 , 1 , 0 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (24 , 1 , 0 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , 4 , 1 , 0 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (25 , 1 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , 5 , 0 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (26 , 1 , 0 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (27 , 1 , 0 , NULL , 'MENU_SUPPORT' , 'support.php' , NULL , NULL , 7 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (28 , 1 , 0 , NULL , 'MENU_FORUM' , 'forums.php' , NULL , NULL , 8 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (29 , 1 , 0 , NULL , 'MENU_EVENTS' , 'articles.php?category_id=6' , NULL , NULL , 9 , 0 , 0 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (30 , 1 , 0 , NULL , 'MENU_FAQ' , 'articles.php?category_id=4' , NULL , NULL , 10 , 0 , 0 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (31 , 1 , 0 , NULL , 'MENU_HELP' , 'page.php?page=help' , NULL , NULL , 11 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (32 , 1 , 0 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , 12 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (33 , 3 , 0 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (34 , 3 , 0 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (35 , 3 , 0 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (36 , 3 , 0 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , 4 , 1 , 0 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (37 , 3 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , 5 , 0 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (38 , 3 , 0 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (39 , 6 , 0 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (40 , 6 , 0 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (41 , 6 , 0 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (42 , 6 , 0 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , 4 , 1 , 0 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (44 , 6 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , 5 , 0 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (46 , 6 , 0 , NULL , 'MENU_EVENTS' , 'events.php' , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (51 , 6 , 0 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , NULL , 7 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (52 , 7 , 0 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (53 , 7 , 0 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (54 , 7 , 0 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (55 , 7 , 0 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , 4 , 1 , 0 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (56 , 7 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , 5 , 0 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (62 , 7 , 0 , NULL , 'MENU_HELP' , 'page.php?page=help' , NULL , NULL , 11 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (63 , 7 , 0 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , 12 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (64 , 9 , 0 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (65 , 9 , 0 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (66 , 9 , 0 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (67 , 9 , 0 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , 4 , 1 , 0 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (68 , 9 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , 5 , 0 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (69 , 9 , 0 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (70 , 8 , 0 , NULL , 'MENU_HOME' , 'index.php' , 'images/curved/menu-main.gif' , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (71 , 8 , 0 , NULL , 'MENU_PRODUCTS' , 'products.php' , 'images/curved/menu-products.gif' , NULL , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (72 , 8 , 0 , NULL , 'MENU_BASKET' , 'basket.php' , 'images/curved/menu-basket.gif' , NULL , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (73 , 8 , 0 , NULL , NULL , 'index.php' , 'images/curved/logo_os.gif' , NULL , 4 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (76 , 8 , 0 , NULL , 'MENU_MYPROFILE' , 'user_profile.php' , 'images/curved/menu-registration.gif' , NULL , 5 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (78 , 8 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , 'images/curved/menu-user_home.gif' , NULL , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (81 , 8 , 0 , NULL , 'MENU_HELP' , 'page.php?page=help' , 'images/curved/menu-help.gif' , NULL , 7 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (82 , 8 , 0 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , 'images/curved/menu-about.gif' , NULL , 8 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (83 , 4 , 0 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (84 , 4 , 0 , NULL , 'MENU_PRODUCTS' , 'products.php' , NULL , NULL , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (85 , 4 , 0 , NULL , 'MENU_BASKET' , 'basket.php' , NULL , NULL , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (86 , 4 , 0 , NULL , 'MENU_MYPROFILE' , 'user_profile.php' , NULL , NULL , 4 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (87 , 4 , 0 , NULL , 'MENU_ADMIN' , 'admin/admin.php' , NULL , NULL , 5 , 1 , 0 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (88 , 4 , 0 , NULL , 'MENU_EVENTS' , 'articles.php?category_id=6' , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (90 , 4 , 0 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , NULL , 8 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (91 , 4 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , 9 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (94 , 4 , 0 , NULL , 'MENU_HELP' , 'page.php?page=help' , NULL , NULL , 10 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (95 , 4 , 0 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , 11 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (96 , 5 , 0 , NULL , 'MENU_HOME' , 'index.php' , 'images/curved/menu-main.gif' , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (97 , 5 , 0 , NULL , 'MENU_PRODUCTS' , 'products.php' , 'images/curved/menu-products.gif' , NULL , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (98 , 5 , 0 , NULL , 'MENU_BASKET' , 'basket.php' , 'images/curved/menu-basket.gif' , NULL , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (99 , 5 , 0 , NULL , 'MENU_MYPROFILE' , 'user_profile.php' , 'images/curved/menu-registration.gif' , NULL , 4 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (101 , 5 , 0 , NULL , NULL , 'index.php' , 'images/curved/logo_os.gif' , NULL , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (102 , 5 , 0 , NULL , 'MENU_EVENTS' , 'articles.php?category_id=6' , 'images/curved/menu-events.gif' , NULL , 7 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (103 , 5 , 0 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , 'images/curved/menu-news.gif' , NULL , 8 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (104 , 5 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , 'images/curved/menu-user_home.gif' , NULL , 9 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (107 , 5 , 0 , NULL , 'MENU_HELP' , 'page.php?page=help' , 'images/curved/menu-help.gif' , NULL , 10 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (109 , 3 , 0 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , 7 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (110 , 3 , 0 , NULL , 'MENU_FORUM' , 'forums.php' , NULL , NULL , 8 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (111 , 3 , 0 , NULL , 'MENU_SUPPORT' , 'support.php' , NULL , NULL , 9 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (112 , 6 , 0 , NULL , 'MENU_SIGNOUT' , 'user_login.php?operation=logout' , NULL , NULL , 9 , 0 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (113 , 10 , 0 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (114 , 10 , 0 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , 2 , 1 , 0 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (115 , 10 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , 3 , 0 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (116 , 10 , 0 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , NULL , 4 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (117 , 10 , 0 , NULL , 'MENU_EVENTS' , 'articles.php?category_id=6' , NULL , NULL , 5 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (118 , 10 , 0 , NULL , 'MENU_FAQ' , 'articles.php?category_id=4' , NULL , NULL , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (119 , 11 , 0 , NULL , 'MENU_HOME' , 'index.php' , 'images/curved/menu-main.gif' , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (120 , 11 , 0 , NULL , 'MENU_MYPROFILE' , 'user_profile.php' , 'images/curved/menu-registration.gif' , NULL , 2 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (121 , 11 , 0 , NULL , 'MENU_EVENTS' , 'articles.php?category_id=6' , 'images/curved/menu-events.gif' , NULL , 3 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (122 , 11 , 0 , NULL , NULL , 'index.php' , 'images/curved/logo_os.gif' , NULL , 4 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (123 , 11 , 0 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , 'images/curved/menu-news.gif' , NULL , 5 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (124 , 11 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , 'images/curved/menu-user_home.gif' , NULL , 6 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (125 , 11 , 0 , NULL , 'MENU_HELP' , 'page.php?page=help' , 'images/curved/menu-help.gif' , NULL , 7 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (126 , 11 , 0 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , 'images/curved/menu-about.gif' , NULL , 8 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (127 , 12 , 0 , NULL , 'MENU_HOME' , 'index.php' , NULL , NULL , 1 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (128 , 12 , 0 , NULL , 'MENU_SIGNIN' , 'user_login.php' , NULL , NULL , 2 , 1 , 0 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (129 , 12 , 0 , NULL , 'MENU_USERHOME' , 'user_home.php' , NULL , NULL , 3 , 0 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (130 , 12 , 0 , NULL , 'MENU_NEWS' , 'articles.php?category_id=1' , NULL , NULL , 4 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (131 , 12 , 0 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , 5 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (132 , 3 , 0 , NULL , 'MENU_SIGNOUT' , 'user_login.php?operation=logout' , NULL , NULL , 10 , 0 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (133 , 6 , 0 , NULL , 'MENU_ABOUT' , 'page.php?page=about' , NULL , NULL , 8 , 1 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (134 , 9 , 0 , NULL , 'MENU_SIGNOUT' , 'user_login.php?operation=logout' , NULL , NULL , 7 , 0 , 1 ) ;
INSERT INTO va_header_links (menu_id,layout_id,parent_menu_id,menu_path,menu_title,menu_url,menu_image,menu_image_active,menu_order,show_non_logged,show_logged) VALUES (135 , 12 , 0 , NULL , 'MENU_SIGNOUT' , 'user_login.php?operation=logout' , NULL , NULL , 6 , 0 , 1 ) ;


INSERT INTO va_issue_numbers (issue_number) VALUES (1 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (2 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (3 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (4 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (5 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (6 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (7 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (8 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (9 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (10 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (11 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (12 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (13 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (14 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (15 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (16 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (17 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (18 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (19 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (20 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (21 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (22 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (23 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (24 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (25 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (26 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (27 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (28 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (29 ) ;
INSERT INTO va_issue_numbers (issue_number) VALUES (30 ) ;


INSERT INTO va_item_types (item_type_id,item_type_name,is_gift_voucher,is_bundle) VALUES (1 , 'Product' , 0 , 0 ) ;
INSERT INTO va_item_types (item_type_id,item_type_name,is_gift_voucher,is_bundle) VALUES (2 , 'Accessory' , 0 , 0 ) ;
INSERT INTO va_item_types (item_type_id,item_type_name,is_gift_voucher,is_bundle) VALUES (3 , 'Gift Voucher' , 1 , 0 ) ;
INSERT INTO va_item_types (item_type_id,item_type_name,is_gift_voucher,is_bundle) VALUES (4 , 'Bundle' , 0 , 1 ) ;


INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (4 , 'Manhattan Unfurled' , 1 , 1 , NULL , NULL , 2 , '0375504915' , NULL , NULL , NULL , NULL , 'Matteo Pericoli trained as an architect in Milan and then came to work in New York in 1995. His arrival preceded by just a few days the arrival of the biggest snowstorm of the decade, and the sense of the city in its wakeespecially its silenceremained in his mind. He experienced similar feeling taking photographs of Riverside Drive from the Circle Line ferry, and decided to transpose them into a line drawing. It was then that he felt compelled to photograph the whole of New... ' , 0 , 'Matteo Pericoli trained as an architect in Milan and then came to work in New York in 1995. His arrival preceded by just a few days the arrival of the biggest snowstorm of the decade, and the sense of the city in its wakeespecially its silenceremained in his mind. He experienced similar feeling taking photographs of Riverside Drive from the Circle Line ferry, and decided to transpose them into a line drawing. It was then that he felt compelled to photograph the whole of New Yorks shoreline profilefrom Queens, Brooklyn, the Bronx, and New Jersey (which he reached by motorcycle)  and make two continuous and continuously enchanting pen-and-ink drawing of Manhattans skyline. \r\n\r\nManhattan Unfurled is published in an elegant slipcase, and the drawings fold out, accordion-style, with the West on one side and the East on the other. An introduction by distinguished New Yorker architecture critic Paul Goldberger, who first wrote bout Matteos project in The New Yorkers Talk of the Town, will accompany the drawing in a separate pamphlet. This book is both a wonderful New York City memento, perfect for gift giving, and an entirely unique work of art.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0375504915.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0375504915.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 29.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 20.96 , 30 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (5 , 'The Artist\'s Way Morning Pages Journal : A Companion Volume to the Artist\'s Way' , 1 , 1 , NULL , NULL , 2 , '0874778867' , NULL , NULL , NULL , NULL , NULL , 0 , 'The idea behind Julia Cameron\'s The Artist\'s Way is that by writing three pages, longhand and stream-of consciousness, first thing in the morning, you can overcome the obstacles that stop you from becoming your most creative self. This works partly because it forces you to create something (even if it is just a long list of gripes) every single day. It doesn\'t take much time. You\'re not even supposed to think. But the act itself gets you past all that self-defeating fretting about why you think you aren\'t a creative person. Cameron sees her morning pages as "a form of meditation," as "spiritual windshield wipers."\r\nWhile Cameron touts the morning pages as a way of life, she suggests you start out doing them as part of a "twelve-week program to recover your creativity." If you would like to keep your first twelve weeks of morning pages together in one tidy place, The Artist\'s Way Morning Pages Journal is a fine tool for doing so. Each nearly blank page features an inspiring quotation from The Artist\'s Way: "Leap, and the net will appear," says one; "Creativity lies not in the done but in doing," reminds another. We should mention that many of these little inspirations include references to God, which may be troublesome even for spiritual atheists. --Jane Steinberg \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0874778867.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0874778867.01.MZZZZZZZ.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 11.96 , 20 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (6 , 'Patience & Fortitude : A Roving Chronicle of Book People, Book Places, and Book Culture' , 1 , 1 , NULL , NULL , 2 , '0060196955' , NULL , NULL , NULL , NULL , NULL , 0 , 'A sequel of sorts to Basbanes\'s earlier A Gentle Madness (on the manic nature of bookselling and book-collecting), this copious volume takes its title from the formidable lions guarding the entrance to the main branch of the New York Public Library in Manhattan. Opening with the great libraries of the past, from Alexandria to Pergamum and Glastonbury, Basbanes, former literary editor of the Worcester Sunday Telegram, segues into such venerable active libraries as those at the Vatican, Wolfenbottel and the universities of Durham, Leiden and Oxford. He visits with shrewd, sometimes eccentric book dealers who happily recount tales of bygone bibliophiles, and illustrates a variety of collections, from illuminated medieval manuscripts to volumes more valuable for who owned them than for binding or content. "I absolutely insist on keeping the same crummy look," a bookshop owner tells him proudly. "Every time I make the place too neat, business goes down." But a pathos pervades the book, for despite the huge increase in readers and book buyers, one dealer observes "a radical dismantling of high culture well under way" since the 1930s. The collector in 1939 who bought a rare book about Native American languages "by selling bottles of his own blood" has no latter-day parallel. Basbanes closes with tales of crusty benefactors like Andrew Carnegie, and interviews with librarians faced with the dilemma of too many old books that no one now wants to read. Basbanes\'s fund of stories will delight readers who value books for more than just a good story, have a yen for second-hand books plucked from dusty shops or look to book catalogs for suspense and excitement. 32 pages of b&w photos not seen by PW. Agents, Glen Hartley and Lynn T. Chu. (Oct.)Forecast: This will undoubtedly garner much attention in the book pages, as did its predecessor, aided by a six-city author tour, a 15-city NPR campaign and print features.\r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0060196955.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0060196955.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 35 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 24.5 , 30 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (7 , 'Rock Star' , 1 , 1 , NULL , NULL , 2 , 'B00005TPMA' , NULL , NULL , NULL , NULL , 'Watch Mark Wahlberg and Jennifer Aniston live the highs and lows of a rock  & roll fantasy come true in Rock Star.  Black leather pants recommended.\r\n' , 0 , 'This movie is a must for your collection, especially if you\'re fan of BIG HAIR ROCK. I grew up with the type of music this film is based on. I thought Mark Wahlberg did an amazing job of capturing the essence of a Heavy Metal  frontman. He had the perfect swagger and look. Even if you aren\'t a huge fan of Metal, I\'m sure at one time you\'ve fantasized about being a rock star or some type of entertainer, right? I\'m sure you\'ll be able to relate to the story of a guy who sings for a tribute band of his heroes, eventually getting the call to front the ACTUAL band. Jennifer Aniston and the cast of real life rockers like guitarist Zakk Wylde and Third Eye Blind\'s Stephan Jenkins are all great too. Oh and by the way... the soundtrack CD is also excellent, with original music from the film\'s  band, Steel Dragon and classics from KISS, Bon Jovi and others. For a fun film  ride I enthusiastically recommend ROCK STAR! Enjoy!!!' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005TPMA.01.25TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005TPMA.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.98 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.95 , 25 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (8 , 'Extreme Beauty: The Body Transformed' , 1 , 1 , NULL , NULL , 2 , '0300091176' , NULL , NULL , NULL , NULL , NULL , 0 , 'From Publishers Weekly \r\nHigh-heeled shoes, push-up bras, Elizabethan ruffs and Japanese platform clogs are just a few examples of clothing that has pushed and pulled the human form into new shapes in the last few centuries. With color photos and illustrations, Extreme Beauty: The Body Transformed, which accompanies a Metropolitan Museum of Art exhibit of the same name, traces the role of fashion in manipulating the body to fit physical ideals. Harold Koda, curator of the Met\'s Costume Institute, focuses on extreme exaggerations of human form like the European 19th-century bustle, tiny corseted waists or the enormous-hipped dresses of the 18th-century French court, but also shows how today\'s designers quote and send up these iconic shapes. \r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0300091176.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0300091176.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 40 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 28 , 30 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (9 , 'Anthony Blunt: His Lives' , 1 , 1 , NULL , NULL , 2 , '0374105316' , NULL , NULL , NULL , NULL , NULL , 0 , 'From Publishers Weekly \r\nThis engaging and important biography examines the many masks of the infamous Anthony Blunt (1907-1983), the Cambridge art historian turned spy who worked simultaneously for British Intelligence and the Soviet Union during WWII. Why did he betray his country? Carter provides an exhaustive psychological study of Blunt\'s early life. His brutalizing public school (where he was unhappy and unpopular), Carter argues, "inadvertently fostered a questioning and subversive attitude and a profound distrust of authority." When the Depression hit England in the 1930s and the specter of fascism threatened Europe, communism became fashionable among left-leaning intellectuals like Blunt and his Cambridge friend Guy Burgess. Blunt\'s homosexuality, like Burgess\'s, also appears to have alienated him from the establishment. During WWII, Blunt was assigned to British intelligence, giving him easy access to military secrets, which he smuggled to the Soviets. After his Cambridge spy friends Burgess, Donald MacLean and Kim Philby defected to the Soviet Union after the war, British Intelligence began investigating Blunt. In 1964, he was granted immunity in exchange for his confession and full cooperation. British intelligence worked hard to keep "the Blunt affair" a secret. He wasn\'t publicly exposed until 1979, when Margaret Thatcher denounced him. The biggest challenge any Blunt biographer faces is Blunt himself, a man of almost legendary emotional detachment. Blunt revealed little about his personal life, yet Carter has managed to bring readers as close to this enigmatic man as humanly possible. Thoroughly researched and carefully crafted, this is sure to be the definitive biography. 16 pages of photos not seen by PW. (Jan.)Forecast: Blunt\'s story isn\'t quite the sensation here that it is in England; devotees of spy tales and contemporary British history will read this.\r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0374105316.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0374105316.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 30 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 21 , 30 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (10 , 'Awakening the Virgin' , 1 , 1 , NULL , NULL , 2 , '1555834566' , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1555834566.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/1555834566.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 13.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.16 , 20 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (11 , 'Beaches' , 1 , 1 , NULL , NULL , 2 , '0811826503' , NULL , NULL , NULL , NULL , NULL , 0 , 'The authors of The Beach: The History of Paradise on Earth, the best-selling history of everyone\'s favorite place, are back with a breathtaking visual companion. From moody, craggy coastlines to serene swathes of turquoise water and white sand, Beaches is an astounding photographic survey of the ineffable allure of paradise on earth. This spectacular collection of images from renowned photographers, including Robert Misrach, Joel Meyerowitz, and Art Wolff, stirs the spirit, capturing the mutable beauty of sand, sea, and sky. Throughout, concise and poetic pieces of historic and scientific lore unveil little-known facts and curiosities. With an astonishing range of vision, Beaches evokes the idiosyncratic beauty of the world\'s most stunning coastlines. \r\n\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0811826503.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0811826503.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 24.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.46 , 30 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (12 , 'Beaches of Maui County (A Kolowalu Book)' , 1 , 1 , NULL , NULL , 2 , '0824812468' , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0824812468.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0824812468.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 11.96 , 20 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (13 , 'Exploring Southern California Beaches (FalconGuide)' , 1 , 1 , NULL , NULL , 2 , '1560446323' , NULL , NULL , NULL , NULL , NULL , 0 , '"From the bustle of the Mexican border to the isolated beauty of Point Conception, sit back and enjoy the ride as veteran writer and beach bum David Crowell takes you on Safari in Exploring Southern California Beaches. Discover the diversity of life in " --This text refers to the Digital edition. ' , 1 , '"From the bustle of the Mexican border to the isolated beauty of Point Conception, sit back and enjoy the ride as veteran writer and beach bum David Crowell takes ...' , NULL , 'http://images.amazon.com/images/P/1560446323.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/1560446323.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 18.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.26 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , '' , 2 , 10 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (16 , 'The Millionaires' , 1 , 1 , NULL , NULL , 2 , '0446527297' , NULL , NULL , NULL , NULL , NULL , 0 , 'What would you steal if you couldn\'t get caught? That\'s the tag line of Brad Meltzer\'s new thriller, which pits an ambitious young money manager against a corporate villain, whose intricate financial shenanigans accidentally put a huge chunk of dough right in front of a man who desperately needs it. Of course Oliver Caruso\'s conscience troubles him, but that doesn\'t keep him from letting his somewhat looser and less ethical brother convince him this is too good an opportunity to pass up. Meltzer\'s in interesting territory here, but in order to buy his premise, you have to believe that it\'s OK to steal if you have a good enough reason. This makes his protagonist, who narrates the novel, hard to root for and less than sympathetic. Despite this hollow ring, the book is nicely plotted and should please the author\'s enthusiastic fan club. --Jane Adams ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0446527297.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0446527297.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 25.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.57 , 40 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (17 , 'Blackwater Sound' , 1 , 1 , NULL , NULL , 2 , '0312203845' , NULL , NULL , NULL , NULL , NULL , 0 , 'A powerful Florida family, its high-tech fortune dwindling, is haunted by an elusive, enormous blue marlin that claimed the life of its eldest son, who was meant to restore the family\'s prominence. But the Braswells are tormented by even darker secrets, such as incest and treason, that drive this dark, atmospheric thriller to an explosive conclusion, which might have been pulled straight from recent headlines. James Hall pits Thorn, his series protagonist, against the Braswells and their deadly plans. Although an existentially morose antihero is a convention of the mystery genre, Hall manages to transcend it with a fascinating plot and a powerful narrative, resulting in a suspenseful and resonant novel that shows off his well-developed talents for character development, place, and pacing. The author of 11 previous mysteries (including Mean High Tide and Rough Draft), Hall gets better with every book, and this one continues the trend. --Jane Adams ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0312203845.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0312203845.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 24.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.46 , 30 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (18 , 'To Trust a Stranger' , 1 , 1 , NULL , NULL , 2 , '0671786539' , NULL , NULL , NULL , NULL , NULL , 0 , 'The usual ingredients bubble and boil in Robards\'s latest romantic suspense thriller. Julie Carlson, once a poor girl from the wrong side of the tracks but now the beautiful owner of a successful boutique in Charleston, S.C., seems to have it all. As the novel begins, however, a hit man circles her suburban mansion: Julie\'s rich husband, Sid, has hired thugs to kill her. Unaware of the danger she is in but convinced that Sid is cheating on her, Julie slips out of the house just in time and follows her husband to the red-light district, where she serendipitously and literally runs into private detective Mac McQuarry, dressed up in drag to spy on a client\'s husband. Julie isn\'t sure whether she should trust a man in a dress, but she has no one else to turn to, and soon she and Mac are working together to get the goods on Julie\'s crooked husband. As it happens, Mac holds a personal grudge against Sid, a prominent builder in Charleston, because Sid was involved in the disappearance of Mac\'s half-brother 15 years before, and then got Mac kicked off the police force when Mac tried to prove it. Robards\'s fans will enjoy the machinations before Julie and Mac get together, though cliches clutter every page ("The truth hit him like a hammer over the head: He had a galloping case of the hots for his newest client, who was not incidentally his oldest enemy\'s wife"). Of course, true love solves past mysteries, while hot kisses get as much play as life-threatening confrontations. A bodice ripper at heart, the novel is the equivalent of a box of junk candy. \r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0671786539.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0671786539.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 25 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.5 , 30 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (19 , 'Hearse of a Different Color' , 1 , 1 , NULL , NULL , 2 , '0786889632' , NULL , NULL , NULL , NULL , NULL , 0 , 'Tim Cockey\'s debut novel, The Hearse You Came In On, introduced readers to Hitchcock Sewell, the undertaker-turned-reluctant-sleuth, whose mordant irony and blissfully skewed perspective on the humdrum brought a remarkable vigor to a profession not usually known for its liveliness. The good news for Hitch fans is that Cockey\'s follow-up effort dishes up another heaping helping of sardonic wit: \r\nThe planet was one big marble of wretchedness. And I wasn\'t exactly being lifted aloft by bluebirds either. I was wheeling down the Baltimore- Washington Parkway in my unexciting car on the fourth record-breaking freezing cold day in a row, tuning in to what seemed to be the preexisting fact that I was going to be tracking down a cold-blooded murderer.\r\nSaid murderer has deposited a corpse on Hitch\'s doorstep--in the middle of a wake, no less. The unscheduled body is one Helen Waggoner, a single mother with a double life as a waitress and porn star. Hitch\'s girlfriend sees the unceremonious delivery as a scoop in the making. Bonnie Nash is a less-than- accurate TV weather woman who\'s got a bad case of occupational shame ("I\'m a pair of breasts that tells you what the weather is going to be tomorrow. Maybe."). She figures that solving a murder ought to earn her a network promotion. But it\'s not that easy. When Helen\'s sister also turns to Hitch for some moral and investigative support, the undertaker finds himself digging through the family closets and unearthing some distinctly unsavory skeletons. It turns out that a taste for the (ahem) silver screen is a Waggoner tradition, and that the sisters have a long--and not particularly affectionate--history. It\'s up to Hitch to put the pieces of the puzzle together before a hired killer with a peculiar signature takes him apart.\r\nCockey has a rare gift for sending up the hallowed conventions of mystery fiction with effortlessly wry turns of phrases: "I looked about to assess the scene. I\'m six-three, so I have a decent vantage point for assessing." His plot skills have sharpened since his last outing, and the narrative moves along briskly to a conclusion both tidy and ironic. Appropriately enough, though, in this Hearse, the ride is even more fun than the destination. --Kelly Flynn --This text refers to the Paperback edition. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0786889632.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0786889632.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 7.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 7.99 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (22 , 'Under Cover The Key To Living In God\'s Provision And Protection' , 1 , 1 , NULL , NULL , 2 , '0785269916' , NULL , NULL , NULL , NULL , NULL , 0 , 'This well loved writer effectively uses his personal mistakes to illustrate riveting truths about repentance and forgiveness. As he focuses on the true authority of God, he is careful to explain by example the important difference between submission and obedience. \r\nThe same struggle with divine authority is also represented through the lives of John the Baptist, the Apostle Paul, and other biblical figures. An especially helpful book for Christians who want to develop a serious pursuit of God. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0785269916.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0785269916.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 11.99 , 20 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (24 , 'The Church of Irresistible Influence' , 1 , 1 , NULL , NULL , 2 , '0310239567' , NULL , NULL , NULL , NULL , NULL , 0 , 'An inspiring description and story showing how a church can become an irresistible influence on its neighborhood, community, and world by building bridges over troubled waters to a dying culture through showing the love of God in action. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0310239567.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0310239567.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 13.99 , 30 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (25 , 'God : A Biography' , 1 , 1 , NULL , NULL , 2 , '0679743685' , NULL , NULL , NULL , NULL , NULL , 0 , 'Is it possible to approach God not as an object of religious reverence, but as the protagonist of the world\'s greatest book -- as a character who possesses all the depths, contradictions, and ambiguities of a Hamlet? How does he depend on the other characters, and how does his relationship with them show his development? Miles provides a learned, original exegesis that will send readers back to the Bible in curious amazement. Winner of the 1996 Pulitzer Prize for biography. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0679743685.01.TZZZZZZZ.gif' , NULL , 'http://images.amazon.com/images/P/0679743685.01.MZZZZZZZ.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 15 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 12 , 20 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (27 , 'The Pleasures of God : Meditations on God\'s Delight in Being God' , 1 , 1 , NULL , NULL , 2 , '1576736652' , NULL , NULL , NULL , NULL , NULL , 0 , 'Beginning where the foundational truth of Desiring God left off, that "God is most glorified in us when we are most satisfied in Him," this expanded rerelease of another classic by John Piper will further explore a life-changing essential "We will be most satisfied in God when we know why God himself is most satisfied in God." Fully understanding the joy of God will draw the reader into an encounter with His overflowing, self-replenishing, all-encompassing grace(the source of living water that all Christians desire to drink.) The Pleasures of God will again put God at the center of Creation and leave the reader very satisfied in Him. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1576736652.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/1576736652.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.99 , 20 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (28 , 'The Lord of the Rings (Collector\'s Edition)' , 1 , 1 , NULL , NULL , 2 , '0395193958' , NULL , NULL , NULL , NULL , NULL , 0 , 'The New York Times \r\n"A unique, wholly realized other world, evoked from deep in the well of Time, massively detailed, absorbingly entertaining..." ' , 1 , 'The New York Times \r\n"A unique, wholly realized other world, evoked from deep in the well of Time, massively detailed, absorbingly entertaining..." ' , NULL , 'http://images.amazon.com/images/P/0395193958.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0395193958.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 75 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 52.5 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (29 , 'The Lord of the Rings (Boxed Set)' , 4 , 1 , NULL , NULL , 2 , '0395489326' , NULL , NULL , NULL , NULL , NULL , 0 , 'The three volumes that make up Tolkien\'s epic classic The Lord of the Rings are here presented in their standard cloth editions including large format fold-out maps and an extensive appendices. Set contains The Fellowship of the Ring, The Two Towers, and The Return of the King, with jackets and a box designed by celebrated illustrator Alan Lee. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0395489326.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0395489326.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 65 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 45.5 , 30 , NULL , NULL , NULL , NULL , NULL , 0 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (30 , 'The Silmarillion' , 3 , 1 , NULL , NULL , 2 , '0345325818' , NULL , NULL , NULL , NULL , NULL , 0 , 'The Silmarillion is J.R.R. Tolkien\'s tragic, operatic history of the First Age of Middle-Earth, essential background material for serious readers of the classic Lord of the Rings saga. Tolkien\'s work sets the standard for fantasy, and this audio version of the "Bible of Middle-Earth" does The Silmarillion justice. Martin Shaw\'s reading is grave and resonant, conveying all the powerful events and emotions that shaped elven and human history long before Bilbo, Frodo, Gandalf and all the rest embarked on their quests. Beginning with the Music of the Ainur, The Silmarillion tells a tale of the Elder Days, when Elves and Men became estranged by the Dark Lord Morgoth\'s lust for the Silmarils, pure and powerful magic jewels. Even the love between a human warrior and the daughter of the Elven king cannot defeat Morgoth, but the War of Wrath finally brings down the Dark Lord. Peace reigns until the evil Sauron recovers the Rings of Power and sets the stage for the events told in the Lord of the Rings. This is epic fantasy at its finest, thrillingly read and gloriously unabridged. (Running time: 14 hours, 6 CDs) --This text refers to the Audio CD edition. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0345325818.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0345325818.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 6.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 6.99 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (31 , 'Osmosis Jones (2001)' , 1 , 1 , NULL , NULL , 2 , 'B00005QAQH' , NULL , NULL , NULL , NULL , NULL , 0 , 'After the stiff attempts at realism in many recent features, it\'s a treat to see broad\r\n                  cartoon-style animation on the big screen in Osmosis Jones, a spoof of cop movies\r\n                  set inside the human body. The title character (voice by Chris Rock) is a\r\n                  street-smart white blood cell, working for Frank\'s immune system. He and Drix\r\n                  (David Hyde Pierce), an over-the-counter cold capsule, are reluctant partners\r\n                  fighting what appears to be a minor infection. Osmosis discovers Frank has really\r\n                  contracted a fatal virus, Thrax (Laurence Fishburne): he battles a corrupt body\r\n                  politic led by a venal mayor (William Shatner) to save Frank\'s life and win the\r\n                  affection of the mayor\'s aide, Leah (Brandy Norwood). Rock\'s motor-mouth\r\n                  delivery can get annoying, but it contrasts nicely with straight arrow Drix (imagine\r\n                  a fussy Buzz Lightyear). Excellent drawing and a powerful vocal performance make\r\n                  Thrax a genuinely frightening villain.\r\n\r\n                  Osmosis Jones is about two-thirds animation and one-third live action, which is\r\n                  why two-thirds of the film is entertaining and funny, and one-third is not. The life\r\n                  Osmosis and Drix save belongs to Frank, a slob played in live-action sequences by\r\n                  Bill Murray, who\'s undercut rather than supported by Chris Elliott and Molly\r\n                  Shannon. Shamelessly over-the-top performances make the human characters\r\n                  seem flatter than the two-dimensional cartoons. The live action was shot by the\r\n                  Farrelly brothers and features lots of gross-out gags about zits, flatulence, vomit,\r\n                  snot, etc. The audience endures these leaden segments, waiting to get back to the\r\n                  animation--and the real comedy. Suitable for ages 9 and up: profanity, violence,\r\n                  bodily function jokes. --Charles Solomon' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005QAQH.01.14TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005QAQH.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 24.98 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 21.49 , 14 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 3 , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (32 , 'Dark Journey (Star Wars: The New Jedi Order, Book 10)' , 2 , 1 , NULL , NULL , 2 , '0345428692' , NULL , NULL , NULL , NULL , NULL , 0 , 'About the Author \r\nA former music and history teacher, Elaine Cunningham has written more than a dozen fantasy novels and many short stories. She is best known for the Songs & Swords books, particularly Elfshadow, a mystery in a fantasy setting. She lives with her family in a coastal New England town.\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0345428692.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0345428692.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 6.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 6.99 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (33 , 'The John Singleton Collection (Boyz N the Hood, Poetic Justice, Higher Learning)' , 1 , 1 , NULL , NULL , 2 , 'B00005JD5K' , NULL , NULL , NULL , NULL , NULL , 0 , 'Poetic Justice: BOYZ N THE HOOD writer-director Singleton suffers the\r\n                  sophomore jinx in this ambitious but fatally pretentious saga of a melancholy\r\n                  South Central L. A. beautician (Jackson), who has retreated from the world after\r\n                  her boyfriend\'s murder; mailman Shakur attempts to break through to her, with\r\n                  predictable results. Implausibly, the poetry this otherwise ordinary woman\r\n                  composes actually is the work of Maya Angelou (who appears onscreen as Aunt\r\n                  June). Jackson is OK in her screen debut.\r\n                  Higher Learning: Provocative drama of life at a big university where problems\r\n                  tend to break down along racial and sexual lines. Epps plays a young black\r\n                  athlete searching for direction and, sometimes blindly, raging at injustice.\r\n                  Fishburne is a political science professor who tries to help him see the world as\r\n                  it is. Credible, well-acted film goes awry when writer-director Singleton steers it\r\n                  toward melodrama, and foregoes student relations to focus on a group of\r\n                  extremist skinheads.\r\n                  Boyz N the Hood: Sober, thoughtful look at life in the black section of South\r\n                  Central L. A. A divorced father strives to raise his son with values--and steer him\r\n                  away from the ignorance and aimlessness that has led to an epidemic of\r\n                  senseless violence in the neighborhood. Impressive debut for 23-year-old\r\n                  writer-director Singleton; longish, and not always on-the-money, but overall quite\r\n                  potent and effective. Singleton has a bit part as a mailman.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005JD5K.01.25TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005JD5K.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 44.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 33.71 , 25 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (34 , 'Amazing Grace (1974)' , 1 , 1 , NULL , NULL , 2 , 'B00005R5W2' , NULL , NULL , NULL , NULL , NULL , 0 , 'A few laughs in Philadelphia-made comedy about an elderly busybody who disrupts\r\n                  corrupt Baltimore politics. Mabley\'s only starring film; cameos by Butterfly\r\n                  McQueen, unrecognizable Stepin Fetchit.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5W2.01.10TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005R5W2.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 13.46 , 10 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (35 , 'HomeSite 5.0' , 1 , 1 , NULL , NULL , 2 , 'B00005U2FY' , NULL , NULL , NULL , NULL , 'Ever popular with professional Web developers, HomeSite 5.0 offers advanced hand-coding features, productivity enhancing wizards, and a customizable user interface to efficiently build, deploy, and manage your entire Web site. HomeSite 5.0 also includes XHTML support and new Folder Deployment settings. Check out the full or upgrade version today.\r\n' , 0 , 'Developers can create professional Web sites fast with the code editing features of Macromedia HomeSite 5. The software delivers advanced hand coding features, productivity-enhancing wizards, and a customizable user interface to efficiently build, deploy, and manage your entire Web site. Effortlessly validate, reuse, navigate, and format your code with integrated coding tools. The wizards quickly create pages, tables, frames, and JavaScript elements for you.\r\nWith XHTML support, based on the W3C specifications for XHTML 1.0, developers can build pages with the latest Web technologies. The extensibility of XHTML provides the flexibility to incorporate new Web communication and presentation ideas as they emerge. Developers can use the new Secondary Files tab to browse local and remote files simultaneously and to drag and drop files between the two Files tabs, efficiently incorporating documents and images. \r\n\r\nThe new Folder Deployment settings enable developers to determine the deployment method for individual folders and files within a project. These new settings make deployment much more accessible to the novice user while maintaining the sophistication of the feature for the high-end user. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005U2FY.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005U2FY.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (36 , 'J.D.\'s Revenge (1976)' , 1 , 1 , NULL , NULL , 2 , 'B00005R5W1' , NULL , NULL , NULL , NULL , NULL , 0 , 'It\'s been branded with the "blaxploitation" label, but there is little that\'s exploitive in\r\n                  J.D.\'s Revenge, a film of well-drawn, articulate characters dragged into a\r\n                  supernatural showdown. Glynn Turman (Cooley High) is especially fine as the\r\n                  sensitive and quiet Ike, a determined student moonlighting as a cab driver, so\r\n                  wound up he\'s on the verge of cracking. Enter (literally) the ghost of J.D., a\r\n                  violent, vengeful gangster murdered in the opening moments. He could be Ike\'s\r\n                  own Mr. Hyde, a dapper, flamboyant ladykiller with a fiery temper and a straight\r\n                  razor who slowly smothers Ike\'s easygoing personality. Driven by flashes of\r\n                  memory, he sets his vengeful sights on fire-and-brimstone preacher Reverend\r\n                  Bliss (Louis Gossett Jr.), whose dark past is intricately tied up with J.D.\'s\r\n                  murder. Director Arthur Marks (Detroit 9000) sidesteps the usual spooky clich?s\r\n                  to stir up a modern New Orleans gumbo of ghost story, gangster tale, and\r\n                  character drama. J.D. is both devilish sadist and avenging angel, while the\r\n                  tortured Ike awakens from J.D.\'s violent rampages with a hole in his memory but\r\n                  a sick feeling from his imagined complicity in the crimes. The story gets wrapped\r\n                  up a little too neatly in the end, but the dark character shadings and the evocative\r\n                  mystery at the center of Ike\'s possession makes J.D.\'s Revenge an\r\n                  unexpectedly compelling supernatural thriller. --Sean Axmaker' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5W1.01.10TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005R5W1.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 13.46 , 10 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (37 , 'Homestead Professional - 3 Month Subscription' , 1 , 1 , NULL , NULL , 2 , 'B00005U1US' , NULL , NULL , NULL , NULL , 'Product Description\r\nHomestead Professional\'s three-month subscription includes everything you need to build, host, and maintain a professional Web site. This drag-and-drop Web site software makes it easy to create a professional online presence. The Homestead... ' , 0 , 'Homestead Professional\'s three-month subscription includes everything you need to build, host, and maintain a professional Web site. This drag-and-drop Web site software makes it easy to create a professional online presence. The Homestead Professional package offers a three-month subscription to site hosting, 75 MB of storage space, unlimited pages, and 15 GB of traffic per month. It also sets you up with your own domain name along with two matching e-mail accounts.\r\nComprehensive e-commerce tools, interactive elements, site design wizards, and a gallery loaded with more than a million images makes designing your Web site fun and professionally rewarding. The easy-to-use e-commerce tools help you set up and market your products and services online. Interactive hit counters, guestbooks, Web polls, chat rooms, and forms let you monitor traffic, while statistics and reporting tools aid in building customer profiles and tracking marketing efforts. Throughout, Homestead\'s extensive online help is there to guide you through the design process. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005U1US.01.33TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005U1US.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 89.97 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 59.97 , 33 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (38 , 'Adobe After Effects 5.5 Standard Upgrade from 5.0 ST-ST' , 1 , 1 , NULL , NULL , 2 , 'B00005UMC8' , NULL , NULL , NULL , NULL , 'Adobe After Effects 5.5 delivers a comprehensive set of tools to efficiently produce motion graphics and visual effects for film, video, multimedia, and the Web. The Standard version provides core compositing, animation, and effects tools. After... ' , 0 , 'Adobe After Effects 5.5 delivers a comprehensive set of tools to efficiently produce motion graphics and visual effects for film, video, multimedia, and the Web. The Standard version provides core compositing, animation, and effects tools. After Effects offers a high level of integration with Adobe Premiere, Adobe Photoshop, and Adobe Illustrator to produce professional results. New features include controls to manipulate lighting in 3-D compositions, easier application of effects, and versatile import and output options. And now get native support for Mac OS X. \r\nAfter Effects 5.5 features increased control over lighting properties, allowing users to cast colored shadows or simulate the effects of stained glass. Create spotlights that cast light in the shape of stars or logos. After Effects 5.5 also includes eight new effects, giving you more than 90 effects to use alone or in combination to produce looks that are tailored for any project. And now you can apply effects more efficiently and organize them however you like with the new effects palette. Just drag and drop effects from the palette and arrange them using customized folders or list them alphabetically.\r\n\r\nAfter Effects 5.5 offers more import and output options. Create RealMedia streaming or Web download files that support RealVideo, RealAudio, and RealVideo with audio. Get support for work in 16-bit-per-channel formats such as Maya IFF, QuickTime, RPF, and SGI files. Import Macromedia Flash files and MPEG-1 files to use in your compositions. Cross-media delivery of high-quality digital content with After Effects has never been easier or more flexible.\r\n' , 0 , NULL , 'This is an upgrade version for owners of After Effects 5.0 Standard. \r\n' , 'http://images.amazon.com/images/P/B00005UMC8.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UMC8.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (39 , 'The Curse of the Jade Scorpion (2001)' , 1 , 1 , NULL , NULL , 2 , 'B00003CY6A' , NULL , NULL , NULL , NULL , NULL , 0 , 'With The Curse of the Jade Scorpion, Woody Allen pays another visit to his\r\n                  idealized past, and his retro blend of humor and nostalgia will surely satisfy the\r\n                  filmmaker\'s most loyal fans. Like The Purple Rose of Cairo, Radio Days, and\r\n                  Sweet and Lowdown, The Curse of the Jade Scorpion is physically impeccable:\r\n                  its period-perfect costumes and sets capture 1940 New York with splendid\r\n                  authenticity and are further enhanced by the burnished glow of Zhao Fei\'s\r\n                  cinematography. And like those earlier films, Jade Scorpion mines comedic gold\r\n                  from its timeframe, molding it into a plot laced with expert zingers that could only\r\n                  spring from a rich awareness of comedic tradition. Add an appealing roster of\r\n                  costars (including Elizabeth Berkley and Charlize Theron) and you\'ve got vintage\r\n                  Woody that perks right along.\r\n\r\n                  The movie\'s also as trivial as it is engaging; hack off 30 minutes and it might have\r\n                  had the delirious precision of early Marx Brothers classics. Instead, Allen\'s goofy\r\n                  conceit--enemies falling in love by hypnotic suggestion--is stretched to absurdity\r\n                  when efficiency expert Betty Ann "Fitz" Fitzgerald (Helen Hunt) is hypnotically\r\n                  attracted to seasoned insurance investigator C.W. Briggs (Allen), despite their\r\n                  office enmity. Plus, a jewel-heist caper masterminded by the nightclub hypnotist\r\n                  (David Ogden Stiers) casts them both as suspects! Woody harvests a bumper\r\n                  crop of old-fashioned laughs from this predicament, and despite their\r\n                  conspicuous age difference and occasional awkward delivery, Hunt and Allen\r\n                  exchange volleys of dialogue like a seasoned comedy team. Dan Aykroyd is also\r\n                  good in a stodgy supporting role, but Jade Scorpion remains a mixed blessing--a\r\n                  welcomed throwback to comedy\'s yesteryear, from a master funnyman who\'s\r\n                  struggling to maintain relevance in the present. --Jeff Shannon' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00003CY6A.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00003CY6A.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 32.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 26.49 , 20 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 3 , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (40 , 'Microsoft Visual Studio .NET Professional Upgrade' , 1 , 1 , NULL , NULL , 2 , 'B00005RV50' , NULL , NULL , NULL , NULL , 'Visual Studio .NET Professional enables developers to build the next generation of Internet applications with XML Web services, database applications with XML, and RAD for the .NET Server. \r\nIt enables developers to build solutions for the broadest... ' , 0 , 'Visual Studio .NET Professional enables developers to build the next generation of Internet applications with XML Web services, database applications with XML, and RAD for the .NET Server. It enables developers to build solutions for the broadest range of clients--from Web applications to Windows to thin-client devices to smart devices. The RAD capabilities provide a shared IDE and a choice of programming languages, including Visual Basic, C++, C#, and Java. Visual Studio .NET Professional is RAD for the programmable Web.\r\nIn XML, Visual Studio .NET developers can build data-driven applications using built-in ADO.NET tools that target a variety of databases, including SQL Server, Oracle, or any other XML source. With support for XML, ADO.NET enables developers to share data across computing platforms. Additionally, Visual Studio .NET includes the Microsoft Data Engine (MSDE), a SQL Server-compatible database that provides programmers with a viable development database and natively supports XML.\r\n\r\nVisual Studio .NET allows programmers to create and deploy critical server-based programming. With Visual Studio .NET, developers can visually compose middle-tier components using the Visual Component Designer (VCD). The VCD enables developers to drag and drop nonvisual objects such as message queues, timers, and event logs to a design surface, automatically discovering all necessary server-based resources and configuring required components. \r\n\r\n' , 0 , NULL , 'This is an upgrade version. Any owner of Visual Studio 97 or Visual Studio 6.0 and later--except for standard versions--is eligible for the upgrade. ' , 'http://images.amazon.com/images/P/B00005RV50.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005RV50.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 549 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 544.99 , 1 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (41 , 'Groundhog Day (Special Edition) (1993)' , 1 , 1 , NULL , NULL , 2 , 'B00005U8EM' , NULL , NULL , NULL , NULL , NULL , 0 , 'Bill Murray does warmth in his most consistently effective post-Stripes comedy,\r\n                  a romantic fantasy about a wacky weatherman forced to relive one strange day\r\n                  over and over again, until he gets it right. Snowed in during a road-trip expedition\r\n                  to watch the famous groundhog encounter his shadow, Murray falls into a time\r\n                  warp that is never explained but pays off so richly that it doesn\'t need to be. The\r\n                  elaborate loop-the-loop plot structure cooked up by screenwriter Danny Rubin is\r\n                  crystal-clear every step of the way, but it\'s Murray\'s world-class reactive timing\r\n                  that makes the jokes explode, and we end up looking forward to each new\r\n                  variation. He squeezes all the available juice out of every scene. Without forcing\r\n                  the issue, he makes us understand why this fly-away personality responds so\r\n                  intensely to the radiant sanity of the TV producer played by Andie MacDowell.\r\n                  The blissfully clueless Chris Elliott (Cabin Boy) is Murray\'s nudnik cameraman.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005U8EM.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005U8EM.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 24.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 18.71 , 25 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (42 , 'Nothing in Common(1986)' , 1 , 1 , NULL , NULL , 2 , 'B00005UQ6M' , NULL , NULL , NULL , NULL , NULL , 0 , 'Interminably long, highly uneven comedy-drama about a perpetual adolescent\r\n                  who\'s forced to deal with his aging, unloving father when his mom leaves him flat.\r\n                  Some poignant, relevant conclusions about love and responsibility (and some\r\n                  funny shots at the advertising business) are undermined by overlength and\r\n                  meandering nature of film. Hanks is excellent; Gleason is abrasive (in his last film\r\n                  appearance). Later a TV series. Super 35.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UQ6M.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UQ6M.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.96 , 25 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (43 , 'Adobe Indesign 2.0 Promo Upgrade' , 1 , 1 , NULL , NULL , 2 , 'B00005T7C7' , NULL , NULL , NULL , NULL , 'Inspire your creativity and simplify elaborate design tasks with the latest version of Adobe\'s popular page-layout software. InDesign 2.0 offers object transparency, long-document management options, one-step table creation, XML import and export, and improved performance' , 0 , 'Adobe InDesign 2.0 page-layout software has the tools to inspire your creativity and simplify elaborate design tasks. Version 2.0 offers object transparency, long-document management options, one-step table creation, XML import and export, improved performance, and more. InDesign 2.0 delivers tight integration with other Adobe graphics applications, easy-to-use tools that reduce elaborate design tasks to a few steps, and built-in support for publishing pages anywhere--in print, on the Web, to Adobe PDF, as e-books, and more. \r\nCapture inspiration with the ability to apply drop shadows, feathering, and other editable transparency settings to any object. Use Overprint Preview for proofing spot-color effects and overprint settings. Flexible table creation tools let you turn tab-delimited text into tables in one step. Plus, get faster performance when opening, saving, and closing documents and placing high-resolution images. \r\n\r\nInDesign\'s integration with other Adobe products allows you to work more efficiently. You can directly export Adobe PDF files in Acrobat 4.0 or Acrobat 5.0 format. You\'ll have the ability to place native Photoshop and Illustrator files with the transparency preserved. InDesign 2.0 also features support for importing and exporting well-formed XML and easier tracking, management, and retrieval of InDesign documents through Adobe\'s new XML-based metadata framework. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005T7C7.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005T7C7.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99 , NULL , 0 , NULL , NULL , NULL , NULL , 1 , NULL , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (44 , 'AutoCAD LT 2002' , 1 , 1 , NULL , NULL , 1 , 'B00005M0UB' , NULL , NULL , NULL , NULL , 'Product Description\r\nAutoCAD LT 2002 is design and drawing software featuring new timesaving drawing tools. Minimize the number of steps you need to take, freeing you and your team to explore more design options. Save time with true associative dimensioning. When you... ' , 0 , 'AutoCAD LT 2002 is design and drawing software featuring new timesaving drawing tools. Minimize the number of steps you need to take, freeing you and your team to explore more design options. Save time with true associative dimensioning. When you change the geometry of any drawing, the dimensions immediately change. Work smarter and faster with new layer, text, and attribute tools, such as text scaling, the enhanced attribute editor, block attribute manager, layer translator, and an extended spell checker. Robust standards-management tools make checking and adhering to drafting standards easy, whether you work from corporate or ANSI, ISO, DIN, or JIS standards. \r\nTake your designs further by sharing and accessing design data for a more productive team. Get your design information where it\'s needed--quickly, easily, and accurately. With AutoCAD LT 2002, you\'ll enjoy 100 percent drawing file compatibility. The AutoCAD DWG format remains unchanged from AutoCAD 2000 and AutoCAD 2000i, protecting your investment in AutoCAD 2000/2000i files already in production. You can even translate your DWG files into lightweight, read-only DWF files for maximum intranet or Internet viewing and newly updated high-fidelity plotting. \r\n\r\nSave time and money with eTransmit, which bundles all your drawing files and delivers them at Net speed. Now eTransmit even builds the appropriate design standards right in. You don\'t need to be a Web expert to post your content on an intranet or any dedicated central location. Advanced Publish to Web makes it even easier to build pages and follow your corporate look and feel. Store your files online with My Files at Autodesk Point A--Autodesk\'s portal for design professionals--or on any FTP or HTTP server. Plus, with simple i-drop publishing, it\'s easy to use and reuse design content--from archived libraries to specs from a manufacturer\'s site, and more. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005M0UB.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005M0UB.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 659 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 659 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (45 , 'Corel Graphics Suite 10 Upgrade' , 1 , 1 , NULL , NULL , 2 , 'B00005OLZP' , NULL , NULL , NULL , NULL , 'Specifically designed for professional Mac users, this sophisticated graphics suite includes drawing tools, image editing features, and vector animation software. Containing CorelDRAW 10, Corel Photo-Paint 10, Corel R.A.V.E., and Canto Cumulus 5.0, Corel Graphics Suite 10 also includes built-in PDF output, professional color management, and industry-standard import and export filters. Check out the full or upgrade version today.\r\n\r\n' , 0 , 'Corel Graphics Suite 10 Upgrade works with all previous versions of CorelDRAW and Corel Photo-Paint to bring sophisticated graphics applications, including drawing tools, image editing features, and vector animation software, to your desktop. \r\nDesigned for professional Mac users in the graphic design, business, and educational communities, Corel Graphics Suite 10 features CorelDRAW 10, Corel Photo-Paint 10, Corel R.A.V.E., and Canto Cumulus 5.0. Interactive tools, context-sensitive toolbars, and Live Effects software put you in control of the design process. Advanced features, such as Web Image Optimizer and Web publishing, add flair to your sites. Built-in PDF output, professional color management, and industry-standard import and export filters ensure desired results. \r\n\r\nCorel Graphics Suite 10 Upgrade runs natively under Mac OS X and Mac OS 8.6 to 9.2. User manuals are included. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005OLZP.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005OLZP.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 249.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 234.99 , 6 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (46 , 'Picture Publisher 10 Digital Camera' , 1 , 1 , NULL , NULL , 2 , 'B00005Q5IN' , NULL , NULL , NULL , NULL , 'Picture Publisher, Digital Camera Edition was created specifically for small businesses and individuals that have made digital cameras an integral part of their business. It is flexible and powerful, yet does not require the user to spend hours... ' , 0 , 'Picture Publisher, Digital Camera Edition was created specifically for small businesses and individuals that have made digital cameras an integral part of their business. It is flexible and powerful, yet does not require the user to spend hours learning complicated software. Create high-impact graphics for print, presentations, and the Web using intuitive one-click macros and a task-oriented visual toolbar to make common tasks easy to accomplish. \r\nPicture Publisher, Digital Camera Edition provides a wide array of features that allow users to manage, correct, enhance, create, and publish digital photos. Easily input photos directly from a digital camera; effectively correct and enhance photos through a batch process; use drawing, painting, and text tools to create new images or enhance existing photos; and choose from multiple publish options including printing and HTML slide shows. \r\n\r\nThe task-oriented visual toolbar steps users through common tasks to make them easy to accomplish. One-click macros make common tasks like white balancing and color correction quick and easy. Full-screen previews make it easy to see the effects to images before making the actual change. Unlimited undos make it easy to take back that last change that wasn\'t quite right. You can then organize photos in albums that make sense, and even include the same picture in multiple albums. Manage them with ease by adding keywords for easy lookup later. Save time by working with a number of photos at once. Select the group to be worked with, then add common descriptions, keyword, names, or colors and correct them all at once. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005Q5IN.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005Q5IN.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 49 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 44.99 , 8 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (47 , 'The Typing of the Dead' , 1 , 1 , NULL , NULL , 2 , 'B00005RV5M' , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005RV5M.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005RV5M.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 19.99 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (49 , 'Survivor: The Interactive Game' , 2 , 1 , NULL , NULL , 2 , 'B00005ME4Z' , NULL , NULL , NULL , NULL , NULL , 0 , 'For the first time ever, the hit TV series Survivor has come to your PC. Play as any of the actual 32 Pulau Tiga and Australian Outback cast members or create your own character. Now you can put your skills to the test and see if you have what it takes to become the ultimate survivor.\r\nDetermine your role in the tribe by choosing from 10 essential survivor skills, such as field craft, fishing, and cooking. Form alliances and develop relationships with fellow tribe members, or choose to vote off competitors at the tribal council.\r\n\r\nLearn the ins and outs of self-preservation from the interactive Survivor bush guide while you compete in 24 reward and immunity challenges. Play through a full-, half-, or short-season game. And once you\'re up to the challenge, compete against friends via LAN or the Internet. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005ME4Z.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005ME4Z.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.99 , NULL , 0 , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 2 , 2 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (51 , 'Animosity [EXPLICIT LYRICS]' , 1 , 1 , NULL , NULL , 2 , 'B00005R5ZG' , NULL , NULL , NULL , NULL , NULL , 0 , 'For the first time in the life of the band, Sevendust (TVT Records) have had time to write and create their songs at home, not in between tour dates as they have in the past. With this new, found freedom, the band wrote 13 mind blowing, beautifully-crafted hard rock classics. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5ZG.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005R5ZG.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 17.9 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.99 , 22 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (52 , 'Sin After Sin [Expanded Edition] [ORIGINAL RECORDING REMASTERED] [EXTRA TRACKS]' , 1 , 1 , NULL , NULL , 2 , 'B00005R62O' , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R62O.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005R62O.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 11.98 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.98 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (53 , 'Every Six Seconds' , 1 , 1 , NULL , NULL , 2 , 'B00005ABO8' , NULL , NULL , NULL , NULL , NULL , 0 , 'Saliva\'s heavy rock--with a dash of rap--is at once current and timeless, unlike many of the bands spawned by Korn and Limp Bizkit. This Memphis-bred bunch\'s powerful, diverse debut features a dozen lyrically and musically focused tracks from a band clearly possessed of strong chops and smart heads. Rangy singer Josey Scott\'s passionate delivery works well when matched with the chunky riffing of "Musta Been Wrong," the soaring, layered song\'s intensity balanced by shredding guitar. Every Six Seconds has many such moments, with producer Bob Marlette\'s taut, techno-inflected touch lending "Lackluster" and "Faultline" a NIN vibe. "Hollywood" is a classic midtempo take on Tinseltown, while the CD\'s first single, "Your Disease," is simply a hit. "My Goodbyes," the ideal album closer, has a mystical musical quality befitting departed loved ones. Ultimately, Saliva\'s thoughtful, heartfelt, earthy intensity make Every Six Seconds an impressive entre from start to finish. --Katherine Turman ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005ABO8.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005ABO8.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 18.9 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 14.99 , 21 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (54 , 'There Is No Eye: Music for Photographs' , 1 , 1 , NULL , NULL , 2 , 'B00005R5ZU' , NULL , NULL , NULL , NULL , NULL , 0 , 'There Is No Eye: Music for Photographs--Recordings of Musicians Photographed by John Cohen is a great mix CD of raw, ragged, and right American folk music. Though that\'s little surprise as, since the late 1950s, John Cohen has patched together an alchemical body of work as a filmmaker, photographer, self-taught ethnographer, music writer, art professor, and musician. The CD accompanies a book of Cohen\'s beautiful, black-and-white documentary photos. Cohen really knows his folk music; his 1968 interview with Harry Smith for the Sing Out! fanzine remains the Rosetta stone for the all-important Anthology of American Folk Music, and as one-third of the New Lost City Ramblers he helped bring the visceral pleasures of true traditional Americana to a larger audience during the folk revival. This collection is wide-ranging and largely unerring. From Beat jazz to gospel, Appalachian a cappella singing to a Peruvian string band--it\'s all here, with no slick O Brother arrangements or anything else to get in the way of the music as it would have been heard on front porches, small clubs, and backyards. About a third of the tracks are previously unreleased; Dylanologists will need this CD for a swell unreleased track by the young Bobby, a version of "Roll on John" from a 1961 WBAI radio broadcast. --Mike McGonigal ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5ZU.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005R5ZU.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 16.9 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.99 , 18 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (56 , 'Proverbial Wisdom Board Game' , 1 , 1 , NULL , NULL , 2 , 'B00000IS2G' , NULL , NULL , NULL , NULL , NULL , 0 , 'Although it takes only two to tango, it takes at least four people to play\r\n                       Proverbial Wisdom (of course, the more the merrier). Teams try to make\r\n                       heads or tails of sketches drawn by the presiding Wisdom Master (every\r\n                       picture tells a story!). They must also identify common sayings drawn on\r\n                       game cards, and choose the meaning of proverbs from three given\r\n                       options. The first team to get all the way around the board and solve the\r\n                       final sketch clue wins. After a few rounds, you and your friends and family\r\n                       will be spouting bits of conventional wisdom and age-old sayings\r\n                       everywhere you go. This great game isn\'t easy, but as they say... practice\r\n                       makes perfect! --Rachel Radway ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00000IS2G.01.17TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00000IS2G.01.DTLS.MZZZZZZZ.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 29.99 , NULL , NULL , NULL , 4.09 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 24.99 , 17 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 2 , 6 , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (57 , 'Five Stories' , 1 , 1 , NULL , NULL , 2 , 'B00005R62D' , NULL , NULL , NULL , NULL , NULL , 0 , 'Part of Boston\'s vibrant (and crowded) singer-songwriter scene, Kris Delmhorst stands out thanks to a gorgeous, tender, evocative voice and a textured and varied musical palette. She opens with a funked-up reworking of "Cluck Old Hen," complete with Beck-like banjo, followed by the bittersweet "Damn Love Song," where only acoustic guitar, cello, and accordion color in the lines behind her. "Broken White Line" is graced with delicate strains of pedal steel and mandolin, while the ominous, languid "Just What I Meant," a highlight here, crawls along with occasional bursts of cello and baritone sax. And her wounded voice on the haunting chorus of "Gave It Away" sends shivers. While Delmhorst is at her most appealing when the musical settings are ambitious, her lyrics seem to benefit from a more restrained approach. Thus, songs like "Words Fail You" and "Yellow Brick Road"--with basic musical tracks and too-clever words--fall comparatively flat. But for the most part, this is a powerful sophomore effort, one where elements of traditional roots-based folk successfully mingle with modern singer-songwriter flourishes. --Marc Greilsamer ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R62D.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005R62D.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 16.9 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.99 , 18 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (58 , 'One Thousand Pennies' , 1 , 1 , NULL , NULL , 2 , 'B00005UP2Z' , NULL , NULL , NULL , NULL , NULL , 0 , 'Canadian entertainer Norman Foote\'s songwriting talents come to the fore on his new CD, One Thousand Pennies. An outstanding collection of 13 new songs, each featuring exquisite arrangements. Once again Norman puts his theatrical and comedic talents to use as he weaves stories and paints musical imagery with character voices that young listeners can respond to immediately. The songs are playful, with clever lyrics and melodies combining a variety of musical styles. \r\nA Song Sampling from One Thousand Pennies: \r\n\r\nThe title song, "One Thousand Pennies" with its Celtic beat takes us to a child\'s thoughts of what he thinks he can buy with One Thousand Pennies. Maybe to him they are magic pennies and seem to be worth much more than money itself. Loose Tooth is a conversation between a father and his child. All fathers would love to pull out their child\'s loose tooth if their child would only let them. This song has a comedic twist to its ending with the child saying to his father "If you really want to pull out someone\'s tooth pull one out of your own". Graduation Day has another cool Latin American beat and paints a picture of a child on his graduation day. It also has a comedic surprise ending when we learn he has only graduated from kindergarten. Norman\'s sensibility on this song shows how he can relate to young listeners ."I\'m ready for grade one, I can tie my shoes. I don\'t need velcro". Snuggle Up is a sweet sing-along type of tune that reminds us all of how wonderful a snuggle can be! Lost Umbrellas and Odd Socks takes us on a fanciful and imaginative journey to the land of lost umbrellas. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UP2Z.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UP2Z.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 13.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.99 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (59 , 'The Simpson\'s Loser Takes All Game' , 1 , 1 , NULL , NULL , 2 , 'B00005LBAP' , NULL , NULL , NULL , NULL , NULL , 0 , 'Losers of the world, unite! In the Simpson\'s Loser Takes All Game, players\r\n                       travel around the board and ask themselves some of life\'s most important\r\n                       questions. "Can I flip my eyelids up?" "Have I ever photocopied a body\r\n                       part?" Here\'s the catch: another player has to predict what your answer\r\n                       will be. If your answers are different, you lose a Character card. And in\r\n                       this game, that\'s a good thing. If the two answers match, the other player\r\n                       gets to lose a Character card. The player with the least amount of points\r\n                       accumulated from Junk Food Tokens, Fake Money, and Character cards,\r\n                       is the loser--and wins the game. Homer would be so proud! ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005LBAP.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005LBAP.01.DTLS.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.99 , NULL , NULL , NULL , 2.2 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 3 , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (60 , 'Free To Be ... You And Me (1972 Television Cast) [CAST RECORDING]' , 1 , 1 , NULL , NULL , 2 , 'B000002VDL' , NULL , NULL , NULL , NULL , NULL , 0 , 'There are thousands upon thousands of children\'s albums out there, but the one that quietly left its mark with more \'70s children than perhaps any other album was this disc. Free to Be...You and Me was a pet project of proud feminist Marlo Thomas (a.k.a. "That Girl"), and it was born--according to the liner notes--by the desire to provide her niece with music "to celebrate who she was and who she could be." Harry Belafonte sings "Parents Are People," ex-football great Rosie Grier offers an incredible, touching melody titled "It\'s All Right to Cry," and Diana Ross waxes future-positive on "When We Grow Up." A great hour of brain food for young--and not-so-young--children. --Denise Sheppard ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000002VDL.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B000002VDL.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 11.98 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.98 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (61 , 'Trivial Pursuit Genus 5 Game' , 1 , 1 , NULL , NULL , 2 , 'B00005BY4G' , NULL , NULL , NULL , NULL , NULL , 0 , 'e first edition of Trivial Pursuit (early 80s?) was a great game that\r\n                       contributed to the emergence of the whole social games genre. But as a\r\n                       young teenager, I knew nothing about JFK\'s cabinet members, the rat\r\n                       pack, or dead movie stars, and this made the game impossibly difficult\r\n                       (and unbearably long). Between then and now, the questions have been\r\n                       modernized AND we\'ve all gotten older and more experienced. Genus 5 is\r\n                       perfectly targeted at the 30ish crowd, and more playable than the original\r\n                       for those younger or older. The questions are fairly balanced and\r\n                       reasonable.\r\n\r\n                       As always, the metagame of Trivial Pursuit (the board part) is, well, trivial\r\n                       and adds little of interest to the game play. It\'s really just a framework for\r\n                       asking each other trivia questions and there is no significant strategy\r\n                       involved. The artwork is pretty uninspired as well.\r\n\r\n                       Overall, Trivial Pursuit Genus 5 Edition is a solid, more playable version of\r\n                       a classic game.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BY4G.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005BY4G.01.DTLS.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 29.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 29.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (62 , 'Playhouse Disney' , 1 , 1 , NULL , NULL , 2 , 'B00005NWKX' , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005NWKX.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005NWKX.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 12.9 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 12.33 , 5 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (63 , 'Candy Land 50th Anniversary Edition' , 1 , 1 , NULL , NULL , 2 , 'B00000JGQA' , NULL , NULL , NULL , NULL , NULL , 0 , 'This perennial favorite prereading game has gotten a makeover for its 50th\r\n                       anniversary. The basics are the same: players still move ahead according\r\n                       to the color of the card they draw; they still try to avoid getting stuck in the\r\n                       Molasses Swamp; and they still thrill when they draw the magical Queen\r\n                       Frostine card. It\'s the game\'s graphics that have been updated. A\r\n                       three-dimensional version of the Candy Castle beckons at the end of the\r\n                       trail; the playing pieces look remarkably like gingerbread-folk come to life;\r\n                       and even the color blocks on the cards have a tastefully decorative frame\r\n                       around them. The whole thing is packed in a collector\'s tin for safekeeping.\r\n                       --Lisa Whipple ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00000JGQA.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00000JGQA.01.DTLS.MZZZZZZZ.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.99 , NULL , NULL , NULL , 2.3 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 19.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (64 , 'No Nagging' , 1 , 1 , NULL , NULL , 2 , 'B00005QK1W' , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005QK1W.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005QK1W.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 17.9 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.99 , 11 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (65 , 'Standard Scrabble' , 1 , 1 , NULL , NULL , 2 , 'B00000IWDB' , NULL , NULL , NULL , NULL , NULL , 0 , 'After all these years, it\'s still hard to get a triple word score, the tiles are\r\n                       still made of wood, and there\'s only one "X" in the whole box. The game of\r\n                       Scrabble has sparked feuds and a near-cult following. All the fuss is over a\r\n                       spelling game that hasn\'t had an upgrade in 50 years. It takes a little luck\r\n                       and a lot of skill to make high-scoring words out of seven little letters,\r\n                       sometimes with an overabundance of vowels and letters that don\'t go\r\n                       together--sometimes there\'s Q without U. Two to four players battle it out\r\n                       on the board, and while some players might be proud of impressive words\r\n                       ("I spelled gestalt!"), skilled players know how to use the premium letter\r\n                       and word squares on the 225-square board to their best advantage. This\r\n                       crossword game has strict rules (no names, no slang) and comes with a\r\n                       warning label: "Choose a dictionary first to avoid any ugly word disputes."\r\n                       --Lynne Sampson \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00000IWDB.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00000IWDB.01.DTLS.MZZZZZZZ.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 11.99 , NULL , NULL , NULL , 1.5 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 11.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (66 , 'Music Inspired by Middle Earth featuring David Arkenstone' , 1 , 1 , NULL , NULL , 2 , 'B00005R5LV' , NULL , NULL , NULL , NULL , NULL , 0 , 'It\'s very hip to refer to Tolkien, given the success of Lord of the Rings on celluloid. But to be fair to David Arkenstone, he\'s always been inspired by the master fantasy author, so the release of this album just happens to be timely. A collaboration between composer-multi-instrumentalists David and Diane Arkenstone, the disc features many of David\'s trademarks as it incorporates influences as diverse as Aaron Copland, international sounds, and progressive rock. With both orchestral and ethnic instruments at their disposal, the composers and their Middle Earth Orchestra journey from grand symphonic peaks to delicate valleys, including the grand fanfare of "Field of Cormallen," the mysterious and ethereal atmosphere of "Palantir," and the lively, Renaissance-flavored dance of "Road to Rivendell." While this ode to Middle Earth is nothing groundbreaking within Arkenstone\'s extensive catalog, it\'s still an amiable, engaging album that will appeal to longtime listeners and intrigue many fantasy fans. --Bryan Reesman ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5LV.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005R5LV.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 16.9 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 12.99 , 23 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (67 , 'The Soul Of Healing Meditations' , 1 , 1 , NULL , NULL , 2 , 'B00005TZSK' , NULL , NULL , NULL , NULL , NULL , 0 , 'Featuring the soothing narration of Deepak Chopra over the trancelike music of Adam Plack, The Soul of Healing Meditations serves as an introduction to meditation for neophytes and as a more advanced tool to help overcome a physical ailment and/or emotional toxicity. That may make it sound like a digital elixir, but as Chopra says in his liner notes: "We like to tell our patients (at the Chopra Center for Well Being) that the body is the best pharmacy in the world and is capable of making wonder drugs." His message here is that one can naturally prevail over serious life challenges by becoming more attuned to one\'s body--by relaxing and filtering out the external world, focusing on and influencing internal sensations and biorhythms, and banishing negative thoughts and focusing on the positive aspects of life. This CD is not meant as a cure-all for physical or emotional ills. Rather, it\'s a supplemental experience to other treatments or programs, and it shows how enlightening and empowering meditation can be when practiced properly. Its actual effects will depend upon the receptiveness of the listener. Plack\'s accompanying soundtrack ranges from delicate ambient tones to more active Indian music, appropriately serving the mood of each of the album\'s eight tracks. --Bryan Reesman ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005TZSK.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005TZSK.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 17.9 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.99 , 22 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (68 , 'Across an Ocean of Dreams' , 1 , 1 , NULL , NULL , 2 , 'B00005UF2F' , NULL , NULL , NULL , NULL , NULL , 0 , 'What does the ocean dream? Glimpse into the depths of jeweled waters and the fantasia within. Surrender to the siren call. Come! Be transported under the waves, flowing with 2002\'s delicate strings, guitar, flute, keyboard and distant voices of angels of the deep. 2002 - Favorites on Billboard\'s New Age Chart for the past five years! \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UF2F.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UF2F.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 17.9 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 14.99 , 17 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 0 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (69 , 'My Life Belongs To You' , 1 , 1 , NULL , NULL , 2 , 'B00005TQ18' , NULL , NULL , NULL , NULL , NULL , 0 , 'It seems pretty clear that Ronan Tynan has no intention of resting on his laurels. Despite a stunning string of world-dominating, top-selling releases as a member of the much-loved Irish Tenors--not to mention his accomplishments as a champion athlete, an M.D., and a memoirist (see his recently published Halfway Home: My Life \'til Now)--the singer has now released his debut solo effort on Sony Classical. No matter which member of the Irish Tenors happens to be your favorite, My Life Belongs to You is a treat, affording as it does a chance to bask in the deeply expressive, mellifluous voice of Tynan. He has chosen his selections well and is equally poised and tender in classics from Mario Lanza ("Because You\'re Mine," "I\'ll Walk with God"), Broadway, and sacred music. What\'s especially wonderful is the opportunity to hear Tynan\'s emotionally gripping vocalism from so many angles. The mixing by Frank McNamara gives a lovely old-time feeling to the orchestral playing--a bit like a treasured old sepia photograph. A bonus track of Irving Berlin\'s "God Bless America" is included. --Sarah Chin \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005TQ18.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005TQ18.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 13.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.29 , 5 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 2 , 2 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (70 , 'Barbie Toddler Helmet Value Pack' , 1 , 1 , NULL , NULL , 2 , 'B000054A9P' , NULL , NULL , NULL , NULL , NULL , 0 , 'Little girls can cycle, scooter, skate, and skateboard in style with this\r\n                       colorful, flowered Barbie helmet set. Manufactured by Bell Sports, bicycle\r\n                       helmet specialists, this seven-vent helmet has adjustable straps and\r\n                       additional foam pads to fit a child between 1 and 4 years of age.\r\n                       Composed of a foam liner and covered with a tight plastic shell, the helmet\r\n                       complies with CPSC (Consumer Product Safety Commission) standards\r\n                       for this age group. In our nonscientific study, it endured several hard\r\n                       slams by an adult to the edge of a desk, without showing any damage.\r\n                       With the addition of a sturdy pair of pink glasses with flip-up sun lenses in\r\n                       flowered rims and an 8-ounce water bottle, this ensemble will be a big hit\r\n                       with Barbie fans. --Diane Tuman ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000054A9P.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B000054A9P.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.99 , NULL , NULL , NULL , 1 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 19.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (71 , 'Cristal: Glass Music Through The Ages' , 1 , 1 , NULL , NULL , 2 , 'B00005UT2L' , NULL , NULL , NULL , NULL , NULL , 0 , 'The haunting, ethereal tone of the glass armonica, which was invented by Ben Franklin in 1761, was said to drive its players insane. On Cristal, Dennis James risks madness as he surveys three centuries of music composed for Franklin\'s armonica, and two other glass instruments called the seraphim and the cristal baschet. Most of the selections date from the armonica\'s first period of popularity, which started in the late 1700s and ended in the 1830s, and include compositions by Hasse, Apell, Scmittbauer, a composer who also made armonicas, and Mozart, who composed the Adagio and Rondo for armonica just weeks before he died. James is joined on the Mozart piece by the Emerson String Quartet, who also play on Garry Eister\'s Quintet for Glass and Strings, one of the few 20th century pieces written for armonica. Cristal was produced by Linda Rondstadt, who also sings a duet with Ruth Ann Swenson on a lovely arrangement of Faur\'s Pavane. Ronstadt wisely avoids trying to turn this into a pop crossover and instead lets the fragile beauty of the music speak for itself. --Michael Simmons ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UT2L.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UT2L.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 17.9 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.99 , 11 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (72 , 'Acrobat Sno Board' , 1 , 1 , NULL , NULL , 2 , 'B000050B39' , NULL , NULL , NULL , NULL , NULL , 0 , 'Sharp cut Edge- Twin tip freestyle design- sidecut for easy turning- New\r\n                       toe strap design for younger riders. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000050B39.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B000050B39.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.99 , NULL , NULL , NULL , 2.55 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 15.99 , 20 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (73 , 'Verdi - Messa da Requiem / Gheorghiu  Barcellona  Alagna  Konstantinov  Berliner Philharmoniker  Abbado' , 1 , 1 , NULL , NULL , 2 , 'B00005MG6F' , NULL , NULL , NULL , NULL , NULL , 0 , 'Verdi\'s Requiem--certainly one of his most moving, eloquent masterpieces--was written in honor of the great Italian poet Alessandro Manzoni, whom he admired enormously both for his writings and his political outlook. Though its text is the Latin liturgy, it has been called Verdi\'s greatest opera because of its basically dramatic character, as well as his own ambivalent attitude toward organized religion. Thus, interpretations tend to emphasize its secular or its sacred aspect, though, naturally, the soloists are trained in the Verdi opera tradition.\r\nFor example, Toscanini\'s legendary performance, recorded live at Carnegie Hall in 1951, takes exactly the opposite approach to this version. Inwardly expressive, noble, devout, pleading, prayerful, yet with plenty of dramatic intensity, the Toscanini encompasses every human emotion and offers a synthesis of Verdi\'s vision of the earthly and the sublime. The performers on this recording, captured live on the 100th anniversary of Verdi\'s death, take the theatrical view. The soloists swoop and slide, sob and sigh, and overdramatize the fear and trembling. Tenor Roberto Alagna belts out his part in the best operatic style, the bass sounds rough, the alto\'s vibrato wobbles, but soprano Angela Gheorghiu soars radiantly. The choruses are good, the orchestra is wonderful, but the dynamic contrasts go from inaudible to ear-splitting. --Edith Eisler \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005MG6F.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005MG6F.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 16.9 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.49 , 9 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (74 , 'Avalanche Double Snow Tube' , 1 , 1 , NULL , NULL , 2 , 'B00005RV4D' , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005RV4D.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005RV4D.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 24.99 , NULL , NULL , NULL , 5 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 24.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (75 , 'Baby Sleigh' , 1 , 1 , NULL , NULL , 2 , 'B000050B0J' , NULL , NULL , NULL , NULL , NULL , 0 , 'I\'m sorry to say that I was very disapointed with the quality of this product.\r\n                       I had 2 concerns with the build quality of the sleigh, 1st the side rails were\r\n                       not mounted securely and were prone to wobbling which did not instill\r\n                       confidence in their safety factor. Secondly was with the mounting set-up\r\n                       for the runners of the sleigh, the surface that the runers mounted too was\r\n                       almost twice as wide as the actual runners themselves which caused the\r\n                       snow to build up under the sleigh creating a fair amount of drag, which\r\n                       could cause the sleigh to become unstable and tip over. I have since\r\n                       returned the sleigh and am currently looking for another that is built better.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000050B0J.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B000050B0J.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 39.99 , NULL , NULL , NULL , 7.15 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 39.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 2 , 2 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (76 , '110 Hyper Sno Board' , 1 , 1 , NULL , NULL , 2 , 'B000050B0A' , NULL , NULL , NULL , NULL , NULL , 0 , 'Overall, this snowboard is very good. I definitely recommend it. The only\r\n                       thing that prevented it from getting five stars in the "fun" category is that\r\n                       the manner in which you adjust the straps is very cumbersome. I got this\r\n                       as a gift for my nephew, and he wanted to go outside and try it out\r\n                       immediately. But it took us a long time to get the foot straps the right size\r\n                       for him. They are made of two pieces of plastic, each with two rows of\r\n                       holes in them. You choose the hole that is the right size for the kid\'s foot,\r\n                       then you connect them with a screw and nut combination that is pretty\r\n                       awkward. I would say that it was worth it, however, since he and his\r\n                       brother argued over whose turn it was for until their father made them\r\n                       come inside. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000050B0A.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B000050B0A.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.99 , NULL , NULL , NULL , 4.1 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 19.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (77 , '28" Clifford with Sound' , 1 , 1 , NULL , NULL , 2 , 'B00005BRS3' , NULL , NULL , NULL , NULL , NULL , 0 , 'Clifford the Big Red Dog comes to life for his fans in the form of this\r\n                       28-inch-long plush pooch. A soft, rich red coat and Clifford\'s other familiar\r\n                       features--big paws, happy eyes, and a kind smile--combine to welcome\r\n                       friends into his furry embrace. Clifford\'s curled tail, yellow bone collar, and\r\n                       patch of black yarn hair complete his well-loved look. But he does more\r\n                       than sit around as your child\'s big ol\' buddy. Clifford makes three\r\n                       distinctive barks when his left paw is pressed, thanks to a battery-powered\r\n                       chip inside his large, soft body. Each bark seems to impart something\r\n                       different and important: your child can use his or her imagination to figure\r\n                       out just what Clifford is trying to say... --Diane Beall ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BRS3.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005BRS3.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 39.99 , NULL , NULL , NULL , 3.2 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 29.99 , 25 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (78 , 'Apple iBook Notebook (600-MHz PowerPC G3, 256 MB RAM, 20 GB hard drive)' , 1 , 1 , NULL , NULL , 2 , 'B00005V5YU' , NULL , NULL , NULL , NULL , 'The new Apple iBook Notebook sports the largest display ever at 14 inches. Other features include a 600 MHz PowerPC G3 processor, 256 MB of SDRAM, a 20 GB Ultra ATA hard drive, a combination CD-RW and DVD-ROM drive, and Mac OS X.' , 0 , 'Now there\'s even more to love about Apple\'s iBook notebook. Weighing in at an easily portable 5.99 pounds and featuring a 600 MHz PowerPC G3 processor, a 20 GB hard drive, and 256 MB of RAM (expandable to 640 MB)--plus AirPort wireless networking and FireWire, USB, and Ethernet ports--the iBook connects to hundreds of peripherals designed to fit your life.\r\nThis system features a brilliant 14.1-inch TFT XGA active-matrix display and razor-sharp 1,024 x 768 resolution. It\'s the perfect place for doing everything from working on spreadsheets to displaying your movies and digital pictures in millions of colors (incidentally, the iBook display scales down beautifully, again with millions of colors, for special games and applications optimized for 800 x 600 or 640 x 480 resolutions). It\'s a marvel that such a wide screen has been fitted into a notebook computer that measures just 12.7 inches wide, 10.2 inches deep, and 1.35 inches thick. Note also the fit and finish that has always been a big part of the appeal of the iBook, as well as the subtle design touches that make it the quintessential consumer portable.\r\n\r\nIncluded is a CD-ROM drive for playing games and music CDs, as well as the option to upgrade with a DVD-ROM for enjoying DVD movies. The 600 MHz iBook ships with a 20 GB Ultra ATA hard disk drive, or upgrade to an optional 30 GB hard drive for even more storage space. In addition, this system comes with the ATI Rage Mobility 128 graphics accelerator with 8 MB of SDRAM and AGP 2x support for gorgeous 3-D graphics.\r\n\r\nThe iBook also comes loaded with iPhoto, the cool new software application in the easy-to-use tradition of iTunes, iMovie, and iDVD. iPhoto makes it a snap to manage your digital pictures. You can present them in a full-screen slide show (accompanied by your favorite music), e-mail them to your family and friends, print them on your inkjet printer, order Kodak prints over the Internet, or have them made into custom-printed, linen-bound books.\r\n\r\nIn addition to handling digital photos with ease, the iBook lets you make your own movies--and show them anywhere. Capture digital video footage on your DV camcorder and turn it into engaging movies with the iMovie 2 software that comes pre-installed. iMovie lets you transfer video clips from your digital camcorder to your hard disk using the included FireWire port. Use iMovie to snip out the boring parts and enhance the best parts with cool effects, transitions, and titles. Then add a great soundtrack and you\'re done. Now watch your finished movies full-screen on your iBook or use the iMovie Export feature to select from a range of predefined QuickTime formats for creating and sharing movies. You can, for example, compress your movies so you can burn them onto a CD or post them on the Internet, or use the VGA video output port (for video mirroring on an external display) and an AV port to show your movies and presentations on a big-screen TV or projector (just add an optional Apple AV cable).\r\n\r\nFor those interested in audio as well as video applications, the iBook comes with iTunes 2, the software that lets you convert (or "rip") the songs on your music CDs to MP3 format, simply by clicking a button. iTunes compresses CD-quality audio files to about a tenth of their original size with very little loss in audible quality. These significantly smaller file sizes enable you to store thousands of songs on your iBook\'s hard disk drive. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005V5YU.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005V5YU.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1799 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 1799 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (79 , 'Briarberry Friends: Lavender Berrybeth' , 1 , 1 , NULL , NULL , 2 , 'B00000IZWR' , NULL , NULL , NULL , NULL , NULL , 0 , 'She may look shy, but Berrybeth is no shrinking violet. She\'s one in a\r\n                       series of beautiful, collectable, fun teddy bears from the Briarberry Patch\r\n                       collection. Berrybeth has fur colored a hazy lavender hue, and she wears\r\n                       a light purple dress and bow. The tints of lavender and lilac bring out the\r\n                       blush in her cheeks and the brightness in her blue eyes. Read Berrybeth\'s\r\n                       story and collect all her Briarberry friends. The set is great for collectors\r\n                       of plush toys, or little girls who want a friendly companion. --Courtney\r\n                       Hudak ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00000IZWR.01.TZZZZZZZ.gif' , NULL , 'http://images.amazon.com/images/P/B00000IZWR.01.MZZZZZZZ.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.99 , NULL , NULL , NULL , 0.5 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 9.98 , 33 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (80 , 'Compaq Presario 2715US Notebook (1.13-MHz Pentium III, 512 MB RAM, 30 GB hard drive)' , 1 , 1 , NULL , NULL , 2 , 'B00005UT2X' , NULL , NULL , NULL , NULL , 'As a notebook for business or entertainment, Compaq\'s Presario 2715US offers a combination of solid features and price that is tough to beat. It boasts a 1.13 GHz Pentium III processor, 512 MB of RAM (expandable to 1,024 MB), a 15-inch,... \r\n Read more \r\n' , 0 , 'As a notebook for business or entertainment, Compaq\'s Presario 2715US offers a combination of solid features and price that is tough to beat. It boasts a 1.13 GHz Pentium III processor, 512 MB of RAM (expandable to 1,024 MB), a 15-inch, active-matrix, flat-panel screen, and both an 8x (write) CD-RW and 8x DVD-ROM drive. Also included are a 30 GB hard disk, a 56K modem, and a 10/100 Mbps Ethernet NIC. To round out this Presario\'s versatile package, the pre-installed operating system is Windows XP Home. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UT2X.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UT2X.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 2099 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 2099 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (81 , 'Jumbo Music Block' , 1 , 1 , NULL , NULL , 2 , 'B00005BHTK' , NULL , NULL , NULL , NULL , NULL , 0 , 'Jumbo Music Block is big on fun and big on learning! Designed to help\r\n                       children learn shapes, colors, and dressing skills, this giant foam block\r\n                       features fun music, surprise pockets, and interactive activities. Each side\r\n                       plays two children\'s songs - toe-tapping classics and jazzy new tunes\r\n                       entertain children while reinforcing shape learning and language skills. Each\r\n                       side of this huggable oversized block also features a colorful geometric\r\n                       shape and a secret surprise pocket. Zippers, snaps, and buttons develop\r\n                       fine motor skills and challenge children to uncover whimsical activities\r\n                       including a shiny peek-a-boo mirror, an ABC & 123 book, and a wiggly busy\r\n                       ball. Batteries sold separately. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BHTK.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005BHTK.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 59.99 , NULL , NULL , NULL , 6.2 , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 59.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (82 , 'IBM Thinkpad T23 Notebook (1.2-GHz Pentium III, 128 MB RAM, 48 GB hard drive)' , 1 , 1 , NULL , NULL , 2 , 'B00005TSMH' , NULL , NULL , NULL , NULL , '1.2 GHz Intel Pentium III, 128 MB SDRAM, 48 GB EIDE Hard Disk, 24x (read), 8x (write), 4x (rewrite) CD-RW, and Windows XP Professional, IBM Software Installer, IBM Access Connections ' , 0 , 'Highly portable and with plenty of processing speed, the ThinkPad T23 has a lot to offer those seeking a business-oriented notebook. Consider, for example, its 1.2 GHz Pentium III chip, 48 GB hard disk, and 128 MB of RAM (expandable to 1,024 MB). A large 14.1-inch, active-matrix screen and 24x (read), 8x (write), 4x (rewrite) CD-RW drive make this system adequate in the area of entertainment as well. The installed operating system is Windows XP Professional, which adds business-oriented security and networking features to Microsoft\'s Windows 2000 OS. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005TSMH.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005TSMH.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 3599 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 3599 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (83 , 'Compaq Presario 5410US Desktop (1.3-GHz Celeron, 256 MB RAM, 40 GB hard drive)' , 1 , 1 , NULL , NULL , 2 , 'B00005UT2R' , NULL , NULL , NULL , NULL , '1.3 GHz Intel Celeron, 256 MB SDRAM, 40 GB Hard Disk, 8x (write) CD-RW, 16x DVD-ROM, and Windows XP Home Edition, Microsoft Money 2001, Windows Media Player 7, Microsoft Works 6.0, Selective QuickRestore, ... ' , 0 , 'Whether you\'re looking for a corporate, multimedia, or family desktop, Compaq\'s Presario 5410US is a solid choice. Just look at some of its features: an 8x (write) CD-RW and 16x DVD-ROM drive, a 1.3 GHz Celeron chip, and 256 MB of RAM (expandable to 512 MB). Its price is lower than average both for desktops as a whole and among similarly rated products, continuing Compaq\'s price-conscious tradition. The product also includes a 40 GB hard disk, integrated graphics, a 56K modem, and a 10/100 Mbps Ethernet NIC. In addition, the Presario 5410US features Windows XP Home as the pre-installed operating system. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UT2R.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UT2R.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 699 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 699 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (84 , 'Compaq Presario 5400US Desktop (1.2-GHz Celeron, 128 MB RAM, 20 GB hard drive) + Compaq MV540 15" Monitor' , 1 , 1 , NULL , NULL , 2 , 'B00005V7HD' , NULL , NULL , NULL , NULL , '1.2 GHz Intel Celeron, 128 MB SDRAM, 20 GB Hard Disk, 8x (write) CD-RW, This bundled system comes with a 15" Monitor, and Windows XP Home Edition, Microsoft Money 2001, Windows Media Player 7, Microsoft Works 6.0, Selective QuickRestore, ... ' , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005V7HD.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005V7HD.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 868 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 868 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (85 , 'Compaq Deskpro 4000 Desktop (266-MHz Pentium II, 32 MB RAM, 3.2 GB hard drive)' , 1 , 1 , NULL , NULL , 2 , 'B00005V600' , NULL , NULL , NULL , NULL , '266 MHz Intel Pentium II, 32 MB RAM,  3.2 GB Hard Disk, Included CD-ROM, and No Operating System ' , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005V600.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005V600.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 115.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 115.95 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (86 , 'Apple iMac Desktop, graphite (600-MHz PowerPC G3, 256 MB RAM, 40 GB hard drive)' , 1 , 1 , NULL , NULL , 2 , 'B00005NK3C' , NULL , NULL , NULL , NULL , '600 MHz PowerPC G3, 256 MB SDRAM, 40 GB Hard Disk, 24x (read), 8x (write), 4x (rewrite) CD-RW, and Mac OS 9 and below, Mac OS X, QuickTime, iMovie 2, iTunes, AppleWorks, Microsoft Internet Explorer, Microsoft Outlook ... ' , 0 , 'If you like the all-in-one design of the iMac desktop but need more power than entry-level units offer, this enhanced model may be right for you. It includes a PowerPC G3 chip running at 600 MHz, 256 MB of RAM (expandable to a gigabyte), and a 40 GB hard disk drive. That\'s big enough to store thousands of MP3 music files, for example--and the included CD-RW drive makes it easy to burn your own CDs. A 56K modem and 100 Mbps networking are standard. The system\'s integrated case design, in a translucent gray that Apple calls "graphite," houses a 15-inch monitor with 13.8-inch viewable area. The system comes with both the classic Mac OS 9 and the slick new Mac OS X installed. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005NK3C.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005NK3C.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 994 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 994 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (87 , 'Apple Power Mac Desktop (1-GHz Dual Processor PowerPC G4, 512 MB RAM, 80 GB hard drive)' , 1 , 1 , NULL , NULL , 2 , 'B00005YXCD' , NULL , NULL , NULL , NULL , 'Dual 1 GHz PowerPC G4, 512 MB SDRAM, 80 GB Ultra ATA Hard Disk, 24x (read), 8x (write), 4x (rewrite) CD-RW, 6x (read), 2x (write) DVD-R, and Mac OS 9 and below, Mac OS X, QuickTime, iMovie 2, iPhoto, iTunes 2, Mac OS X Mail, iDVD 2, DVD Player, Microsoft ... ' , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005YXCD.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005YXCD.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 2999 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 2999 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (88 , 'Compaq Presario 5420US Desktop (Athlon XP 1700+, 512 MB RAM, 80 GB hard drive)' , 1 , 1 , NULL , NULL , 2 , 'B00005UT2S' , NULL , NULL , NULL , NULL , '1.47 GHz AMD Athlon XP, 512 MB SDRAM, 80 GB Hard Disk, 16x (write) CD-RW, 16x DVD-ROM, and Windows XP Home Edition, Microsoft Money 2001, Windows Media Player 7, Microsoft Works 6.0, Selective QuickRestore, ...  \r\n' , 0 , 'It would be hard to go wrong with a system like the Compaq Presario 5420US. Equipped with a 1.7 GHz Athlon XP processor, an 80 GB hard disk drive, and 512 MB of RAM (expandable to 1,536 MB), it has all the basics covered--and then some. For ease of use, improved multimedia, and better support of peripherals, Compaq has installed Windows XP Home Edition. To enhance multimedia applications and Internet connectivity, this system includes a 16x (write) CD-RW and 16x DVD-ROM drive, integrated graphics, a 56K modem, and a 10/100 Mbps Ethernet NIC. All these features at a price lower than most comparably equipped desktops make this system a versatile addition to any home or office. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UT2S.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UT2S.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 899 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 899 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (89 , 'Compaq Presario 5420US Desktop (Athlon XP 1700+, 512 MB RAM, 80 GB hard drive) + Compaq FS740 17" Monitor' , 1 , 1 , NULL , NULL , 2 , 'B00005V7J8' , NULL , NULL , NULL , NULL , '1.47 GHz AMD Athlon XP, 512 MB SDRAM, 80 GB Hard Disk, 16x (write) CD-RW, 16x DVD-ROM, This bundle comes with Compaq 17" Monitor, and Windows XP Home Edition, Microsoft Money 2001, Windows Media Player 7, Microsoft Works 6.0, Selective QuickRestore, ... ' , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005V7J8.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005V7J8.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1298 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 1298 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (92 , 'NEC MultiSync FP1370 Totally Flat 22" Monitor (PC/Mac)' , 1 , 1 , NULL , NULL , 2 , 'B00004Y6C8' , NULL , NULL , NULL , NULL , NULL , 0 , 'The NEC MultiSync FP1370 totally flat 22-inch monitor is ideal for users whose work demands high-end performance. This full-featured 22-inch (20-inch viewable) display is well suited for CAD/CAM, graphic design, desktop publishing, animation, document imaging, prepress, medical imaging, and Web design applications. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004Y6C8.01.11TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00004Y6C8.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 899.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 799.99 , 11 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 3 , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (94 , 'KDS VS-21E 21" Monitor' , 1 , 1 , NULL , NULL , 2 , 'B00001R3VE' , NULL , NULL , NULL , NULL , 'The VS-21e is designed for imaging and CAD/CAM/CAE professionals who want maximum performance for today\'s technology. A powerful tool for high-end graphics, production, scientific, and engineering design applications, its advanced features deliver sharp pictures, crisp colors, and precise lines with virtually no eyestrain. \r\n' , 0 , 'If you\'re tired of squinting at the small monitor in front of you, the KDS Visual Sensation 21e is the 21-inch solution to your tiny-display woes. Whether you\'re a high-end CAD user, graphics professional, or even a casual user, the KDS VS-21e offers an advanced and robust display at a slim price. This massive display provides 19.9 inches of display, perfect for those who are bogged down by the clutter of overlapping windows.\r\nThe display quality of the KDS VS-21e amazed us; the display has rich color and tight contrast and brightness controls. We found the DVD playback to be bright and colorful, as were screens using various graphics programs. Onscreen controls include RGB color temperature, pincushion controls, horizontal and vertical convergence adjustment, and positioning controls. Calibration controls are a cinch with a four-button touch pad and easily navigable onscreen display menu.\r\n\r\nTired of the flicker of low-refresh-rate monitors? The Visual Sensation supports a whopping 1,920 x 1,440 at 75 Hz. And even if you prefer lower resolutions, the VS-21e supports sky-scraping refresh rates. For graphics professionals, the VS-21e provides BNC connections for a top-quality image. The only flaw we noticed was a slight geometric distortion that couldn\'t be corrected, in the corners of the monitor. Even with this rather minor flaw, the KDS Visual Sensation 21e is the all-in-one solution for graphics professionals, businesses, and even everyday users. --Dan Simpson \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00001R3VE.01.16TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00001R3VE.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 549.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 463.94 , 16 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (96 , 'Envision 15" EN-5100 TFT LCD High Resolution Color Display' , 1 , 1 , NULL , NULL , 2 , 'B00005MNSR' , NULL , NULL , NULL , NULL , 'Envision\'s EN5100 brings size, value, and performance in LCD display technology to a new level. The EN5100\'s LCD technology means that the super-thin screen will take up very little desktop space. A 15-inch diagonal viewing size and 1,024 x 768 resolution guarantees a high-definition picture that won\'t have you straining your eyes. The onscreen display is easily accessible on the front panel and allows you to configure color temperature and display settings. The display is EPA Energy Star... ' , 0 , 'Envision\'s EN5100 brings size, value, and performance in LCD display technology to a new level. The EN5100\'s LCD technology means that the super-thin screen will take up very little desktop space. A 15-inch diagonal viewing size and 1,024 x 768 resolution guarantees a high-definition picture that won\'t have you straining your eyes. The onscreen display is easily accessible on the front panel and allows you to configure color temperature and display settings. The display is EPA Energy Star compliant and VESA, XGA, SVGA, and VGA compatible. It offers complete plug-and-play setup and operation, which means that it is ready to be hooked up to your computer right out of the box. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005MNSR.01.22TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005MNSR.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 459.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 359.99 , 22 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (97 , 'Samsung 15" 570V TFT LCD Monitor' , 1 , 1 , NULL , NULL , 2 , 'B00005NDUP' , NULL , NULL , NULL , NULL , 'The SyncMaster 570-volt TFT is Samsung\'s most affordable display solution for business and home users who want all the space-saving benefits of a flat-panel display. Not only does this monitor provide stunning color and razor-sharp images, it takes up a third of the desktop space of a traditional CRT monitor.\r\n\r\nThis Samsung monitor line delivers flat images that are easier on the eyes, and includes slimmer products that save valuable desk space. Samsung applies state-of-the-art display... \r\n' , 0 , 'The SyncMaster 570-volt TFT is Samsung\'s most affordable display solution for business and home users who want all the space-saving benefits of a flat-panel display. Not only does this monitor provide stunning color and razor-sharp images, it takes up a third of the desktop space of a traditional CRT monitor.\r\n\r\nThis Samsung monitor line delivers flat images that are easier on the eyes, and includes slimmer products that save valuable desk space. Samsung applies state-of-the-art display technology to create flat and slim products that are clearer, brighter, and more energy efficient. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005NDUP.01.36TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005NDUP.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 609 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 389.99 , 36 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (98 , 'ViewSonic VP181 18" Flat Panel LCD Monitor' , 1 , 1 , NULL , NULL , 2 , 'B00004SYWC' , NULL , NULL , NULL , NULL , 'ViewSonic\'s VP181 ViewPanel is the first 18-inch multifunctional flat panel to incorporate digital, analog, and composite video inputs into an all-in-one display. With its thin 4-inch profile, the adjustable, ergonomically designed ViewSonic VP181 fits easily into confined spaces or can be wall mounted. Its TVT active-matrix display delivers 16.7 million colors. A 1,280 x 1,024 native resolution ( maximum resolution of 1,600 x 1,200) combined with 235 nits of brightness dispense crisp images.\r\n\r\n' , 0 , 'ViewSonic\'s VP181 ViewPanel is the first 18-inch multifunctional flat panel to incorporate digital, analog, and composite video inputs into an all-in-one display. With its thin 4-inch profile, the adjustable, ergonomically designed ViewSonic VP181 fits easily into confined spaces or can be wall mounted. Its TVT active-matrix display delivers 16.7 million colors. A 1,280 x 1,024 native resolution ( maximum resolution of 1,600 x 1,200) combined with 235 nits of brightness dispense crisp images.\r\n\r\nOn-demand audio, picture-in-picture capabilities, a variety of supported video formats, and analog and digital compatibility are some of the ViewSonic VP181\'s many features. It is capable of accepting multiple input signals. You can hook up additional USB peripherals, such as a scanner, camcorder, or DVD player to the USB ports on the base of the display. The ViewSonic VP181 allows composite video input from your DVD or VCR to run live while working real time on other applications. The USB inputs on the base and panel allow flexible configuration.\r\n\r\nA pair of built-in two-watt speakers produce stereo sound. There are a number of advanced image and sound options for customized viewing and audio. Software drivers are included that enable you to display in both landscape and portrait modes for full-page viewing.\r\n\r\nViewSonic backs the VP181 with a three-year limited warranty on parts and labor. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004SYWC.01.17TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00004SYWC.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 1935 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 1599.99 , 17 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (101 , 'Sceptre D50X 15" Non-Glare Flat Screen CRT Monitor' , 1 , 1 , NULL , NULL , 2 , 'B00004Y7E8' , NULL , NULL , NULL , NULL , 'With a maximum resolution of 1,024 x 768 at a 65 Hz refresh rate, and 0.28-millimeter dot pitch, the Sceptre D50X 15-inch nonglare flat-screen CRT (cathode-ray tube) monitor produces a high level of sharpness, resulting in more stable pictures with less flicker. Multistep dynamic focus (MSDF) provides clearer, crisper images at all points of the screen. The antireflective, antistatic screen coating helps diminish eyestrain. The D50X monitor also features two easy-to-use knobs, one for... ' , 0 , 'With a maximum resolution of 1,024 x 768 at a 65 Hz refresh rate, and 0.28-millimeter dot pitch, the Sceptre D50X 15-inch nonglare flat-screen CRT (cathode-ray tube) monitor produces a high level of sharpness, resulting in more stable pictures with less flicker. Multistep dynamic focus (MSDF) provides clearer, crisper images at all points of the screen. The antireflective, antistatic screen coating helps diminish eyestrain. The D50X monitor also features two easy-to-use knobs, one for selecting the function you wish to modify and the other for making actual adjustments. This provides you with more control over adjustments, and you avoid having to push buttons or cycle through a menu of choices. The optional USB technology allows for higher video throughput, and connectors can be daisy-chained to free up input/output ports. \r\n\r\nThe D50X is MRP II certified and is backed by a five-year limited warranty. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004Y7E8.01.26TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00004Y7E8.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 189 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 139.99 , 26 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (103 , 'NEC AccuSync 50M 15" Multimedia Monitor (PC/Mac)' , 1 , 1 , NULL , NULL , 2 , 'B00004Y74D' , NULL , NULL , NULL , NULL , 'The NEC AccuSync 50M 15-inch monitor is specifically designed for small to medium businesses and home users who demand quality performance and a range of usage. This full-featured 15-inch (13.8-inch viewable) display is ideal for office automation including word processing, spreadsheets, and data entry. \r\n\r\nThe NEC AccuSync 50M\'s 1,280 x 1,024 maximum resolution at 66 Hz refresh rate, combined with its fine 0.28-millimeter dot pitch, ensure sharp, crisp images. For enhanced screen sharpness... \r\n' , 0 , 'The NEC AccuSync 50M 15-inch monitor is specifically designed for small to medium businesses and home users who demand quality performance and a range of usage. This full-featured 15-inch (13.8-inch viewable) display is ideal for office automation including word processing, spreadsheets, and data entry. \r\n\r\nThe NEC AccuSync 50M\'s 1,280 x 1,024 maximum resolution at 66 Hz refresh rate, combined with its fine 0.28-millimeter dot pitch, ensure sharp, crisp images. For enhanced screen sharpness and color intensity, the antistatic, antiglare screen treatment greatly reduces reflection while providing full use of the entire display area. The AccuSync 50M also includes two 2.2-inch full-range speakers in the base for multimedia applications. The audio base has a headphone jack for private listening. Additional value-added features include up-front controls, an invar shadow mask, and a multilayer screen coating with OptiClear viewing. The monitor is in compliance with EPA Energy Star and MPR-II regulations. It is backed by a three-year limited warranty. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00004Y74D.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00004Y74D.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 179.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 169.99 , 6 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (104 , 'Nokia 3360 Phone (AT&T)' , 1 , 1 , NULL , NULL , 2 , 'B00005QIQI' , NULL , NULL , NULL , NULL , 'For a limited time, get a $50 rebate\r\n                                                from AT&T when you purchase a\r\n                                                Nokia 3360 phone and activate\r\n                                                monthly service. Then, save an\r\n                                                additional $50 with our Amazon.com\r\n                                                gift certificate, which makes your\r\n                                                phone free! Is that a bargain, or\r\n                                                what?' , 0 , 'Fun, form, and function are what the Nokia 3360 is all about. Highlights include\r\n                   an oversized five-line screen, e-mail capability, PIM functions, text-messaging\r\n                   support, and a couple games. Snap-on faceplates let you customize the 3360 to\r\n                   your heart\'s content, and you can further personalize it with downloadable\r\n                   ringers. The NiMH battery is rated for up to 240 minutes of digital talk time and\r\n                   10.5 days of digital standby time. A charger and hands-free headset are\r\n                   included.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005QIQI.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005QIQI.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 38.94 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 38.94 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (105 , 'Motorola T193 Phone (VoiceStream Wireless)' , 1 , 1 , NULL , NULL , 2 , '253275' , NULL , NULL , NULL , NULL , 'Grab the Motorola T193 for free\r\n             when you sign up for a\r\n             VoiceStream Wireless service\r\n             plan costing $29.99 or more!' , 0 , 'The Motorola T193 phone from VoiceStream Wireless is an attractive phone designed for high-speed\r\n Internet access. The phone is built on GPRS technology, a system which uses the wireless network\r\n only when you send and receive data, resulting in transmission speeds more than two times faster\r\n than...' , 0 , NULL , NULL , 'http://g-images.amazon.com/images/G/01/wireless/features/motorola-t193-f.gif' , NULL , 'http://images.amazon.com/images/P/B00005S022.01.TZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (106 , 'Nokia 5165 Prepaid Phone (AT&T)' , 1 , 1 , NULL , NULL , 2 , 'B00005BAUV' , NULL , NULL , NULL , NULL , 'Looking to buy a cell phone without\r\n       breaking the piggy bank? Choose a\r\n       Nokia 5165 phone with AT&T\'s Free2Go\r\n       prepaid service, and score a $50 rebate\r\n       from AT&T Wireless.' , 0 , 'This Nokia 5165 model, which works with AT&T\'s Wireless\'s prepaid service,\r\n                   has quickly caught on in popularity. Like its predecessor, the 5160i, the 5165 is\r\n                   a lightweight personal phone with impressive talk and standby times that\'s loaded\r\n                   with classic, simple-to-learn features. Its changeable faceplates, 30 different\r\n                   ringers (and room for five downloadable tones), and an expansive world of\r\n                   accessories add up to a fun general-purpose phone that\'s a perfect fit for\r\n                   prepaid use. And handy refill cards allow you to purchase additional airtime\r\n                   minutes whenever you need them. \r\n\r\n                   Weighing in at 6.2 ounces (including battery), the 5165 measures 5.2 inches\r\n                   high, 1.85 inches wide, and 1.2 inches deep. It\'s extremely rugged, and should\r\n                   stand up well to being thrown into bags and briefcases or occasionally dropped.\r\n                   And, its dual-band/trimode operation ensures you\'ll be able to receive cellular\r\n                   service anywhere it\'s available. The addition of predictive T9 text input, wireless\r\n                   business cards, and e-mail capabilities make it a viable business\r\n                   communications tool as well. \r\n\r\n                   Four buttons handle most menu navigation: a hefty "Navi" key in the middle, up\r\n                   and down arrow buttons that control volume during calls, and a key marked "C"\r\n                   for "clear". Menu navigation is very intuitive. A tap of the Navi key brings up the\r\n                   first of a series of graphical menu items. Hit Navi again for additional menu\r\n                   options, or tap the up or down arrow keys to select a different menu. Top-level\r\n                   menu choices are a phone book, messages (SMS and voice-mail alerts), call\r\n                   log, settings (for calls, phone, and security), system, games (Memory, Snake,\r\n                   and Logic), clock, tones, and keypad lock. The brightly backlit display works well\r\n                   with the control keys to simplify finding and making choices. In text mode, the\r\n                   phone provides five 16-character lines. \r\n\r\n                   The 5165 lets you choose from 30 preprogrammed ringer tones, and you can\r\n                   also download an additional five from AT&T Wireless\'s Web site. Although\r\n                   there\'s no internal vibration mode, an optional vibrating battery is available. You\r\n                   can store electronic business cards in your phone book. Any friend or\r\n                   associate can forward his or her name, number, and e-mail address to your\r\n                   phone, and you can automatically store the information with some deft menu\r\n                   navigation. \r\n\r\n                   One caveat regarding faceplates: In theory, all 5100-series faceplates should\r\n                   work with this phone, but in practice, only Nokia-brand faceplates seem to work.\r\n                   The problem is the keypad, the thin rubber pad inside the phone on which the\r\n                   actual keys are mounted. We tried several different faceplate models (both\r\n                   Nokia-branded and after-market models) and found the 5165\'s original keypad\r\n                   will not accommodate non-Nokia faceplates. \r\n\r\n                   The 5165 supports the usual array of call and messaging features, including\r\n                   caller ID, call waiting, call forwarding, and voice-mail. A call history stores the\r\n                   last 10 numbers dialed, the 10 most recently received calls, and the last 10\r\n                   missed calls. The phone supports two-way SMS text messaging, but isn\'t\r\n                   Web-enabled. \r\n\r\n                   The 5165 offers four basic security features: an initial security code, a keypad\r\n                   lock, call-restriction modes, and a lock code that can activate or deactivate\r\n                   memory and menu options. The lock-code feature lets you store numbers in a\r\n                   secret unlocked location, allowing you to make calls even if the phone is locked. \r\n\r\n                   The 5165\'s NiMH battery is rated to last up to 180 minutes of digital talk time and\r\n                   200 hours of digital standby time. In our testing, we achieved 180 minutes of\r\n                   digital talk time and over 225 hours of digital standby time. \r\n\r\n                   Overall, Nokia\'s 5165 is a noteworthy and reasonably priced prepaid phone.\r\n                   Choose your favorite faceplate color and ringer tone and start dialing!' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BAUV.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005BAUV.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 3 , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (107 , 'Nokia 8290 Phone (VoiceStream Wireless)' , 1 , 1 , NULL , NULL , 2 , 'B000050ZFG' , NULL , NULL , NULL , NULL , 'Did you know the Nokia 8290 is smaller and\r\n                                        lighter than its sister phone, the Nokia 8260? It\r\n                                        also boasts voice-activated dialing, excellent talk\r\n                                        and standby times, and text messaging support.\r\n                                        Don\'t forget about our instant-savings offer,\r\n                                        which takes $50 off the price.' , 0 , 'With the introduction of its striking 8290 digital phone, Nokia sets a new\r\n                   standard for eye-catching style and extreme portability. \r\n\r\n                   We were impressed with the 8290\'s robust construction and overall navigation.\r\n                   The phone, which is for GSM networks (like VoiceStream Wireless), also boasts\r\n                   a newly designed internal antenna, excellent talk and standby times, and a host\r\n                   of sophisticated functions including voice-activated dialing and SMS capabilities.\r\n                   The only real missing feature is Web-browsing support. \r\n\r\n                   Where did this tiny phone come from? Essentially, Nokia updated the\r\n                   electronics and boosted the antenna power of its high-end classic, the 8860; put\r\n                   the new design in a sleek, tiny package; and significantly lowered the price. The\r\n                   8290 also borrows the navigation that is a hallmark of its popular 5100-series\r\n                   phones. \r\n\r\n                   Although many of the 8290\'s features are available in other premium phone\r\n                   models, its design is like nothing you\'ve ever held. Weighing a mere 3.2 ounces\r\n                   and measuring 3.9 by 1.7 by 0.7 inches, the 8290 literally fits in the palm of\r\n                   your hand. It\'s also slightly smaller than its sister phone, the popular 8260. \r\n\r\n                   The side-mounted volume-control keys were easy to operate while on a call, and\r\n                   we hooked up a hands-free kit to the headphone jack so we could stow the\r\n                   phone in our pocket while having conversations. One caveat: the tiny power\r\n                   button, located on top of the phone, is almost flush with the casing and hard to\r\n                   find. You won\'t be likely to turn the phone on inadvertently, but at times it was a\r\n                   challenge to turn the phone on at all. Other than this quibble, the 8290 is a joy to\r\n                   use. Plus, the 8290 is shipped with a Jabra EarSet for hands-free use. \r\n\r\n                   Three buttons handle most of the menu navigation: a roller-bar navigation key\r\n                   lets you scroll through menu options, and two additional buttons let you select\r\n                   menu options as they appear. The right prompt button also provides one-touch\r\n                   access to your phone book. The top-level menu choices are: Messages (SMS\r\n                   and voice-mail alerts), Call Log, Profiles (so you can choose how your phone\r\n                   behaves in different environments), Settings (for calls, phone, and security),\r\n                   System (so you can select a service provider or opt for automatic selection),\r\n                   Games (Rotation, Memory, Snake, and Logic), Calculator, Calendar, and\r\n                   Keyguard Lock. The backlit, three-line display works well with the control keys,\r\n                   and we found it easy to locate menus and make selections. Despite the phone\'s\r\n                   small size, the keypad is well spaced, and we had no problems dialing with one\r\n                   hand. \r\n\r\n                   The Nokia 8290 has a full roster of call and messaging features. If offered by\r\n                   your service plan, it supports caller ID, call waiting, SMS, voice mail, numeric\r\n                   paging, multiparty calling, and e-mail. Three different call logs maintain the last\r\n                   10 dialed numbers, 10 most recently received calls, and 10 missed calls. PIM\r\n                   functions include a clock, currency converter, calculator, calendar with room for\r\n                   50 appointments and reminders, and a 250-entry phone book. There is no\r\n                   standard method of connecting the 8290 to a PC or other device. \r\n\r\n                   A few more cool things worth noting: the 8290 supports swappable faceplates\r\n                   and it has three-NAM capability, so you can route three different numbers to the\r\n                   phone. Its built-in vibrating alert guarantees you will get your calls without\r\n                   annoying the people sitting next to you. \r\n\r\n                   The 8290 offers four basic security features: An initial security code, keypad\r\n                   lock, call restriction modes, and a lock code that can activate or deactivate\r\n                   memory and menu options. One nice thing about the lock-code feature is you\r\n                   can store numbers in a secret unlocked location, which will allow you to make\r\n                   calls even when the phone is locked. \r\n\r\n                   The 8290\'s lithium-ion battery is rated to last for a maximum of 210 minutes of\r\n                   digital talk time and 192 hours of digital standby time. In our battery testing it\r\n                   came impressively close. We held an open call for just over three hours, and the\r\n                   phone lasted for nearly eight days in standby mode. \r\n\r\n                   The 8290 is one of the lightest, smallest, most stylish phones around, and it\r\n                   backs up its cool appearance with solid construction and functions. In fact, it\r\n                   one-ups its counterpart, the 8260, with its more compact design and\r\n                   voice-activated dialing feature. Unless you need a phone with a minibrowser,\r\n                   this unit is an excellent match for almost any personal or professional\r\n                   communications need.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B000050ZFG.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B000050ZFG.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (108 , 'Nokia 3390 Prepaid Phone with AOL (VoiceStream Wireless)' , 1 , 1 , NULL , NULL , 2 , 'B00005UL4Y' , NULL , NULL , NULL , NULL , 'VoiceStream Wireless has an amazing offer--a\r\n  prepaid Nokia 3390 outfitted with AOL Instant\r\n  Messenger and a bunch of other cool features.\r\n  You can call your friends, or opt to send them a\r\n  quick note while you\'re on the run. Airtime worth\r\n  $50 is included with purchase.' , 0 , 'This Nokia 3390 is a fun, shapely prepaid phone with several cool features,\r\n                   including picture messaging, changeable faceplates (front and back), and\r\n                   voice-activated dialing. \r\n\r\n                   Here\'s the tale of the tape: the 3390 measures 4.4 by 1.9 by 0.8 inches, and it\r\n                   weighs 4 ounces. This means the phone is slightly longer than a business card\r\n                   and weighs the same as today\'s ultracompact phones. It also has an internal\r\n                   antenna--which people either love or hate--though we never had trouble with call\r\n                   reception. To us, everything about this phone is executed correctly; the keypad\r\n                   is well-spaced, it has salient features (even though it can\'t access the Internet\r\n                   wirelessly), and it\'s inconspicuous while in use. \r\n\r\n                   Three buttons handle most of the menu navigation: a central oval-shaped key\r\n                   activates the main menu and lets you select options as they appear; the\r\n                   roller-bar navigation key scrolls through menu options; and the "C" (clear) button\r\n                   jumps back a step and erases text-entry mistakes. \r\n\r\n                   Menu choices are: Phone Book, Messages (SMS and voice-mail alerts), Call\r\n                   Log, Profiles (so you can choose how your phone behaves in different\r\n                   environments), Settings (for calls, phone, and security), Forwarding, Games,\r\n                   Calculator, Calendar, Composer (for DIY ring tones), and Keyguard Lock. With\r\n                   the backlit, five-line display (three lines of text, two lines of icons and indicators),\r\n                   we found it easy to navigate through menus and make selections. And here\'s a\r\n                   definite design improvement on the 8260: the 3390\'s power button, located on\r\n                   top of the phone, is raised a bit so it\'s easier to use (and find). \r\n\r\n                   Like other phones, the 3390 has a full roster of call and messaging features. If\r\n                   offered by your service plan, it supports caller ID, call waiting, SMS, voice mail,\r\n                   numeric paging, multiparty calling, and e-mail. Call logs maintain the last 10\r\n                   dialed numbers, 10 most recently received calls, and 10 missed calls. PIM\r\n                   functions include a clock, currency converter, calculator, calendar with room for\r\n                   50 appointments and reminders, and a 250-entry phonebook. \r\n\r\n                   But, as we said, the 3390 offers a couple of new features (at least for Nokia\r\n                   phones). We stored eight different voice-activated dialing numbers (a simple\r\n                   process), and logged on to VoiceStream Wireless\'s site from our PC so we\r\n                   could download additional ring tones. The 3390 also has eight preset images\r\n                   you can e-mail to your friends--but in order to take advantage of it both people\r\n                   need to have a 3390 that supports picture messaging. You can also download\r\n                   additional images from VoiceStream Wireless\'s site, provided your service plan\r\n                   supports this action. \r\n\r\n                   The front and back faceplates are separate, so you can have a two-tone phone\r\n                   if you desire. It was a minor challenge to remove the faceplate on the first try,\r\n                   but it was worth the effort. And while the phone\'s included games weren\'t enough\r\n                   to take us away from PlayStation 2, we enjoyed Space Impact (sort of\r\n                   Defender meets Space Invaders), one of the 3390\'s four new games. It also\r\n                   features Snake II, Bantumi, and Pairs I. \r\n\r\n                   The 3390 offers five basic security features: an initial phone lock, keypad lock,\r\n                   SIM card lock, call-restriction modes, fixed dialing (allows you to store secret\r\n                   numbers on the SIM card), and the ability to change access codes at any time. \r\n\r\n                   The NiMH battery is rated for up to 160 minutes of digital talk time and 7.5 days\r\n                   of digital standby time. In our tests, we got the phone to hold a call for just about\r\n                   three hours, and it lasted for a full seven days in standby mode. \r\n\r\n                   We highly recommend the 3390, and we don\'t want to give our sample phone\r\n                   back. It looks different from the rest of the herd and has the features we want\r\n                   and need on a daily basis--all for under $100.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UL4Y.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UL4Y.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (109 , 'Samsung N200 Phone (Sprint PCS)' , 1 , 1 , NULL , NULL , 2 , 'B00005K2LZ' , NULL , NULL , NULL , NULL , 'We\'re enamored with the new Samsung N-200,\r\n                                        and think it would suit just about anyone\'s needs.\r\n                                        It\'s highly stylized and outfitted with the right\r\n                                        features--including voice-activated dialing, an\r\n                                        organized minibrowser, and a 229-number\r\n                                        phone book.' , 0 , 'Communicate well into the 21st century with the Samsung N-200. This modern\r\n                   dual-mode marvel--an updated version of the bestselling SCH-3500 model--is\r\n                   equipped with a built-in mini-browser, PIM functions, and voice-activated dialing\r\n                   capabilities. The N-200 is smaller and lighter than its predecessor, and has a\r\n                   five-line display as well as a convenient minijoystick for menu navigation. Other\r\n                   standard features include a vibrating alert, multiple ringer options, and multiple\r\n                   language options.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005K2LZ.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005K2LZ.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 149.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 149.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 4 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (110 , 'Motorola V2397 Prepaid Phone (AT&T)' , 1 , 1 , NULL , NULL , 2 , 'B00005BAUT' , NULL , NULL , NULL , NULL , 'Our customers love the V2397, a prepaid phone\r\n  from AT&T Wireless. And with its swappable\r\n  phone-wrap covers, SMS capabilities, and\r\n  reasonable price tag, we can see why.' , 0 , 'Flexible prepaid service, swappable "phone wrap" fashion covers, two-way SMS\r\n                   capabilities, and a reasonable price are some of the highlights of the new\r\n                   Motorola V2397, a prepaid phone offered by AT&T Wireless. \r\n\r\n                   The V2397 measures 6.5 by 2.0 by 1.1 inches, and weighs in at 5.2 ounces.\r\n                   While relatively large, the phone is lightweight, easily portable, and it sports\r\n                   dual-band/dual-mode electronics. \r\n\r\n                   Motorola\'s characteristic smart-button navigation, commonly seen on the\r\n                   company\'s StarTAC phones, guides you through the V2397\'s menu options. The\r\n                   keypad design is less cluttered and confusing than StarTAC phones, however--a\r\n                   definite improvement. Although you still have to use the FCN (function) button to\r\n                   access menu options, all control keys (Function, Store, Clear, Recall) are well\r\n                   spaced. The raised, oval-shaped keypad buttons were quite responsive, and we\r\n                   rarely misdialed a call. The phone felt good to hold, and we could dial\r\n                   one-handed. The four-line screen (two lines of text, two lines of status icons) is\r\n                   backlit and easy to read. A standard 2.5-millimeter communication jack for\r\n                   hands-free devices is integrated into the phone. \r\n\r\n                   The V2397\'s handy call management features, including scratchpad memory,\r\n                   nine assignable ringer tones, one-touch speed-dial locations, multiple call timers,\r\n                   and any-key answer, help you organize your communications. You can store up\r\n                   to 99 numbers in the V2397\'s phone book, although it does not support multiple\r\n                   entries per contact. Entering phone numbers is easy. Just punch in the number\r\n                   and a unique descriptor, and assign it a memory location. The 30-incoming and\r\n                   20-outgoing call logs help you keep track of your conversations, and the\r\n                   incoming call log keeps track of missed calls to boot. The V2397 supports\r\n                   carrier-dependent features such as caller ID, call waiting, voice-mail alerts, and\r\n                   two-way SMS text messaging, which lets you send and receive alphanumeric\r\n                   messages with other devices. Unfortunately, there is no way to tether the V2397\r\n                   to a PC, so you can\'t use it as a digital modem, or import your computer\'s\r\n                   address book to the phone. Also, the V2397 is missing a minibrowser, PIM\r\n                   funtions, profile settings, and vibrating alert. \r\n\r\n                   To keep your V2397 secure, you can use a three-digit code to lock the whole\r\n                   phone or to restrict outgoing calls to one of 10 numbers stored in special\r\n                   memory locations. \r\n\r\n                   The V2397\'s NiMH battery is rated up to 100 minutes\' talk time and 110 hours\'\r\n                   standby time. In our testing, the V2397 held a call for 105 minutes, and it lasted\r\n                   for 112 hours in standby mode. \r\n\r\n                   A basic phone for everyday use, the Motorola V2397 scores high marks in\r\n                   visual design and reliability, although it lacks many desirable features. Still,\r\n                   interchangeable phone wraps, two-way text messaging, and a very reasonable\r\n                   price make the V2397 as a viable prepaid option.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005BAUT.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005BAUT.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 99.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 99.99 , 0 , NULL , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 3 , 3 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (111 , 'Churches' , 1 , 1 , NULL , NULL , 2 , '0060194383' , NULL , NULL , NULL , NULL , NULL , 0 , 'The physical dimensions alone would be enough to make Churches, Judith Dupre\'s sumptuous chronology of Christian art and architecture, one of the most  absorbing ways possible to learn about the world\'s most beautiful houses of worship. It is almost too big to fit in your lap, and each brilliantly colored page is  almost three times the width of a human head. In addition, Churches offers floor  plans, histories, and theological interpretations of almost 60 churches around the  world, from the Pantheon in Rome to La Sagrada Familia in Barcelona to the  Crystal Cathedral in Garden Grove, California. Interspersed with these chapters  are photographic essays on such topics as "Building a Gothic Cathedral" and  "Ancient Paths: Contemporary Labyrinths." All of the images and essays are  presented in a format accessible to the general reader. Those more broadly  informed about architecture will be drawn to the interview with Swiss-Italian  architect Mario Botta--his first in-depth interview published in English. In the end,  the book\'s most amazing accomplishment is to provide readers with sensations  that approximate both the grandeur and the intimacy of visiting the churches it  depicts. --Michael Joseph Gross' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0060194383.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0060194383.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 40 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 28 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (112 , 'Celebrate Your Creative Self : Over 25 Exercises to Unleash the Artist Within' , 1 , 1 , NULL , NULL , 2 , '1581801025' , NULL , NULL , NULL , NULL , NULL , 0 , 'Book Description \r\nArtists and creatives of all kinds who are looking for new ways to liberate their artistic imagination will love this book. Readers are invited to playfully explore various aspects of visual art, such as light, color, texture and design through a series of imaginative art projects. Artists will experiment hands-on with dozens of techniques and mediums in new and unconventional ways including: * Capturing whites with crayon and wax resist * Glazing and floating colors * Portraying the patterns of nature with sedimentation and precipitation * Loosening up with gesso painting and printing with plastic * Constructing a new piece of art from old work * Experimenting with three-dimensional assemblage * Creating a street map In addition, artists are prompted to challenge their imaginations by building new painting surfaces, creating their own personal symbols and more. Further inspiration can be found in a gallery of work by more than 30 contributing artists. Celebrate Your Creative Self is a fun, no-fail guide every artist should have. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1581801025.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/1581801025.01.LZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 28.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 18.26 , 37 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , '' , 1 , 5 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (113 , 'Exploring Southern California Beaches (FalconGuide) from Amazon' , 1 , 1 , NULL , NULL , 2 , '1560446323' , NULL , NULL , NULL , NULL , NULL , 0 , '"From the bustle of the Mexican border to the isolated beauty of Point Conception, sit back and enjoy the ride as veteran writer and beach bum David Crowell takes you on Safari in Exploring Southern California Beaches. Discover the diversity of life in " --This text refers to the Digital edition. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1560446323.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/1560446323.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 18.95 , NULL , NULL , 0 , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.26 , 30 , 0 , NULL , NULL , 0 , NULL , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/1560446323' , 2 , 10 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (114 , 'The Lord of the Rings (Collector\'s Edition)' , 1 , 1 , NULL , NULL , 2 , '0395193958' , NULL , NULL , NULL , NULL , NULL , 0 , 'The New York Times \r\n"A unique, wholly realized other world, evoked from deep in the well of Time, massively detailed, absorbingly entertaining..." ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0395193958.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0395193958.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 75 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 52.5 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0395193958' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (115 , 'Dark Journey (Star Wars: The New Jedi Order, Book 10)' , 2 , 1 , NULL , NULL , 2 , '0345428692' , NULL , NULL , NULL , NULL , NULL , 0 , 'About the Author \r\nA former music and history teacher, Elaine Cunningham has written more than a dozen fantasy novels and many short stories. She is best known for the Songs & Swords books, particularly Elfshadow, a mystery in a fantasy setting. She lives with her family in a coastal New England town.\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0345428692.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0345428692.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 6.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 0 , 6.99 , NULL , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0345428692' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (116 , 'The Silmarillion' , 3 , 1 , NULL , NULL , 2 , '0345325818' , NULL , NULL , NULL , NULL , NULL , 0 , 'The Silmarillion is J.R.R. Tolkien\'s tragic, operatic history of the First Age of Middle-Earth, essential background material for serious readers of the classic Lord of the Rings saga. Tolkien\'s work sets the standard for fantasy, and this audio version of the "Bible of Middle-Earth" does The Silmarillion justice. Martin Shaw\'s reading is grave and resonant, conveying all the powerful events and emotions that shaped elven and human history long before Bilbo, Frodo, Gandalf and all the rest embarked on their quests. Beginning with the Music of the Ainur, The Silmarillion tells a tale of the Elder Days, when Elves and Men became estranged by the Dark Lord Morgoth\'s lust for the Silmarils, pure and powerful magic jewels. Even the love between a human warrior and the daughter of the Elven king cannot defeat Morgoth, but the War of Wrath finally brings down the Dark Lord. Peace reigns until the evil Sauron recovers the Rings of Power and sets the stage for the events told in the Lord of the Rings. This is epic fantasy at its finest, thrillingly read and gloriously unabridged. (Running time: 14 hours, 6 CDs) --This text refers to the Audio CD edition. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0345325818.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0345325818.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 6.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 0 , NULL , NULL , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0345325818' , 1 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (117 , 'The Lord of the Rings (Boxed Set)' , 4 , 1 , NULL , NULL , 2 , '0395489326' , NULL , NULL , NULL , NULL , NULL , 0 , 'The three volumes that make up Tolkien\'s epic classic The Lord of the Rings are here presented in their standard cloth editions including large format fold-out maps and an extensive appendices. Set contains The Fellowship of the Ring, The Two Towers, and The Return of the King, with jackets and a box designed by celebrated illustrator Alan Lee. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0395489326.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0395489326.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 65 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 45.5 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0395489326' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (118 , 'Under Cover The Key To Living In God\'s Provision And Protection' , 1 , 1 , NULL , NULL , 2 , '0785269916' , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , 'This well loved writer effectively uses his personal mistakes to illustrate riveting truths about repentance and forgiveness. As he focuses on the true authority of God, he is careful to explain by example the important difference between submission and obedience. \r\nThe same struggle with divine authority is also represented through the lives of John the Baptist, the Apostle Paul, and other biblical figures. An especially helpful book for Christians who want to develop a serious pursuit of God. \r\n\r\n' , NULL , 'http://images.amazon.com/images/P/0785269916.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0785269916.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 11.99 , 20 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0785269916' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (119 , 'The Church of Irresistible Influence' , 2 , 1 , NULL , NULL , 2 , '0310239567' , NULL , NULL , NULL , NULL , NULL , 0 , 'An inspiring description and story showing how a church can become an irresistible influence on its neighborhood, community, and world by building bridges over troubled waters to a dying culture through showing the love of God in action. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0310239567.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0310239567.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 13.99 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0310239567' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (120 , 'God : A Biography' , 3 , 1 , NULL , NULL , 2 , '0679743685' , NULL , NULL , NULL , NULL , NULL , 0 , 'Is it possible to approach God not as an object of religious reverence, but as the protagonist of the world\'s greatest book -- as a character who possesses all the depths, contradictions, and ambiguities of a Hamlet? How does he depend on the other characters, and how does his relationship with them show his development? Miles provides a learned, original exegesis that will send readers back to the Bible in curious amazement. Winner of the 1996 Pulitzer Prize for biography. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0679743685.01.TZZZZZZZ.gif' , NULL , 'http://images.amazon.com/images/P/0679743685.01.MZZZZZZZ.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 15 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 12 , 20 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0679743685' , 1 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (121 , 'The Pleasures of God : Meditations on God\'s Delight in Being God' , 4 , 1 , NULL , NULL , 2 , '1576736652' , NULL , NULL , NULL , NULL , NULL , 0 , 'Beginning where the foundational truth of Desiring God left off, that "God is most glorified in us when we are most satisfied in Him," this expanded rerelease of another classic by John Piper will further explore a life-changing essential "We will be most satisfied in God when we know why God himself is most satisfied in God." Fully understanding the joy of God will draw the reader into an encounter with His overflowing, self-replenishing, all-encompassing grace(the source of living water that all Christians desire to drink.) The Pleasures of God will again put God at the center of Creation and leave the reader very satisfied in Him. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1576736652.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/1576736652.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.99 , 20 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/1576736652' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (122 , 'The Millionaires' , 1 , 1 , NULL , NULL , 2 , '0446527297' , NULL , NULL , NULL , NULL , NULL , 0 , 'What would you steal if you couldn\'t get caught? That\'s the tag line of Brad Meltzer\'s new thriller, which pits an ambitious young money manager against a corporate villain, whose intricate financial shenanigans accidentally put a huge chunk of dough right in front of a man who desperately needs it. Of course Oliver Caruso\'s conscience troubles him, but that doesn\'t keep him from letting his somewhat looser and less ethical brother convince him this is too good an opportunity to pass up. Meltzer\'s in interesting territory here, but in order to buy his premise, you have to believe that it\'s OK to steal if you have a good enough reason. This makes his protagonist, who narrates the novel, hard to root for and less than sympathetic. Despite this hollow ring, the book is nicely plotted and should please the author\'s enthusiastic fan club. --Jane Adams ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0446527297.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0446527297.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 25.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 15.57 , 40 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0446527297' , 1 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (123 , 'Blackwater Sound' , 2 , 1 , NULL , NULL , 2 , '0312203845' , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , 'A powerful Florida family, its high-tech fortune dwindling, is haunted by an elusive, enormous blue marlin that claimed the life of its eldest son, who was meant to restore the family\'s prominence. But the Braswells are tormented by even darker secrets, such as incest and treason, that drive this dark, atmospheric thriller to an explosive conclusion, which might have been pulled straight from recent headlines. James Hall pits Thorn, his series protagonist, against the Braswells and their deadly plans. Although an existentially morose antihero is a convention of the mystery genre, Hall manages to transcend it with a fascinating plot and a powerful narrative, resulting in a suspenseful and resonant novel that shows off his well-developed talents for character development, place, and pacing. The author of 11 previous mysteries (including Mean High Tide and Rough Draft), Hall gets better with every book, and this one continues the trend. --Jane Adams ' , NULL , 'http://images.amazon.com/images/P/0312203845.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0312203845.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 24.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.46 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0312203845' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (124 , 'To Trust a Stranger' , 3 , 1 , NULL , NULL , 2 , '0671786539' , NULL , NULL , NULL , NULL , NULL , 0 , 'The usual ingredients bubble and boil in Robards\'s latest romantic suspense thriller. Julie Carlson, once a poor girl from the wrong side of the tracks but now the beautiful owner of a successful boutique in Charleston, S.C., seems to have it all. As the novel begins, however, a hit man circles her suburban mansion: Julie\'s rich husband, Sid, has hired thugs to kill her. Unaware of the danger she is in but convinced that Sid is cheating on her, Julie slips out of the house just in time and follows her husband to the red-light district, where she serendipitously and literally runs into private detective Mac McQuarry, dressed up in drag to spy on a client\'s husband. Julie isn\'t sure whether she should trust a man in a dress, but she has no one else to turn to, and soon she and Mac are working together to get the goods on Julie\'s crooked husband. As it happens, Mac holds a personal grudge against Sid, a prominent builder in Charleston, because Sid was involved in the disappearance of Mac\'s half-brother 15 years before, and then got Mac kicked off the police force when Mac tried to prove it. Robards\'s fans will enjoy the machinations before Julie and Mac get together, though cliches clutter every page ("The truth hit him like a hammer over the head: He had a galloping case of the hots for his newest client, who was not incidentally his oldest enemy\'s wife"). Of course, true love solves past mysteries, while hot kisses get as much play as life-threatening confrontations. A bodice ripper at heart, the novel is the equivalent of a box of junk candy. \r\n\r\nCopyright 2001 Cahners Business Information, Inc.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0671786539.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0671786539.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 25 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.5 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0671786539' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (125 , 'Hearse of a Different Color' , 4 , 1 , NULL , NULL , 2 , '0786889632' , NULL , NULL , NULL , NULL , NULL , 0 , 'Tim Cockey\'s debut novel, The Hearse You Came In On, introduced readers to Hitchcock Sewell, the undertaker-turned-reluctant-sleuth, whose mordant irony and blissfully skewed perspective on the humdrum brought a remarkable vigor to a profession not usually known for its liveliness. The good news for Hitch fans is that Cockey\'s follow-up effort dishes up another heaping helping of sardonic wit: \r\nThe planet was one big marble of wretchedness. And I wasn\'t exactly being lifted aloft by bluebirds either. I was wheeling down the Baltimore- Washington Parkway in my unexciting car on the fourth record-breaking freezing cold day in a row, tuning in to what seemed to be the preexisting fact that I was going to be tracking down a cold-blooded murderer.\r\nSaid murderer has deposited a corpse on Hitch\'s doorstep--in the middle of a wake, no less. The unscheduled body is one Helen Waggoner, a single mother with a double life as a waitress and porn star. Hitch\'s girlfriend sees the unceremonious delivery as a scoop in the making. Bonnie Nash is a less-than- accurate TV weather woman who\'s got a bad case of occupational shame ("I\'m a pair of breasts that tells you what the weather is going to be tomorrow. Maybe."). She figures that solving a murder ought to earn her a network promotion. But it\'s not that easy. When Helen\'s sister also turns to Hitch for some moral and investigative support, the undertaker finds himself digging through the family closets and unearthing some distinctly unsavory skeletons. It turns out that a taste for the (ahem) silver screen is a Waggoner tradition, and that the sisters have a long--and not particularly affectionate--history. It\'s up to Hitch to put the pieces of the puzzle together before a hired killer with a peculiar signature takes him apart.\r\nCockey has a rare gift for sending up the hallowed conventions of mystery fiction with effortlessly wry turns of phrases: "I looked about to assess the scene. I\'m six-three, so I have a decent vantage point for assessing." His plot skills have sharpened since his last outing, and the narrative moves along briskly to a conclusion both tidy and ironic. Appropriately enough, though, in this Hearse, the ride is even more fun than the destination. --Kelly Flynn --This text refers to the Paperback edition. \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0786889632.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0786889632.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 7.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 0 , 7.99 , NULL , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0786889632' , 1 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (126 , 'Beaches' , 1 , 1 , NULL , NULL , 2 , '0811826503' , NULL , NULL , NULL , NULL , NULL , 0 , 'The authors of The Beach: The History of Paradise on Earth, the best-selling history of everyone\'s favorite place, are back with a breathtaking visual companion. From moody, craggy coastlines to serene swathes of turquoise water and white sand, Beaches is an astounding photographic survey of the ineffable allure of paradise on earth. This spectacular collection of images from renowned photographers, including Robert Misrach, Joel Meyerowitz, and Art Wolff, stirs the spirit, capturing the mutable beauty of sand, sea, and sky. Throughout, concise and poetic pieces of historic and scientific lore unveil little-known facts and curiosities. With an astonishing range of vision, Beaches evokes the idiosyncratic beauty of the world\'s most stunning coastlines. \r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0811826503.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0811826503.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 24.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 17.46 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0811826503' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (127 , 'Beaches of Maui County (A Kolowalu Book)' , 2 , 1 , NULL , NULL , 2 , '0824812468' , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0824812468.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0824812468.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 2 , NULL , NULL , NULL , 1 , 11.96 , 20 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0824812468' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (128 , 'Exploring Southern California Beaches (FalconGuide)' , 3 , 1 , NULL , NULL , 2 , '1560446323' , NULL , NULL , NULL , NULL , NULL , 0 , '"From the bustle of the Mexican border to the isolated beauty of Point Conception, sit back and enjoy the ride as veteran writer and beach bum David Crowell takes you on Safari in Exploring Southern California Beaches. Discover the diversity of life in " --This text refers to the Digital edition. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1560446323.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/1560446323.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 18.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 13.26 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/1560446323' , 2 , 10 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (129 , 'Manhattan Unfurled' , 1 , 1 , NULL , NULL , 2 , '0375504915' , NULL , NULL , NULL , NULL , 'Matteo Pericoli trained as an architect in Milan and then came to work in New York in 1995. His arrival preceded by just a few days the arrival of the biggest snowstorm of the decade, and the sense of the city in its wakeespecially its silenceremained in his mind. He experienced similar feeling taking photographs of Riverside Drive from the Circle Line ferry, and decided to transpose them into a line drawing. It was then that he felt compelled to photograph the whole of New... ' , 0 , 'Matteo Pericoli trained as an architect in Milan and then came to work in New York in 1995. His arrival preceded by just a few days the arrival of the biggest snowstorm of the decade, and the sense of the city in its wakeespecially its silenceremained in his mind. He experienced similar feeling taking photographs of Riverside Drive from the Circle Line ferry, and decided to transpose them into a line drawing. It was then that he felt compelled to photograph the whole of New Yorks shoreline profilefrom Queens, Brooklyn, the Bronx, and New Jersey (which he reached by motorcycle)  and make two continuous and continuously enchanting pen-and-ink drawing of Manhattans skyline. \r\n\r\nManhattan Unfurled is published in an elegant slipcase, and the drawings fold out, accordion-style, with the West on one side and the East on the other. An introduction by distinguished New Yorker architecture critic Paul Goldberger, who first wrote bout Matteos project in The New Yorkers Talk of the Town, will accompany the drawing in a separate pamphlet. This book is both a wonderful New York City memento, perfect for gift giving, and an entirely unique work of art.\r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0375504915.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0375504915.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 29.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 20.96 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0375504915' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (130 , 'The Artist\'s Way Morning Pages Journal : A Companion Volume to the Artist\'s Way' , 2 , 1 , NULL , NULL , 2 , '0874778867' , NULL , NULL , NULL , NULL , NULL , 0 , 'The idea behind Julia Cameron\'s The Artist\'s Way is that by writing three pages, longhand and stream-of consciousness, first thing in the morning, you can overcome the obstacles that stop you from becoming your most creative self. This works partly because it forces you to create something (even if it is just a long list of gripes) every single day. It doesn\'t take much time. You\'re not even supposed to think. But the act itself gets you past all that self-defeating fretting about why you think you aren\'t a creative person. Cameron sees her morning pages as "a form of meditation," as "spiritual windshield wipers."\r\nWhile Cameron touts the morning pages as a way of life, she suggests you start out doing them as part of a "twelve-week program to recover your creativity." If you would like to keep your first twelve weeks of morning pages together in one tidy place, The Artist\'s Way Morning Pages Journal is a fine tool for doing so. Each nearly blank page features an inspiring quotation from The Artist\'s Way: "Leap, and the net will appear," says one; "Creativity lies not in the done but in doing," reminds another. We should mention that many of these little inspirations include references to God, which may be troublesome even for spiritual atheists. --Jane Steinberg \r\n\r\n' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0874778867.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0874778867.01.MZZZZZZZ.gif' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 11.96 , 20 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0874778867/' , 1 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (131 , 'Patience & Fortitude : A Roving Chronicle of Book People, Book Places, and Book Culture' , 3 , 1 , NULL , NULL , 2 , '0060196955' , NULL , NULL , NULL , NULL , NULL , 0 , 'A sequel of sorts to Basbanes\'s earlier A Gentle Madness (on the manic nature of bookselling and book-collecting), this copious volume takes its title from the formidable lions guarding the entrance to the main branch of the New York Public Library in Manhattan. Opening with the great libraries of the past, from Alexandria to Pergamum and Glastonbury, Basbanes, former literary editor of the Worcester Sunday Telegram, segues into such venerable active libraries as those at the Vatican, Wolfenbottel and the universities of Durham, Leiden and Oxford. He visits with shrewd, sometimes eccentric book dealers who happily recount tales of bygone bibliophiles, and illustrates a variety of collections, from illuminated medieval manuscripts to volumes more valuable for who owned them than for binding or content. "I absolutely insist on keeping the same crummy look," a bookshop owner tells him proudly. "Every time I make the place too neat, business goes down." But a pathos pervades the book, for despite the huge increase in readers and book buyers, one dealer observes "a radical dismantling of high culture well under way" since the 1930s. The collector in 1939 who bought a rare book about Native American languages "by selling bottles of his own blood" has no latter-day parallel. Basbanes closes with tales of crusty benefactors like Andrew Carnegie, and interviews with librarians faced with the dilemma of too many old books that no one now wants to read. Basbanes\'s fund of stories will delight readers who value books for more than just a good story, have a yen for second-hand books plucked from dusty shops or look to book catalogs for suspense and excitement. 32 pages of b&w photos not seen by PW. Agents, Glen Hartley and Lynn T. Chu. (Oct.)Forecast: This will undoubtedly garner much attention in the book pages, as did its predecessor, aided by a six-city author tour, a 15-city NPR campaign and print features.\r\n\r\nCopyright 2001 Cahners Business Information, Inc.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0060196955.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/0060196955.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 35 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 24.5 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0060196955' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (132 , 'Extreme Beauty: The Body Transformed' , 4 , 1 , NULL , NULL , 2 , '0300091176' , NULL , NULL , NULL , NULL , NULL , 0 , 'From Publishers Weekly \r\nHigh-heeled shoes, push-up bras, Elizabethan ruffs and Japanese platform clogs are just a few examples of clothing that has pushed and pulled the human form into new shapes in the last few centuries. With color photos and illustrations, Extreme Beauty: The Body Transformed, which accompanies a Metropolitan Museum of Art exhibit of the same name, traces the role of fashion in manipulating the body to fit physical ideals. Harold Koda, curator of the Met\'s Costume Institute, focuses on extreme exaggerations of human form like the European 19th-century bustle, tiny corseted waists or the enormous-hipped dresses of the 18th-century French court, but also shows how today\'s designers quote and send up these iconic shapes. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0300091176.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0300091176.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 40 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 28 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0300091176' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (133 , 'Anthony Blunt: His Lives' , 5 , 1 , NULL , NULL , 2 , '0374105316' , NULL , NULL , NULL , NULL , NULL , 0 , 'From Publishers Weekly \r\nThis engaging and important biography examines the many masks of the infamous Anthony Blunt (1907-1983), the Cambridge art historian turned spy who worked simultaneously for British Intelligence and the Soviet Union during WWII. Why did he betray his country? Carter provides an exhaustive psychological study of Blunt\'s early life. His brutalizing public school (where he was unhappy and unpopular), Carter argues, "inadvertently fostered a questioning and subversive attitude and a profound distrust of authority." When the Depression hit England in the 1930s and the specter of fascism threatened Europe, communism became fashionable among left-leaning intellectuals like Blunt and his Cambridge friend Guy Burgess. Blunt\'s homosexuality, like Burgess\'s, also appears to have alienated him from the establishment. During WWII, Blunt was assigned to British intelligence, giving him easy access to military secrets, which he smuggled to the Soviets. After his Cambridge spy friends Burgess, Donald MacLean and Kim Philby defected to the Soviet Union after the war, British Intelligence began investigating Blunt. In 1964, he was granted immunity in exchange for his confession and full cooperation. British intelligence worked hard to keep "the Blunt affair" a secret. He wasn\'t publicly exposed until 1979, when Margaret Thatcher denounced him. The biggest challenge any Blunt biographer faces is Blunt himself, a man of almost legendary emotional detachment. Blunt revealed little about his personal life, yet Carter has managed to bring readers as close to this enigmatic man as humanly possible. Thoroughly researched and carefully crafted, this is sure to be the definitive biography. 16 pages of photos not seen by PW. (Jan.)Forecast: Blunt\'s story isn\'t quite the sensation here that it is in England; devotees of spy tales and contemporary British history will read this.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0374105316.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0374105316.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 30 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 21 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0374105316' , 1 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (134 , 'Awakening the Virgin' , 6 , 1 , NULL , NULL , 2 , '1555834566' , NULL , NULL , NULL , NULL , NULL , 0 , NULL , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1555834566.01.__PIm.arrow,TopLeft,-2,-19_SCTZZZZZZZ_.jpg' , NULL , 'http://images.amazon.com/images/P/1555834566.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 13.95 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , 1 , NULL , NULL , NULL , 1 , 11.16 , 20 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/1555834566' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (135 , 'Churches' , 7 , 1 , NULL , NULL , 2 , '0060194383' , NULL , NULL , NULL , NULL , 'The physical dimensions alone would be enough to make Churches, Judith Dupre\'s sumptuous chronology of Christian art and architecture, one of the most absorbing ways possible to learn about the world\'s most beautiful houses of worship. It is almost too big to fit in your lap, and each brilliantly...' , 0 , 'The physical dimensions alone would be enough to make Churches, Judith Dupre\'s sumptuous chronology of Christian art and architecture, one of the most  absorbing ways possible to learn about the world\'s most beautiful houses of worship. It is almost too big to fit in your lap, and each brilliantly colored page is  almost three times the width of a human head. In addition, Churches offers floor  plans, histories, and theological interpretations of almost 60 churches around the  world, from the Pantheon in Rome to La Sagrada Familia in Barcelona to the  Crystal Cathedral in Garden Grove, California. Interspersed with these chapters  are photographic essays on such topics as "Building a Gothic Cathedral" and  "Ancient Paths: Contemporary Labyrinths." All of the images and essays are  presented in a format accessible to the general reader. Those more broadly  informed about architecture will be drawn to the interview with Swiss-Italian  architect Mario Botta--his first in-depth interview published in English. In the end,  the book\'s most amazing accomplishment is to provide readers with sensations  that approximate both the grandeur and the intimacy of visiting the churches it  depicts. --Michael Joseph Gross' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/0060194383.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/0060194383.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 40 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 28 , 30 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/0060194383/' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (136 , 'Celebrate Your Creative Self : Over 25 Exercises to Unleash the Artist Within' , 8 , 1 , NULL , NULL , 2 , '1581801025' , NULL , NULL , NULL , NULL , NULL , 0 , 'Book Description \r\nArtists and creatives of all kinds who are looking for new ways to liberate their artistic imagination will love this book. Readers are invited to playfully explore various aspects of visual art, such as light, color, texture and design through a series of imaginative art projects. Artists will experiment hands-on with dozens of techniques and mediums in new and unconventional ways including: * Capturing whites with crayon and wax resist * Glazing and floating colors * Portraying the patterns of nature with sedimentation and precipitation * Loosening up with gesso painting and printing with plastic * Constructing a new piece of art from old work * Experimenting with three-dimensional assemblage * Creating a street map In addition, artists are prompted to challenge their imaginations by building new painting surfaces, creating their own personal symbols and more. Further inspiration can be found in a gallery of work by more than 30 contributing artists. Celebrate Your Creative Self is a fun, no-fail guide every artist should have. ' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/1581801025.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/1581801025.01.LZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 28.99 , NULL , NULL , NULL , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 18.26 , 37 , 0 , NULL , NULL , NULL , NULL , 1 , NULL , 'http://www.amazon.com/exec/obidos/ASIN/1581801025/' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (137 , 'Rock Star from Amazon' , 1 , 1 , NULL , NULL , 2 , 'B00005TPMA' , NULL , NULL , NULL , NULL , 'Watch Mark Wahlberg and Jennifer Aniston live the highs and lows of a rock  & roll fantasy come true in Rock Star.  Black leather pants recommended.\r\n' , 0 , 'This movie is a must for your collection, especially if you\'re fan of BIG HAIR ROCK. I grew up with the type of music this film is based on. I thought Mark Wahlberg did an amazing job of capturing the essence of a Heavy Metal  frontman. He had the perfect swagger and look. Even if you aren\'t a huge fan of Metal, I\'m sure at one time you\'ve fantasized about being a rock star or some type of entertainer, right? I\'m sure you\'ll be able to relate to the story of a guy who sings for a tribute band of his heroes, eventually getting the call to front the ACTUAL band. Jennifer Aniston and the cast of real life rockers like guitarist Zakk Wylde and Third Eye Blind\'s Stephan Jenkins are all great too. Oh and by the way... the soundtrack CD is also excellent, with original music from the film\'s  band, Steel Dragon and classics from KISS, Bon Jovi and others. For a fun film  ride I enthusiastically recommend ROCK STAR! Enjoy!!!' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005TPMA.01.25TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005TPMA.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.98 , NULL , NULL , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.95 , 25 , 0 , NULL , NULL , 0 , NULL , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/B00005TPMA/' , 1 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (138 , 'The Curse of the Jade Scorpion (2001) from Amazon' , 1 , 1 , NULL , NULL , 2 , 'B00003CY6A' , NULL , NULL , NULL , NULL , NULL , 0 , 'With The Curse of the Jade Scorpion, Woody Allen pays another visit to his idealized past, and his retro blend of humor and nostalgia will surely satisfy the filmmaker\'s most loyal fans. Like The Purple Rose of Cairo, Radio Days, and Sweet and Lowdown, The Curse of the Jade Scorpion is physically impeccable: its period-perfect costumes and sets capture 1940 New York with splendid authenticity and are further enhanced by the burnished glow of Zhao Fei\'s cinematography. And like those earlier films, Jade Scorpion mines comedic gold from its timeframe, molding it into a plot laced with expert zingers that could only spring from a rich awareness of comedic tradition. Add an appealing roster of costars (including Elizabeth Berkley and Charlize Theron) and you\'ve got vintage Woody that perks right along. The movie\'s also as trivial as it is engaging; hack off 30 minutes and it might have had the delirious precision of early Marx Brothers classics. Instead, Allen\'s goofy conceit--enemies falling in love by hypnotic suggestion--is stretched to absurdity when efficiency expert Betty Ann "Fitz" Fitzgerald (Helen Hunt) is hypnotically attracted to seasoned insurance investigator C.W. Briggs (Allen), despite their office enmity. Plus, a jewel-heist caper masterminded by the nightclub hypnotist\r\n(David Ogden Stiers) casts them both as suspects! Woody harvests a bumper crop of old-fashioned laughs from this predicament, and despite their conspicuous age difference and occasional awkward delivery, Hunt and Allen exchange volleys of dialogue like a seasoned comedy team. Dan Aykroyd is also good in a stodgy supporting role, but Jade Scorpion remains a mixed blessing--a welcomed throwback to comedy\'s yesteryear, from a master funnyman who\'s struggling to maintain relevance in the present. --Jeff Shannon' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00003CY6A.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00003CY6A.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 32.99 , NULL , NULL , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 26.49 , 20 , 0 , NULL , NULL , 0 , NULL , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/B00003CY6A/' , 1 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (139 , 'Groundhog Day (Special Edition) (1993) from Amazon' , 2 , 1 , NULL , NULL , 2 , 'B00005U8EM' , NULL , NULL , NULL , NULL , NULL , 0 , 'Bill Murray does warmth in his most consistently effective post-Stripes comedy,\r\n                  a romantic fantasy about a wacky weatherman forced to relive one strange day\r\n                  over and over again, until he gets it right. Snowed in during a road-trip expedition\r\n                  to watch the famous groundhog encounter his shadow, Murray falls into a time\r\n                  warp that is never explained but pays off so richly that it doesn\'t need to be. The\r\n                  elaborate loop-the-loop plot structure cooked up by screenwriter Danny Rubin is\r\n                  crystal-clear every step of the way, but it\'s Murray\'s world-class reactive timing\r\n                  that makes the jokes explode, and we end up looking forward to each new\r\n                  variation. He squeezes all the available juice out of every scene. Without forcing\r\n                  the issue, he makes us understand why this fly-away personality responds so\r\n                  intensely to the radiant sanity of the TV producer played by Andie MacDowell.\r\n                  The blissfully clueless Chris Elliott (Cabin Boy) is Murray\'s nudnik cameraman.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005U8EM.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005U8EM.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 24.95 , NULL , NULL , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 18.71 , 25 , 0 , NULL , NULL , 0 , NULL , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/B00005U8EM/' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (140 , 'Nothing in Common (1986) from Amazon' , 3 , 1 , NULL , NULL , 2 , 'B00005UQ6M' , NULL , NULL , NULL , NULL , NULL , 0 , 'Interminably long, highly uneven comedy-drama about a perpetual adolescent\r\n                  who\'s forced to deal with his aging, unloving father when his mom leaves him flat.\r\n                  Some poignant, relevant conclusions about love and responsibility (and some\r\n                  funny shots at the advertising business) are undermined by overlength and\r\n                  meandering nature of film. Hanks is excellent; Gleason is abrasive (in his last film\r\n                  appearance). Later a TV series. Super 35.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005UQ6M.01.TZZZZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005UQ6M.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 19.95 , NULL , NULL , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 14.96 , 25 , 0 , NULL , NULL , 0 , NULL , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/B00005UQ6M/' , 1 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (141 , 'Osmosis Jones (2001) from Amazon' , 1 , 1 , NULL , NULL , 2 , 'B00005QAQH' , NULL , NULL , NULL , NULL , NULL , 0 , 'After the stiff attempts at realism in many recent features, it\'s a treat to see broad\r\n                  cartoon-style animation on the big screen in Osmosis Jones, a spoof of cop movies\r\n                  set inside the human body. The title character (voice by Chris Rock) is a\r\n                  street-smart white blood cell, working for Frank\'s immune system. He and Drix\r\n                  (David Hyde Pierce), an over-the-counter cold capsule, are reluctant partners\r\n                  fighting what appears to be a minor infection. Osmosis discovers Frank has really\r\n                  contracted a fatal virus, Thrax (Laurence Fishburne): he battles a corrupt body\r\n                  politic led by a venal mayor (William Shatner) to save Frank\'s life and win the\r\n                  affection of the mayor\'s aide, Leah (Brandy Norwood). Rock\'s motor-mouth\r\n                  delivery can get annoying, but it contrasts nicely with straight arrow Drix (imagine\r\n                  a fussy Buzz Lightyear). Excellent drawing and a powerful vocal performance make\r\n                  Thrax a genuinely frightening villain.\r\n\r\n                  Osmosis Jones is about two-thirds animation and one-third live action, which is\r\n                  why two-thirds of the film is entertaining and funny, and one-third is not. The life\r\n                  Osmosis and Drix save belongs to Frank, a slob played in live-action sequences by\r\n                  Bill Murray, who\'s undercut rather than supported by Chris Elliott and Molly\r\n                  Shannon. Shamelessly over-the-top performances make the human characters\r\n                  seem flatter than the two-dimensional cartoons. The live action was shot by the\r\n                  Farrelly brothers and features lots of gross-out gags about zits, flatulence, vomit,\r\n                  snot, etc. The audience endures these leaden segments, waiting to get back to the\r\n                  animation--and the real comedy. Suitable for ages 9 and up: profanity, violence,\r\n                  bodily function jokes. --Charles Solomon' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005QAQH.01.14TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005QAQH.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 24.98 , NULL , NULL , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 21.49 , 14 , 0 , NULL , NULL , 0 , NULL , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/B00005QAQH/' , 1 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (142 , 'The John Singleton Collection (Boyz N the Hood, Poetic Justice, Higher Learning) from Amazon' , 2 , 1 , NULL , NULL , 2 , 'B00005JD5K' , NULL , NULL , NULL , NULL , NULL , 0 , 'Poetic Justice: BOYZ N THE HOOD writer-director Singleton suffers the\r\n                  sophomore jinx in this ambitious but fatally pretentious saga of a melancholy\r\n                  South Central L. A. beautician (Jackson), who has retreated from the world after\r\n                  her boyfriend\'s murder; mailman Shakur attempts to break through to her, with\r\n                  predictable results. Implausibly, the poetry this otherwise ordinary woman\r\n                  composes actually is the work of Maya Angelou (who appears onscreen as Aunt\r\n                  June). Jackson is OK in her screen debut.\r\n                  Higher Learning: Provocative drama of life at a big university where problems\r\n                  tend to break down along racial and sexual lines. Epps plays a young black\r\n                  athlete searching for direction and, sometimes blindly, raging at injustice.\r\n                  Fishburne is a political science professor who tries to help him see the world as\r\n                  it is. Credible, well-acted film goes awry when writer-director Singleton steers it\r\n                  toward melodrama, and foregoes student relations to focus on a group of\r\n                  extremist skinheads.\r\n                  Boyz N the Hood: Sober, thoughtful look at life in the black section of South\r\n                  Central L. A. A divorced father strives to raise his son with values--and steer him\r\n                  away from the ignorance and aimlessness that has led to an epidemic of\r\n                  senseless violence in the neighborhood. Impressive debut for 23-year-old\r\n                  writer-director Singleton; longish, and not always on-the-money, but overall quite\r\n                  potent and effective. Singleton has a bit part as a mailman.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005JD5K.01.25TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005JD5K.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 44.95 , NULL , NULL , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 33.71 , 25 , 0 , NULL , NULL , 0 , NULL , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/B00005JD5K/' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (143 , 'Amazing Grace (1974) from Amazon' , 3 , 1 , NULL , NULL , 2 , 'B00005R5W2' , NULL , NULL , NULL , NULL , NULL , 0 , 'A few laughs in Philadelphia-made comedy about an elderly busybody who disrupts corrupt Baltimore politics. Mabley\'s only starring film; cameos by Butterfly McQueen, unrecognizable Stepin Fetchit.' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5W2.01.10TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005R5W2.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.95 , NULL , NULL , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 13.46 , 10 , 0 , NULL , NULL , 0 , NULL , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/B00005R5W2/' , 1 , 5 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_items (item_id,item_name,item_order,item_type_id,issue_date,language_code,manufacturer_id,manufacturer_code,template_name,hide_add_list,hide_add_details,features,short_description,full_desc_type,full_description,is_special_offer,special_offer,notes,small_image,small_image_alt,big_image,big_image_alt,super_image,preview_url,preview_width,preview_height,specification,buying_price,price,is_price_edit,properties_price,tax_free,weight,stock_level,use_stock_level,hide_out_of_stock,disable_out_of_stock,shipping_in_stock,shipping_out_stock,shipping_rule_id,shipping_cost,is_sales,sales_price,discount_percent,downloadable,download_period,download_path,generate_serial,activations_number,is_showing,is_compared,buy_link,votes,points,rating,meta_title,meta_keywords,meta_description,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message,admin_id_added_by,admin_id_modified_by,date_added,date_modified) VALUES (144 , 'J.D.\'s Revenge (1976) from Amazon' , 4 , 1 , NULL , NULL , 2 , 'B00005R5W1' , NULL , NULL , NULL , NULL , NULL , 0 , 'It\'s been branded with the "blaxploitation" label, but there is little that\'s exploitive in\r\n                  J.D.\'s Revenge, a film of well-drawn, articulate characters dragged into a\r\n                  supernatural showdown. Glynn Turman (Cooley High) is especially fine as the\r\n                  sensitive and quiet Ike, a determined student moonlighting as a cab driver, so\r\n                  wound up he\'s on the verge of cracking. Enter (literally) the ghost of J.D., a\r\n                  violent, vengeful gangster murdered in the opening moments. He could be Ike\'s\r\n                  own Mr. Hyde, a dapper, flamboyant ladykiller with a fiery temper and a straight\r\n                  razor who slowly smothers Ike\'s easygoing personality. Driven by flashes of\r\n                  memory, he sets his vengeful sights on fire-and-brimstone preacher Reverend\r\n                  Bliss (Louis Gossett Jr.), whose dark past is intricately tied up with J.D.\'s\r\n                  murder. Director Arthur Marks (Detroit 9000) sidesteps the usual spooky clich?s\r\n                  to stir up a modern New Orleans gumbo of ghost story, gangster tale, and\r\n                  character drama. J.D. is both devilish sadist and avenging angel, while the\r\n                  tortured Ike awakens from J.D.\'s violent rampages with a hole in his memory but\r\n                  a sick feeling from his imagined complicity in the crimes. The story gets wrapped\r\n                  up a little too neatly in the end, but the dark character shadings and the evocative\r\n                  mystery at the center of Ike\'s possession makes J.D.\'s Revenge an\r\n                  unexpectedly compelling supernatural thriller. --Sean Axmaker' , 0 , NULL , NULL , 'http://images.amazon.com/images/P/B00005R5W1.01.10TRZZZZ.jpg' , NULL , 'http://images.amazon.com/images/P/B00005R5W1.01.MZZZZZZZ.jpg' , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 14.95 , NULL , NULL , 0 , NULL , NULL , 0 , 0 , 0 , NULL , NULL , NULL , NULL , 1 , 13.46 , 10 , 0 , NULL , NULL , 0 , NULL , 1 , 0 , 'http://www.amazon.com/exec/obidos/ASIN/B00005R5W1/' , 1 , 4 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;




INSERT INTO va_items_categories (item_id,category_id) VALUES (4 , 0 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (4 , 2 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (5 , 0 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (5 , 2 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (6 , 0 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (6 , 2 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (7 , 5 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (8 , 2 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (9 , 2 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (10 , 2 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (11 , 8 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (12 , 8 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (13 , 1 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (13 , 8 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (16 , 9 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (17 , 9 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (18 , 9 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (19 , 9 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (22 , 10 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (24 , 10 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (25 , 10 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (27 , 10 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (28 , 11 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (29 , 11 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (30 , 11 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (31 , 12 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (32 , 11 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (33 , 12 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (34 , 12 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (35 , 14 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (36 , 12 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (37 , 14 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (38 , 14 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (39 , 15 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (40 , 14 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (41 , 15 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (42 , 15 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (43 , 16 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (44 , 16 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (45 , 16 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (46 , 16 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (47 , 19 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (49 , 19 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (51 , 25 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (52 , 25 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (53 , 25 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (54 , 26 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (56 , 4 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (57 , 26 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (58 , 26 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (59 , 4 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (60 , 27 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (61 , 4 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (62 , 27 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (63 , 4 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (64 , 27 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (65 , 4 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (66 , 28 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (67 , 28 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (68 , 28 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (69 , 30 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (70 , 29 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (71 , 30 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (72 , 29 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (73 , 30 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (74 , 29 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (75 , 29 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (76 , 29 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (77 , 34 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (78 , 36 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (79 , 34 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (80 , 36 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (81 , 34 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (82 , 36 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (83 , 37 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (84 , 37 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (85 , 37 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (86 , 37 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (87 , 37 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (88 , 37 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (89 , 37 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (92 , 41 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (94 , 41 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (96 , 41 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (97 , 41 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (98 , 41 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (101 , 41 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (103 , 41 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (104 , 43 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (105 , 43 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (106 , 43 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (107 , 43 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (108 , 43 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (109 , 43 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (110 , 43 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (111 , 2 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (112 , 2 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (113 , 48 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (114 , 49 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (115 , 49 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (116 , 49 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (117 , 49 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (118 , 50 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (119 , 50 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (120 , 50 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (121 , 50 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (122 , 51 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (123 , 51 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (124 , 51 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (125 , 51 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (126 , 52 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (127 , 52 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (128 , 52 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (129 , 53 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (130 , 53 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (131 , 53 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (132 , 53 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (133 , 53 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (134 , 53 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (135 , 53 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (136 , 53 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (137 , 54 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (138 , 55 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (139 , 55 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (140 , 55 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (141 , 56 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (142 , 56 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (143 , 56 ) ;
INSERT INTO va_items_categories (item_id,category_id) VALUES (144 , 56 ) ;


















INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('ar' , 1 , 'Arabic' , 1 , 'images/flags/sa.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('cs' , 1 , 'Czech' , 1 , 'images/flags/cz.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('el' , 1 , 'Greek' , 1 , 'images/flags/gr.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('en' , 1 , 'English' , 1 , 'images/flags/gb.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('es' , 1 , 'Spanish' , 1 , 'images/flags/es.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('lv' , 1 , 'Latvian' , 1 , 'images/flags/lv.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('nl' , 1 , 'Dutch' , 1 , 'images/flags/nl.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('pl' , 1 , 'Polish' , 1 , 'images/flags/pl.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('pt' , 1 , 'Portuguese' , 1 , 'images/flags/pt.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('ru' , 1 , 'Russian' , 1 , 'images/flags/ru.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('sk' , 1 , 'Slovak' , 1 , 'images/flags/sk.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('sv' , 1 , 'Swedish' , 1 , 'images/flags/se.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('tr' , 1 , 'Turkish' , 1 , 'images/flags/tr.gif' , NULL ) ;
INSERT INTO va_languages (language_code,language_order,language_name,show_for_user,language_image,currency_code) VALUES ('uk' , 1 , 'Ukrainian' , 1 , 'images/flags/ua.gif' , NULL ) ;


INSERT INTO va_layouts (layout_id,layout_name,style_name,templates_dir,admin_templates_dir) VALUES (1 , 'Default (Enterprise)' , 'default' , './templates/user' , '../templates/admin' ) ;
INSERT INTO va_layouts (layout_id,layout_name,style_name,templates_dir,admin_templates_dir) VALUES (2 , 'Curved (Enterprise)' , 'curved' , './templates/user' , '../templates/admin' ) ;
INSERT INTO va_layouts (layout_id,layout_name,style_name,templates_dir,admin_templates_dir) VALUES (3 , 'Silver (Enterprise)' , 'silver' , './templates/user' , '../templates/admin' ) ;


INSERT INTO va_manufacturers (manufacturer_id,manufacturer_name,affiliate_code) VALUES (2 , 'Amazon' , '/viartco-20/' ) ;


INSERT INTO va_news (news_id,news_date,news_title,author,is_html,is_showing,show_on_index,preview_text,news_body) VALUES (1 , '2004-11-07 00:00:00' , 'Mr. Incredible versus Shrek ' , NULL , 1 , 1 , 1 , 'NEW YORK (CNN/Money) - Movie buffs flocking to "The Incredibles" will see a story of an overweight ex-superhero living in suburbia and newly unemployed when he secretly returns to his crime-fighting life and uncovers a sinister plot' , 'But for producer Pixar Animation Studios, Mr. Incredible is battling darker forces, namely the rise of its chief nemesis, DreamWorks Animation. \r\n\r\nOn Friday, the same day "The Incredibles" arrived in theaters nationwide, DreamWorks counterattacked by releasing its most potent weapon -- "Shrek 2" -- on DVD. \r\n\r\nWhile the DVD didn\'t put much of a dent into the box office release -- "The Incredibles" took in $70.7 million this weekend according to preliminary figures -- the simultaneous arrival points to the growing rivalry between Pixar and DreamWorks. \r\n\r\nBoth studios have been on a tear lately. Pixar\'s stock hit what was at the time an all-time high of $82.28 a share last week, the same day that DreamWorks Animation began trading on the New York Stock Exchange after its $812 million initial public offering. \r\n\r\nThis past Friday, Pixar set an all-time intraday high of $85.10 on buzz about the new movie. \r\n\r\nDreamWorks (up $0.10 to $40.45, Research) shares soared their first day and were up 44 percent from their offering price in late trading Thursday. \r\n\r\nBattle of the egos?\r\nThis isn\'t the first time that DreamWorks has tried to one-up its chief rival with a same-day release. \r\n\r\nAnd McAlpine thinks the studio\'s motive is not about business -- it\'s personal. \r\n\r\n   \r\nShrek 2 could ring in more profits, but Mr. Incredible won\'t be far behind. \r\nDreamWorks Animation CEO Jeffrey Katzenberg was head of Disney\'s animation arm when he bolted in 1994, after being passed up for the job of president at Disney. \r\n\r\nKatzenberg, instead, teamed with Steven Spielberg and record industry guru David Geffen to form DreamWorks, with the idea of building the company into a full-fledged entertainment shop. \r\n\r\nWhile Katzenberg and crew focused on DreamWorks, Disney concentrated on its existing deal with Pixar: The two studios split production costs, and Disney distributes the films and retains exclusive rights to the library. \r\n\r\nThe venture has been lucrative for both, with their six smash hit films outperforming each one that came before it. "Finding Nemo," released in 2003, became the top-grossing animation movie ever and has, according to DVD Exclusive, sold more DVDs than any other film. \r\n\r\nNow comes "The Incredibles," the sixth film from the Disney-Pixar duo. \r\n\r\nIt\'s their first film to be rated PG (as opposed to G) and based on human characters. And the story about a family of ex-superheroes lured from suburban retirement back to fighting crime is expected to generate a stellar opening weekend. Some analysts forecast a three-day haul of more than $80 million. \r\n\r\n \r\nDreamWorks, meanwhile, has had a tougher time spinning gold from its computer animation films, with one notable exception -- Shrek. \r\n\r\nThe original 2001 movie about a green ogre who finds love while battling an evil lord generated a whopping $479 million in worldwide ticket sales. \r\n\r\nThis summer\'s "Shrek 2" edged aside "Finding Nemo" when it set new records for an animation film with a worldwide haul of $879 million at the box office. \r\n\r\nSomebody blinked\r\nWhile Friday\'s release of "Shrek 2" poses a bigger box office threat to Nemo\'s DVD record than it does to "The Incredibles," the timing isn\'t a coincidence. \r\n\r\n"It seems to me that Mr. Katzenberg is nudging (Pixar chief Steven Jobs) and Mr. Eisner," said McAlpine, noting that DreamWorks has at least twice before timed DVD releases to a Pixar-Disney box office debut. Michael Eisner, Disney\'s CEO, plans to step down in 2006. \r\n\r\nDavid Mantell, an analyst with Loop Capital Markets, agreed that DreamWorks is sending a message to its rivals. \r\n\r\nFrom a business standpoint, however, Mantell said the bigger threat to "The Incredibles" comes next week, when Warner Bros. releases "The Polar Express," its first major push into computer animation. Warner Bros., like CNN/Money, is owned by Time Warner (Research). \r\n\r\n \r\nThat said, the jab from DreamWorks is coming at an especially sensitive time for Disney (up $0.11 to $26.43, Research) and Pixar (up $3.59 to $84.45, Research). Their coproduction deal expires after next year\'s release of "Cars." \r\n\r\nEarlier this year, Jobs broke off negotiations, after the two sides could not agree on terms for a new deal, amid reports he didn\'t get along with Eisner. \r\n\r\nThe impasse leaves Pixar and Disney at a crossroads. Pixar has been scouting for a new distribution partner, one that would receive a far smaller slice of revenues than Disney pockets under the current deal. \r\n\r\nAnd Disney has been preparing for life without Pixar by beefing up its own animation division. But Disney\'s track record with non-Pixar animated films is less than stellar. \r\n\r\nFor that reason, some analysts think Disney needs Pixar and its creative know-how more than Pixar needs Disney. \r\n\r\nFriday\'s release of "Shrek 2" on DVD could be Katzenberg\'s way of reminding Eisner that "he made a mistake and should have brought (Katzenberg) in to run the company," said McAlpine. \r\n\r\nIf so, Katzenberg recently shied away from the ultimate battle of the studios. \r\n\r\n"Shark Tale," the latest DreamWorks animation about an underwater mafia of sharks, was originally scheduled for a Nov. 5 release. When Disney put "The Incredibles" on the same calendar, Katzenberg blinked. \r\n\r\n"Shark Tale" debuted Oct. 1.   \r\n' ) ;
INSERT INTO va_news (news_id,news_date,news_title,author,is_html,is_showing,show_on_index,preview_text,news_body) VALUES (2 , '2004-11-07 00:00:00' , 'Bosox \'curse\' contract: $1M plus' , NULL , 0 , 1 , 1 , 'NEW YORK (CNN/Money) - The document that "cursed" the Boston Red Sox for 86 years is about to become a $1 million-plus blessing for a Rhode Island homeless shelter. \r\n\r\n \r\n' , 'The original 1919 contract selling Babe Ruth to the New York Yankees for $100,000 is being auctioned by a Rhode Island philanthropist, Alan Shawn Feinstein, on the eBay auction site. As of 7:25 p.m. ET Sunday, bidding on the contract stood at $1,001,000. \r\n\r\nIn addition to the contract, the successful bidder will receive a 4-page feature story about the curse that kept the Red Sox from winning the World Series, and a letter from Hall of Famer Ty Cobb describing Ruth as baseball\'s greatest player. \r\n\r\n   \r\nBuy Red Sox Tickets\r\nRazorGator.com offers quality pricing, selection and service to sold-out and...\r\nwww.razorgator.com\r\n\r\nThe Curse is Over\r\nGo Red Sox. Buy commemorative t-shirts, bumper stickers, hats, and more.\r\nwww.cafepress.com\r\n\r\nReverse Boston\'s Curse\r\nHey Red Sox fans. Looking for a new and fun way to support the team? We have...\r\nwww.cursereverse.com\r\n\r\nBoston Red Sox Pins, Earrings, Key Chain\r\nRed Sox collector pins, pin sets, earrings, key chains and other...\r\nteampins.com \r\nSome 220 bids have been received in the auction, which ends at 12:08 p.m. ET Tuesday. \r\n\r\nAccording to the eBay page describing the auction, proceeds from the sale will go to the House of Hope, a homeless shelter in Warwick, R.I. \r\n\r\nThe 73-year-old Feinstein told the New York Times that he has raised another $2 million for charity by selling copies of the contract, which he bought in 1993 for $99,000, for $30. \r\n\r\nThe Feinstein Foundation\'s Web site says Feinstein, who made his fortune as a financial newsletter publisher, wants to name the shelter for a late Sister of Mercy nun, Fran Conway, who was a die-hard Sox fan. \r\n\r\nThe item description says that right after Feinstein donated the contract for the auction last month, the Red Sox won the eight straight games that gave them their first World Series title since 1918. That, of course, was the year before Red Sox owner Harry Frazee sold Ruth to the Yankees, which some fans believe led to Boston\'s baseball curse. \r\n\r\n \r\n"Maybe all the good that came from the sale of these contracts made the gods smile," Feinstein told the Times. "From good comes good. Maybe someday, these kids will tell their grandkids, \'We helped break the jinx on the Red Sox.\'"   \r\n' ) ;
INSERT INTO va_news (news_id,news_date,news_title,author,is_html,is_showing,show_on_index,preview_text,news_body) VALUES (3 , '2004-11-08 00:00:00' , 'Iraqi minister berates Annan' , NULL , 0 , 1 , 1 , 'FALLUJA, Iraq (CNN) -- Iraq\'s interim defense minister Hazem Sha\'alan has lashed out at U.N. Secretary-General Kofi Annan and leaders of other Arab countries during a pep talk for Iraqi troops before an expected assault on the insurgent-held city of Falluja' , 'FALLUJA, Iraq (CNN) -- Iraq\'s interim defense minister Hazem Sha\'alan has lashed out at U.N. Secretary-General Kofi Annan and leaders of other Arab countries during a pep talk for Iraqi troops before an expected assault on the insurgent-held city of Falluja.\r\n\r\nAnnan warned in a letter dated October 31 to the United States, Britain and Iraq that such an assault would have a "negative impact" on the prospects for elections, now scheduled for January.\r\n\r\nBut Sha\'alan said on Sunday that Annan did nothing to help Iraqis under the rule of ousted leader Saddam Hussein.\r\n\r\n"Where was Kofi Annan when Saddam was slaughtering the Iraqis like sheep?" Sha\'alan said.\r\n\r\n"Where were the calls we hear from Arab and Islamic countries when Saddam was messing up the country?"\r\n\r\nWith thousands of U.S. troops poised to launch a major assault on Falluja, which has been under insurgent control for months, Sha\'alan told the Iraqi troops set to participate in the offensive that they were "the defenders of democracy" who would rescue a city held hostage.\r\n\r\n"Those who call not to fight the criminals, we say to them, \'You are the criminals.\' They are the criminals," he said.\r\n\r\n"How could you shake hands with Saddam Hussein before? You were a slave to Saddam Hussein, and today you try your best to restore dictatorship and crime, but under a new umbrella -- that is the umbrella of Islam."\r\n\r\nThe troops crowded in to hear him, raising their rifles into the air and cheering, dancing and singing at the end.\r\n\r\nSha\'alan predicted the insurgents, who have been in effective control of Falluja for months, would "run away like rats" when attacked.\r\n\r\n"We will chase them from house to house, from room to room," he said.\r\n\r\nThe U.S. military censored the report of Sha\'alan\'s remarks before allowing it to be sent to media participating in the pool.\r\n\r\nIraqi special forces backed by U.S. Marines seized Falluja\'s main hospital late Sunday, but it remains unclear when the main assault into the city will begin.\r\n\r\n\r\n' ) ;












INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (1 , 'New Order Placed' , 0 , 0 , 0 , 1 , 0 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (2 , 'CC Info Added' , 0 , 0 , 0 , 1 , 0 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (3 , 'Confirmed by User' , 0 , 0 , 0 , 1 , 0 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (4 , 'Paid' , 0 , 0 , 0 , 1 , 1 , 0 , 1 , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL ) ;
INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (5 , 'Goods shipped' , 0 , 0 , 0 , 1 , 1 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (6 , 'Pending' , 0 , 0 , 0 , 1 , 0 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (7 , 'Closed' , 0 , 0 , 0 , 1 , 2 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (8 , 'Declined' , 0 , 0 , 0 , 1 , 0 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (9 , 'Validated' , 0 , 0 , 0 , 1 , 2 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (10 , 'Failed' , 0 , 0 , 0 , 1 , 0 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (11 , 'Dispatch' , 0 , 0 , 1 , 1 , 2 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_order_statuses (status_id,status_name,is_user_cancel,allow_user_cancel,is_dispatch,is_list,download_activation,download_notify,item_notify,mail_notify,mail_to,mail_from,mail_cc,mail_bcc,mail_reply_to,mail_return_path,mail_type,mail_subject,mail_body,sms_notify,sms_recipient,sms_originator,sms_message) VALUES (12 , 'Cancelled' , 1 , 0 , 0 , 1 , 0 , 0 , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL , NULL , NULL , NULL , NULL , NULL ) ;


















INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'a_breadcrumb_1' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'a_details_1' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'a_latest_cols_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'a_latest_recs_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'a_related_1' , 2 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'a_subcats_type_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'language_selection' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_1' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'a_breadcrumb_3' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'a_details_3' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'a_latest_cols_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'a_latest_recs_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'a_subcats_type_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_3' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'a_breadcrumb_30' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'a_details_30' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'a_latest_cols_30' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'a_latest_recs_30' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'a_subcats_cols_30' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'a_subcats_subs_30' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'a_subcats_type_30' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'language_selection' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_30' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_4' , 'a_details_4' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_4' , 'a_latest_cols_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_4' , 'a_latest_recs_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_4' , 'a_subcats_type_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_4' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_4' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_4' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_4' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_4' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_4' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_4' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'a_details_5' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'a_latest_cols_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'a_latest_recs_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'a_subcats_cols_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'a_subcats_subs_5' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'a_subcats_type_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_5' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'a_breadcrumb_6' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'a_details_6' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'a_latest_cols_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'a_latest_recs_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'a_subcats_cols_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'a_subcats_subs_6' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'a_subcats_type_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_details_6' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'a_breadcrumb_1' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'a_hot_cols_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'a_hot_recs_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'a_latest_cols_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'a_latest_recs_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'a_list_1' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'a_list_cols_1' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'a_list_recs_1' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'a_subcats_cols_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'a_subcats_subs_1' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'a_subcats_type_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'language_selection' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_1' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_breadcrumb_3' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_cats_3' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_cats_cols_3' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_cats_subs_3' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_cats_type_3' , NULL , '3' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_hot_cols_3' , NULL , '3' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_hot_recs_3' , NULL , '3' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_latest_cols_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_latest_recs_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_list_3' , 2 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_list_cols_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'a_list_recs_3' , NULL , '20' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_3' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'a_breadcrumb_30' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'a_hot_cols_30' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'a_hot_recs_30' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'a_latest_cols_30' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'a_latest_recs_30' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'a_list_30' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'a_list_cols_30' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'a_list_recs_30' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'a_subcats_cols_30' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'a_subcats_subs_30' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'a_subcats_type_30' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'language_selection' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_30' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'a_content_4' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'a_hot_cols_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'a_hot_recs_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'a_latest_cols_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'a_latest_recs_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'a_list_4' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'a_list_cols_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'a_list_recs_4' , NULL , '20' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'a_subcats_cols_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'a_subcats_subs_4' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'a_subcats_type_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_4' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'a_hot_cols_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'a_hot_recs_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'a_latest_cols_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'a_latest_recs_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'a_list_5' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'a_list_cols_5' , NULL , '3' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'a_list_recs_5' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'a_subcats_cols_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'a_subcats_subs_5' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'a_subcats_type_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'right_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_5' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'a_breadcrumb_6' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'a_hot_cols_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'a_hot_recs_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'a_latest_cols_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'a_latest_recs_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'a_list_6' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'a_list_cols_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'a_list_recs_6' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'a_subcats_cols_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'a_subcats_subs_6' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'a_subcats_type_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'a_list_6' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_categories' , 2 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_categories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_categories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_category_info' , 0 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_details' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_recently_viewed' , 3 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_search' , 1 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_details' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_categories' , 1 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_categories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_categories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_categories_type' , NULL , '3' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_category_info' , 0 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_list' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_search' , 2 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'ads_list' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'forum_list' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'language_selection' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_list' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'forum_view_topic' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'language_selection' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topic' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'cb_admin_type_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'cb_admin_type_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'cb_params_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'cb_params_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'cb_user_type_2' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'cb_user_type_3' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'forum_topics_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'language_selection' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'left_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'left_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'middle_column_width' , NULL , '100%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'forum_topics' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'cart_block' , 0 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'categories_block' , 1 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'details_block' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'left_column_width' , NULL , '30%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'middle_column_width' , NULL , '70%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'products_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'related_block' , 2 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'related_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'related_per_page' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_details' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'cart_block' , 0 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'categories_block' , 1 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'currency_block' , 2 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'left_column_width' , NULL , '30%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'middle_column_width' , NULL , '70%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'products_block' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'products_breadcrumb' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'products_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'products_per_page' , NULL , '20' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'right_column_width' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'search_block' , 3 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'subcategories_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'products_list' , 'subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_hot_1' , 2 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_hot_cols_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_hot_cols_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_hot_cols_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_hot_cols_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_hot_cols_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_hot_recs_1' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_hot_recs_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_hot_recs_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_hot_recs_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_hot_recs_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_latest_cols_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_latest_cols_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_latest_cols_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_latest_cols_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_latest_cols_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_latest_recs_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_latest_recs_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_latest_recs_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_latest_recs_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_latest_recs_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_cols_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_cols_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_cols_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_cols_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_cols_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_subs_1' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_subs_3' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_subs_4' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_subs_5' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_subs_6' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_type_1' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_type_3' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_type_4' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_type_5' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'a_subcats_type_6' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_details_tabs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_hot_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_hot_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_latest_cols' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_latest_recs' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_list_columns' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_list_per_page' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_subcategories_subs' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_subcategories_type' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'ads_user_type_id' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'bestsellers_days' , NULL , '7' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'bestsellers_records' , NULL , '10' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'bestsellers_status' , NULL , NULL ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'cart_block' , 1 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'categories_block' , 1 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'language_block' , 0 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'language_selection' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'left_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'left_column_width' , NULL , '25%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'login_block' , 4 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'middle_column_hide' , NULL , '0' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'middle_column_width' , NULL , '75%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'offers_block' , 0 , 'middle' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'products_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'products_per_page' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'recent_records' , NULL , '5' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'right_column_hide' , NULL , '1' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'right_column_width' , NULL , '10%' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'search_block' , 2 , 'left' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'subcategories_columns' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'subcategories_subs' , NULL , '6' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'subcategories_type' , NULL , '2' ) ;
INSERT INTO va_page_settings (layout_id,page_name,setting_name,setting_order,setting_value) VALUES (0 , 'index' , 'top_products_block' , 3 , 'left' ) ;


INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (1 , 'home' , 'Home' , 'index.php' , 1 , 1 , 0 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (2 , 'products' , 'Products' , 'products.php' , 2 , 1 , 0 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (3 , 'basket' , 'Basket' , 'basket.php' , 3 , 1 , 0 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (4 , 'admin' , 'Administration' , 'admin/admin.php' , 11 , 1 , 0 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (5 , 'registration' , 'Registration' , 'user_profile.php' , 1 , 1 , 0 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (6 , 'news' , 'News' , 'articles.php?category_id=1' , 5 , 1 , 1 , NULL , NULL , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (7 , 'help' , 'How to Shop' , NULL , 8 , 1 , 0 , 1 , NULL , NULL , '<table width=600 border=0 bgcolor=#cccccc cellpadding=0 cellspacing=0 align="center">\r\n<tr><td>\r\n<table width=100% border=0 cellpadding=2 cellspacing=1>\r\n<tr bgcolor=#eeeeee><td><font face="Arial, Helvetica" size="5">\r\n\t<b>&nbsp;How to Shop at Our Online Store</b>&nbsp;</font>\r\n</td></tr>\r\n</table>\r\n</td></tr>\r\n</table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 align=center>\r\n<tr><td><font face="Verdana, Arial, Helvetica"  size=2>\r\n<p align="justify"> \r\n\r\nShopping online with us is\r\na lot like shopping at a retail store you browse our catalogue of products for the items you\'d\r\nlike, put them in a shopping basket, and complete your purchase at the check-out\r\narea. The only difference is, we\'re open 24 hours a day - seven days a week,\r\n...and you don\'t have to put on shoes and leave the comfort of your home to shop!\r\n\r\n<p align="justify">\r\n\r\nSo read on and find out how you can enjoy the shopping experience with Our Online Store.\r\n</td></tr></table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 bgcolor=#cccccc cellpadding=0 cellspacing=0 align="center">\r\n<tr><td>\r\n<table width=100% border=0 cellpadding=2 cellspacing=1>\r\n<tr bgcolor=#eeeeee><td><font face="Arial, Helvetica" size="4">\r\n\t<b>&nbsp;Step 1. &nbsp;Make Your Product Selections</b>&nbsp;</font>\r\n</td></tr>\r\n</table>\r\n</td></tr>\r\n</table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 align=center>\r\n<tr><td><font face="Verdana, Arial, Helvetica"  size=2>\r\n<p align="justify"> \r\n\r\nThe first thing to do is browse our shop for the items you\'d like. \r\nAs you browse you\'ll see \'Add/Buy\' link.\r\nOnce you\'ve found the\tfirst product you\'d like, simply add it to your online \r\nshopping basket by clicking on the \'Add/Buy\' link.\r\n\r\n<p align="justify">\r\n\r\nJust like in a retail store, the shopping basket is a holding place \r\nfor your items until you are ready to purchase them. You can view the\r\ncontents of your basket at any time by clicking on the \'View Basket\' link on your\r\nshopping page. And, just like a retail store, you can always remove items from your \r\nbasket and put them back on the shelves.\r\n\r\n</td></tr></table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 bgcolor=#cccccc cellpadding=0 cellspacing=0 align="center">\r\n<tr><td>\r\n<table width=100% border=0 cellpadding=2 cellspacing=1>\r\n<tr bgcolor=#eeeeee><td><font face="Arial, Helvetica" size="4">\r\n\t<b>&nbsp;Step 2.&nbsp;Proceed to the Check Out</b>&nbsp;</font>\r\n</td></tr>\r\n</table>\r\n</td></tr>\r\n</table>\r\n\r\n<br>\r\n   \r\n<table width=600 border=0 align=center>\r\n<tr><td><font face="Verdana, Arial, Helvetica"  size=2>\r\n<p align="justify"> \r\n\r\nOnce you\'ve decided upon your selection and \r\nchecked your basket, you proceed to the Ordering Stage by clicking "Check Out". \r\nAt this point you must decide whether you want to register with us or just place your order without registration. \r\nRegistration means that you don\'t need to complete your details again if you order from us in the future. \r\nThis action takes you to page where we need some extra details to complete the order.\r\nYou enter your personal information, your name and address so we know where to send the goods.\r\n\r\n<!-- \r\n<p align="justify"> \r\nShipping in the US is $7 per order. \r\nBuyers outside of the US will be charged at cost and will be advised of the shipping and packing charges by email.&nbsp;&nbsp;\r\n-->\r\n</td></tr></table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 bgcolor=#cccccc cellpadding=0 cellspacing=0 align="center">\r\n<tr><td>\r\n<table width=100% border=0 cellpadding=2 cellspacing=1>\r\n<tr bgcolor=#eeeeee><td><font face="Arial, Helvetica" size="4">\r\n\t<b>&nbsp;Step 3.&nbsp;Submit your Order</b>&nbsp;</font>\r\n</td></tr>\r\n</table>\r\n</td></tr>\r\n</table>\r\n\r\n<br>\r\n\r\n<table width=600 border=0 align=center>\r\n<tr><td><font face="Verdana, Arial, Helvetica"  size=2>\r\n<p align="justify"> \r\n\r\nAt this point you must decide upon the payment method.&nbsp;&nbsp;You can pay online by entering your credit card information.&nbsp;&nbsp;Alternatively you can print out the form and fax it to us, <b>or</b> you can submit the form without credit card details and call us later with this information.<P>\r\n\r\nWe appreciate that ordering online the first time can be a little confusing so if you have any problems or are unsure of any aspects of the ordering process please contact us and we\'ll try to help you out.<P>\r\n\r\n<!-- \r\nIf you submit your order by e-mail, you\'ll get an immediate acknowledgement \r\nin your electronic mailbox to let you know that we\'ve received the order.\r\nIf you choose fax or mail we\'ll either fax back, send an acknowledgment in \r\nthe mail, telephone you or send an e-mail.\r\n<P>\r\n-->\r\n\r\n</td></tr></table>' , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (8 , 'about' , 'About Us' , NULL , 9 , 1 , 0 , 1 , 1 , NULL , '<b>Contact Us</b>\r\n<p>\r\nWondering when your order will arrive? Need to change something about an order you\'ve placed? You can review and revise your order so that it\'s just the way you want it by visiting Your Account.\r\n<p>\r\nIf you were unable to find your answer using our Web site\'s self-service features, click one of the links to the left to contact our customer service department. We\'ll be happy to assist you. Please note: \r\n<p>\r\nFor security reasons, we can only modify orders or send account information when the request comes from the e-mail address that is associated with your Amazon.com account. \r\nWe can only read and respond to messages in English. \r\n<p>\r\n<b>Not Receiving Replies?</b>\r\n<p>\r\nIf you have used our forms to contact us in the past but have not received a reply, your ISP or e-mail client may be blocking e-mail from Amazon.com. If you suspect this is happening, please consult the help section of your e-mail program to see how to relax or remove the settings that filter or block mail. Once you\'ve established that you should be able to receive mail from us, please contact us again with your question.\r\n<p>\r\nWant to check if your ISP or e-mail client is blocking mail from Amazon.com? Try subscribing for a Special Occasion Reminder. If you don\'t receive it on the date you specify, you will know that messages from Amazon.com are being blocked or deleted automatically.\r\n \r\n' , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (11 , 'faq' , 'FAQ' , 'articles.php?category_id=4' , 7 , 1 , 1 , 1 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (13 , 'forum' , 'Forum' , 'forum.php' , 6 , 1 , 0 , 0 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (14 , 'support' , 'Support' , 'support.php' , 10 , 1 , 0 , 0 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (15 , 'links' , 'Links' , 'articles.php?category_id=3' , 12 , 1 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (16 , 'images' , 'Image Gallery' , 'articles.php?category_id=5' , 13 , 1 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL ) ;
INSERT INTO va_pages (page_id,page_code,page_title,page_url,page_order,is_showing,link_in_footer,is_html,page_type,page_path,page_body,meta_title,meta_keywords,meta_description) VALUES (17 , 'events' , 'Events' , 'articles.php?category_id=6' , 14 , 1 , 1 , 0 , 1 , NULL , NULL , NULL , NULL , NULL ) ;


INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (1 , 1 , 'order_id' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (2 , 1 , 'vc' , 'VARIABLE' , 'vc' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (8 , 2 , 'PARTNER' , 'CONSTANT' , '!Your partner ID!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (9 , 2 , 'TYPE' , 'CONSTANT' , 'S' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (10 , 2 , 'LOGIN' , 'CONSTANT' , '!Your customer login!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (11 , 2 , 'DESCRIPTION' , 'VARIABLE' , 'description' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (12 , 2 , 'AMOUNT' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (13 , 2 , 'INVOICE' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (14 , 3 , 'x_login' , 'CONSTANT' , '!Your customer login!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (15 , 3 , 'x_tran_key' , 'CONSTANT' , '!Transaction key obtained from the merchant interface!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (16 , 3 , 'x_secret' , 'CONSTANT' , '!Type here your Autorize MD5 Hash Secret!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (17 , 3 , 'x_invoice_num' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (18 , 3 , 'x_first_name' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (19 , 3 , 'x_last_name' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (20 , 3 , 'x_address' , 'VARIABLE' , 'address' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (21 , 3 , 'x_city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (22 , 3 , 'x_state' , 'VARIABLE' , 'state' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (23 , 3 , 'x_zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (25 , 3 , 'x_country' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (26 , 3 , 'x_phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (27 , 3 , 'x_fax' , 'VARIABLE' , 'fax' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (28 , 4 , 'instId' , 'CONSTANT' , '!Your installation ID!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (29 , 4 , 'cartId' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (30 , 4 , 'amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (31 , 4 , 'currency' , 'CONSTANT' , 'USD' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (32 , 4 , 'desc' , 'VARIABLE' , 'description' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (33 , 4 , 'testMode' , 'CONSTANT' , '100' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (34 , 4 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (35 , 4 , 'name' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (36 , 4 , 'address' , 'VARIABLE' , 'address' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (37 , 4 , 'postcode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (38 , 4 , 'country' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (39 , 4 , 'tel' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (40 , 5 , 'sid' , 'CONSTANT' , '!Your vendor number!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (41 , 5 , 'total' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (42 , 5 , 'cart_order_id' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (43 , 5 , 'card_holder_name' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (44 , 5 , 'street_address' , 'VARIABLE' , 'address' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (45 , 5 , 'city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (46 , 5 , 'state' , 'VARIABLE' , 'state' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (47 , 5 , 'zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (48 , 5 , 'country' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (49 , 5 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (50 , 5 , 'phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (51 , 6 , 'business' , 'CONSTANT' , 'your.paypal@email.address' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (52 , 6 , 'at' , 'CONSTANT' , '!please specify your identity token!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (53 , 6 , 'cmd' , 'CONSTANT' , '_xclick' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (54 , 6 , 'invoice' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (55 , 6 , 'item_name' , 'VARIABLE' , 'basket' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (56 , 6 , 'amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (57 , 6 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (58 , 6 , 'first_name' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (59 , 6 , 'last_name' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (60 , 6 , 'city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (61 , 6 , 'zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (62 , 6 , 'state' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (63 , 3 , 'x_company' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (64 , 3 , 'x_fp_timestamp' , 'VARIABLE' , 'timestamp' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (65 , 3 , 'x_fp_hash' , 'VARIABLE' , 'fingerprint' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (66 , 3 , 'x_fp_sequence' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (67 , 3 , 'x_relay_response' , 'CONSTANT' , 'TRUE' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (68 , 3 , 'x_show_form' , 'CONSTANT' , 'PAYMENT_FORM' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (69 , 5 , 'id_type' , 'CONSTANT' , '1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (70 , 5 , 'c_prod_{digit}' , 'VARIABLE' , '{item_id},{quantity}' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (71 , 5 , 'c_name_{digit}' , 'VARIABLE' , 'item_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (72 , 5 , 'c_description_{digit}' , 'VARIABLE' , 'short_description' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (73 , 5 , 'c_price_{digit}' , 'VARIABLE' , 'price' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (74 , 5 , 'c_tangible_{digit}' , 'CONSTANT' , 'Y' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (75 , 7 , 'x_version' , 'CONSTANT' , '3.1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (76 , 7 , 'x_delim_data' , 'CONSTANT' , 'True' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (77 , 7 , 'x_relay_response' , 'CONSTANT' , 'False' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (78 , 7 , 'x_login' , 'VARIABLE' , '!Your Login ID!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (79 , 7 , 'x_tran_key' , 'VARIABLE' , '!Transaction key obtained from the Merchant Interface!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (80 , 7 , 'x_amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (81 , 7 , 'x_card_num' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (82 , 7 , 'x_exp_date' , 'VARIABLE' , '{cc_expiry_month}{cc_expiry_year}' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (83 , 7 , 'x_type' , 'CONSTANT' , 'AUTH_CAPTURE' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (84 , 7 , 'x_description' , 'VARIABLE' , 'description' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (85 , 7 , 'x_first_name' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (86 , 7 , 'x_last_name' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (87 , 7 , 'x_address' , 'VARIABLE' , 'address' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (88 , 7 , 'x_city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (89 , 7 , 'x_state' , 'VARIABLE' , 'state' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (90 , 7 , 'x_zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (91 , 7 , 'x_country' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (92 , 7 , 'x_phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (93 , 8 , 'MerchantID' , 'CONSTANT' , '!Your Assigned Number!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (94 , 8 , 'RegKey' , 'CONSTANT' , '!Security Key!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (95 , 8 , 'Amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (96 , 8 , 'REFID' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (97 , 8 , 'TaxAmount' , 'VARIABLE' , '0' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (98 , 8 , 'AccountNo' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (99 , 8 , 'CCMonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (100 , 8 , 'CCYear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (101 , 8 , 'NameonAccount' , 'VARIABLE' , 'cc_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (102 , 8 , 'AVSADDR' , 'VARIABLE' , 'address' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (103 , 8 , 'AVSZIP' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (104 , 8 , 'CCRURL' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (105 , 8 , 'CVV2' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (106 , 7 , 'x_delim_char' , 'CONSTANT' , '|' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (110 , 9 , 'storename' , 'CONSTANT' , '!fill with your store number!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (111 , 9 , 'chargetotal' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (112 , 9 , 'txnorg' , 'CONSTANT' , 'eci' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (113 , 9 , 'mode' , 'CONSTANT' , 'payplus' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (114 , 9 , 'txntype' , 'CONSTANT' , 'sale' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (115 , 9 , 'baddr1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (116 , 9 , 'baddr2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (117 , 9 , 'bcity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (118 , 9 , 'bcompany' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (119 , 9 , 'bcountry' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (120 , 9 , 'bname' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (121 , 9 , 'bstate' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (122 , 9 , 'bstate2' , 'VARIABLE' , 'province' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (123 , 9 , 'bzip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (124 , 10 , 'configfile' , 'CONSTANT' , '!fill with your store id!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (125 , 10 , 'keyfile' , 'CONSTANT' , '!location of your SSL certificate file!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (126 , 10 , 'ordertype' , 'CONSTANT' , 'SALE' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (127 , 10 , 'result' , 'CONSTANT' , 'LIVE' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (128 , 10 , 'oid' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (129 , 10 , 'chargetotal' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (130 , 10 , 'cardnumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (131 , 10 , 'cardexpmonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (132 , 10 , 'cardexpyear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (133 , 10 , 'cvmindicator' , 'CONSTANT' , 'provided' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (134 , 10 , 'cvmvalue' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (135 , 11 , 'storename' , 'CONSTANT' , '!fill with your store number!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (136 , 11 , 'chargetotal' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (137 , 11 , 'txnorg' , 'CONSTANT' , 'eci' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (138 , 11 , 'mode' , 'CONSTANT' , 'payplus' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (139 , 11 , 'txntype' , 'CONSTANT' , 'sale' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (140 , 11 , 'baddr1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (141 , 11 , 'baddr2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (142 , 11 , 'bcity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (143 , 11 , 'bcompany' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (144 , 11 , 'bcountry' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (145 , 11 , 'bname' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (146 , 11 , 'bstate' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (147 , 11 , 'bstate2' , 'VARIABLE' , 'province' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (148 , 11 , 'bzip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (149 , 12 , 'configfile' , 'CONSTANT' , '!fill with your store id!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (150 , 12 , 'keyfile' , 'CONSTANT' , '!location of your SSL certificate file!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (151 , 12 , 'ordertype' , 'CONSTANT' , 'SALE' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (152 , 12 , 'result' , 'CONSTANT' , 'LIVE' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (153 , 12 , 'oid' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (154 , 12 , 'chargetotal' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (155 , 12 , 'cardnumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (156 , 12 , 'cardexpmonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (157 , 12 , 'cardexpyear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (158 , 12 , 'cvmindicator' , 'CONSTANT' , 'provided' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (159 , 12 , 'cvmvalue' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (160 , 6 , 'country' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (176 , 5 , 'secret_word' , 'CONSTANT' , '!Your secret word!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (177 , 14 , 'mid' , 'CONSTANT' , '!Enter the username you use to log into the Paymate website!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (178 , 14 , 'ref' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (179 , 14 , 'amt' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (180 , 14 , 'currency' , 'CONSTANT' , 'AUD' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (181 , 14 , 'pmt_sender_email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (182 , 14 , 'pmt_contact_firstname' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (183 , 14 , 'pmt_contact_surname' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (184 , 14 , 'pmt_contact_phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (185 , 14 , 'regindi_address1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (186 , 14 , 'regindi_address2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (187 , 14 , 'regindi_sub' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (188 , 14 , 'regindi_pcode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (189 , 14 , 'return ' , 'VARIABLE' , '{site_url}order_final.php' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (190 , 14 , 'popup ' , 'CONSTANT' , 'false' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (191 , 15 , 'VPSProtocol' , 'CONSTANT' , '2.22' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (192 , 15 , 'TxType' , 'CONSTANT' , 'PAYMENT' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (193 , 15 , 'Vendor' , 'CONSTANT' , '!type your vendor name here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (194 , 15 , 'EncryptionPassword' , 'CONSTANT' , '!type your encryption password here!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (195 , 15 , 'VendorTxCode' , 'VARIABLE' , 'order_id' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (196 , 15 , 'Amount' , 'VARIABLE' , 'order_total' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (197 , 15 , 'Currency' , 'VARIABLE' , 'currency_code' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (198 , 15 , 'Description' , 'VARIABLE' , '{total_quantity} products; Goods Total: {goods_total}; Order Total: {order_total}' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (199 , 15 , 'SuccessURL' , 'VARIABLE' , '{site_url}order_final.php' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (200 , 15 , 'FailureURL' , 'VARIABLE' , '{site_url}order_final.php' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (201 , 15 , 'CustomerName' , 'VARIABLE' , 'name' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (202 , 15 , 'CustomerEmail' , 'VARIABLE' , 'email' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (203 , 15 , 'eMailMessage' , 'CONSTANT' , NULL , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (204 , 15 , 'BillingAddress' , 'VARIABLE' , '{address1} {address2} {city} {province} {state}  {country}' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (205 , 15 , 'BillingPostCode' , 'VARIABLE' , 'zip' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (206 , 15 , 'DeliveryAddress' , 'VARIABLE' , '{delivery_address1} {delivery_address2} {delivery_city} {delivery_province} {delivery_state}  {delivery_country}' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (207 , 15 , 'DeliveryPostCode' , 'VARIABLE' , 'delivery_zip' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (208 , 15 , 'ContactNumber' , 'VARIABLE' , 'phone' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (209 , 15 , 'ContactFax' , 'VARIABLE' , 'fax' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (210 , 15 , 'Crypt' , 'VARIABLE' , 'protx_crypt' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (211 , 16 , 'VPSProtocol' , 'CONSTANT' , '2.22' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (212 , 16 , 'TxType' , 'CONSTANT' , 'PAYMENT' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (213 , 16 , 'Vendor' , 'CONSTANT' , '!type your vendor name here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (214 , 16 , 'VendorTxCode' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (215 , 16 , 'Amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (216 , 16 , 'Currency' , 'VARIABLE' , 'currency_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (217 , 16 , 'Description' , 'VARIABLE' , '{total_quantity} products; Goods Total: {goods_total}; Order Total: {order_total}' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (218 , 16 , 'CardHolder' , 'VARIABLE' , 'cc_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (219 , 16 , 'CardNumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (220 , 16 , 'ExpiryDate' , 'VARIABLE' , '{cc_expiry_month}{cc_expiry_year}' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (221 , 16 , 'CardType' , 'VARIABLE' , 'cc_type' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (222 , 16 , 'CV2' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (223 , 17 , 'PAYEE_ACCOUNT' , 'CONSTANT' , '!Enter your account!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (224 , 17 , 'PAYEE_NAME' , 'CONSTANT' , '!Enter your name!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (225 , 17 , 'PAYEE_PASSPHRASE' , 'CONSTANT' , '!Enter your alternate passphrase!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (226 , 17 , 'PAYMENT_AMOUNT' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (227 , 17 , 'PAYMENT_UNITS' , 'CONSTANT' , '1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (228 , 17 , 'PAYMENT_METAL_ID' , 'CONSTANT' , '1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (229 , 17 , 'PAYMENT_ID' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (230 , 17 , 'STATUS_URL' , 'VARIABLE' , '{site_url}payments/egold_response.php' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (231 , 17 , 'PAYMENT_URL' , 'VARIABLE' , '{site_url}order_final.php' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (232 , 17 , 'PAYMENT_URL_METHOD' , 'CONSTANT' , 'POST' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (233 , 17 , 'NOPAYMENT_URL' , 'VARIABLE' , '{site_url}order_final.php' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (234 , 17 , 'NOPAYMENT_URL_METHOD' , 'CONSTANT' , 'POST' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (235 , 17 , 'BAGGAGE_FIELDS' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (236 , 18 , 'requestType' , 'CONSTANT' , 'BACKEND' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (237 , 18 , 'merchant_id' , 'CONSTANT' , '!type your merchant_id here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (238 , 18 , 'trnOrderNumber' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (239 , 18 , 'trnAmount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (240 , 18 , 'trnCardOwner' , 'VARIABLE' , 'cc_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (241 , 18 , 'trnCardNumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (242 , 18 , 'trnExpMonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (243 , 18 , 'trnExpYear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (244 , 18 , 'ordName' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (245 , 18 , 'ordEmailAddress' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (246 , 18 , 'ordAddress1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (247 , 18 , 'ordAddress2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (248 , 18 , 'ordCity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (249 , 18 , 'ordProvince' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (250 , 18 , 'ordPostalCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (251 , 18 , 'ordCountry' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (252 , 18 , 'ordPhoneNumber' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (253 , 19 , 'merchantid' , 'CONSTANT' , '!type your merchantid here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (254 , 19 , 'cardnumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (255 , 19 , 'cardholder' , 'VARIABLE' , 'cc_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (256 , 19 , 'amount' , 'VARIABLE' , 'order_total_100' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (257 , 19 , 'expmonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (258 , 19 , 'expyear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (259 , 19 , 'premonth' , 'VARIABLE' , 'cc_start_month' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (260 , 19 , 'preyear' , 'VARIABLE' , 'cc_start_year' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (261 , 19 , 'issuenumber' , 'VARIABLE' , 'cc_issue_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (262 , 19 , 'identifier' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (263 , 19 , 'cv2' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (264 , 19 , 'debug' , 'CONSTANT' , 'true' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (265 , 19 , 'test' , 'CONSTANT' , 'false' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (266 , 19 , 'avspostcode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (267 , 20 , 'MerchantID' , 'CONSTANT' , '!Your Merchant ID!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (268 , 20 , 'SubID' , 'CONSTANT' , '0' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (269 , 20 , 'IssuerID' , 'CONSTANT' , NULL , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (270 , 20 , 'Privatekey' , 'CONSTANT' , '!full path to your private key!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (271 , 20 , 'Privatecert' , 'CONSTANT' , '!full path to your certificate!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (272 , 20 , 'Certificate0' , 'CONSTANT' , '!full path to default public certificate!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (273 , 20 , 'PrivatekeyPass' , 'CONSTANT' , '!Your Private key Password!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (274 , 20 , 'EntranceCode' , 'CONSTANT' , '!Your Entrance Code!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (275 , 20 , 'AcquirerURL' , 'CONSTANT' , 'ssl://ideal.secure-ing.com:443/ideal/iDeal' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (276 , 20 , 'AcquirerTimeout' , 'CONSTANT' , '10' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (277 , 20 , 'AuthenticationType' , 'CONSTANT' , 'SHA1_RSA' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (278 , 20 , 'MerchantReturnURL' , 'VARIABLE' , '{site_url}order_final.php' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (279 , 20 , 'Currency' , 'CONSTANT' , 'EUR' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (280 , 20 , 'ExpirationPeriod' , 'CONSTANT' , 'PT120S' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (281 , 20 , 'Language' , 'CONSTANT' , 'en' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (282 , 20 , 'DESCRIPTION' , 'CONSTANT' , 'default description' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (283 , 4 , 'callbackPW' , 'CONSTANT' , NULL , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (285 , 6 , 'address1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (286 , 10 , 'name' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (287 , 10 , 'company' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (288 , 10 , 'address1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (289 , 10 , 'address2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (290 , 10 , 'city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (291 , 10 , 'state' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (292 , 10 , 'zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (293 , 10 , 'country' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (294 , 10 , 'phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (295 , 10 , 'fax' , 'VARIABLE' , 'fax' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (296 , 10 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (297 , 10 , 'addrnum' , 'VARIABLE' , 'address_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (298 , 12 , 'name' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (299 , 12 , 'company' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (300 , 12 , 'address1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (301 , 12 , 'address2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (302 , 12 , 'city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (303 , 12 , 'state' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (304 , 12 , 'zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (305 , 12 , 'country' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (306 , 12 , 'phone' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (307 , 12 , 'fax' , 'VARIABLE' , 'fax' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (308 , 12 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (309 , 12 , 'addrnum' , 'VARIABLE' , 'address_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (310 , 16 , 'StartDate' , 'VARIABLE' , '{cc_start_month}{cc_start_year}' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (311 , 16 , 'BillingAddress' , 'VARIABLE' , '{address1} {address2} {city} {province} {state}  {country}' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (312 , 16 , 'BillingPostCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (313 , 16 , 'DeliveryAddress' , 'VARIABLE' , '{delivery_address1} {delivery_address2} {delivery_city} {delivery_province} {delivery_state}  {delivery_country}' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (314 , 16 , 'DeliveryPostCode' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (315 , 16 , 'CustomerName' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (316 , 16 , 'CustomerEmail' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (317 , 16 , 'ContactNumber' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (318 , 21 , 'Username' , 'CONSTANT' , '!Your API Account Name' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (319 , 21 , 'Password' , 'CONSTANT' , '!Your API Account Password' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (320 , 21 , 'Subject' , 'CONSTANT' , NULL , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (321 , 21 , 'SSLCert' , 'CONSTANT' , '!Absolute path to your API certificate' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (322 , 21 , 'OrderTotal' , 'VARIABLE' , 'order_total' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (323 , 21 , 'ReturnURL' , 'VARIABLE' , '{site_url}payments/paypal_details.php' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (324 , 21 , 'CancelURL' , 'VARIABLE' , '{site_url}order_final.php' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (325 , 22 , 'Username' , 'CONSTANT' , '!Your API Account Name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (326 , 22 , 'Password' , 'CONSTANT' , '!Your API Account Password' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (327 , 22 , 'Subject' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (328 , 22 , 'SSLCert' , 'CONSTANT' , '!Absolute path to your API certificate' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (329 , 22 , 'InvoiceID' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (330 , 22 , 'OrderTotal' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (331 , 22 , 'CreditCardType' , 'VARIABLE' , 'cc_type' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (332 , 22 , 'CreditCardNumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (333 , 22 , 'ExpMonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (334 , 22 , 'ExpYear' , 'VARIABLE' , 'cc_expiry_yyyy' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (335 , 22 , 'Payer' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (336 , 22 , 'CCFirstName' , 'VARIABLE' , 'cc_first_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (337 , 22 , 'CCLastName' , 'VARIABLE' , 'cc_last_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (338 , 22 , 'CVV2' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (339 , 22 , 'Name' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (340 , 22 , 'Street1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (341 , 22 , 'Street2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (342 , 22 , 'CityName' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (343 , 22 , 'StateOrProvince' , 'VARIABLE' , 'state_code_or_province' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (344 , 22 , 'Country' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (345 , 22 , 'PostalCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (346 , 22 , 'ShipName' , 'VARIABLE' , 'delivery_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (347 , 22 , 'ShipStreet1' , 'VARIABLE' , 'delivery_address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (348 , 22 , 'ShipStreet2' , 'VARIABLE' , 'delivery_address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (349 , 22 , 'ShipCityName' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (350 , 22 , 'ShipStateOrProvince' , 'VARIABLE' , 'delivery_state_code_or_province' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (351 , 22 , 'ShipCountry' , 'VARIABLE' , 'delivery_country_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (352 , 22 , 'ShipPostalCode' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (353 , 21 , 'ShipName' , 'VARIABLE' , 'delivery_name' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (354 , 21 , 'ShipStreet1' , 'VARIABLE' , 'delivery_address1' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (355 , 21 , 'ShipStreet2' , 'VARIABLE' , 'delivery_address2' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (356 , 21 , 'ShipCityName' , 'VARIABLE' , 'delivery_city' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (357 , 21 , 'ShipStateOrProvince' , 'VARIABLE' , 'delivery_state_code_or_province' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (358 , 21 , 'ShipCountry' , 'VARIABLE' , 'delivery_country_code' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (359 , 21 , 'ShipPostalCode' , 'VARIABLE' , 'delivery_zip' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (360 , 23 , 'Binary' , 'CONSTANT' , '/path/to/your/bin/pfpro' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (361 , 23 , 'Library' , 'CONSTANT' , '/path/to/your/lib/libpfpro.so' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (362 , 23 , 'CertPath' , 'CONSTANT' , '/path/to/your/certs' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (363 , 23 , 'VENDOR' , 'VARIABLE' , '!your vendor name!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (364 , 23 , 'PARTNER' , 'VARIABLE' , '!your parner name!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (365 , 23 , 'USER' , 'VARIABLE' , '!your user name!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (366 , 23 , 'PWD' , 'VARIABLE' , '!your password!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (367 , 23 , 'TRXTYPE' , 'CONSTANT' , 'S' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (368 , 23 , 'TENDER' , 'CONSTANT' , 'C' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (369 , 23 , 'ACCT' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (370 , 23 , 'AMT' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (371 , 23 , 'EXPDATE' , 'VARIABLE' , '{cc_expiry_month}{cc_expiry_year}' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (372 , 23 , 'CVV2' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (373 , 23 , 'NAME' , 'VARIABLE' , 'cc_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (374 , 23 , 'INVNUM' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (375 , 23 , 'STREET' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (376 , 23 , 'ZIP' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (377 , 3 , 'x_description' , 'VARIABLE' , 'description' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (378 , 3 , 'x_version' , 'CONSTANT' , '3.1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (379 , 3 , 'x_ship_to_first_name' , 'VARIABLE' , 'delivery_first_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (380 , 3 , 'x_ship_to_last_name' , 'VARIABLE' , 'delivery_last_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (381 , 3 , 'x_ship_to_company' , 'VARIABLE' , 'delivery_company_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (382 , 3 , 'x_ship_to_address' , 'VARIABLE' , 'delivery_address' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (383 , 3 , 'x_ship_to_city' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (384 , 3 , 'x_ship_to_state' , 'VARIABLE' , 'delivery_delivery_state' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (385 , 3 , 'x_ship_to_zip' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (386 , 3 , 'x_ship_to_country' , 'VARIABLE' , 'delivery_country' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (387 , 3 , 'x_amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (388 , 3 , 'x_currency_code' , 'CONSTANT' , 'USD' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (389 , 3 , 'x_method' , 'CONSTANT' , 'CC' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (390 , 3 , 'x_type' , 'CONSTANT' , 'AUTH_CAPTURE' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (391 , 6 , 'address2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (392 , 6 , 'currency_code' , 'VARIABLE' , 'currency_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (393 , 24 , 'clientid' , 'CONSTANT' , '!specify your client id!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (394 , 24 , 'password' , 'CONSTANT' , '!specify your pass-phrase!' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (395 , 24 , 'oid' , 'VARIABLE' , 'order_id' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (396 , 24 , 'chargetype' , 'CONSTANT' , 'Auth' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (397 , 24 , 'currencycode' , 'VARIABLE' , 'currency_value' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (398 , 24 , 'total' , 'VARIABLE' , 'order_total' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (399 , 24 , 'epdqdata' , 'VARIABLE' , 'epdqdata' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (400 , 24 , 'returnurl' , 'VARIABLE' , '{site_url}order_final.php' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (401 , 24 , 'merchantdisplayname' , 'CONSTANT' , '!specify you company name!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (402 , 24 , 'baddr1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (403 , 24 , 'baddr2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (404 , 24 , 'bcity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (405 , 24 , 'bcountry' , 'VARIABLE' , 'country_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (406 , 24 , 'bpostalcode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (407 , 24 , 'bstate' , 'VARIABLE' , 'state_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (408 , 24 , 'btelephonenumber' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (409 , 24 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (410 , 24 , 'bcountyprovince' , 'VARIABLE' , 'province' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (411 , 24 , 'saddr1' , 'VARIABLE' , 'delivery_address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (412 , 24 , 'saddr2' , 'VARIABLE' , 'delivery_address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (413 , 24 , 'scity' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (414 , 24 , 'scountyprovince' , 'VARIABLE' , 'delivery_province' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (415 , 24 , 'scountry' , 'VARIABLE' , 'delivery_country_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (416 , 24 , 'spostalcode' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (417 , 24 , 'sstate' , 'VARIABLE' , 'delivery_state_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (418 , 24 , 'stelephonenumber' , 'VARIABLE' , 'delivery_phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (419 , 21 , 'sandbox' , 'CONSTANT' , '0' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (420 , 22 , 'sandbox' , 'CONSTANT' , '0' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (421 , 25 , 'ClientId' , 'CONSTANT' , '!Enter your ClientId here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (422 , 25 , 'Name' , 'CONSTANT' , '!Enter your user bane here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (423 , 25 , 'Password' , 'CONSTANT' , '!Enter your password here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (424 , 25 , 'Email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (425 , 25 , 'Mode' , 'CONSTANT' , 'P' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (426 , 25 , 'OrderId' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (427 , 25 , 'GroupId' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (428 , 25 , 'TransId' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (429 , 25 , 'UserId' , 'VARIABLE' , 'user_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (430 , 25 , 'Type' , 'CONSTANT' , 'Auth' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (431 , 25 , 'Number' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (432 , 25 , 'Expires' , 'VARIABLE' , 'cc_expiry_date' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (433 , 25 , 'Cvv2Val' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (434 , 25 , 'Total' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (435 , 25 , 'Currency' , 'CONSTANT' , '792' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (436 , 25 , 'Taksit' , 'CONSTANT' , '0' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (437 , 25 , 'BillToName' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (438 , 25 , 'BillToStreet1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (439 , 25 , 'BillToStreet2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (440 , 25 , 'BillToStreet3' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (441 , 25 , 'BillToCity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (442 , 25 , 'BillToStateProv' , 'VARIABLE' , 'province' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (443 , 25 , 'BillToPostalCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (444 , 25 , 'BillToCountry' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (445 , 25 , 'BillToCompany' , 'VARIABLE' , 'company_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (446 , 25 , 'BillToTelVoice' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (447 , 25 , 'ShipToName' , 'VARIABLE' , 'delivery_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (448 , 25 , 'ShipToStreet1' , 'VARIABLE' , 'delivery_address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (449 , 25 , 'ShipToStreet2' , 'VARIABLE' , 'delivery_address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (450 , 25 , 'ShipToStreet3' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (451 , 25 , 'ShipToCity' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (452 , 25 , 'ShipToStateProv' , 'VARIABLE' , 'delivery_province' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (453 , 25 , 'ShipToPostalCode' , 'VARIABLE' , 'delivery_zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (454 , 25 , 'ShipToCountry' , 'VARIABLE' , 'delivery_country' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (455 , 26 , 'username' , 'CONSTANT' , '!Enter your User Name here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (456 , 26 , 'password' , 'CONSTANT' , '!Enter your Password here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (457 , 26 , 'site' , 'CONSTANT' , '!Enter your Site ID here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (458 , 26 , 'package' , 'CONSTANT' , '!Enter your Package ID here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (459 , 26 , 'login' , 'CONSTANT' , '!Enter your Login here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (460 , 26 , 'region_code' , 'CONSTANT' , '!Enter your Region Code here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (461 , 26 , 'price' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (462 , 26 , 'first_name' , 'VARIABLE' , 'first_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (463 , 26 , 'last_name' , 'VARIABLE' , 'last_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (464 , 26 , 'email' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (465 , 26 , 'address' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (466 , 26 , 'zip' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (467 , 26 , 'city' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (468 , 26 , 'country_code' , 'VARIABLE' , 'country' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (469 , 26 , 'cc_number' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (470 , 26 , 'expire_month' , 'VARIABLE' , 'cc_expire_month' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (471 , 26 , 'expire_year' , 'VARIABLE' , 'cc_expire_year' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (472 , 26 , 'cvcode' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (473 , 27 , 'UserName' , 'CONSTANT' , '!specify your username!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (474 , 27 , 'Password' , 'CONSTANT' , '!specify your password!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (475 , 27 , 'ClientId' , 'CONSTANT' , '!specify your client id!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (476 , 27 , 'Mode' , 'CONSTANT' , 'P' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (477 , 27 , 'Type' , 'CONSTANT' , 'Auth' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (478 , 27 , 'PoNumber' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (479 , 27 , 'Currency' , 'VARIABLE' , 'currency_value' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (480 , 27 , 'OrderTotal' , 'VARIABLE' , 'order_total_100' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (481 , 27 , 'CCNumber' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (482 , 27 , 'CCExpires' , 'VARIABLE' , '{cc_expiry_month}/{cc_expiry_year}' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (483 , 27 , 'Cvv2Val' , 'VARIABLE' , 'cc_security_code' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (484 , 27 , 'CCStartDate' , 'VARIABLE' , '{cc_start_month}/{cc_start_year}' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (485 , 27 , 'CCType' , 'VARIABLE' , 'cc_type' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (486 , 27 , 'CCIssueNum' , 'VARIABLE' , 'cc_issue_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (487 , 27 , 'BillEmail' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (488 , 27 , 'BillName' , 'VARIABLE' , 'name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (489 , 27 , 'BillStreet1' , 'VARIABLE' , 'address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (490 , 27 , 'BillStreet2' , 'VARIABLE' , 'address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (491 , 27 , 'BillCity' , 'VARIABLE' , 'city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (492 , 27 , 'BillStateProv' , 'VARIABLE' , 'state_code_or_province' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (493 , 27 , 'BillPostalCode' , 'VARIABLE' , 'zip' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (494 , 27 , 'BillCountry' , 'VARIABLE' , 'country_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (495 , 27 , 'BillTelVoice' , 'VARIABLE' , 'phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (496 , 27 , 'BillTelFax' , 'VARIABLE' , 'fax' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (497 , 27 , 'ShipName' , 'VARIABLE' , 'delivery_name' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (498 , 27 , 'ShipStreet1' , 'VARIABLE' , 'delivery_address1' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (499 , 27 , 'ShipStreet2' , 'VARIABLE' , 'delivery_address2' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (500 , 27 , 'ShipCity' , 'VARIABLE' , 'delivery_city' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (501 , 27 , 'ShipStateProv' , 'VARIABLE' , 'delivery_state_code_or_province' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (502 , 27 , 'ShipCountry' , 'VARIABLE' , 'delivery_country_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (503 , 27 , 'ShipTelVoice' , 'VARIABLE' , 'delivery_phone' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (504 , 27 , 'ShipTelFax' , 'VARIABLE' , 'delivery_fax' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (505 , 27 , 'ShipEmail' , 'VARIABLE' , 'delivery_email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (506 , 28 , 'merchantID' , 'CONSTANT' , '!Enter your merchantID here!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (507 , 28 , 'APACScommand' , 'CONSTANT' , 'NewPayment' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (508 , 28 , 'amount' , 'VARIABLE' , 'order_total_100' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (509 , 28 , 'merchantRef' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (510 , 28 , 'merchantDesc' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (511 , 28 , 'currency' , 'CONSTANT' , '0978' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (512 , 28 , 'lang' , 'CONSTANT' , 'EN' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (513 , 28 , 'CustomerEmail' , 'VARIABLE' , 'email' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (514 , 28 , 'Offset' , 'CONSTANT' , '0' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (515 , 28 , 'Period' , 'CONSTANT' , '0' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (516 , 28 , 'var1' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (517 , 28 , 'var2' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (518 , 28 , 'var3' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (519 , 28 , 'var4' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (520 , 28 , 'var5' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (521 , 28 , 'var6' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (522 , 28 , 'var7' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (523 , 28 , 'var8' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (524 , 28 , 'var9' , 'CONSTANT' , NULL , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (525 , 29 , 'username' , 'CONSTANT' , '!Enter your username!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (526 , 29 , 'password' , 'CONSTANT' , '!Enter your password!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (527 , 29 , 'mid' , 'CONSTANT' , '!Enter your mid!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (528 , 29 , 'tid' , 'CONSTANT' , '!Enter your tid!' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (529 , 29 , 'currencyCode' , 'CONSTANT' , 'YT' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (530 , 29 , 'installment' , 'CONSTANT' , '03' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (531 , 29 , 'extraPoint' , 'CONSTANT' , '000000' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (532 , 29 , 'multiplePoint' , 'CONSTANT' , '00' , 1 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (533 , 29 , 'amount' , 'VARIABLE' , 'order_total' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (534 , 29 , 'orderID' , 'VARIABLE' , 'order_id' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (535 , 29 , 'ccno' , 'VARIABLE' , 'cc_number' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (536 , 29 , 'cardexpyear' , 'VARIABLE' , 'cc_expiry_year' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (537 , 29 , 'cardexpmonth' , 'VARIABLE' , 'cc_expiry_month' , 0 ) ;
INSERT INTO va_payment_parameters (parameter_id,payment_id,parameter_name,parameter_type,parameter_source,not_passed) VALUES (538 , 29 , 'cvc' , 'VARIABLE' , 'cc_security_code' , 0 ) ;


INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (1 , 'Personal' , NULL , NULL , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , NULL ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (2 , 'VeriSign PayFlow Link' , NULL , 'Please specify value for parameters  \'LOGIN\' and \'PARTNER\'.\r\nIf you setup your Verisign PayFlow Link account directly through Verisign, than your Partner ID is likely "Verisign" (without the quotes).\r\n' , 'https://payments.verisign.com/payflowlink' , NULL , NULL , NULL , 'GET' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (3 , 'Authorize.Net SIM' , NULL , 'Please specify values for parameters \'x_login\' and \'x_tran_key\'.\r\n\r\nIf you want receive response from Authorize.net about submiited transactions please also specify \'x_secret\' parameter to the same value as in your Authorize settings.\r\n\r\nTo choose your MD5 Hash Secret in the Authorize.net account please do the following:\r\n- Log into your merchant menu at https://secure.authorize.net/ \r\n- Click "Settings"\r\n- Select "MD5 Hash" under the "Security" portion of your account settings\r\n- Enter the MD5 Hash Secret value that you would like to use\r\n- Confirm the MD5 Hash value\r\n- Click "Submit" to save the changes\r\n\r\nAlso you need specify response URL in your Authorize.net account:\r\n- Select "Response/Receipt URLs" under the "Transaction Response" portion of your account settings\r\n- Click on "Edit" link for "Default Relay Response URL"\r\n- Enter your response URL (for this url you can use following page \'http://your_site_url/order_final.php\')\r\n- Click "Submit" to save the changes' , 'https://secure.authorize.net/gateway/transact.dll' , NULL , NULL , NULL , 'POST' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (4 , 'WorldPay' , NULL , 'Please specify your installation ID for parameter \'instId\'.\r\nAs well you can specify callbackPW parameter if you set Callback password for your installation on the WorldPay Customer Management System. As the value of this is only known to this and your callback script it can be used as a basic security check within your script.\r\nAlways leave \'Not Passed\' checkbox checked for callbackPW parameter.' , 'https://select.worldpay.com/wcc/purchase' , NULL , NULL , NULL , 'POST' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (5 , '2CheckOut' , NULL , 'Please specify values for parameters \'sid\' and \'secret_word\'.\r\n\'sid\' - it is your vendor number in system like 340000, \'secret_word\' - must be the same as in your 2CheckOut settings.\r\nFor return url you can use following page \'http://your_site_url/order_final.php\'.' , 'https://www2.2checkout.com/2co/buyer/purchase' , NULL , NULL , NULL , 'POST' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (6 , 'PayPal' , NULL , 'Please specify your business email address where it says \'your.paypal@email.address\' and specify value for \'at\' (identity token) parameter from your PayPal settings.\r\n\r\nAlso in the PayPal settings you need specify Return URL as \'http://your_site_url/order_final.php\' and set parameters Auto Return and Payment Data Transfer to \'On\'.\r\n\r\nAlso it\'s recommended to turn on PayPal IPN notifications. For this withing you PayPal account please go to \'Profile > Instant Payment Notification Preferences\' and turn on this setting and set \'Notification URL\' as \'http://your_site_url/payments/paypal_ipn.php\'.\r\n\r\nIf you don\'t want pass data to PayPal in multicurrencies please specify for currency_code parameter preferred currency code like \'USD\'.' , 'https://www.paypal.com/cgi-bin/webscr' , NULL , NULL , NULL , 'POST' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 1 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (7 , 'Authorize.Net AIM' , NULL , 'Please specify values for parameters \'x_login\' and \'x_tran_key\'.\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'https://secure.authorize.net/gateway/transact.dll' , './payments/authorize_aim.php' , 9 , NULL , 10 , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (8 , 'PRI Merchants Advanced' , NULL , 'Please specify values for parameters \'MerchantID\' and \'RegKey\'.\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'https://webservices.primerchants.com/billing/TransactionCentral/processCC.asp' , './payments/pri_merchants.php' , 9 , NULL , 10 , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (9 , 'YourPay Connect' , NULL , 'Please specify value for parameter \'storename\'.' , 'https://secure.linkpt.net/lpcentral/servlet/lppay' , NULL , NULL , NULL , 'POST' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (10 , 'YourPay API' , NULL , 'Please specify values for parameters \'configfile\' and \'keyfile\'.\r\n\'configfile\' - it is you store number in system, \'keyfile\' - local path to your SSL certificate provided by YourPay.\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'https://secure.linkpt.net:1129/LSGSXML' , './payments/yourpay_api.php' , 4 , NULL , 10 , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (11 , 'LinkPoint Connect' , NULL , 'Please specify value for parameter \'storename\'.' , 'https://www.linkpointcentral.com/lpc/servlet/lppay' , NULL , NULL , NULL , 'POST' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (12 , 'LinkPoint API' , NULL , 'Please specify values for parameters \'configfile\' and \'keyfile\'.\r\n\'configfile\' - it is you store number in system, \'keyfile\' - local path to your SSL certificate provided by Linkpoint.\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'https://secure.linkpt.net:1129/LSGSXML' , './payments/linkpoint_api.php' , 4 , NULL , 10 , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (14 , 'Paymate Express' , NULL , 'Please specify value for parameter \'mid\'.\r\nAs well you can specify differenct currency (AUD,USD).' , 'https://www.paymate.com.au/PayMate/ExpressPayment' , NULL , NULL , NULL , 'GET' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (15 , 'Protx VSP Form' , NULL , 'Please specify your Vendor name and your EncryptionPassword. As well you can change currency_code parameter to some default value like \'USD\'.\r\n-- Simulator site\r\nhttps://ukvpstest.protx.com/VSPSimulator/VSPFormGateway.asp\r\n--  Test site\r\nhttps://ukvpstest.protx.com/vps2form/submit.asp\r\n-- Live site url\r\nhttps://ukvps.protx.com/vps2form/submit.asp' , 'https://ukvps.protx.com/vps2form/submit.asp' , NULL , NULL , NULL , 'POST' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , NULL ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (16 , 'Protx VSP Direct' , NULL , 'Please specify your Vendor name. As well you can change currency_code parameter to some default value like \'USD\'.\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php\r\n-- Simulator site\r\nhttps://ukvpstest.protx.com/VSPSimulator/VSPDirectGateway.asp\r\n-- Test site\r\nhttps://ukvpstest.protx.com/vpsDirectAuth/PaymentGateway.asp\r\n-- Live site url\r\nhttps://ukvps.protx.com/vpsDirectAuth/PaymentGateway.asp' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'https://ukvps.protx.com/vpsDirectAuth/PaymentGateway.asp' , './payments/protx_direct.php' , 4 , NULL , 10 , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (17 , 'eGold SCI' , NULL , 'Please specify your account number, name and passpharse in fields below. If you want change currency please use PAYMENT_UNITS parameter (1 - USD, 2 - CAD, 85 - EUR, 81 - JPY).' , 'https://www.e-gold.com/sci_asp/payments.asp' , NULL , NULL , NULL , 'POST' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (18 , 'Beanstream API' , NULL , 'Please specify your merchant_id.\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'https://www.beanstream.com/scripts/process_transaction.asp' , './payments/beanstream_api.php' , 4 , NULL , 10 , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (19 , 'Payoffshore API' , NULL , 'Please specify your merchantid.\r\nIf you want test system before go live you can change \'test\' parameter value to \'true\'.\r\nFor security purposes you also need to change Payment URL to the absolute secure path, e.g. https://your_site/credit_card_info.php' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'https://secure.payoffshore.com/ecom/api.xml' , './payments/payoffshore_api.php' , 4 , NULL , 10 , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (20 , 'iDEAL' , NULL , 'Please specify your MerchanID and your certificates information.\r\nIf you will using only one Issuer you can specify it for IssuerID parameter as well.\r\nLive site: ssl://ideal.secure-ing.com:443/ideal/iDeal\r\nTest site: ssl://idealtest.secure-ing.com:443/ideal/iDeal' , './payments/ideal_process.php' , NULL , NULL , NULL , 'GET' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (21 , 'PayPal Pro (Express Checkout)' , NULL , 'Before proceed with this method you need request an API Certificate withing your PayPal account from \'Profile > API Access\'.\r\n\r\nThen please specify you API information like \'Username\', \'Password\' and \'SSLCert\' in the fields below.\r\n\r\nFor testing with PayPal SandBox please change \'sandbox\' parameter value to \'1\'.' , 'payments/paypal_checkout.php' , NULL , NULL , NULL , 'GET' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (22 , 'PayPal Pro (Direct API)' , NULL , 'Before proceed with this method you need request an API Certificate withing your PayPal account from \'Profile > API Access\' and \'Submit Application\' from \'Merchant Tools > Business Solutions > Website Payment Pro\'. (Works only for USA customers)\r\n\r\nThen please specify you API information like \'Username\', \'Password\' and \'SSLCert\' in the fields below.\r\n\r\nPlease note that Direct Payment API is not a standalone product. You are required to use Direct Payment API and Express Checkout together as part of the Website Payments Pro solution accordingly to PayPal documentation.\r\n\r\nFor testing with PayPal SandBox please change \'sandbox\' parameter value to \'1\'.' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'https://api-aa.paypal.com/2.0/' , './payments/paypal_direct.php' , 4 , NULL , 10 , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (23 , 'VeriSign PayFlow Pro' , NULL , 'First of all you need to download the Payflow Pro SDK and extract the files to one of your server directory.\r\n\r\nSet PayFlow SDK parameters in the parametrs list below\r\nBinary - absolute path to PayFlow executable module pfpro or pfpro.exe\r\nLibrary - absolute path to PayFlow library\r\nCertPath - absolute path to the folder with certificates\r\n\r\nThen please specify your login information like \'VENDOR\', \'PARTNER\', \'USER\' and \'PWD\' in the fields below.' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'payflow.verisign.com' , './payments/verisign_pro.php' , 4 , 6 , 10 , 0 , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (24 , 'ePDQ CPI' , NULL , 'Please specify values for parameters \'clientid\', \'password\' and \'merchantdisplayname\'.\r\nPlease use for the \'password\' parameter the same value as you specified it for \'Pass-phrase\' field in your ePDQ settings.\r\n\r\nTo receive order results please specify in your ePDQ settings \'POST URL\' as \'http://your_site_url/payments/epqd_cpi_response.php\' and set parameters \'POST Order result\' to \'Yes\'.\r\n\r\nIf you don\'t want pass data to ePDQ in multicurrencies please specify for currencycode parameter preferred currency value like 840 for USD, 826 for GBP.' , 'https://secure2.epdq.co.uk/cgi-bin/CcxBarclaysEpdq.e' , NULL , NULL , NULL , 'GET' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (25 , 'Garanti' , NULL , 'ClientId - Shop Code sent you via e-mail\r\nName - Payment pages user id\r\nPassword - User password\r\nCurrency - Currency code' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'https://ccpos.garanti.com.tr/servlet/cc5ApiServer' , './payments/garanti.php' , 4 , NULL , 10 , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (26 , 'VXSBill.com' , NULL , 'Please specify values for the following parameters:\r\n\r\nusername - Your user name\r\npassword - Your password\r\nsite - Site ID, integer value\r\npackage - Package ID, integer value\r\nlogin - Your login\r\nregion_code - Region code, or 0 if is not known\r\n\r\nThey are sent to you by email after registering at vxsbill.com' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'https://secure.vxsbill.com/create_transaction.php3' , './payments/vxsbill.php' , 4 , NULL , 10 , 0 , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (27 , 'ePDQ MPI' , NULL , 'Please specify values for parameters \'UserName\', \'Password\' and \'ClientId\'.\r\nAs well you can change currency to some default value\r\n840 - US Dollar\r\n826 - British Pound' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'https://secure2.epdq.co.uk:11500/' , './payments/epdq_mpi.php' , 4 , NULL , 10 , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (28 , 'ProxyPay' , NULL , NULL , 'https://eptest.eurocommerce.gr/proxypay/apacs' , NULL , NULL , NULL , 'POST' , 0 , NULL , NULL , NULL , NULL , NULL , NULL , 0 , 0 ) ;
INSERT INTO va_payment_systems (payment_id,payment_name,payment_info,payment_notes,payment_url,processing_time,processing_fee,fee_type,submit_method,is_advanced,advanced_url,advanced_php_lib,success_status_id,pending_status_id,failure_status_id,failure_action,is_active,is_default) VALUES (29 , 'Posnet' , NULL , 'Posnet XML service lets posnet merchants send posnet transactions by sending XML documents. Merchants send XML documents to a URL like https://www.posnet.ykb.com/PosnetWebService/XML?xmldata=XML \r\n(for test environment: \r\nhttp://setmpos.ykb.com/PosnetWebService/XML?xmldata=XML). \r\nResponse is returned to the merchant also as an XML document.\r\n\r\nDon\'t forget to enter your account details in appropriate fields: username, password, mid, tid.\r\n\r\nProduction URL:\r\nhttps://www.posnet.ykb.com/PosnetWebService/XML\r\n\r\ntesting URL:\r\nhttp://setmpos.ykb.com/PosnetWebService/XML\r\n\r\nSite for more information https://www.posnet.ykb.com' , 'credit_card_info.php' , NULL , NULL , NULL , 'GET' , 1 , 'http://setmpos.ykb.com/PosnetWebService/XML' , './payments/posnet.php' , 4 , 6 , 10 , NULL , 0 , 0 ) ;


INSERT INTO va_polls (poll_id,poll_type,question,is_active,date_added,total_votes) VALUES (1 , 1 , 'As gas prices continue to escalate, how close are you to purchasing an electric car or a gas/electric hybrid car?' , 1 , '2005-09-06 20:00:00' , 0 ) ;


INSERT INTO va_polls_options (poll_option_id,poll_id,option_description,is_default_value) VALUES (1 , 1 , 'An electric or hybrid car will definitely be my next auto purchase. ' , 0 ) ;
INSERT INTO va_polls_options (poll_option_id,poll_id,option_description,is_default_value) VALUES (2 , 1 , 'I will purchase one provided they are comparably priced to gasoline cars. ' , 0 ) ;
INSERT INTO va_polls_options (poll_option_id,poll_id,option_description,is_default_value) VALUES (3 , 1 , 'I doubt this will be a viable technology for some time to come. ' , 0 ) ;
INSERT INTO va_polls_options (poll_option_id,poll_id,option_description,is_default_value) VALUES (4 , 1 , 'I like the size, style and horsepower of gas-powered cars; I don\'t intend to ever go electric.  ' , 0 ) ;
INSERT INTO va_polls_options (poll_option_id,poll_id,option_description,is_default_value) VALUES (5 , 1 , 'I already own one of these cars. ' , 0 ) ;
INSERT INTO va_polls_options (poll_option_id,poll_id,option_description,is_default_value) VALUES (6 , 1 , 'Not sure. ' , 0 ) ;




INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (1 , 1 , 1 , '2003-05-23 00:00:00' , 'Fixed bug when FAQ articles has some redundant spaces in HTML \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (2 , 1 , 1 , '2003-05-23 00:00:00' , 'Fixed bug when News articles maintenance didn\'t allow entering large title containing HTML tags' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (3 , 1 , 2 , '2003-01-10 00:00:00' , 'Added Postgre SQL and ODBC support ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (4 , 1 , 2 , '2003-01-10 00:00:00' , 'Added search box to Sales Orders maintenance ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (5 , 1 , 2 , '2003-01-10 00:00:00' , 'Added \'Page sources\' options for Web pages maintenance \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (6 , 1 , 2 , '2003-01-10 00:00:00' , 'Added \'Remember me\' option to Login page ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (7 , 1 , 2 , '2003-01-10 00:00:00' , 'Added search box to \'Countries maintenance\' ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (8 , 1 , 1 , '2003-01-10 00:00:00' , 'Fixed bug when countries listbox wasn\'t sorted by \'Country Order\' ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (9 , 1 , 1 , '2003-01-10 00:00:00' , 'Fixed typo in Web pages section of Administration \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (10 , 1 , 1 , '2003-01-10 00:00:00' , 'Fixed bug when two Administrators could not access Administration simultaneously ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (11 , 1 , 1 , '2003-01-10 00:00:00' , 'Fixed bug when Final Checkout page sent two Administrator notifications instead of one \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (12 , 1 , 2 , '2003-01-23 00:00:00' , 'Added Forum system \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (13 , 1 , 2 , '2003-01-24 00:00:00' , 'Added Customizable Layouts support' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (14 , 1 , 2 , '2003-01-24 00:00:00' , 'Added \'Downloadable\' products support \\r\\n' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (15 , 1 , 2 , '2003-01-25 00:00:00' , 'Added ability to assign one product to multiple categories ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (16 , 1 , 2 , '2003-01-25 00:00:00' , 'Added ability to reassign cases within Support System (only Enterprise Edition) ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (17 , 1 , 2 , '2003-01-25 00:00:00' , 'Added customizable payment systems support ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (18 , 1 , 2 , '2003-01-26 00:00:00' , 'Added ability to submit POST payment systems parameters ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (19 , 1 , 2 , '2003-01-26 00:00:00' , 'Added option that allows hiding Reviews section at Product details page ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (20 , 1 , 2 , '2003-01-27 00:00:00' , 'Added custom tags support to email notifications ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (21 , 1 , 2 , '2003-01-27 00:00:00' , 'Added \'free shipping\' rules to Shipping settings ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (22 , 1 , 1 , '2003-01-28 00:00:00' , 'Fixed bug when footer menu didn\'t hide when there were no menu items ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (23 , 1 , 1 , '2003-01-28 00:00:00' , 'Fixed bug when sorting order wasn\'t preserved in \'Countries\' maintenance ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (24 , 1 , 1 , '2003-01-28 00:00:00' , 'Fixed bug with complex date formats masks processing ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (25 , 1 , 1 , '2003-01-28 00:00:00' , 'Fixed bug when product description had illegal characters ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (26 , 1 , 1 , '2003-01-28 00:00:00' , 'Fixed bug when sending emails from some domains took more time then from others ' , 1 ) ;
INSERT INTO va_release_changes (change_id,release_id,change_type_id,change_date,change_desc,is_showing) VALUES (27 , 1 , 1 , '2003-01-29 00:00:00' , 'Fixed bug when some phone numbers were not considered to be valid during user registration ' , 1 ) ;


INSERT INTO va_release_types (type_id,type_name) VALUES (1 , 'Upgrade' ) ;
INSERT INTO va_release_types (type_id,type_name) VALUES (2 , 'Update' ) ;
INSERT INTO va_release_types (type_id,type_name) VALUES (3 , 'New Version' ) ;


INSERT INTO va_releases (release_id,item_id,release_type_id,release_date,release_title,version,release_desc,download_type,path_to_file,is_showing,show_on_index) VALUES (1 , 1 , 1 , '2003-12-24 00:00:00' , 'New Upgrade for C2S' , '2.0.1.11' , NULL , 1 , '/etc/c2s/c2s.tgz' , 0 , 0 ) ;




INSERT INTO va_shipping_modules (shipping_module_id,shipping_module_name,module_notes,is_external,php_external_lib,external_url,tracking_url,is_active) VALUES (1 , 'Custom Shipping' , NULL , 0 , NULL , NULL , NULL , 1 ) ;
INSERT INTO va_shipping_modules (shipping_module_id,shipping_module_name,module_notes,is_external,php_external_lib,external_url,tracking_url,is_active) VALUES (2 , 'UPS' , 'United Parcel Service (UPS)\r\n\r\nObtain UserID, Password and Developer\'s Key from your country\'s UPS E-Business web site. (See the\r\n\'Security Elements\' section in the Product Overview chapter.)\r\n\r\nObtain Access Key. (See \'Security Elements\' in the Product Overview section.)\r\n\r\nFor Signature Tracking and Shipping, follow the product certification process identified in the Customer\r\nIntegration Environment section.\r\n\r\nFill in the parameters list below and set UPS system as active and begin receive you online shipping rates.\r\n\r\nShipperPostalCode - The shipper\'s postal code. Required if country utilizes postal codes (i.e. US & PR)\r\n\r\nShipperCountryCode - The UPS billing code for the shipper\'s country. See Origin Country Information\r\n table. Default = US.\r\n\r\nShipFromPostalCode - The sender\'s postal code. Required if Ship To country code is US. Must supply\r\n either the sender\'s city or postal code.\r\n\r\nShipFromCountryCode - The UPS billing code representing the sender\'s country. See Appendix C for\r\n UPS Country Code table. Default = US.\r\n\r\nPackageWeightUnitOfMeasurement - The code representing the unit of measure associated with the \r\n package weight. LBS = Pounds (default) KGS = Kilograms\r\n\r\nPickupType:\r\n 01 - Daily Pickup\r\n 03 - Customer Counter\r\n 06 - One Time Pickup\r\n 07 - On Call Air Pickup\r\n 11 - Suggested Retail Rates (UPS Store)\r\n 19 - Letter Center\r\n 20 - Air Service Center\r\n\r\nPackagingType:\r\n 01 - UPS letter/ UPS Express Envelope\r\n 02 - Package\r\n 03 - UPS Tube\r\n 04 - UPS Pak\r\n 21 - UPS Express Box\r\n 24 - UPS 25Kg Box\r\n 25 - UPS 10Kg Box\r\n\r\nFor PackagingType 02 or 21 you must fill PackagingTypeUnitOfMeasurement, PackageLength,\r\n PackageWidth and PackageHeight. \r\n\r\nPackagingTypeUnitOfMeasurement - The code for the unit of measure associated with the package\r\n dimensions. IN = Inches (default)\r\n\r\nPackageLength - The length of the package used to determine dimensional weight. Valid values are\r\n between 1 and 108.00.\r\n\r\nPackageWidth - The width of the package used to determine dimensional weight. Valid values are\r\n between 1 and 108.00.\r\n\r\nPackageHeight - The height of the package used to determine dimensional weight. Valid values are\r\n between 1and 108.00.\r\n\r\nYou may visit your country\'s UPS E-Business web site for more information about UPS Rates & Service Selection Tool. http://www.ups.com' , 1 , './shipping/ups.php' , 'https://www.ups.com/ups.app/xml/Rate' , 'http://wwwapps.ups.com/WebTracking/processInputRequest?HTMLVersion=5.0&error_carried=true&tracknums_displayed=1&TypeOfInquiryNumber=T&loc=en_US&AgreeToTermsAndConditions=yes&InquiryNumber1=' , 0 ) ;
INSERT INTO va_shipping_modules (shipping_module_id,shipping_module_name,module_notes,is_external,php_external_lib,external_url,tracking_url,is_active) VALUES (3 , 'USPS' , 'United States Postal Service (USPS).\r\n\r\nTo use the USPS Web Tools you must be a registered user. Completing the registration process resulted in the receipt of your user ID, password, and test server URL. This test URL is already filled in.\r\n\r\nTo gain access to Live server, all users, including those registered for previous Web Tools use, must contact the Internet Customer Care Center (ICCC) for the URL to make Live calls. The ICCC will send the Live URL via e-mail. Fill live url in the field  External URL instead of present one.\r\n\r\nThis office is manned from 7:00 AM to 11:00 PM EST daily. \r\nE-mail address: icustomercare@usps.com \r\nTelephone: 1-800-344-7779 (7:00 AM to 11:00 PM EST daily)\r\n\r\nCommon parameters:\r\n  USERID - required, use user ID provided with registration.\r\n  PASSWORD - is not required now, use password provided with registration if any.\r\n\r\nDomestic parameters:\r\n  ZipOrigination - required. Your ZIP code where dispath will be made from. ZIP code must be valid. Maximum characters allowed: 5.\r\n  Container - required, is only applicable for Express Mail and Priority Mail. Must contain one of the following valid packaging type names: "Flat Rate Envelope", "Flat Rate Box".\r\n  Size - required, must be one of the following: "Regular", "Large", "Oversize".\r\n  Machinable - optional. Applies only to Parcel Post. For Parcel Post, the value entered must be either True or False.\r\n\r\nInternational parameters:\r\n  MailType - required, the following are valid international mail types: package, postcards or aerogrammes, matter for the blind, envelope.' , 1 , './shipping/usps.php' , 'http://production.shippingapis.com/ShippingAPI.dll' , 'http://trkcnfrm1.smi.usps.com/PTSInternetWeb/InterLabelInquiry.do?formattedLabel=' , 0 ) ;
INSERT INTO va_shipping_modules (shipping_module_id,shipping_module_name,module_notes,is_external,php_external_lib,external_url,tracking_url,is_active) VALUES (4 , 'FedEx' , 'The FedEx sign-up process requires some interaction with the company. FedEx requires that developers and their applications be certified. The first step is to register for a FedEx Ship Manager Direct account by visiting https://www.fedex.com/cgi-bin/shipapiDownload.cgi?link=4&first=y and completing the form. In addition to the standard contact information, you must indicate how you intend to use their online tools. If you\'re developing e-commerce solutions for multiple clients, choose the Consultant option, otherwise select Corporate Developer. Select the communication path used - FSM Direct. Finally, you\'ll need to select the Data Format desired - XML Tools. After you\'ve registered, you\'ll be given an address to a shipping server to be used in your testing phases, please apply it to \'External URL\' field below.\r\n\r\nYou\'ll need to next contact FedEx by e-mail (websupport@fedex.com) to request to have you or your client\'s account set up in a test environment. You\'ll need to specify whether you\'re using the Express, Ground, or both services. As well you can include source code from the shipping folder to contact the FedEx Direct. Although the company\'s documentation indicates a 24 hour turn-around for approval, representatives indicate the wait can go up to 72 hours.\r\n\r\nAfter you\'ve been approved, the next task is to subscribe to FedEx to get a meter number. Meter numbers are programmatically generated. Before sending subscription request please change the parameters below. \r\nAccountNumber - you FedEx account number.\r\nPersonName, CompanyName, Department, PhoneNumber, PagerNumber, FaxNumber, EmailAddress - your contact information\r\nLine1, Line2, City, StateOrProvinceCode, PostalCode, CountryCode - your address information\r\nWhen all the data are ready you can go to the page at http://your_site_url/shipping/fedex_subscription.php and send subscription request.\r\nAfter successfully running the FedEx subscription request a meter number will be returned, add this value to the MeterNumber field below.\r\n\r\nPlease update the rest of fields below.\r\nStateOrProvinceCode - Represents the state or province from which the shipment will be originating. (Required only if Sender Country Code is US or CA)\r\nPostalCode - Represents the postal code from which the shipment will be originating. (Required only if Sender Country Code is US or CA. May be required for other postal-aware countries when rating an internationally shipment.)\r\nCountryCode - Represents the country from which the shipment will be originating. (Required)\r\nReturnShipmentIndicator - NONRETURN, PRINTRETURNLABEL, EMAILLABEL\r\nDropoffType - REGULARPICKUP, REQUESTCOURIER, DROPBOX, BUSINESSSERVICECENTER, STATION\r\nPackaging - FEDEXENVELOPE, FEDEXPAK, FEDEXBOX, FEDEXTUBE, FEDEX10KGBOX, FEDEX25KGBOX, YOURPACKAGING\r\nFor YOURPACKAGING you also need specify package sizes: Length, Width, Height, Units (IN, CM)\r\nWeightUnits - LBS, KGS\r\nSet FedEx system as active and receive you online shipping rates.\r\n\r\nAfter your application testing is done, contact FedEx again by e-mail (websupport@fedex.com) or phone (800.810.9073) to initiate the certification process. For retrieving rates, you\'ll be asked to state exactly how you will be using their API; you can also request to be moved to the production environment in a specific timeframe. Once certified, FedEx will provide you with a FedEx server address to be used when you re-subscribe to receive your production meter number.' , 1 , './shipping/fedex.php' , 'https://sslserver.fedex.com:443/GatewayDC' , 'http://www.fedex.com/Tracking?ascend_header=1&clienttype=dotcom&cntry_code=us&language=english&tracknumbers=' , 0 ) ;


INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (1 , 3 , 'USERID' , '!Enter your USERID here!' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (2 , 3 , 'PASSWORD' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (3 , 3 , 'ZipOrigination' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (4 , 3 , 'Container' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (5 , 3 , 'Size' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (6 , 3 , 'Machinable' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (7 , 3 , 'MailType' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (8 , 2 , 'user_id' , '!Enter your USERID here!' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (9 , 2 , 'password' , '!Enter your PASSWORD here!' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (10 , 2 , 'access_license_number' , '!Enter your Access License Number here!' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (11 , 2 , 'ShipperPostalCode' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (12 , 2 , 'ShipperCountryCode' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (13 , 2 , 'ShipFromPostalCode' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (14 , 2 , 'ShipFromCountryCode' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (15 , 2 , 'PickupType' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (16 , 2 , 'PackagingType' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (21 , 2 , 'PackageWeightUnitOfMeasurement' , 'LBS' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (22 , 4 , 'CustomerTransactionIdentifier' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (23 , 4 , 'AccountNumber' , '!Type here your account number!' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (24 , 4 , 'MeterNumber' , '!Type here your subscription number!' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (25 , 4 , 'CarrierCode' , 'FDXE' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (26 , 4 , 'PersonName' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (27 , 4 , 'CompanyName' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (28 , 4 , 'Department' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (29 , 4 , 'PhoneNumber' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (30 , 4 , 'PagerNumber' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (31 , 4 , 'FaxNumber' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (32 , 4 , 'EMailAddress' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (33 , 4 , 'Line1' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (34 , 4 , 'Line2' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (35 , 4 , 'City' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (36 , 4 , 'StateOrProvinceCode' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (37 , 4 , 'PostalCode' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (38 , 4 , 'CountryCode' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (40 , 4 , 'ReturnShipmentIndicator' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (41 , 4 , 'DropoffType' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (42 , 4 , 'Packaging' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (43 , 4 , 'WeightUnits' , 'LBS' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (44 , 4 , 'PayorType' , 'SENDER' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (45 , 4 , 'Length' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (46 , 4 , 'Width' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (47 , 4 , 'Height' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (48 , 4 , 'Units' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (49 , 4 , 'PackageCount' , '1' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (50 , 2 , 'PackagingTypeUnitOfMeasurement' , 'IN' , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (51 , 2 , 'PackageLength' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (52 , 2 , 'PackageWidth' , NULL , 0 ) ;
INSERT INTO va_shipping_modules_parameters (parameter_id,shipping_module_id,parameter_name,parameter_source,not_passed) VALUES (53 , 2 , 'PackageHeight' , NULL , 0 ) ;


INSERT INTO va_shipping_rules (shipping_rule_id,shipping_rule_desc) VALUES (1 , 'Can ship anywhere' ) ;
INSERT INTO va_shipping_rules (shipping_rule_id,shipping_rule_desc) VALUES (2 , 'Can ship only within USA' ) ;
INSERT INTO va_shipping_rules (shipping_rule_id,shipping_rule_desc) VALUES (3 , 'Can ship only within United Kingdom' ) ;


INSERT INTO va_shipping_times (shipping_time_id,shipping_time_desc,availability_time) VALUES (1 , 'Usually ships in 2 to 3 days' , NULL ) ;
INSERT INTO va_shipping_times (shipping_time_id,shipping_time_desc,availability_time) VALUES (2 , 'Usually ships in 24 hours' , NULL ) ;


INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (1 , 3 , 1 , 'Express Mail to PO Addressee' , 'USPS Express Mail to PO Addressee' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (2 , 3 , 1 , 'Express Mail Flat Rate Envelope (12.5" x 9.5")' , 'USPS Express Mail Flat Rate Envelope (12.5" x 9.5")' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (3 , 3 , 1 , 'Priority Mail' , 'USPS Priority Mail' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (4 , 3 , 1 , 'Priority Mail Flat Rate Envelope (12.5" x 9.5")' , 'USPS Priority Mail Flat Rate Envelope (12.5" x 9.5")' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (5 , 3 , 1 , 'Priority Mail Flat Rate Box (11.25" x 8.75" x 6")' , 'USPS Priority Mail Flat Rate Box (11.25" x 8.75" x 6")' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (6 , 3 , 1 , 'Priority Mail Flat Rate Box (14" x 12" x 3.5")' , 'USPS Priority Mail Flat Rate Box (14" x 12" x 3.5")' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (7 , 3 , 1 , 'Media Mail' , 'USPS Media Mail' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (8 , 3 , 1 , 'Library Mail' , 'USPS Library Mail' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (9 , 3 , 1 , 'Parcel Post' , 'USPS Parcel Post' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (10 , 3 , 1 , 'First-Class Mail' , 'USPS First-Class Mail' , NULL , NULL , 0 , 10000 , 0 , 0.75 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (11 , 3 , 1 , 'Bound Printed Matter' , 'USPS Bound Printed Matter' , NULL , NULL , 0 , 10000 , 0 , 15 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (12 , 4 , 1 , 'PRIORITYOVERNIGHT' , 'FedEx Priority Overnight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (13 , 4 , 1 , 'STANDARDOVERNIGHT' , 'FedEx Standard Overnight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (14 , 4 , 1 , 'FIRSTOVERNIGHT' , 'FedEx First Overnight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (15 , 4 , 1 , 'FEDEX2DAY' , 'FedEx 2Day' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (16 , 4 , 1 , 'FEDEXEXPRESSSAVER' , 'FedEx Express Saver' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (17 , 4 , 1 , 'FEDEX1DAYFREIGHT' , 'FedEx 1Day Freight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (18 , 4 , 1 , 'FEDEX2DAYFREIGHT' , 'FedEx 2Day Freight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (19 , 4 , 1 , 'FEDEX3DAYFREIGHT' , 'FedEx 3Day Freight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (20 , 4 , 1 , 'FEDEXGROUND' , 'FedEx Ground' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (21 , 4 , 1 , 'GROUNDHOMEDELIVERY' , 'FedEx Home Delivery' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (22 , 4 , 1 , 'INTERNATIONALPRIORITY' , 'FedEx International Priority' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (23 , 4 , 1 , 'INTERNATIONALECONOMY' , 'FedEx International Economy' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (24 , 4 , 1 , 'INTERNATIONALFIRST' , 'FedEx International First' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (25 , 4 , 1 , 'INTERNATIONALPRIORITYFREIGHT' , 'FedEx International Priority Freight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (26 , 4 , 1 , 'INTERNATIONALECONOMYFREIGHT' , 'FedEx International Economy Freight' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (27 , 4 , 1 , 'EUROPEFIRSTINTERNATIONALPRIORITY' , 'FedEx Europe First' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (28 , 2 , 1 , '01' , 'UPS Next Day Air' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (29 , 2 , 1 , '02' , 'UPS 2nd Day Air' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (30 , 2 , 1 , '03' , 'UPS Ground' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (31 , 2 , 1 , '07' , 'UPS Worldwide ExpressSM' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (32 , 2 , 1 , '08' , 'UPS Worldwide ExpeditedSM' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (33 , 2 , 1 , '11' , 'UPS Standard' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (34 , 2 , 1 , '12' , 'UPS 3 Day Select' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (35 , 2 , 1 , '13' , 'UPS Next Day Air Saver' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (36 , 2 , 1 , '14' , 'UPS Next Day Air Early A.M.' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (37 , 2 , 1 , '54' , 'UPS Worldwide Express PlusSM' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (38 , 2 , 1 , '01' , 'UPS Express' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (39 , 2 , 1 , '02' , 'UPS Expedited' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (40 , 2 , 1 , '13' , 'UPS Express Saver' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (41 , 2 , 1 , '14' , 'UPS Express Early A.M.' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (42 , 2 , 1 , '07' , 'UPS Express' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (43 , 2 , 1 , '65' , 'UPS Express Saver' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (44 , 2 , 1 , '59' , 'UPS 2nd Day Air A.M.' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (45 , 2 , 1 , '08' , 'UPS Expedited' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (46 , 2 , 1 , '54' , 'UPS Express Plus' , NULL , NULL , 0 , 10000 , 0 , 10000 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (47 , 3 , 1 , 'Global Express Guaranteed (GXG) Document Service' , 'USPS Global Express Guaranteed Document Service' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (48 , 3 , 1 , 'Global Express Guaranteed (GXG) Non-Document Service' , 'USPS Global Express Guaranteed Non-Document Service' , NULL , NULL , 0 , 10000 , 0 , 70 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (49 , 3 , 1 , 'Global Express Mail (EMS)' , 'USPS Global Express Mail (EMS)' , NULL , NULL , 0 , 10000 , 0 , 44 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (50 , 3 , 1 , 'Airmail Letter Post' , 'USPS Airmail Letter Post' , NULL , NULL , 0 , 10000 , 0 , 4 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (51 , 3 , 1 , 'Airmail Parcel Post' , 'USPS Airmail Parcel Post' , NULL , NULL , 0 , 10000 , 0 , 22 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (52 , 3 , 1 , 'Economy (Surface) Letter Post' , 'USPS Economy (Surface) Letter Post' , NULL , NULL , 0 , 10000 , 0 , 4 , NULL , NULL , NULL , 1 , 1 ) ;
INSERT INTO va_shipping_types (shipping_type_id,shipping_module_id,shipping_order,shipping_type_code,shipping_type_desc,shipping_time,tare_weight,min_goods_cost,max_goods_cost,min_weight,max_weight,cost_per_order,cost_per_product,cost_per_weight,is_taxable,is_active) VALUES (53 , 3 , 1 , 'Economy (Surface) Parcel Post' , 'USPS Economy (Surface) Parcel Post' , NULL , NULL , 0 , 10000 , 0 , 22 , NULL , NULL , NULL , 1 , 1 ) ;


INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'AZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (24 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'BZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (34 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (38 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (39 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (40 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (41 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (24 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'CZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (24 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'DE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'DJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'DK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'DM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'DO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'DZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'EC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'EE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'EG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'EH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'ER' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'ES' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'ET' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'FI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'FJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'FK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'FM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'FO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (24 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'FR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'FX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (24 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'GY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'HK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'HM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'HN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'HR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'HT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'HU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'ID' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'IE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'IL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'IN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'IO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'IQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'IR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'IS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (24 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'IT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'JM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'JO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'JP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'KE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'KG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'KH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'KI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'KM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'KN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'KP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'KR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'KW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'KY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'KZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'LA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'LB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'LC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'LI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'LK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'LR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'LS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'LT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'LU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'LV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'LY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'ML' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MQ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (45 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (46 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MX' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'MZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'NZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'OM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (28 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (29 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (30 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (36 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'PY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'QA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'RE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'RO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'RU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'RW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SB' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (27 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SL' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (42 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (43 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'ST' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'SZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TD' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TH' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TJ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TK' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TO' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TP' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TV' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'TZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'UA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'UG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'UM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (2 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (3 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (4 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (5 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (6 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (7 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (8 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (9 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (10 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (11 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (13 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (14 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (15 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (16 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (21 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (18 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (17 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (20 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (12 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (19 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (28 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (29 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (30 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (33 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (34 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (35 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (36 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (44 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (1 , 'US' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'UY' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'UZ' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'VA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'VC' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'VE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'VG' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'VI' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'VN' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'VU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'WF' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'WS' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'YE' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'YT' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'YU' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'ZA' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'ZM' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'ZR' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (23 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (22 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (25 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (26 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (31 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (37 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (32 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (49 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (50 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (52 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (53 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (51 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (47 , 'ZW' ) ;
INSERT INTO va_shipping_types_countries (shipping_type_id,country_code) VALUES (48 , 'ZW' ) ;


INSERT INTO va_states (state_code,state_name) VALUES ('AK' , 'Alaska' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('AL' , 'Alabama' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('AR' , 'Arkansas' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('AZ' , 'Arizona' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('CA' , 'California' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('CO' , 'Colorado' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('CT' , 'Connecticut' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('DC' , 'District of Columbia' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('DE' , 'Delaware' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('FL' , 'Florida' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('GA' , 'Georgia' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('HI' , 'Hawaii' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('IA' , 'Iowa' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('ID' , 'Idaho' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('IL' , 'Illinois' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('IN' , 'Indiana' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('KS' , 'Kansas' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('KY' , 'Kentucky' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('LA' , 'Louisiana' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('MA' , 'Massachusetts' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('MD' , 'Maryland' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('ME' , 'Maine' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('MI' , 'Michigan' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('MN' , 'Minnesota' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('MO' , 'Missouri' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('MS' , 'Mississippi' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('MT' , 'Montana' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('NC' , 'North Carolina' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('ND' , 'North Dakota' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('NE' , 'Nebraska' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('NH' , 'New Hampshire' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('NJ' , 'New Jersey' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('NM' , 'New Mexico' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('NV' , 'Nevada' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('NY' , 'New York' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('OH' , 'Ohio' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('OK' , 'Oklahoma' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('OR' , 'Oregon' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('PA' , 'Pennsylvania' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('RI' , 'Rhode Island' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('SC' , 'South Carolina' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('SD' , 'South Dakota' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('TN' , 'Tennessee' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('TX' , 'Texas' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('UT' , 'Utah' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('VA' , 'Virginia' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('VT' , 'Vermont' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('WA' , 'Washington' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('WI' , 'Wisconsin' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('WV' , 'West Virginia' ) ;
INSERT INTO va_states (state_code,state_name) VALUES ('WY' , 'Wyoming' ) ;






INSERT INTO va_support_departments (dep_id,short_title,full_title,signature,attachments_dir,attachments_mask,incoming_account,incoming_type_id,incoming_product_id,outgoing_account,show_for_user) VALUES (1 , 'Support' , 'Support Department' , NULL , NULL , NULL , 'support@your_site.com' , NULL , NULL , 'support@your_site.com' , 1 ) ;






INSERT INTO va_support_priorities (priority_id,priority_name,priority_rank,admin_html,is_default) VALUES (1 , 'High' , 1 , '<img src="../images/high.gif" width="8" height="12" border="0">' , 0 ) ;
INSERT INTO va_support_priorities (priority_id,priority_name,priority_rank,admin_html,is_default) VALUES (2 , 'Normal' , 2 , NULL , 1 ) ;
INSERT INTO va_support_priorities (priority_id,priority_name,priority_rank,admin_html,is_default) VALUES (3 , 'Low' , 3 , '<img src="../images/low.gif" width="8" height="12" border="0">' , 0 ) ;


INSERT INTO va_support_products (product_id,product_name,show_for_user) VALUES (1 , 'The Lord of the Rings' , 1 ) ;


INSERT INTO va_support_statuses (status_id,status_name,show_for_user,status_caption,status_icon,html_start,html_end,is_user_new,is_user_reply,is_operation,is_reassign,is_internal,is_list,is_closed,is_add_knowledge) VALUES (1 , 'New' , 1 , 'New' , NULL , NULL , NULL , 1 , 0 , 0 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO va_support_statuses (status_id,status_name,show_for_user,status_caption,status_icon,html_start,html_end,is_user_new,is_user_reply,is_operation,is_reassign,is_internal,is_list,is_closed,is_add_knowledge) VALUES (2 , 'Proposed Solution' , 0 , 'Propose Solution' , NULL , NULL , NULL , 0 , 0 , 1 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO va_support_statuses (status_id,status_name,show_for_user,status_caption,status_icon,html_start,html_end,is_user_new,is_user_reply,is_operation,is_reassign,is_internal,is_list,is_closed,is_add_knowledge) VALUES (3 , 'Awaiting Response' , 1 , 'Reply to Customer' , NULL , NULL , NULL , 0 , 0 , 1 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO va_support_statuses (status_id,status_name,show_for_user,status_caption,status_icon,html_start,html_end,is_user_new,is_user_reply,is_operation,is_reassign,is_internal,is_list,is_closed,is_add_knowledge) VALUES (4 , 'Request More Information' , 1 , 'Request More Information' , NULL , NULL , NULL , 0 , 0 , 1 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO va_support_statuses (status_id,status_name,show_for_user,status_caption,status_icon,html_start,html_end,is_user_new,is_user_reply,is_operation,is_reassign,is_internal,is_list,is_closed,is_add_knowledge) VALUES (5 , 'Investigating' , 0 , 'Mark as "Investigating"' , NULL , NULL , NULL , 0 , 0 , 1 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO va_support_statuses (status_id,status_name,show_for_user,status_caption,status_icon,html_start,html_end,is_user_new,is_user_reply,is_operation,is_reassign,is_internal,is_list,is_closed,is_add_knowledge) VALUES (6 , 'Closed' , 0 , 'Close' , NULL , NULL , NULL , 0 , 0 , 1 , 0 , 0 , 0 , 1 , 0 ) ;
INSERT INTO va_support_statuses (status_id,status_name,show_for_user,status_caption,status_icon,html_start,html_end,is_user_new,is_user_reply,is_operation,is_reassign,is_internal,is_list,is_closed,is_add_knowledge) VALUES (7 , 'Assigned to Manager' , 0 , 'Reassign' , NULL , NULL , NULL , 0 , 0 , 1 , 1 , 1 , 1 , NULL , 0 ) ;
INSERT INTO va_support_statuses (status_id,status_name,show_for_user,status_caption,status_icon,html_start,html_end,is_user_new,is_user_reply,is_operation,is_reassign,is_internal,is_list,is_closed,is_add_knowledge) VALUES (8 , 'Customer Reply' , 0 , 'Customer Reply' , NULL , NULL , NULL , 0 , 1 , 0 , 0 , 0 , 1 , NULL , 0 ) ;
INSERT INTO va_support_statuses (status_id,status_name,show_for_user,status_caption,status_icon,html_start,html_end,is_user_new,is_user_reply,is_operation,is_reassign,is_internal,is_list,is_closed,is_add_knowledge) VALUES (9 , 'Added to Knowledge Base' , 0 , 'Add to KB' , NULL , NULL , NULL , 0 , 0 , 0 , 0 , 1 , 0 , 0 , 1 ) ;




INSERT INTO va_support_types (type_id,type_name,show_for_user) VALUES (1 , 'Bug/Issue' , 1 ) ;
INSERT INTO va_support_types (type_id,type_name,show_for_user) VALUES (2 , 'Question' , 1 ) ;
INSERT INTO va_support_types (type_id,type_name,show_for_user) VALUES (3 , 'Wish/Request' , 1 ) ;
INSERT INTO va_support_types (type_id,type_name,show_for_user) VALUES (4 , 'Other' , 1 ) ;






INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (1 , 'VAT' , NULL , 'AT' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (2 , 'VAT' , NULL , 'BE' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (3 , 'VAT' , NULL , 'CY' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (4 , 'VAT' , NULL , 'CZ' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (5 , 'VAT' , NULL , 'DK' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (6 , 'VAT' , NULL , 'EE' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (7 , 'VAT' , NULL , 'FI' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (8 , 'VAT' , NULL , 'FR' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (9 , 'VAT' , NULL , 'DE' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (10 , 'VAT' , NULL , 'GR' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (11 , 'VAT' , NULL , 'HU' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (12 , 'VAT' , NULL , 'IE' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (13 , 'VAT' , NULL , 'IT' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (14 , 'VAT' , NULL , 'LV' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (15 , 'VAT' , NULL , 'LT' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (16 , 'VAT' , NULL , 'LU' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (17 , 'VAT' , NULL , 'MT' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (18 , 'VAT' , NULL , 'MC' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (19 , 'VAT' , NULL , 'AN' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (20 , 'VAT' , NULL , 'NL' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (21 , 'VAT' , NULL , 'PL' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (22 , 'VAT' , NULL , 'PT' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (23 , 'VAT' , NULL , 'SK' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (24 , 'VAT' , NULL , 'SI' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (25 , 'VAT' , NULL , 'ES' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (26 , 'VAT' , NULL , 'SE' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (27 , 'VAT' , NULL , 'GB' , 17.5 ) ;
INSERT INTO va_tax_rates (tax_id,tax_name,state_code,country_code,tax_percent) VALUES (28 , 'Sales Tax' , NULL , 'US' , 8.5 ) ;




INSERT INTO va_user_types (type_id,type_name,is_default,discount_type,discount_amount,coupons_ids) VALUES (1 , 'Customer' , 1 , NULL , NULL , NULL ) ;


INSERT INTO va_user_types_settings (type_id,setting_name,setting_value) VALUES (1 , 'add_ad' , '1' ) ;
INSERT INTO va_user_types_settings (type_id,setting_name,setting_value) VALUES (1 , 'approve_ad' , '0' ) ;
INSERT INTO va_user_types_settings (type_id,setting_name,setting_value) VALUES (1 , 'approve_profile' , '1' ) ;
INSERT INTO va_user_types_settings (type_id,setting_name,setting_value) VALUES (1 , 'delete_ad' , '1' ) ;
INSERT INTO va_user_types_settings (type_id,setting_name,setting_value) VALUES (1 , 'edit_ad' , '1' ) ;
INSERT INTO va_user_types_settings (type_id,setting_name,setting_value) VALUES (1 , 'edit_profile' , '1' ) ;
INSERT INTO va_user_types_settings (type_id,setting_name,setting_value) VALUES (1 , 'new_profile' , '1' ) ;


INSERT INTO va_users (user_id,user_type_id,is_approved,discount_type,discount_amount,coupons_ids,login,password,security_question,security_answer,personal_image,name,first_name,last_name,company_id,company_name,email,address1,address2,city,province,state_code,zip,country_code,phone,daytime_phone,evening_phone,cell_phone,fax,delivery_name,delivery_first_name,delivery_last_name,delivery_company_id,delivery_company_name,delivery_email,delivery_address1,delivery_address2,delivery_city,delivery_province,delivery_state_code,delivery_zip,delivery_country_code,delivery_phone,delivery_daytime_phone,delivery_evening_phone,delivery_cell_phone,delivery_fax,registration_ip,registration_date,modified_ip,modified_date,last_visit_ip,last_visit_date,reset_password_code,reset_password_date) VALUES (1 , 1 , 1 , NULL , NULL , NULL , 'joy' , 'joy' , '' , '' , NULL , 'joy' , '' , '' , NULL , NULL , 'jnothing@yahoo.com' , '5-th Avenue' , NULL , 'New York' , NULL , 'NY' , '95000' , 'US' , NULL , '1234567890' , '1234567890' , NULL , NULL , 'joy' , NULL , NULL , NULL , NULL , NULL , '5-th Avenue' , NULL , 'New York' , NULL , 'NY' , '95000' , 'US' , NULL , NULL , NULL , NULL , NULL , NULL , '2004-06-22 20:03:44' , NULL , '2004-06-22 20:03:44' , NULL , '2006-05-05 12:46:41' , NULL , NULL ) ;

